	; IntyBASIC compiler v1.2.9 Nov/07/2017
        ;
        ; Prologue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Spacing adjustment and more comments.
        ; Revision: Apr/01/2014. It now sets the starting screen pos. for PRINT
        ; Revision: Aug/26/2014. Added PAL detection code.
        ; Revision: Dec/12/2014. Added optimized constant multiplication routines.
        ;                        by James Pujals.
        ; Revision: Jan/25/2015. Added marker for automatic title replacement.
        ;                        (option --title of IntyBASIC)
        ; Revision: Aug/06/2015. Turns off ECS sound. Seed random generator using
        ;                        trash in 16-bit RAM. Solved bugs and optimized
        ;                        macro for constant multiplication.
        ; Revision: Jan/12/2016. Solved bug in PAL detection.
        ; Revision: May/03/2016. Changed in _mode_select initialization.
        ; Revision: Jul/31/2016. Solved bug in multiplication by 126 and 127.
        ; Revision: Sep/08/2016. Now CLRSCR initializes screen position for PRINT, this
        ;                        solves bug when user programs goes directly to PRINT.
        ; Revision: Oct/21/2016. Accelerated MEMSET.
        ;

        ROMW 16
        ORG $5000

        ; This macro will 'eat' SRCFILE directives if the assembler doesn't support the directive.
        IF ( DEFINED __FEATURE.SRCFILE ) = 0
            MACRO SRCFILE x, y
            ; macro must be non-empty, but a comment works fine.
            ENDM
        ENDI

        ;
        ; ROM header
        ;
        BIDECLE _ZERO           ; MOB picture base
        BIDECLE _ZERO           ; Process table
        BIDECLE _MAIN           ; Program start
        BIDECLE _ZERO           ; Background base image
        BIDECLE _ONES           ; GRAM
        BIDECLE _TITLE          ; Cartridge title and date
        DECLE   $03C0           ; No ECS title, jump to code after title,
                                ; ... no clicks
                                
_ZERO:  DECLE   $0000           ; Border control
        DECLE   $0000           ; 0 = color stack, 1 = f/b mode
        
_ONES:  DECLE   $0001, $0001    ; Initial color stack 0 and 1: Blue
        DECLE   $0001, $0001    ; Initial color stack 2 and 3: Blue
        DECLE   $0001           ; Initial border color: Blue

C_WHT:  EQU $0007

CLRSCR: MVII #$200,R4           ; Used also for CLS
	MVO R4,_screen		; Set up starting screen position for PRINT
        MVII #$F0,R1
FILLZERO:
        CLRR R0
MEMSET:
        SARC R1,2
        BNOV $+4
        MVO@ R0,R4
        MVO@ R0,R4
        BNC $+3
        MVO@ R0,R4
        BEQ $+7
        MVO@ R0,R4
        MVO@ R0,R4
        MVO@ R0,R4
        MVO@ R0,R4
        DECR R1
        BNE $-5
        JR R5

        ;
        ; Title, Intellivision EXEC will jump over it and start
        ; execution directly in _MAIN
        ;
	; Note mark is for automatic replacement by IntyBASIC
_TITLE:
	BYTE 118,'mINTY',0
        
        ;
        ; Main program
        ;
_MAIN:
        DIS
        MVII #STACK,R6

_MAIN0:
        ;
        ; Clean memory
        ;
        CALL CLRSCR             ; Clean up screen, right here to avoid brief
                                ; screen display of title in Sears Intellivision.
        MVII #$00e,R1           ; 14 of sound (ECS)
        MVII #$0f0,R4           ; ECS PSG
        CALL FILLZERO
        MVII #$0fe,R1           ; 240 words of 8 bits plus 14 of sound
        MVII #$100,R4           ; 8-bit scratch RAM
        CALL FILLZERO

	; Seed random generator using 16 bit RAM (not cleared by EXEC)
	CLRR R0
	MVII #$02F0,R4
	MVII #$0110/4,R1        ; Includes phantom memory for extra randomness
_MAIN4:                         ; This loop is courtesy of GroovyBee
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	DECR R1
	BNE _MAIN4
	MVO R0,_rand

        MVII #$058,R1           ; 88 words of 16 bits
        MVII #$308,R4           ; 16-bit scratch RAM
        CALL FILLZERO

        MVII #_pal1_vector,R0 ; Points to interrupt vector
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1

        EIS

_MAIN1:	MVI _ntsc,R0
	CMPI #3,R0
	BNE _MAIN1
	CLRR R2
_MAIN2:	INCR R2
	MVI _ntsc,R0
	CMPI #4,R0
	BNE _MAIN2

        ; 596 for PAL in jzintv
        ; 444 for NTSC in jzintv
        CMPI #520,R2
        MVII #1,R0
        BLE _MAIN3
        CLRR R0
_MAIN3: MVO R0,_ntsc

        CALL _wait
	CALL _init_music
        MVII #2,R0
        MVO R0,_mode_select
        MVII #$038,R0
        MVO R0,$01F8            ; Configures sound
        MVO R0,$00F8            ; Configures sound (ECS)
        CALL _wait

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- James Pujals (DZ-Jay), 2014                              *;
;* ======================================================================== *;

; Modified by Oscar Toledo G. (nanochess), Aug/06/2015
; * Tested all multiplications with automated test.
; * Accelerated multiplication by 7,14,15,28,31,60,62,63,112,120,124
; * Solved bug in multiplication by 23,39,46,47,55,71,78,79,87,92,93,94,95,103,110,111,119
; * Improved sequence of instructions to be more interruptible.

;; ======================================================================== ;;
;;  MULT reg, tmp, const                                                    ;;
;;  Multiplies "reg" by constant "const" and using "tmp" for temporary      ;;
;;  calculations.  The result is placed in "reg."  The multiplication is    ;;
;;  performed by an optimal combination of shifts, additions, and           ;;
;;  subtractions.                                                           ;;
;;                                                                          ;;
;;  NOTE:   The resulting contents of the "tmp" are undefined.              ;;
;;                                                                          ;;
;;  ARGUMENTS                                                               ;;
;;      reg         A register containing the multiplicand.                 ;;
;;      tmp         A register for temporary calculations.                  ;;
;;      const       The constant multiplier.                                ;;
;;                                                                          ;;
;;  OUTPUT                                                                  ;;
;;      reg         Output value.                                           ;;
;;      tmp         Trashed.                                                ;;
;;      .ERR.Failed True if operation failed.                               ;;
;; ======================================================================== ;;
MACRO   MULT reg, tmp, const
;
    LISTING "code"

_mul.const      QSET    %const%
_mul.done       QSET    0

        IF (%const% > $7F)
_mul.const      QSET    (_mul.const SHR 1)
                SLL     %reg%,  1
        ENDI

        ; Multiply by $00 (0)
        IF (_mul.const = $00)
_mul.done       QSET    -1
                CLRR    %reg%
        ENDI

        ; Multiply by $01 (1)
        IF (_mul.const = $01)
_mul.done       QSET    -1
                ; Nothing to do
        ENDI

        ; Multiply by $02 (2)
        IF (_mul.const = $02)
_mul.done       QSET    -1
                SLL     %reg%,  1
        ENDI

        ; Multiply by $03 (3)
        IF (_mul.const = $03)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $04 (4)
        IF (_mul.const = $04)
_mul.done       QSET    -1
                SLL     %reg%,  2
        ENDI

        ; Multiply by $05 (5)
        IF (_mul.const = $05)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $06 (6)
        IF (_mul.const = $06)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $07 (7)
        IF (_mul.const = $07)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $08 (8)
        IF (_mul.const = $08)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
        ENDI

        ; Multiply by $09 (9)
        IF (_mul.const = $09)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0A (10)
        IF (_mul.const = $0A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0B (11)
        IF (_mul.const = $0B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0C (12)
        IF (_mul.const = $0C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0D (13)
        IF (_mul.const = $0D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0E (14)
        IF (_mul.const = $0E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0F (15)
        IF (_mul.const = $0F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $10 (16)
        IF (_mul.const = $10)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $11 (17)
        IF (_mul.const = $11)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $12 (18)
        IF (_mul.const = $12)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $13 (19)
        IF (_mul.const = $13)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $14 (20)
        IF (_mul.const = $14)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $15 (21)
        IF (_mul.const = $15)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $16 (22)
        IF (_mul.const = $16)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $17 (23)
        IF (_mul.const = $17)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $18 (24)
        IF (_mul.const = $18)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $19 (25)
        IF (_mul.const = $19)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1A (26)
        IF (_mul.const = $1A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1B (27)
        IF (_mul.const = $1B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1C (28)
        IF (_mul.const = $1C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1D (29)
        IF (_mul.const = $1D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1E (30)
        IF (_mul.const = $1E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1F (31)
        IF (_mul.const = $1F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $20 (32)
        IF (_mul.const = $20)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
        ENDI

        ; Multiply by $21 (33)
        IF (_mul.const = $21)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $22 (34)
        IF (_mul.const = $22)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $23 (35)
        IF (_mul.const = $23)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $24 (36)
        IF (_mul.const = $24)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $25 (37)
        IF (_mul.const = $25)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $26 (38)
        IF (_mul.const = $26)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $27 (39)
        IF (_mul.const = $27)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $28 (40)
        IF (_mul.const = $28)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $29 (41)
        IF (_mul.const = $29)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2A (42)
        IF (_mul.const = $2A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2B (43)
        IF (_mul.const = $2B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2C (44)
        IF (_mul.const = $2C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2D (45)
        IF (_mul.const = $2D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2E (46)
        IF (_mul.const = $2E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $2F (47)
        IF (_mul.const = $2F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $30 (48)
        IF (_mul.const = $30)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $31 (49)
        IF (_mul.const = $31)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $32 (50)
        IF (_mul.const = $32)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $33 (51)
        IF (_mul.const = $33)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $34 (52)
        IF (_mul.const = $34)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $35 (53)
        IF (_mul.const = $35)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $36 (54)
        IF (_mul.const = $36)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $37 (55)
        IF (_mul.const = $37)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
		SLL	%reg%,	1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $38 (56)
        IF (_mul.const = $38)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $39 (57)
        IF (_mul.const = $39)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3A (58)
        IF (_mul.const = $3A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3B (59)
        IF (_mul.const = $3B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3C (60)
        IF (_mul.const = $3C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3D (61)
        IF (_mul.const = $3D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3E (62)
        IF (_mul.const = $3E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3F (63)
        IF (_mul.const = $3F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $40 (64)
        IF (_mul.const = $40)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $41 (65)
        IF (_mul.const = $41)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $42 (66)
        IF (_mul.const = $42)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $43 (67)
        IF (_mul.const = $43)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $44 (68)
        IF (_mul.const = $44)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $45 (69)
        IF (_mul.const = $45)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $46 (70)
        IF (_mul.const = $46)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $47 (71)
        IF (_mul.const = $47)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $48 (72)
        IF (_mul.const = $48)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $49 (73)
        IF (_mul.const = $49)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4A (74)
        IF (_mul.const = $4A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4B (75)
        IF (_mul.const = $4B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4C (76)
        IF (_mul.const = $4C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4D (77)
        IF (_mul.const = $4D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4E (78)
        IF (_mul.const = $4E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $4F (79)
        IF (_mul.const = $4F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $50 (80)
        IF (_mul.const = $50)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $51 (81)
        IF (_mul.const = $51)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $52 (82)
        IF (_mul.const = $52)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $53 (83)
        IF (_mul.const = $53)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $54 (84)
        IF (_mul.const = $54)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $55 (85)
        IF (_mul.const = $55)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $56 (86)
        IF (_mul.const = $56)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $57 (87)
        IF (_mul.const = $57)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR    %reg%,	%tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $58 (88)
        IF (_mul.const = $58)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $59 (89)
        IF (_mul.const = $59)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5A (90)
        IF (_mul.const = $5A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5B (91)
        IF (_mul.const = $5B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5C (92)
        IF (_mul.const = $5C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5D (93)
        IF (_mul.const = $5D)
_mul.done       QSET    -1
		MOVR	%reg%,	%tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5E (94)
        IF (_mul.const = $5E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5F (95)
        IF (_mul.const = $5F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                ADDR	%reg%,	%reg%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $60 (96)
        IF (_mul.const = $60)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $61 (97)
        IF (_mul.const = $61)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $62 (98)
        IF (_mul.const = $62)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $63 (99)
        IF (_mul.const = $63)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $64 (100)
        IF (_mul.const = $64)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $65 (101)
        IF (_mul.const = $65)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $66 (102)
        IF (_mul.const = $66)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $67 (103)
        IF (_mul.const = $67)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $68 (104)
        IF (_mul.const = $68)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $69 (105)
        IF (_mul.const = $69)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6A (106)
        IF (_mul.const = $6A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6B (107)
        IF (_mul.const = $6B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6C (108)
        IF (_mul.const = $6C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6D (109)
        IF (_mul.const = $6D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6E (110)
        IF (_mul.const = $6E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $6F (111)
        IF (_mul.const = $6F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $70 (112)
        IF (_mul.const = $70)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $71 (113)
        IF (_mul.const = $71)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $72 (114)
        IF (_mul.const = $72)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $73 (115)
        IF (_mul.const = $73)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $74 (116)
        IF (_mul.const = $74)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $75 (117)
        IF (_mul.const = $75)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $76 (118)
        IF (_mul.const = $76)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $77 (119)
        IF (_mul.const = $77)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $78 (120)
        IF (_mul.const = $78)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $79 (121)
        IF (_mul.const = $79)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7A (122)
        IF (_mul.const = $7A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7B (123)
        IF (_mul.const = $7B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7C (124)
        IF (_mul.const = $7C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7D (125)
        IF (_mul.const = $7D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7E (126)
        IF (_mul.const = $7E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7F (127)
        IF (_mul.const = $7F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        IF  (_mul.done = 0)
            ERR $("Invalid multiplication constant \'%const%\', must be between 0 and ", $#($7F), ".")
        ENDI

    LISTING "prev"
ENDM

;; ======================================================================== ;;
;;  EOF: pm:mac:lang:mult                                                   ;;
;; ======================================================================== ;;

	;FILE minty.bas
	;[1] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",1
	;[2] REM mINTY - the IntyBASIC Bitcoin miner 
	SRCFILE "minty.bas",2
	;[3] REM
	SRCFILE "minty.bas",3
	;[4] REM Bitcoin miner implementation taken from "Bitcoin mining the Hard Way" 
	SRCFILE "minty.bas",4
	;[5] REM http://www.righto.com/2014/02/bitcoin-mining-hard-way-algorithms.html
	SRCFILE "minty.bas",5
	;[6] REM
	SRCFILE "minty.bas",6
	;[7] REM SHA256 implementation taken from
	SRCFILE "minty.bas",7
	;[8] REM https://github.com/B-Con/crypto-algorithms/blob/master/sha256.c
	SRCFILE "minty.bas",8
	;[9] REM
	SRCFILE "minty.bas",9
	;[10] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",10
	;[11] 
	SRCFILE "minty.bas",11
	;[12]     INCLUDE "constants.bas"
	SRCFILE "minty.bas",12
	;FILE /Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas
	;[1] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",1
	;[2] REM HEADER - CONSTANTS.BAS
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",2
	;[3] REM 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",3
	;[4] REM Started by Mark Ball, July 2015
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",4
	;[5] REM
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",5
	;[6] REM Constants for use in IntyBASIC
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",6
	;[7] REM
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",7
	;[8] REM HISTORY
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",8
	;[9] REM -------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",9
	;[10] REM 1.00F 05/07/15 - First version.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",10
	;[11] REM 1.01F 07/07/15 - Added disc directions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",11
	;[12] REM                - Added background modes.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",12
	;[13] REM                - Minor comment changes.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",13
	;[14] REM 1.02F 08/07/15 - Renamed constants.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",14
	;[15] REM                - Added background access information.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",15
	;[16] REM                - Adjustments to layout.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",16
	;[17] REM 1.03F 08/07/15 - Fixed comment delimiter.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",17
	;[18] REM 1.04F 11/07/15 - Added useful functions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",18
	;[19] REM	               - Added controller movement mask.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",19
	;[20] REM 1.05F 11/07/15 - Added BACKGROUND constants.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",20
	;[21] REM 1.06F 11/07/15 - Changed Y, X order to X, Y in DEF FN functions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",21
	;[22] REM 1.07F 11/07/15 - Added colour stack advance.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",22
	;[23] REM 1.08F 12/07/15 - Added functions for sprite position handling.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",23
	;[24] REM 1.09F 12/07/15 - Added a function for resetting a sprite.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",24
	;[25] REM 1.10F 13/07/15 - Added keypad constants.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",25
	;[26] REM 1.11F 13/07/15 - Added side button constants.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",26
	;[27] REM 1.12F 13/07/15 - Updated sprite functions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",27
	;[28] REM 1.13F 19/07/15 - Added border masking constants.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",28
	;[29] REM 1.14F 20/07/15 - Added a combined border masking constant.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",29
	;[30] REM 1.15F 20/07/15 - Renamed border masking constants to BORDER_HIDE_xxxx.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",30
	;[31] REM 1.16F 28/09/15 - Fixed disc direction typos.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",31
	;[32] REM 1.17F 30/09/15 - Fixed DISC_SOUTH_WEST value.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",32
	;[33] REM 1.18F 05/12/15 - Fixed BG_XXXX colours.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",33
	;[34] REM 1.19F 01/01/16 - Changed name of BACKTAB constant to avoid confusion with #BACKTAB array.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",34
	;[35] REM                - Added pause key constants.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",35
	;[36] REM 1.20F 14/01/16 - Added coloured squares mode's pixel colours.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",36
	;[37] REM 1.21F 15/01/16 - Added coloured squares mode's X and Y limits.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",37
	;[38] REM 1.22F 23/01/16 - Added PSG constants.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",38
	;[39] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",39
	;[40] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",40
	;[41] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",41
	;[42] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",42
	;[43] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",43
	;[44] REM Background information.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",44
	;[45] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",45
	;[46] CONST BACKTAB_ADDR			= $0200		' Start of the BACKground TABle (BACKTAB) in RAM.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",46
	;[47] CONST BACKGROUND_ROWS		= 12		' Height of the background in cards.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",47
	;[48] CONST BACKGROUND_COLUMNS	= 20		' Width of the background in cards.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",48
	;[49] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",49
	;[50] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",50
	;[51] REM Background GRAM cards.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",51
	;[52] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",52
	;[53] CONST BG00 					= $0800
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",53
	;[54] CONST BG01 					= $0808
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",54
	;[55] CONST BG02 					= $0810
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",55
	;[56] CONST BG03 					= $0818
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",56
	;[57] CONST BG04 					= $0820
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",57
	;[58] CONST BG05 					= $0828
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",58
	;[59] CONST BG06 					= $0830
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",59
	;[60] CONST BG07 					= $0838
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",60
	;[61] CONST BG08 					= $0840
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",61
	;[62] CONST BG09 					= $0848
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",62
	;[63] CONST BG10 					= $0850
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",63
	;[64] CONST BG11 					= $0858
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",64
	;[65] CONST BG12 					= $0860
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",65
	;[66] CONST BG13 					= $0868
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",66
	;[67] CONST BG14 					= $0870
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",67
	;[68] CONST BG15 					= $0878
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",68
	;[69] CONST BG16 					= $0880
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",69
	;[70] CONST BG17 					= $0888
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",70
	;[71] CONST BG18 					= $0890
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",71
	;[72] CONST BG19 					= $0898
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",72
	;[73] CONST BG20 					= $08A0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",73
	;[74] CONST BG21 					= $08A8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",74
	;[75] CONST BG22 					= $08B0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",75
	;[76] CONST BG23 					= $08B8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",76
	;[77] CONST BG24 					= $08C0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",77
	;[78] CONST BG25 					= $08C8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",78
	;[79] CONST BG26 					= $08D0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",79
	;[80] CONST BG27 					= $08D8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",80
	;[81] CONST BG28 					= $08E0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",81
	;[82] CONST BG29 					= $08E8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",82
	;[83] CONST BG30 					= $08F0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",83
	;[84] CONST BG31 					= $08F8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",84
	;[85] CONST BG32 					= $0900
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",85
	;[86] CONST BG33 					= $0908
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",86
	;[87] CONST BG34 					= $0910
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",87
	;[88] CONST BG35 					= $0918
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",88
	;[89] CONST BG36 					= $0920
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",89
	;[90] CONST BG37 					= $0928
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",90
	;[91] CONST BG38 					= $0930
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",91
	;[92] CONST BG39 					= $0938
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",92
	;[93] CONST BG40 					= $0940
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",93
	;[94] CONST BG41 					= $0948
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",94
	;[95] CONST BG42 					= $0950
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",95
	;[96] CONST BG43 					= $0958
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",96
	;[97] CONST BG44 					= $0960
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",97
	;[98] CONST BG45 					= $0968
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",98
	;[99] CONST BG46 					= $0970
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",99
	;[100] CONST BG47 					= $0978
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",100
	;[101] CONST BG48 					= $0980
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",101
	;[102] CONST BG49 					= $0988
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",102
	;[103] CONST BG50 					= $0990
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",103
	;[104] CONST BG51 					= $0998
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",104
	;[105] CONST BG52 					= $09A0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",105
	;[106] CONST BG53 					= $09A8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",106
	;[107] CONST BG54 					= $09B0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",107
	;[108] CONST BG55 					= $09B8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",108
	;[109] CONST BG56 					= $09C0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",109
	;[110] CONST BG57 					= $09C8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",110
	;[111] CONST BG58 					= $09D0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",111
	;[112] CONST BG59 					= $09D8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",112
	;[113] CONST BG60 					= $09E0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",113
	;[114] CONST BG61 					= $09E8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",114
	;[115] CONST BG62 					= $09F0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",115
	;[116] CONST BG63 					= $09F8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",116
	;[117] 	
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",117
	;[118] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",118
	;[119] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",119
	;[120] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",120
	;[121] REM GRAM card index numbers.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",121
	;[122] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",122
	;[123] REM Note: For use with the "define" command.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",123
	;[124] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",124
	;[125] CONST DEF00 				= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",125
	;[126] CONST DEF01 				= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",126
	;[127] CONST DEF02 				= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",127
	;[128] CONST DEF03 				= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",128
	;[129] CONST DEF04 				= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",129
	;[130] CONST DEF05 				= $0005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",130
	;[131] CONST DEF06 				= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",131
	;[132] CONST DEF07 				= $0007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",132
	;[133] CONST DEF08 				= $0008
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",133
	;[134] CONST DEF09 				= $0009
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",134
	;[135] CONST DEF10 				= $000A
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",135
	;[136] CONST DEF11 				= $000B
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",136
	;[137] CONST DEF12 				= $000C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",137
	;[138] CONST DEF13 				= $000D
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",138
	;[139] CONST DEF14 				= $000E
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",139
	;[140] CONST DEF15 				= $000F
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",140
	;[141] CONST DEF16 				= $0010
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",141
	;[142] CONST DEF17 				= $0011
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",142
	;[143] CONST DEF18 				= $0012
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",143
	;[144] CONST DEF19 				= $0013
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",144
	;[145] CONST DEF20 				= $0014
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",145
	;[146] CONST DEF21 				= $0015
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",146
	;[147] CONST DEF22 				= $0016
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",147
	;[148] CONST DEF23 				= $0017
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",148
	;[149] CONST DEF24 				= $0018
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",149
	;[150] CONST DEF25 				= $0019
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",150
	;[151] CONST DEF26 				= $001A
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",151
	;[152] CONST DEF27 				= $001B
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",152
	;[153] CONST DEF28 				= $001C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",153
	;[154] CONST DEF29 				= $001D
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",154
	;[155] CONST DEF30 				= $001E
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",155
	;[156] CONST DEF31 				= $001F
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",156
	;[157] CONST DEF32 				= $0020
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",157
	;[158] CONST DEF33 				= $0021
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",158
	;[159] CONST DEF34 				= $0022
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",159
	;[160] CONST DEF35 				= $0023
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",160
	;[161] CONST DEF36 				= $0024
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",161
	;[162] CONST DEF37 				= $0025
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",162
	;[163] CONST DEF38 				= $0026
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",163
	;[164] CONST DEF39 				= $0027
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",164
	;[165] CONST DEF40 				= $0028
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",165
	;[166] CONST DEF41 				= $0029
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",166
	;[167] CONST DEF42 				= $002A
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",167
	;[168] CONST DEF43 				= $002B
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",168
	;[169] CONST DEF44 				= $002C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",169
	;[170] CONST DEF45 				= $002D
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",170
	;[171] CONST DEF46 				= $002E
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",171
	;[172] CONST DEF47 				= $002F
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",172
	;[173] CONST DEF48 				= $0030
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",173
	;[174] CONST DEF49 				= $0031
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",174
	;[175] CONST DEF50 				= $0032
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",175
	;[176] CONST DEF51 				= $0033
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",176
	;[177] CONST DEF52 				= $0034
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",177
	;[178] CONST DEF53 				= $0035
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",178
	;[179] CONST DEF54 				= $0036
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",179
	;[180] CONST DEF55 				= $0037
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",180
	;[181] CONST DEF56 				= $0038
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",181
	;[182] CONST DEF57 				= $0039
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",182
	;[183] CONST DEF58 				= $003A
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",183
	;[184] CONST DEF59 				= $003B
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",184
	;[185] CONST DEF60 				= $003C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",185
	;[186] CONST DEF61 				= $003D
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",186
	;[187] CONST DEF62 				= $003E
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",187
	;[188] CONST DEF63 				= $003F
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",188
	;[189] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",189
	;[190] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",190
	;[191] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",191
	;[192] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",192
	;[193] REM Screen modes.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",193
	;[194] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",194
	;[195] REM Note: For use with the "mode" command.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",195
	;[196] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",196
	;[197] CONST SCREEN_COLOR_STACK			= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",197
	;[198] CONST SCREEN_FOREGROUND_BACKGROUND	= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",198
	;[199] REM Abbreviated versions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",199
	;[200] CONST SCREEN_CS						= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",200
	;[201] CONST SCREEN_FB						= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",201
	;[202] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",202
	;[203] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",203
	;[204] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",204
	;[205] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",205
	;[206] REM COLORS - Border.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",206
	;[207] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",207
	;[208] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",208
	;[209] REM - For use with the commands "mode 0" and "mode 1".
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",209
	;[210] REM - For use with the "border" command.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",210
	;[211] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",211
	;[212] CONST BORDER_BLACK			= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",212
	;[213] CONST BORDER_BLUE			= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",213
	;[214] CONST BORDER_RED			= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",214
	;[215] CONST BORDER_TAN			= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",215
	;[216] CONST BORDER_DARKGREEN		= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",216
	;[217] CONST BORDER_GREEN			= $0005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",217
	;[218] CONST BORDER_YELLOW			= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",218
	;[219] CONST BORDER_WHITE			= $0007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",219
	;[220] CONST BORDER_GREY			= $0008
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",220
	;[221] CONST BORDER_CYAN			= $0009
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",221
	;[222] CONST BORDER_ORANGE			= $000A
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",222
	;[223] CONST BORDER_BROWN			= $000B
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",223
	;[224] CONST BORDER_PINK			= $000C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",224
	;[225] CONST BORDER_LIGHTBLUE		= $000D
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",225
	;[226] CONST BORDER_YELLOWGREEN	= $000E
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",226
	;[227] CONST BORDER_PURPLE			= $000F
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",227
	;[228] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",228
	;[229] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",229
	;[230] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",230
	;[231] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",231
	;[232] REM BORDER - Edge masks.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",232
	;[233] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",233
	;[234] REM Note: For use with the "border color, edge" command.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",234
	;[235] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",235
	;[236] CONST BORDER_HIDE_LEFT_EDGE		= $0001		' Hide the leftmost column of the background.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",236
	;[237] CONST BORDER_HIDE_TOP_EDGE		= $0002		' Hide the topmost row of the background.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",237
	;[238] CONST BORDER_HIDE_TOP_LEFT_EDGE	= $0003		' Hide both the topmost row and leftmost column of the background.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",238
	;[239] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",239
	;[240] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",240
	;[241] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",241
	;[242] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",242
	;[243] REM COLORS - Mode 0 (Color Stack).
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",243
	;[244] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",244
	;[245] REM Stack
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",245
	;[246] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",246
	;[247] REM Note: For use as the last 4 parameters used in the "mode 1" command.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",247
	;[248] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",248
	;[249] CONST STACK_BLACK			= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",249
	;[250] CONST STACK_BLUE			= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",250
	;[251] CONST STACK_RED				= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",251
	;[252] CONST STACK_TAN				= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",252
	;[253] CONST STACK_DARKGREEN		= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",253
	;[254] CONST STACK_GREEN			= $0005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",254
	;[255] CONST STACK_YELLOW			= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",255
	;[256] CONST STACK_WHITE			= $0007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",256
	;[257] CONST STACK_GREY			= $0008
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",257
	;[258] CONST STACK_CYAN			= $0009
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",258
	;[259] CONST STACK_ORANGE			= $000A
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",259
	;[260] CONST STACK_BROWN			= $000B
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",260
	;[261] CONST STACK_PINK			= $000C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",261
	;[262] CONST STACK_LIGHTBLUE		= $000D
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",262
	;[263] CONST STACK_YELLOWGREEN		= $000E
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",263
	;[264] CONST STACK_PURPLE			= $000F
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",264
	;[265] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",265
	;[266] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",266
	;[267] REM Foreground.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",267
	;[268] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",268
	;[269] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",269
	;[270] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",270
	;[271] REM - Only one foreground colour permitted per background card.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",271
	;[272] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",272
	;[273] CONST CS_BLACK				= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",273
	;[274] CONST CS_BLUE				= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",274
	;[275] CONST CS_RED				= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",275
	;[276] CONST CS_TAN				= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",276
	;[277] CONST CS_DARKGREEN			= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",277
	;[278] CONST CS_GREEN				= $0005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",278
	;[279] CONST CS_YELLOW				= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",279
	;[280] CONST CS_WHITE				= $0007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",280
	;[281] CONST CS_GREY				= $1000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",281
	;[282] CONST CS_CYAN				= $1001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",282
	;[283] CONST CS_ORANGE				= $1002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",283
	;[284] CONST CS_BROWN				= $1003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",284
	;[285] CONST CS_PINK				= $1004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",285
	;[286] CONST CS_LIGHTBLUE			= $1005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",286
	;[287] CONST CS_YELLOWGREEN		= $1006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",287
	;[288] CONST CS_PURPLE				= $1007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",288
	;[289] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",289
	;[290] CONST CS_CARD_DATA_MASK		= $07F8		' Mask to get the background card's data.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",290
	;[291] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",291
	;[292] CONST CS_ADVANCE			= $2000		' Advance the colour stack by one position.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",292
	;[293] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",293
	;[294] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",294
	;[295] REM Coloured squares mode.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",295
	;[296] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",296
	;[297] REM Notes :
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",297
	;[298] REM - Only available in colour stack mode.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",298
	;[299] REM - Pixels in each BACKTAB card are arranged in the following manner:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",299
	;[300] REM +-------+-------+
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",300
	;[301] REM | Pixel | Pixel |
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",301
	;[302] REM |   0   |   1   !
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",302
	;[303] REM +-------+-------+
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",303
	;[304] REM | Pixel | Pixel |
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",304
	;[305] REM |   2   |   3   !
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",305
	;[306] REM +-------+-------+
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",306
	;[307] REM
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",307
	;[308] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",308
	;[309] CONST CS_COLOUR_SQUARES_ENABLE	=$1000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",309
	;[310] CONST CS_PIX0_BLACK				=0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",310
	;[311] CONST CS_PIX0_BLUE				=1
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",311
	;[312] CONST CS_PIX0_RED				=2
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",312
	;[313] CONST CS_PIX0_TAN				=3
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",313
	;[314] CONST CS_PIX0_DARKGREEN			=4
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",314
	;[315] CONST CS_PIX0_GREEN				=5
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",315
	;[316] CONST CS_PIX0_YELLOW			=6
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",316
	;[317] CONST CS_PIX0_BACKGROUND		=7
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",317
	;[318] CONST CS_PIX1_BLACK				=0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",318
	;[319] CONST CS_PIX1_BLUE				=1*8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",319
	;[320] CONST CS_PIX1_RED				=2*8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",320
	;[321] CONST CS_PIX1_TAN				=3*8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",321
	;[322] CONST CS_PIX1_DARKGREEN			=4*8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",322
	;[323] CONST CS_PIX1_GREEN				=5*8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",323
	;[324] CONST CS_PIX1_YELLOW			=6*8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",324
	;[325] CONST CS_PIX1_BACKGROUND		=7*8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",325
	;[326] CONST CS_PIX2_BLACK				=0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",326
	;[327] CONST CS_PIX2_BLUE				=1*64
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",327
	;[328] CONST CS_PIX2_RED				=2*64
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",328
	;[329] CONST CS_PIX2_TAN				=3*64
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",329
	;[330] CONST CS_PIX2_DARKGREEN			=4*64
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",330
	;[331] CONST CS_PIX2_GREEN				=5*64
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",331
	;[332] CONST CS_PIX2_YELLOW			=6*64
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",332
	;[333] CONST CS_PIX2_BACKGROUND		=7*64
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",333
	;[334] CONST CS_PIX3_BLACK				=0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",334
	;[335] CONST CS_PIX3_BLUE				=$0200
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",335
	;[336] CONST CS_PIX3_RED				=$0400
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",336
	;[337] CONST CS_PIX3_TAN				=$0600
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",337
	;[338] CONST CS_PIX3_DARKGREEN			=$2000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",338
	;[339] CONST CS_PIX3_GREEN				=$2200
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",339
	;[340] CONST CS_PIX3_YELLOW			=$2400
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",340
	;[341] CONST CS_PIX3_BACKGROUND		=$2600
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",341
	;[342] CONST CS_PIX_MASK				=CS_COLOUR_SQUARES_ENABLE+CS_PIX0_BACKGROUND+CS_PIX1_BACKGROUND+CS_PIX2_BACKGROUND+CS_PIX3_BACKGROUND
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",342
	;[343] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",343
	;[344] CONST CS_PIX_X_MIN				=0		' Minimum x coordinate.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",344
	;[345] CONST CS_PIX_X_MAX				=39		' Maximum x coordinate.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",345
	;[346] CONST CS_PIX_Y_MIN				=0		' Minimum Y coordinate.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",346
	;[347] CONST CS_PIX_Y_MAX				=23		' Maximum Y coordinate.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",347
	;[348] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",348
	;[349] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",349
	;[350] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",350
	;[351] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",351
	;[352] REM COLORS - Mode 1 (Foreground Background)
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",352
	;[353] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",353
	;[354] REM Foreground.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",354
	;[355] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",355
	;[356] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",356
	;[357] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",357
	;[358] REM - Only one foreground colour permitted per background card.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",358
	;[359] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",359
	;[360] CONST FG_BLACK				= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",360
	;[361] CONST FG_BLUE				= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",361
	;[362] CONST FG_RED				= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",362
	;[363] CONST FG_TAN				= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",363
	;[364] CONST FG_DARKGREEN			= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",364
	;[365] CONST FG_GREEN				= $0005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",365
	;[366] CONST FG_YELLOW				= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",366
	;[367] CONST FG_WHITE				= $0007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",367
	;[368] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",368
	;[369] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",369
	;[370] REM Background.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",370
	;[371] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",371
	;[372] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",372
	;[373] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",373
	;[374] REM - Only one background colour permitted per background card.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",374
	;[375] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",375
	;[376] CONST BG_BLACK				= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",376
	;[377] CONST BG_BLUE				= $0200
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",377
	;[378] CONST BG_RED				= $0400
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",378
	;[379] CONST BG_TAN				= $0600
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",379
	;[380] CONST BG_DARKGREEN			= $2000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",380
	;[381] CONST BG_GREEN				= $2200
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",381
	;[382] CONST BG_YELLOW				= $2400
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",382
	;[383] CONST BG_WHITE				= $2600
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",383
	;[384] CONST BG_GREY				= $1000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",384
	;[385] CONST BG_CYAN				= $1200
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",385
	;[386] CONST BG_ORANGE				= $1400
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",386
	;[387] CONST BG_BROWN				= $1600
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",387
	;[388] CONST BG_PINK				= $3000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",388
	;[389] CONST BG_LIGHTBLUE			= $3200
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",389
	;[390] CONST BG_YELLOWGREEN		= $3400
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",390
	;[391] CONST BG_PURPLE				= $3600
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",391
	;[392] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",392
	;[393] CONST FGBG_CARD_DATA_MASK	= $01F8		' Mask to get the background card's data.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",393
	;[394] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",394
	;[395] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",395
	;[396] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",396
	;[397] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",397
	;[398] REM Sprites.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",398
	;[399] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",399
	;[400] REM Note: For use with "sprite" command.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",400
	;[401] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",401
	;[402] REM X
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",402
	;[403] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",403
	;[404] REM Note: Add these constants to the sprite command's X parameter.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",404
	;[405] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",405
	;[406] CONST HIT					= $0100		' Enable the sprite's collision detection.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",406
	;[407] CONST VISIBLE				= $0200		' Make the sprite visible.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",407
	;[408] CONST ZOOMX2				= $0400		' Make the sprite twice the width.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",408
	;[409] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",409
	;[410] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",410
	;[411] REM Y
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",411
	;[412] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",412
	;[413] REM Note: Add these constants to the sprite command's Y parameter.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",413
	;[414] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",414
	;[415] CONST DOUBLEY				= $0080		' Make a double height sprite (with 2 GRAM cards).
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",415
	;[416] CONST ZOOMY2				= $0100		' Make the sprite twice (x2) the normal height.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",416
	;[417] CONST ZOOMY4				= $0200		' Make the sprite quadruple (x4) the normal height.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",417
	;[418] CONST ZOOMY8				= $0300		' Make the sprite octuple (x8) the normal height.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",418
	;[419] CONST FLIPX					= $0400		' Flip/mirror the sprite in X.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",419
	;[420] CONST FLIPY					= $0800		' Flip/mirror the sprite in Y.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",420
	;[421] CONST MIRROR				= $0C00		' Flip/mirror the sprite in both X and Y.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",421
	;[422] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",422
	;[423] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",423
	;[424] REM A
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",424
	;[425] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",425
	;[426] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",426
	;[427] REM - Combine to create the sprite command's A parameter.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",427
	;[428] REM - Only one colour per sprite.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",428
	;[429] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",429
	;[430] CONST GRAM					= $0800		' Sprite's data is located in GRAM.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",430
	;[431] CONST BEHIND				= $2000		' Sprite is behind the background.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",431
	;[432] CONST SPR_BLACK				= $0000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",432
	;[433] CONST SPR_BLUE				= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",433
	;[434] CONST SPR_RED				= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",434
	;[435] CONST SPR_TAN				= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",435
	;[436] CONST SPR_DARKGREEN			= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",436
	;[437] CONST SPR_GREEN				= $0005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",437
	;[438] CONST SPR_YELLOW			= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",438
	;[439] CONST SPR_WHITE				= $0007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",439
	;[440] CONST SPR_GREY				= $1000
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",440
	;[441] CONST SPR_CYAN				= $1001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",441
	;[442] CONST SPR_ORANGE			= $1002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",442
	;[443] CONST SPR_BROWN				= $1003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",443
	;[444] CONST SPR_PINK				= $1004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",444
	;[445] CONST SPR_LIGHTBLUE			= $1005
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",445
	;[446] CONST SPR_YELLOWGREEN		= $1006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",446
	;[447] CONST SPR_PURPLE			= $1007
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",447
	;[448] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",448
	;[449] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",449
	;[450] REM GRAM numbers.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",450
	;[451] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",451
	;[452] REM Note: For use in the sprite command's parameter A.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",452
	;[453] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",453
	;[454] CONST SPR00 				= $0800
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",454
	;[455] CONST SPR01 				= $0808
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",455
	;[456] CONST SPR02 				= $0810
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",456
	;[457] CONST SPR03 				= $0818
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",457
	;[458] CONST SPR04 				= $0820
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",458
	;[459] CONST SPR05 				= $0828
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",459
	;[460] CONST SPR06 				= $0830
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",460
	;[461] CONST SPR07 				= $0838
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",461
	;[462] CONST SPR08 				= $0840
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",462
	;[463] CONST SPR09 				= $0848
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",463
	;[464] CONST SPR10 				= $0850
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",464
	;[465] CONST SPR11 				= $0858
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",465
	;[466] CONST SPR12 				= $0860
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",466
	;[467] CONST SPR13 				= $0868
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",467
	;[468] CONST SPR14 				= $0870
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",468
	;[469] CONST SPR15 				= $0878
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",469
	;[470] CONST SPR16 				= $0880
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",470
	;[471] CONST SPR17 				= $0888
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",471
	;[472] CONST SPR18 				= $0890
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",472
	;[473] CONST SPR19 				= $0898
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",473
	;[474] CONST SPR20 				= $08A0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",474
	;[475] CONST SPR21 				= $08A8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",475
	;[476] CONST SPR22 				= $08B0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",476
	;[477] CONST SPR23 				= $08B8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",477
	;[478] CONST SPR24 				= $08C0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",478
	;[479] CONST SPR25 				= $08C8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",479
	;[480] CONST SPR26 				= $08D0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",480
	;[481] CONST SPR27 				= $08D8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",481
	;[482] CONST SPR28 				= $08E0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",482
	;[483] CONST SPR29 				= $08E8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",483
	;[484] CONST SPR30 				= $08F0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",484
	;[485] CONST SPR31 				= $08F8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",485
	;[486] CONST SPR32 				= $0900
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",486
	;[487] CONST SPR33 				= $0908
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",487
	;[488] CONST SPR34 				= $0910
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",488
	;[489] CONST SPR35 				= $0918
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",489
	;[490] CONST SPR36 				= $0920
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",490
	;[491] CONST SPR37 				= $0928
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",491
	;[492] CONST SPR38 				= $0930
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",492
	;[493] CONST SPR39 				= $0938
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",493
	;[494] CONST SPR40 				= $0940
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",494
	;[495] CONST SPR41 				= $0948
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",495
	;[496] CONST SPR42 				= $0950
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",496
	;[497] CONST SPR43 				= $0958
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",497
	;[498] CONST SPR44 				= $0960
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",498
	;[499] CONST SPR45 				= $0968
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",499
	;[500] CONST SPR46 				= $0970
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",500
	;[501] CONST SPR47 				= $0978
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",501
	;[502] CONST SPR48 				= $0980
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",502
	;[503] CONST SPR49 				= $0988
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",503
	;[504] CONST SPR50 				= $0990
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",504
	;[505] CONST SPR51 				= $0998
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",505
	;[506] CONST SPR52 				= $09A0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",506
	;[507] CONST SPR53 				= $09A8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",507
	;[508] CONST SPR54 				= $09B0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",508
	;[509] CONST SPR55 				= $09B8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",509
	;[510] CONST SPR56 				= $09C0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",510
	;[511] CONST SPR57 				= $09C8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",511
	;[512] CONST SPR58 				= $09D0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",512
	;[513] CONST SPR59 				= $09D8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",513
	;[514] CONST SPR60 				= $09E0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",514
	;[515] CONST SPR61 				= $09E8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",515
	;[516] CONST SPR62 				= $09F0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",516
	;[517] CONST SPR63 				= $09F8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",517
	;[518] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",518
	;[519] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",519
	;[520] REM Sprite collision.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",520
	;[521] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",521
	;[522] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",522
	;[523] REM - For use with variables COL0, COL1, COL2, COL3, COL4, COL5, COL6 and COL7.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",523
	;[524] REM - More than one collision can occur simultaneously.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",524
	;[525] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",525
	;[526] CONST HIT_SPRITE0			= $0001		' Sprite collided with sprite 0.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",526
	;[527] CONST HIT_SPRITE1			= $0002		' Sprite collided with sprite 1.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",527
	;[528] CONST HIT_SPRITE2			= $0004		' Sprite collided with sprite 2.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",528
	;[529] CONST HIT_SPRITE3			= $0008		' Sprite collided with sprite 3.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",529
	;[530] CONST HIT_SPRITE4			= $0010		' Sprite collided with sprite 4.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",530
	;[531] CONST HIT_SPRITE5			= $0020		' Sprite collided with sprite 5.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",531
	;[532] CONST HIT_SPRITE6			= $0040		' Sprite collided with sprite 6.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",532
	;[533] CONST HIT_SPRITE7			= $0080		' Sprite collided with sprite 7.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",533
	;[534] CONST HIT_BACKGROUND		= $0100		' Sprite collided with a background pixel.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",534
	;[535] CONST HIT_BORDER			= $0200		' Sprite collided with the top/bottom/left/right border.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",535
	;[536] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",536
	;[537] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",537
	;[538] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",538
	;[539] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",539
	;[540] REM DISC - Compass.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",540
	;[541] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",541
	;[542] REM   NW         N         NE
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",542
	;[543] REM     \   NNW  |  NNE   /
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",543
	;[544] REM       \      |      /
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",544
	;[545] REM         \    |    /
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",545
	;[546] REM    WNW    \  |  /    ENE
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",546
	;[547] REM             \|/
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",547
	;[548] REM  W ----------+---------- E
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",548
	;[549] REM             /|\ 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",549
	;[550] REM    WSW    /  |  \    ESE
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",550
	;[551] REM         /    |    \
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",551
	;[552] REM       /      |      \
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",552
	;[553] REM     /   SSW  |  SSE   \
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",553
	;[554] REM   SW         S         SE
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",554
	;[555] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",555
	;[556] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",556
	;[557] REM - North points upwards on the hand controller.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",557
	;[558] REM - Directions are listed in a clockwise manner.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",558
	;[559] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",559
	;[560] CONST DISC_NORTH			= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",560
	;[561] CONST DISC_NORTH_NORTH_EAST = $0014
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",561
	;[562] CONST DISC_NORTH_EAST		= $0016
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",562
	;[563] CONST DISC_EAST_NORTH_EAST	= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",563
	;[564] CONST DISC_EAST				= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",564
	;[565] CONST DISC_EAST_SOUTH_EAST	= $0012
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",565
	;[566] CONST DISC_SOUTH_EAST		= $0013
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",566
	;[567] CONST DISC_SOUTH_SOUTH_EAST	= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",567
	;[568] CONST DISC_SOUTH			= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",568
	;[569] CONST DISC_SOUTH_SOUTH_WEST	= $0011
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",569
	;[570] CONST DISC_SOUTH_WEST		= $0019
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",570
	;[571] CONST DISC_WEST_SOUTH_WEST	= $0009
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",571
	;[572] CONST DISC_WEST				= $0008
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",572
	;[573] CONST DISC_WEST_NORTH_WEST	= $0018
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",573
	;[574] CONST DISC_NORTH_WEST		= $001C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",574
	;[575] CONST DISC_NORTH_NORTH_WEST	= $000C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",575
	;[576] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",576
	;[577] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",577
	;[578] REM DISC - Compass abbreviated versions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",578
	;[579] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",579
	;[580] CONST DISC_N				= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",580
	;[581] CONST DISC_NNE 				= $0014
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",581
	;[582] CONST DISC_NE				= $0016
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",582
	;[583] CONST DISC_ENE				= $0006
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",583
	;[584] CONST DISC_E				= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",584
	;[585] CONST DISC_ESE				= $0012
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",585
	;[586] CONST DISC_SE				= $0013
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",586
	;[587] CONST DISC_SSE				= $0003
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",587
	;[588] CONST DISC_S				= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",588
	;[589] CONST DISC_SSW				= $0011
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",589
	;[590] CONST DISC_SW				= $0019
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",590
	;[591] CONST DISC_WSW				= $0009
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",591
	;[592] CONST DISC_W				= $0008
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",592
	;[593] CONST DISC_WNW				= $0018
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",593
	;[594] CONST DISC_NW				= $001C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",594
	;[595] CONST DISC_NNW				= $000C
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",595
	;[596] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",596
	;[597] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",597
	;[598] REM DISC - Directions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",598
	;[599] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",599
	;[600] CONST DISC_UP				= $0004
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",600
	;[601] CONST DISC_UP_RIGHT			= $0016		' Up and right diagonal.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",601
	;[602] CONST DISC_RIGHT			= $0002
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",602
	;[603] CONST DISC_DOWN_RIGHT		= $0013		' Down  and right diagonal.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",603
	;[604] CONST DISC_DOWN				= $0001
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",604
	;[605] CONST DISC_DOWN_LEFT		= $0019		' Down and left diagonal.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",605
	;[606] CONST DISC_LEFT				= $0008
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",606
	;[607] CONST DISC_UP_LEFT			= $001C		' Up and left diagonal.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",607
	;[608] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",608
	;[609] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",609
	;[610] REM DISK - Mask.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",610
	;[611] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",611
	;[612] CONST DISK_MASK				= $001F
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",612
	;[613] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",613
	;[614] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",614
	;[615] REM Controller - Keypad.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",615
	;[616] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",616
	;[617] CONST KEYPAD_0				= 72
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",617
	;[618] CONST KEYPAD_1				= 129
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",618
	;[619] CONST KEYPAD_2				= 65
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",619
	;[620] CONST KEYPAD_3				= 33
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",620
	;[621] CONST KEYPAD_4				= 130
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",621
	;[622] CONST KEYPAD_5				= 66
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",622
	;[623] CONST KEYPAD_6				= 34
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",623
	;[624] CONST KEYPAD_7				= 132
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",624
	;[625] CONST KEYPAD_8				= 68
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",625
	;[626] CONST KEYPAD_9				= 36
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",626
	;[627] CONST KEYPAD_CLEAR			= 136
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",627
	;[628] CONST KEYPAD_ENTER			= 40
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",628
	;[629] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",629
	;[630] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",630
	;[631] REM Controller - Pause buttons (1+9 or 3+7 held down simultaneously).
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",631
	;[632] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",632
	;[633] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",633
	;[634] REM - Key codes for 3+7 and 1+9 are the same (165).
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",634
	;[635] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",635
	;[636] CONST KEYPAD_PAUSE			= (KEYPAD_1 XOR KEYPAD_9)
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",636
	;[637] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",637
	;[638] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",638
	;[639] REM Controller - Side buttons.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",639
	;[640] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",640
	;[641] CONST BUTTON_TOP_LEFT		= $A0		' Top left and top right are the same button.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",641
	;[642] CONST BUTTON_TOP_RIGHT		= $A0		' Note: Bit 6 is low. 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",642
	;[643] CONST BUTTON_BOTTOM_LEFT	= $60		' Note: Bit 7 is low.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",643
	;[644] CONST BUTTON_BOTTOM_RIGHT	= $C0		' Note: Bit 5 is low
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",644
	;[645] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",645
	;[646] REM Abbreviated versions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",646
	;[647] CONST BUTTON_1				= $A0		' Top left or top right.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",647
	;[648] CONST BUTTON_2				= $60		' Bottom left.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",648
	;[649] CONST BUTTON_3				= $C0		' Bottom right.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",649
	;[650] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",650
	;[651] REM Mask.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",651
	;[652] CONST BUTTON_MASK			= $E0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",652
	;[653] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",653
	;[654] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",654
	;[655] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",655
	;[656] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",656
	;[657] REM Programmable Sound Generator (PSG)
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",657
	;[658] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",658
	;[659] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",659
	;[660] REM - For use with the SOUND command
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",660
	;[661] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",661
	;[662] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",662
	;[663] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",663
	;[664] REM Internal sound hardware.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",664
	;[665] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",665
	;[666] CONST PSG_CHANNELA		=0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",666
	;[667] CONST PSG_CHANNELB		=1
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",667
	;[668] CONST PSG_CHANNELC		=2
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",668
	;[669] CONST PSG_ENVELOPE		=3
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",669
	;[670] CONST PSG_MIXER			=4
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",670
	;[671] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",671
	;[672] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",672
	;[673] REM ECS sound hardware.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",673
	;[674] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",674
	;[675] CONST PSG_ECS_CHANNELA	=5
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",675
	;[676] CONST PSG_ECS_CHANNELB	=6
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",676
	;[677] CONST PSG_ECS_CHANNELC	=7
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",677
	;[678] CONST PSG_ECS_ENVELOPE	=8
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",678
	;[679] CONST PSG_ECS_MIXER		=9
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",679
	;[680] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",680
	;[681] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",681
	;[682] REM PSG - Volume control.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",682
	;[683] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",683
	;[684] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",684
	;[685] REM - For use in the volume field of the SOUND command.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",685
	;[686] REM - Internal channels: PSG_CHANNELA, PSG_CHANNELB, PSG_CHANNELC
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",686
	;[687] REM - ECS channels: PSG_ECS_CHANNELA, PSG_ECS_CHANNELB, PSG_ECS_CHANNELC
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",687
	;[688] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",688
	;[689] CONST PSG_VOLUME_MAX		=15	' Maximum channel volume.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",689
	;[690] CONST PSG_ENVELOPE_ENABLE	=48	' Channel volume is controlled by envelope generator.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",690
	;[691] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",691
	;[692] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",692
	;[693] REM PSG - Mixer control.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",693
	;[694] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",694
	;[695] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",695
	;[696] REM - Internal channel: PSG_MIXER
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",696
	;[697] REM - EXS channel: PSG_ECS_MIXER
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",697
	;[698] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",698
	;[699] CONST PSG_TONE_CHANNELA_DISABLE		=$01	' Disable channel A tone.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",699
	;[700] CONST PSG_TONE_CHANNELB_DISABLE		=$02	' Disable channel B tone.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",700
	;[701] CONST PSG_TONE_CHANNELC_DISABLE		=$04	' Disable channel C tone.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",701
	;[702] CONST PSG_NOISE_CHANNELA_DISABLE	=$08	' Disable channel A noise.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",702
	;[703] CONST PSG_NOISE_CHANNELB_DISABLE	=$10	' Disable channel B noise.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",703
	;[704] CONST PSG_NOISE_CHANNELC_DISABLE	=$20	' Disable channel C noise.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",704
	;[705] CONST PSG_MIXER_DEFAULT				=$38 	' All notes enabled. all noise disabled.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",705
	;[706] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",706
	;[707] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",707
	;[708] REM PSG - Envelope control.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",708
	;[709] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",709
	;[710] REM Notes:
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",710
	;[711] REM - Internal channel: PSG_ENVELOPE
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",711
	;[712] REM - EXS channel: PSG_ECS_ENVELOPE
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",712
	;[713] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",713
	;[714] CONST PSG_ENVELOPE_HOLD								=$01
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",714
	;[715] CONST PSG_ENVELOPE_ALTERNATE						=$02
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",715
	;[716] CONST PSG_ENVELOPE_ATTACK							=$04
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",716
	;[717] CONST PSG_ENVELOPE_CONTINUE							=$08
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",717
	;[718] CONST PSG_ENVELOPE_SINGLE_SHOT_RAMP_DOWN_AND_OFF	=$00 '\______
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",718
	;[719] CONST PSG_ENVELOPE_SINGLE_SHOT_RAMP_UP_AND_OFF		=$04 '/______
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",719
	;[720] CONST PSG_ENVELOPE_CYCLE_RAMP_DOWN_SAWTOOTH			=$08 '\\\\\\\
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",720
	;[721] CONST PSG_ENVELOPE_CYCLE_RAMP_DOWN_TRIANGLE			=$0A '\/\/\/\
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",721
	;[722] CONST PSG_ENVELOPE_SINGLE_SHOT_RAMP_DOWN_AND_MAX	=$0B '\^^^^^^
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",722
	;[723] CONST PSG_ENVELOPE_CYCLE_RAMP_UP_SAWTOOTH			=$0C '///////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",723
	;[724] CONST PSG_ENVELOPE_SINGLE_SHOT_RAMP_UP_AND_MAX		=$0D '/^^^^^^
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",724
	;[725] CONST PSG_ENVELOPE_CYCLE_RAMP_UP_TRIANGLE			=$0E '/\/\/\/
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",725
	;[726] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",726
	;[727] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",727
	;[728] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",728
	;[729] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",729
	;[730] REM Useful functions.
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",730
	;[731] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",731
	;[732] DEF FN screenpos(aColumn, aRow)		= (((aRow)*BACKGROUND_COLUMNS)+(aColumn))
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",732
	;[733] DEF FN screenaddr(aColumn, aRow)	= (BACKTAB_ADDR+(((aRow)*BACKGROUND_COLUMNS)+(aColumn)))
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",733
	;[734] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",734
	;[735] DEF FN setspritex(aSpriteNo,anXPosition)	= #mobshadow(aSpriteNo)=(#mobshadow(aSpriteNo) and $ff00)+anXPosition
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",735
	;[736] DEF FN setspritey(aSpriteNo,aYPosition)		= #mobshadow(aSpriteNo+8)=(#mobshadow(aSpriteNo+8) and $ff80)+aYPosition
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",736
	;[737] DEF FN resetsprite(aSpriteNo)				= sprite aSpriteNo, 0, 0, 0
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",737
	;[738] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",738
	;[739] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",739
	;[740] 
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",740
	;[741] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",741
	;[742] REM END
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",742
	;[743] REM -------------------------------------------------------------------------
	SRCFILE "/Users/steveno/Desktop/IntyBASIC-2018/intybasic_compiler_v1.2.9/constants.bas",743
	;ENDFILE
	;FILE minty.bas
	;[13] 
	SRCFILE "minty.bas",13
	;[14] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",14
	;[15] REM Most of the maths is unsigned 
	SRCFILE "minty.bas",15
	;[16] 
	SRCFILE "minty.bas",16
	;[17]     UNSIGNED dataLen, i, inpLen, j, k, n, m, #marqPtr, marqIt
	SRCFILE "minty.bas",17
	;[18]     UNSIGNED #xl, #xh, #yl, #yh, #tl, #th
	SRCFILE "minty.bas",18
	;[19]     UNSIGNED #addr1, #addr2, #addr3, #tmp1
	SRCFILE "minty.bas",19
	;[20]     UNSIGNED #bitLen, #dataPtr, #inpPtr, #t1l, #t1h, #t2l, #t2h
	SRCFILE "minty.bas",20
	;[21]     UNSIGNED #noncel, #nonceh
	SRCFILE "minty.bas",21
	;[22]     UNSIGNED #marqOff, #marqTemp
	SRCFILE "minty.bas",22
	;[23]     
	SRCFILE "minty.bas",23
	;[24] 
	SRCFILE "minty.bas",24
	;[25] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",25
	;[26] REM Draw the screen, colour-stack with two tone green background
	SRCFILE "minty.bas",26
	;[27] 
	SRCFILE "minty.bas",27
	;[28]     Mode 0, 0, 0, 0, 0
	SRCFILE "minty.bas",28
	CLRR R0
	MVO R0,_color
	MVII #2,R0
	MVO R0,_mode_select
	;[29]     FOR i = 0 TO 59
	SRCFILE "minty.bas",29
	CLRR R0
	MVO R0,V1
T1:
	;[30]         WAIT
	SRCFILE "minty.bas",30
	CALL _wait
	;[31]     NEXT i
	SRCFILE "minty.bas",31
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMPI #59,R0
	BLE T1
	;[32] 
	SRCFILE "minty.bas",32
	;[33]     Mode 0, 4, 5, 4, 5
	SRCFILE "minty.bas",33
	MVII #17748,R0
	MVO R0,_color
	MVII #2,R0
	MVO R0,_mode_select
	;[34]     WAIT
	SRCFILE "minty.bas",34
	CALL _wait
	;[35] 
	SRCFILE "minty.bas",35
	;[36]     i = 0
	SRCFILE "minty.bas",36
	CLRR R0
	MVO R0,V1
	;[37]     FOR j = 0 TO 11
	SRCFILE "minty.bas",37
	MVO R0,V2
T2:
	;[38]     
	SRCFILE "minty.bas",38
	;[39]         POKE $201 + i, $2000
	SRCFILE "minty.bas",39
	MVII #8192,R0
	MVII #513,R1
	ADD V1,R1
	MVO@ R0,R1
	;[40]         POKE $200 + i, $25       
	SRCFILE "minty.bas",40
	MVII #37,R0
	MVII #512,R1
	ADD V1,R1
	MVO@ R0,R1
	;[41]         POKE $213 + i, $2025
	SRCFILE "minty.bas",41
	MVII #8229,R0
	MVII #531,R1
	ADD V1,R1
	MVO@ R0,R1
	;[42]         i = i + 20        
	SRCFILE "minty.bas",42
	MVI V1,R0
	ADDI #20,R0
	MVO R0,V1
	;[43]     
	SRCFILE "minty.bas",43
	;[44]     NEXT j
	SRCFILE "minty.bas",44
	MVI V2,R0
	INCR R0
	MVO R0,V2
	CMPI #11,R0
	BLE T2
	;[45]     
	SRCFILE "minty.bas",45
	;[46]     FOR j = 0 TO 15
	SRCFILE "minty.bas",46
	CLRR R0
	MVO R0,V2
T3:
	;[47]         POKE $200 + 42 + j, $648 + 4
	SRCFILE "minty.bas",47
	MVII #1612,R0
	MVII #554,R1
	ADD V2,R1
	MVO@ R0,R1
	;[48]     NEXT j
	SRCFILE "minty.bas",48
	MVI V2,R0
	INCR R0
	MVO R0,V2
	CMPI #15,R0
	BLE T3
	;[49] 
	SRCFILE "minty.bas",49
	;[50]     Print At 82 Color 7, "Nonce:"
	SRCFILE "minty.bas",50
	MVII #594,R0
	MVO R0,_screen
	MVII #7,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #368,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #776,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #760,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[51]     Print At 122 Color 7, "Last hash:"
	SRCFILE "minty.bas",51
	MVII #634,R0
	MVO R0,_screen
	MVII #7,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #352,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #872,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #672,R0
	MVO@ R0,R4
	XORI #576,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #656,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[52]     
	SRCFILE "minty.bas",52
	;[53]     m = 0
	SRCFILE "minty.bas",53
	CLRR R0
	MVO R0,V3
	;[54]     #marqPtr = 0 
	SRCFILE "minty.bas",54
	MVO R0,V4
	;[55]     
	SRCFILE "minty.bas",55
	;[56]     GOSUB marqUpdate
	SRCFILE "minty.bas",56
	CALL Q3
	;[57] 
	SRCFILE "minty.bas",57
	;[58]     skipToEnd = 0
	SRCFILE "minty.bas",58
	CLRR R0
	MVO R0,V5
	;[59]     
	SRCFILE "minty.bas",59
	;[60] 
	SRCFILE "minty.bas",60
	;[61] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",61
	;[62] REM Play the music
	SRCFILE "minty.bas",62
	;[63] 
	SRCFILE "minty.bas",63
	;[64]     Wait
	SRCFILE "minty.bas",64
	CALL _wait
	;[65]     Play Full
	SRCFILE "minty.bas",65
	MVII #5,R3
	MVO R3,_music_mode
	;[66]     Play Music
	SRCFILE "minty.bas",66
	MVII #Q4,R0
	CALL _play_music
	;[67] 
	SRCFILE "minty.bas",67
	;[68] 
	SRCFILE "minty.bas",68
	;[69] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",69
	;[70] REM MAIN LOOP interating over nonce values hashing
	SRCFILE "minty.bas",70
	;[71] 
	SRCFILE "minty.bas",71
	;[72] REM Outer, high word nonce loop
	SRCFILE "minty.bas",72
	;[73] 
	SRCFILE "minty.bas",73
	;[74]     FOR #nonceh = $0 TO $ffff
	SRCFILE "minty.bas",74
	CLRR R0
	MVO R0,V6
T4:
	;[75]     
	SRCFILE "minty.bas",75
	;[76]         #addr1 = $200 + 89
	SRCFILE "minty.bas",76
	MVII #601,R0
	MVO R0,V7
	;[77]         #tmp1 = #nonceh
	SRCFILE "minty.bas",77
	MVI V6,R0
	MVO R0,V8
	;[78]         GOSUB writeWord
	SRCFILE "minty.bas",78
	CALL Q5
	;[79] 
	SRCFILE "minty.bas",79
	;[80]         POKE $944f, #nonceh / 256
	SRCFILE "minty.bas",80
	MVI V6,R0
	SWAP R0
	ANDI #255,R0
	MVII #37967,R1
	MVO@ R0,R1
	;[81]         POKE $944e, #nonceh AND 255
	SRCFILE "minty.bas",81
	MVI V6,R0
	ANDI #255,R0
	MVII #37966,R1
	MVO@ R0,R1
	;[82]     
	SRCFILE "minty.bas",82
	;[83] REM Inner, low word nonce loop
	SRCFILE "minty.bas",83
	;[84] 
	SRCFILE "minty.bas",84
	;[85]         FOR #noncel = $0 TO $ffff
	SRCFILE "minty.bas",85
	CLRR R0
	MVO R0,V9
T5:
	;[86]         
	SRCFILE "minty.bas",86
	;[87]             IF skipToEnd = 1 THEN
	SRCFILE "minty.bas",87
	MVI V5,R0
	CMPI #1,R0
	BNE T6
	;[88] 
	SRCFILE "minty.bas",88
	;[89]                 #nonceh = $3308
	SRCFILE "minty.bas",89
	MVII #13064,R0
	MVO R0,V6
	;[90]                 #addr1 = $200 + 89
	SRCFILE "minty.bas",90
	MVII #601,R0
	MVO R0,V7
	;[91]                 #tmp1 = #nonceh
	SRCFILE "minty.bas",91
	MVI V6,R0
	MVO R0,V8
	;[92]                 GOSUB writeWord
	SRCFILE "minty.bas",92
	CALL Q5
	;[93] 
	SRCFILE "minty.bas",93
	;[94]                 POKE $944f, #nonceh / 256
	SRCFILE "minty.bas",94
	MVI V6,R0
	SWAP R0
	ANDI #255,R0
	MVII #37967,R1
	MVO@ R0,R1
	;[95]                 POKE $944e, #nonceh AND 255
	SRCFILE "minty.bas",95
	MVI V6,R0
	ANDI #255,R0
	MVII #37966,R1
	MVO@ R0,R1
	;[96] 
	SRCFILE "minty.bas",96
	;[97]                 #noncel = $7548
	SRCFILE "minty.bas",97
	MVII #30024,R0
	MVO R0,V9
	;[98] 
	SRCFILE "minty.bas",98
	;[99]                 PRINT At 102 Color 3, "Skip to the end"
	SRCFILE "minty.bas",99
	MVII #614,R0
	MVO R0,_screen
	MVII #3,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #960,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #640,R0
	MVO@ R0,R4
	XORI #672,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #632,R0
	MVO@ R0,R4
	XORI #672,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #552,R0
	MVO@ R0,R4
	XORI #552,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[100] 
	SRCFILE "minty.bas",100
	;[101]             END IF
	SRCFILE "minty.bas",101
T6:
	;[102] 
	SRCFILE "minty.bas",102
	;[103]             #addr1 = $200 + 93
	SRCFILE "minty.bas",103
	MVII #605,R0
	MVO R0,V7
	;[104]             #tmp1 = #noncel
	SRCFILE "minty.bas",104
	MVI V9,R0
	MVO R0,V8
	;[105]             GOSUB writeWord
	SRCFILE "minty.bas",105
	CALL Q5
	;[106] 
	SRCFILE "minty.bas",106
	;[107]             POKE $944d, #noncel / 256
	SRCFILE "minty.bas",107
	MVI V9,R0
	SWAP R0
	ANDI #255,R0
	MVII #37965,R1
	MVO@ R0,R1
	;[108]             POKE $944c, #noncel AND 255
	SRCFILE "minty.bas",108
	MVI V9,R0
	ANDI #255,R0
	MVII #37964,R1
	MVO@ R0,R1
	;[109]         
	SRCFILE "minty.bas",109
	;[110] REM Go hash!
	SRCFILE "minty.bas",110
	;[111] 
	SRCFILE "minty.bas",111
	;[112]             inpLen = 80
	SRCFILE "minty.bas",112
	MVII #80,R0
	MVO R0,V10
	;[113]             #inpPtr = $9400
	SRCFILE "minty.bas",113
	MVII #37888,R0
	MVO R0,V11
	;[114]             GOSUB shaDigest
	SRCFILE "minty.bas",114
	CALL Q6
	;[115] 
	SRCFILE "minty.bas",115
	;[116]             inpLen = 32
	SRCFILE "minty.bas",116
	MVII #32,R0
	MVO R0,V10
	;[117]             #inpPtr = $9040
	SRCFILE "minty.bas",117
	MVII #36928,R0
	MVO R0,V11
	;[118]             GOSUB shaDigest
	SRCFILE "minty.bas",118
	CALL Q6
	;[119]             
	SRCFILE "minty.bas",119
	;[120] REM Write resulting has to the screen
	SRCFILE "minty.bas",120
	;[121] 
	SRCFILE "minty.bas",121
	;[122]             #addr1 = $905f
	SRCFILE "minty.bas",122
	MVII #36959,R0
	MVO R0,V7
	;[123]             i = 0
	SRCFILE "minty.bas",123
	CLRR R0
	MVO R0,V1
	;[124]             
	SRCFILE "minty.bas",124
	;[125]             #addr2 = $905f
	SRCFILE "minty.bas",125
	MVII #36959,R0
	MVO R0,V12
	;[126]             #addr1 = $200 + 142
	SRCFILE "minty.bas",126
	MVII #654,R0
	MVO R0,V7
	;[127]             FOR i = 0 TO 3
	SRCFILE "minty.bas",127
	CLRR R0
	MVO R0,V1
T7:
	;[128]             
	SRCFILE "minty.bas",128
	;[129]                 FOR j = 0 TO 7
	SRCFILE "minty.bas",129
	CLRR R0
	MVO R0,V2
T8:
	;[130] 
	SRCFILE "minty.bas",130
	;[131]                     #tmp1 = PEEK(#addr2)
	SRCFILE "minty.bas",131
	MVI V12,R1
	MVI@ R1,R0
	MVO R0,V8
	;[132]                     GOSUB writeByte
	SRCFILE "minty.bas",132
	CALL Q7
	;[133]                     #addr1 = #addr1 + 2
	SRCFILE "minty.bas",133
	MVI V7,R0
	ADDI #2,R0
	MVO R0,V7
	;[134]                     #addr2 = #addr2 - 1
	SRCFILE "minty.bas",134
	MVI V12,R0
	DECR R0
	MVO R0,V12
	;[135]                     
	SRCFILE "minty.bas",135
	;[136]                 NEXT j
	SRCFILE "minty.bas",136
	MVI V2,R0
	INCR R0
	MVO R0,V2
	CMPI #7,R0
	BLE T8
	;[137]                 
	SRCFILE "minty.bas",137
	;[138]                 #addr1 = #addr1 + 4                
	SRCFILE "minty.bas",138
	MVI V7,R0
	ADDI #4,R0
	MVO R0,V7
	;[139]                 
	SRCFILE "minty.bas",139
	;[140]             NEXT i
	SRCFILE "minty.bas",140
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMPI #3,R0
	BLE T7
	;[141]             
	SRCFILE "minty.bas",141
	;[142]             #addr1 = $905f
	SRCFILE "minty.bas",142
	MVII #36959,R0
	MVO R0,V7
	;[143]             
	SRCFILE "minty.bas",143
	;[144] REM Check for leading zeros in the hash
	SRCFILE "minty.bas",144
	;[145] 
	SRCFILE "minty.bas",145
	;[146] leadingZero:
	SRCFILE "minty.bas",146
	; LEADINGZERO
Q8:	;[147] 
	SRCFILE "minty.bas",147
	;[148]             IF (PEEK(#addr1) = 0) THEN
	SRCFILE "minty.bas",148
	MVI V7,R1
	MVI@ R1,R0
	TSTR R0
	BNE T9
	;[149]                 i = i + 1
	SRCFILE "minty.bas",149
	MVI V1,R0
	INCR R0
	MVO R0,V1
	;[150]                 #addr1 = #addr1 - 1
	SRCFILE "minty.bas",150
	MOVR R1,R0
	DECR R0
	MVO R0,V7
	;[151]                 GOTO leadingZero
	SRCFILE "minty.bas",151
	B Q8
	;[152]             END IF
	SRCFILE "minty.bas",152
T9:
	;[153]             
	SRCFILE "minty.bas",153
	;[154]             IF (i > 7) THEN
	SRCFILE "minty.bas",154
	MVI V1,R0
	CMPI #7,R0
	BLE T10
	;[155]                 GOTO found
	SRCFILE "minty.bas",155
	B Q9
	;[156]             END IF
	SRCFILE "minty.bas",156
T10:
	;[157]             
	SRCFILE "minty.bas",157
	;[158]         NEXT #noncel
	SRCFILE "minty.bas",158
	MVI V9,R0
	INCR R0
	MVO R0,V9
	CMPI #65535,R0
	BEQ T5
	BNC T5
	;[159]         
	SRCFILE "minty.bas",159
	;[160]     NEXT #nonceh
	SRCFILE "minty.bas",160
	MVI V6,R0
	INCR R0
	MVO R0,V6
	CMPI #65535,R0
	BEQ T4
	BNC T4
	;[161]                 
	SRCFILE "minty.bas",161
	;[162] done:
	SRCFILE "minty.bas",162
	; DONE
Q10:	;[163] 
	SRCFILE "minty.bas",163
	;[164]     FOR i = 0 TO 12
	SRCFILE "minty.bas",164
	CLRR R0
	MVO R0,V1
T11:
	;[165]         WAIT
	SRCFILE "minty.bas",165
	CALL _wait
	;[166]     NEXT i
	SRCFILE "minty.bas",166
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMPI #12,R0
	BLE T11
	;[167]     
	SRCFILE "minty.bas",167
	;[168]     GOSUB marqUpdate
	SRCFILE "minty.bas",168
	CALL Q3
	;[169]     GOTO done
	SRCFILE "minty.bas",169
	B Q10
	;[170] 
	SRCFILE "minty.bas",170
	;[171] 
	SRCFILE "minty.bas",171
	;[172] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",172
	;[173] REM A coin is found!
	SRCFILE "minty.bas",173
	;[174] 
	SRCFILE "minty.bas",174
	;[175] found:
	SRCFILE "minty.bas",175
	; FOUND
Q9:	;[176] 
	SRCFILE "minty.bas",176
	;[177]     #yl = 0
	SRCFILE "minty.bas",177
	CLRR R0
	MVO R0,V13
	;[178]     PRINT At 102 Color 6, "!! COIN FOUND !!"
	SRCFILE "minty.bas",178
	MVII #614,R0
	MVO R0,_screen
	MVII #6,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #8,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #280,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #304,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
	;[179]     GOTO done
	SRCFILE "minty.bas",179
	B Q10
	;[180] 
	SRCFILE "minty.bas",180
	;[181] 
	SRCFILE "minty.bas",181
	;[182] 
	SRCFILE "minty.bas",182
	;[183] REM DONE MAIN LOOP
	SRCFILE "minty.bas",183
	;[184] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",184
	;[185] REM SUBROUTINES FROM HERE ON
	SRCFILE "minty.bas",185
	;[186] 
	SRCFILE "minty.bas",186
	;[187] 
	SRCFILE "minty.bas",187
	;[188] 
	SRCFILE "minty.bas",188
	;[189] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",189
	;[190] REM Add a 32 bit number in X to Y storing the result in Y
	SRCFILE "minty.bas",190
	;[191] addxy: PROCEDURE
	SRCFILE "minty.bas",191
	; ADDXY
Q12:	PROC
	BEGIN
	;[192] 
	SRCFILE "minty.bas",192
	;[193]     IF (#xl + #yl < #xl) THEN #yh = #yh + #xh + 1 ELSE #yh = #yh + #xh
	SRCFILE "minty.bas",193
	MVI V14,R0
	ADD V13,R0
	CMP V14,R0
	BC T12
	MVI V15,R0
	ADD V16,R0
	INCR R0
	MVO R0,V15
	B T13
T12:
	MVI V15,R0
	ADD V16,R0
	MVO R0,V15
T13:
	;[194]     #yl = #yl + #xl
	SRCFILE "minty.bas",194
	MVI V13,R0
	ADD V14,R0
	MVO R0,V13
	;[195] 
	SRCFILE "minty.bas",195
	;[196]     RETURN
	SRCFILE "minty.bas",196
	RETURN
	;[197]     
	SRCFILE "minty.bas",197
	;[198]     END
	SRCFILE "minty.bas",198
	ENDP
	;[199] 
	SRCFILE "minty.bas",199
	;[200] 
	SRCFILE "minty.bas",200
	;[201] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",201
	;[202] REM AND a 32 bit number in X to Y storing the result in Y
	SRCFILE "minty.bas",202
	;[203] andxy: PROCEDURE
	SRCFILE "minty.bas",203
	; ANDXY
Q13:	PROC
	BEGIN
	;[204] 
	SRCFILE "minty.bas",204
	;[205]     #yl = #yl AND #xl
	SRCFILE "minty.bas",205
	MVI V13,R0
	AND V14,R0
	MVO R0,V13
	;[206]     #yh = #yh AND #xh
	SRCFILE "minty.bas",206
	MVI V15,R0
	AND V16,R0
	MVO R0,V15
	;[207] 
	SRCFILE "minty.bas",207
	;[208]     RETURN
	SRCFILE "minty.bas",208
	RETURN
	;[209]     
	SRCFILE "minty.bas",209
	;[210]     END
	SRCFILE "minty.bas",210
	ENDP
	;[211] 
	SRCFILE "minty.bas",211
	;[212] 
	SRCFILE "minty.bas",212
	;[213] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",213
	;[214] REM CH - (x & y) ^ (~x & z) 
	SRCFILE "minty.bas",214
	;[215] ch: PROCEDURE
	SRCFILE "minty.bas",215
	; CH
Q14:	PROC
	BEGIN
	;[216] 
	SRCFILE "minty.bas",216
	;[217]     #ad = #addr1
	SRCFILE "minty.bas",217
	MVI V7,R0
	MVO R0,V17
	;[218]     GOSUB ldx
	SRCFILE "minty.bas",218
	CALL Q15
	;[219]     #ad = #addr2
	SRCFILE "minty.bas",219
	MVI V12,R0
	MVO R0,V17
	;[220]     GOSUB ldy
	SRCFILE "minty.bas",220
	CALL Q16
	;[221]     GOSUB andxy
	SRCFILE "minty.bas",221
	CALL Q13
	;[222]     GOSUB myt
	SRCFILE "minty.bas",222
	CALL Q17
	;[223]     GOSUB notx
	SRCFILE "minty.bas",223
	CALL Q18
	;[224]     #ad = #addr3
	SRCFILE "minty.bas",224
	MVI V18,R0
	MVO R0,V17
	;[225]     GOSUB ldy
	SRCFILE "minty.bas",225
	CALL Q16
	;[226]     GOSUB andxy
	SRCFILE "minty.bas",226
	CALL Q13
	;[227]     GOSUB xorty
	SRCFILE "minty.bas",227
	CALL Q19
	;[228]     
	SRCFILE "minty.bas",228
	;[229]     RETURN
	SRCFILE "minty.bas",229
	RETURN
	;[230]     
	SRCFILE "minty.bas",230
	;[231]     END
	SRCFILE "minty.bas",231
	ENDP
	;[232] 
	SRCFILE "minty.bas",232
	;[233] 
	SRCFILE "minty.bas",233
	;[234] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",234
	;[235] REM EPO - rotr(x, 2) ^ rotr(x, 13) ^ rotr(x, 22)
	SRCFILE "minty.bas",235
	;[236] ep0: PROCEDURE
	SRCFILE "minty.bas",236
	; EP0
Q20:	PROC
	BEGIN
	;[237] 
	SRCFILE "minty.bas",237
	;[238]     #ad = #addr1
	SRCFILE "minty.bas",238
	MVI V7,R0
	MVO R0,V17
	;[239]     GOSUB ldx
	SRCFILE "minty.bas",239
	CALL Q15
	;[240]     GOSUB mxy
	SRCFILE "minty.bas",240
	CALL Q21
	;[241]     n = 2
	SRCFILE "minty.bas",241
	MVII #2,R0
	MVO R0,V19
	;[242]     GOSUB rotrxn
	SRCFILE "minty.bas",242
	CALL Q22
	;[243]     n = 13
	SRCFILE "minty.bas",243
	MVII #13,R0
	MVO R0,V19
	;[244]     GOSUB rotryn
	SRCFILE "minty.bas",244
	CALL Q23
	;[245]     GOSUB xorxy
	SRCFILE "minty.bas",245
	CALL Q24
	;[246]     GOSUB ldx
	SRCFILE "minty.bas",246
	CALL Q15
	;[247]     n = 22
	SRCFILE "minty.bas",247
	MVII #22,R0
	MVO R0,V19
	;[248]     GOSUB rotrxn
	SRCFILE "minty.bas",248
	CALL Q22
	;[249]     GOSUB xorxy
	SRCFILE "minty.bas",249
	CALL Q24
	;[250]             
	SRCFILE "minty.bas",250
	;[251]     RETURN
	SRCFILE "minty.bas",251
	RETURN
	;[252]     
	SRCFILE "minty.bas",252
	;[253]     END
	SRCFILE "minty.bas",253
	ENDP
	;[254] 
	SRCFILE "minty.bas",254
	;[255] 
	SRCFILE "minty.bas",255
	;[256] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",256
	;[257] REM EP1 - rotr(x, 6) ^ rotr(x, 11) ^ rotr(x, 25)
	SRCFILE "minty.bas",257
	;[258] ep1: PROCEDURE
	SRCFILE "minty.bas",258
	; EP1
Q25:	PROC
	BEGIN
	;[259] 
	SRCFILE "minty.bas",259
	;[260]     #ad = #addr1
	SRCFILE "minty.bas",260
	MVI V7,R0
	MVO R0,V17
	;[261]     GOSUB ldx
	SRCFILE "minty.bas",261
	CALL Q15
	;[262]     GOSUB mxy
	SRCFILE "minty.bas",262
	CALL Q21
	;[263]     n = 6
	SRCFILE "minty.bas",263
	MVII #6,R0
	MVO R0,V19
	;[264]     GOSUB rotrxn
	SRCFILE "minty.bas",264
	CALL Q22
	;[265]     n = 11
	SRCFILE "minty.bas",265
	MVII #11,R0
	MVO R0,V19
	;[266]     GOSUB rotryn
	SRCFILE "minty.bas",266
	CALL Q23
	;[267]     GOSUB xorxy
	SRCFILE "minty.bas",267
	CALL Q24
	;[268]     GOSUB ldx
	SRCFILE "minty.bas",268
	CALL Q15
	;[269]     n = 25
	SRCFILE "minty.bas",269
	MVII #25,R0
	MVO R0,V19
	;[270]     GOSUB rotrxn
	SRCFILE "minty.bas",270
	CALL Q22
	;[271]     GOSUB xorxy
	SRCFILE "minty.bas",271
	CALL Q24
	;[272]             
	SRCFILE "minty.bas",272
	;[273]     RETURN
	SRCFILE "minty.bas",273
	RETURN
	;[274]     
	SRCFILE "minty.bas",274
	;[275]     END
	SRCFILE "minty.bas",275
	ENDP
	;[276] 
	SRCFILE "minty.bas",276
	;[277] 
	SRCFILE "minty.bas",277
	;[278] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",278
	;[279] REM Load a 32bit number from #ad into X
	SRCFILE "minty.bas",279
	;[280] ldx: PROCEDURE
	SRCFILE "minty.bas",280
	; LDX
Q15:	PROC
	BEGIN
	;[281] 
	SRCFILE "minty.bas",281
	;[282]     #xl = PEEK(#ad)
	SRCFILE "minty.bas",282
	MVI V17,R1
	MVI@ R1,R0
	MVO R0,V14
	;[283]     #xh = PEEK(#ad + 1)
	SRCFILE "minty.bas",283
	INCR R1
	MVI@ R1,R0
	MVO R0,V16
	;[284] 
	SRCFILE "minty.bas",284
	;[285]     RETURN
	SRCFILE "minty.bas",285
	RETURN
	;[286] 
	SRCFILE "minty.bas",286
	;[287]     END
	SRCFILE "minty.bas",287
	ENDP
	;[288] 
	SRCFILE "minty.bas",288
	;[289] 
	SRCFILE "minty.bas",289
	;[290] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",290
	;[291] REM Load a 32bit number from #ad into Y
	SRCFILE "minty.bas",291
	;[292] ldy: PROCEDURE
	SRCFILE "minty.bas",292
	; LDY
Q16:	PROC
	BEGIN
	;[293] 
	SRCFILE "minty.bas",293
	;[294]     #yl = PEEK(#ad)
	SRCFILE "minty.bas",294
	MVI V17,R1
	MVI@ R1,R0
	MVO R0,V13
	;[295]     #yh = PEEK(#ad + 1)
	SRCFILE "minty.bas",295
	INCR R1
	MVI@ R1,R0
	MVO R0,V15
	;[296] 
	SRCFILE "minty.bas",296
	;[297]     RETURN
	SRCFILE "minty.bas",297
	RETURN
	;[298] 
	SRCFILE "minty.bas",298
	;[299]     END
	SRCFILE "minty.bas",299
	ENDP
	;[300] 
	SRCFILE "minty.bas",300
	;[301] 
	SRCFILE "minty.bas",301
	;[302] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",302
	;[303] REM MAJ - (x & y) ^ (x & z)  ^ (y & z)
	SRCFILE "minty.bas",303
	;[304] maj: PROCEDURE
	SRCFILE "minty.bas",304
	; MAJ
Q28:	PROC
	BEGIN
	;[305] 
	SRCFILE "minty.bas",305
	;[306]     #ad = #addr1
	SRCFILE "minty.bas",306
	MVI V7,R0
	MVO R0,V17
	;[307]     GOSUB ldx
	SRCFILE "minty.bas",307
	CALL Q15
	;[308]     #ad = #addr2
	SRCFILE "minty.bas",308
	MVI V12,R0
	MVO R0,V17
	;[309]     GOSUB ldy
	SRCFILE "minty.bas",309
	CALL Q16
	;[310]     GOSUB andxy
	SRCFILE "minty.bas",310
	CALL Q13
	;[311]     GOSUB myt
	SRCFILE "minty.bas",311
	CALL Q17
	;[312]     
	SRCFILE "minty.bas",312
	;[313]     #ad = #addr3
	SRCFILE "minty.bas",313
	MVI V18,R0
	MVO R0,V17
	;[314]     GOSUB ldy
	SRCFILE "minty.bas",314
	CALL Q16
	;[315]     GOSUB andxy
	SRCFILE "minty.bas",315
	CALL Q13
	;[316]     GOSUB xorty
	SRCFILE "minty.bas",316
	CALL Q19
	;[317]     GOSUB myt
	SRCFILE "minty.bas",317
	CALL Q17
	;[318]     
	SRCFILE "minty.bas",318
	;[319]     #ad = #addr2
	SRCFILE "minty.bas",319
	MVI V12,R0
	MVO R0,V17
	;[320]     GOSUB ldx
	SRCFILE "minty.bas",320
	CALL Q15
	;[321]     #ad = #addr3
	SRCFILE "minty.bas",321
	MVI V18,R0
	MVO R0,V17
	;[322]     GOSUB ldy
	SRCFILE "minty.bas",322
	CALL Q16
	;[323]     GOSUB andxy
	SRCFILE "minty.bas",323
	CALL Q13
	;[324]     GOSUB xorty
	SRCFILE "minty.bas",324
	CALL Q19
	;[325]         
	SRCFILE "minty.bas",325
	;[326]     RETURN
	SRCFILE "minty.bas",326
	RETURN
	;[327]     
	SRCFILE "minty.bas",327
	;[328]     END
	SRCFILE "minty.bas",328
	ENDP
	;[329] 
	SRCFILE "minty.bas",329
	;[330] 
	SRCFILE "minty.bas",330
	;[331] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",331
	;[332] REM Update the marquee
	SRCFILE "minty.bas",332
	;[333] marqUpdate: PROCEDURE
	SRCFILE "minty.bas",333
	; MARQUPDATE
Q3:	PROC
	BEGIN
	;[334] 
	SRCFILE "minty.bas",334
	;[335]     #marqOff = $9980 + #marqPtr
	SRCFILE "minty.bas",335
	MVII #39296,R0
	ADD V4,R0
	MVO R0,V20
	;[336]     FOR marqIt = 0 TO 15
	SRCFILE "minty.bas",336
	CLRR R0
	MVO R0,V21
T14:
	;[337]     
	SRCFILE "minty.bas",337
	;[338]         #marqTemp = PEEK(#marqOff + marqIt)
	SRCFILE "minty.bas",338
	MVI V20,R1
	ADD V21,R1
	MVI@ R1,R0
	MVO R0,V22
	;[339]         IF (#marqTemp = 0) THEN
	SRCFILE "minty.bas",339
	TSTR R0
	BNE T15
	;[340]             #marqOff = $9980 - marqIt
	SRCFILE "minty.bas",340
	MVII #39296,R0
	SUB V21,R0
	MVO R0,V20
	;[341]             #marqTemp = PEEK(#marqOff + marqIt)    
	SRCFILE "minty.bas",341
	MOVR R0,R1
	ADD V21,R1
	MVI@ R1,R0
	MVO R0,V22
	;[342]         END IF
	SRCFILE "minty.bas",342
T15:
	;[343]         
	SRCFILE "minty.bas",343
	;[344]         POKE $200 + 22 + marqIt, #marqTemp 
	SRCFILE "minty.bas",344
	MVI V22,R0
	MVII #534,R1
	ADD V21,R1
	MVO@ R0,R1
	;[345]         
	SRCFILE "minty.bas",345
	;[346]     NEXT marqIt
	SRCFILE "minty.bas",346
	MVI V21,R0
	INCR R0
	MVO R0,V21
	CMPI #15,R0
	BLE T14
	;[347]     
	SRCFILE "minty.bas",347
	;[348]     IF (#yl AND 1) = 0 THEN
	SRCFILE "minty.bas",348
	MVI V13,R0
	ANDI #1,R0
	BNE T16
	;[349]     
	SRCFILE "minty.bas",349
	;[350]         FOR m = 220 TO 20 STEP - 20
	SRCFILE "minty.bas",350
	MVII #220,R0
	MVO R0,V3
T17:
	;[351]             POKE $200 + m, PEEK($1ec + m)
	SRCFILE "minty.bas",351
	MVII #492,R1
	ADD V3,R1
	MVI@ R1,R0
	MVII #512,R1
	ADD V3,R1
	MVO@ R0,R1
	;[352]         NEXT m
	SRCFILE "minty.bas",352
	MVI V3,R0
	SUBI #20,R0
	MVO R0,V3
	CMPI #20,R0
	BGE T17
	;[353]         
	SRCFILE "minty.bas",353
	;[354]         IF ((#yl AND 6) = 0) OR (CONT1.LEFT <> 0) OR (CONT2.LEFT <> 0) THEN 
	SRCFILE "minty.bas",354
	MVI V13,R0
	ANDI #6,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI 511,R1
	COMR R1
	ANDI #8,R1
	MVII #-1,R1
	BNE $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI 510,R1
	COMR R1
	ANDI #8,R1
	MVII #-1,R1
	BNE $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T18
	;[355]             POKE $200, $27 
	SRCFILE "minty.bas",355
	MVII #39,R0
	MVII #512,R1
	MVO@ R0,R1
	;[356]         ELSE
	SRCFILE "minty.bas",356
	B T19
T18:
	;[357]             POKE $200, $25
	SRCFILE "minty.bas",357
	MVII #37,R0
	MVII #512,R1
	MVO@ R0,R1
	;[358]         END IF
	SRCFILE "minty.bas",358
T19:
	;[359]     
	SRCFILE "minty.bas",359
	;[360]     END IF
	SRCFILE "minty.bas",360
T16:
	;[361] 
	SRCFILE "minty.bas",361
	;[362]     IF (#yl AND $10) = 0 THEN
	SRCFILE "minty.bas",362
	MVI V13,R0
	ANDI #16,R0
	BNE T20
	;[363]     
	SRCFILE "minty.bas",363
	;[364]         FOR m = 220 TO 20 STEP - 20
	SRCFILE "minty.bas",364
	MVII #220,R0
	MVO R0,V3
T21:
	;[365]             POKE $213 + m, PEEK($1ff + m)
	SRCFILE "minty.bas",365
	MVII #511,R1
	ADD V3,R1
	MVI@ R1,R0
	MVII #531,R1
	ADD V3,R1
	MVO@ R0,R1
	;[366]         NEXT m
	SRCFILE "minty.bas",366
	MVI V3,R0
	SUBI #20,R0
	MVO R0,V3
	CMPI #20,R0
	BGE T21
	;[367]         
	SRCFILE "minty.bas",367
	;[368]         IF ((#yl AND $60) = 0) OR (CONT1.RIGHT <> 0) OR (CONT2.RIGHT <> 0) THEN 
	SRCFILE "minty.bas",368
	MVI V13,R0
	ANDI #96,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI 511,R1
	COMR R1
	ANDI #2,R1
	MVII #-1,R1
	BNE $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI 510,R1
	COMR R1
	ANDI #2,R1
	MVII #-1,R1
	BNE $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T22
	;[369]             POKE $213, $2027
	SRCFILE "minty.bas",369
	MVII #8231,R0
	MVII #531,R1
	MVO@ R0,R1
	;[370]         ELSE 
	SRCFILE "minty.bas",370
	B T23
T22:
	;[371]             POKE $213, $2025
	SRCFILE "minty.bas",371
	MVII #8229,R0
	MVII #531,R1
	MVO@ R0,R1
	;[372]         END IF
	SRCFILE "minty.bas",372
T23:
	;[373]     
	SRCFILE "minty.bas",373
	;[374]     END IF
	SRCFILE "minty.bas",374
T20:
	;[375] 
	SRCFILE "minty.bas",375
	;[376]     #marqPtr = #marqPtr + 1
	SRCFILE "minty.bas",376
	MVI V4,R0
	INCR R0
	MVO R0,V4
	;[377]     IF (PEEK($9980 + #marqPtr) = 0) THEN #marqPtr = 0
	SRCFILE "minty.bas",377
	MVII #39296,R1
	ADDR R0,R1
	MVI@ R1,R0
	TSTR R0
	BNE T24
	MVO R0,V4
T24:
	;[378]     m = 0
	SRCFILE "minty.bas",378
	CLRR R0
	MVO R0,V3
	;[379]     
	SRCFILE "minty.bas",379
	;[380]     if (CONT1.DOWN <> 0) OR (CONT2.DOWN <> 0) THEN
	SRCFILE "minty.bas",380
	MVI 511,R0
	COMR R0
	ANDI #1,R0
	MVII #-1,R0
	BNE $+3
	INCR R0
	MVI 510,R1
	COMR R1
	ANDI #1,R1
	MVII #-1,R1
	BNE $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T25
	;[381]         skipToEnd = 1
	SRCFILE "minty.bas",381
	MVII #1,R0
	MVO R0,V5
	;[382]         PRINT At 103 Color 3, "Skip requested"
	SRCFILE "minty.bas",382
	MVII #615,R0
	MVO R0,_screen
	MVII #3,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #960,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #640,R0
	MVO@ R0,R4
	XORI #656,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #160,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[383]     END IF
	SRCFILE "minty.bas",383
T25:
	;[384] 
	SRCFILE "minty.bas",384
	;[385]     RETURN
	SRCFILE "minty.bas",385
	RETURN
	;[386]     
	SRCFILE "minty.bas",386
	;[387]     END
	SRCFILE "minty.bas",387
	ENDP
	;[388]     
	SRCFILE "minty.bas",388
	;[389] 
	SRCFILE "minty.bas",389
	;[390] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",390
	;[391] REM Move a 32bit number from X to T
	SRCFILE "minty.bas",391
	;[392] mxt: PROCEDURE
	SRCFILE "minty.bas",392
	; MXT
Q30:	PROC
	BEGIN
	;[393] 
	SRCFILE "minty.bas",393
	;[394]     #tl = #xl
	SRCFILE "minty.bas",394
	MVI V14,R0
	MVO R0,V23
	;[395]     #th = #xh
	SRCFILE "minty.bas",395
	MVI V16,R0
	MVO R0,V24
	;[396] 
	SRCFILE "minty.bas",396
	;[397]     RETURN
	SRCFILE "minty.bas",397
	RETURN
	;[398] 
	SRCFILE "minty.bas",398
	;[399]     END
	SRCFILE "minty.bas",399
	ENDP
	;[400] 
	SRCFILE "minty.bas",400
	;[401] 
	SRCFILE "minty.bas",401
	;[402] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",402
	;[403] REM Move a 32bit number from X to Y
	SRCFILE "minty.bas",403
	;[404] mxy: PROCEDURE
	SRCFILE "minty.bas",404
	; MXY
Q21:	PROC
	BEGIN
	;[405] 
	SRCFILE "minty.bas",405
	;[406]     #yl = #xl
	SRCFILE "minty.bas",406
	MVI V14,R0
	MVO R0,V13
	;[407]     #yh = #xh
	SRCFILE "minty.bas",407
	MVI V16,R0
	MVO R0,V15
	;[408] 
	SRCFILE "minty.bas",408
	;[409]     RETURN
	SRCFILE "minty.bas",409
	RETURN
	;[410] 
	SRCFILE "minty.bas",410
	;[411]     END
	SRCFILE "minty.bas",411
	ENDP
	;[412] 
	SRCFILE "minty.bas",412
	;[413] 
	SRCFILE "minty.bas",413
	;[414] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",414
	;[415] REM Move a 32bit number from Y to T
	SRCFILE "minty.bas",415
	;[416] myt: PROCEDURE
	SRCFILE "minty.bas",416
	; MYT
Q17:	PROC
	BEGIN
	;[417] 
	SRCFILE "minty.bas",417
	;[418]     #tl = #yl
	SRCFILE "minty.bas",418
	MVI V13,R0
	MVO R0,V23
	;[419]     #th = #yh
	SRCFILE "minty.bas",419
	MVI V15,R0
	MVO R0,V24
	;[420] 
	SRCFILE "minty.bas",420
	;[421]     RETURN
	SRCFILE "minty.bas",421
	RETURN
	;[422] 
	SRCFILE "minty.bas",422
	;[423]     END
	SRCFILE "minty.bas",423
	ENDP
	;[424] 
	SRCFILE "minty.bas",424
	;[425] 
	SRCFILE "minty.bas",425
	;[426] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",426
	;[427] REM Logical NOT a 32 bit number in X
	SRCFILE "minty.bas",427
	;[428] notx: PROCEDURE
	SRCFILE "minty.bas",428
	; NOTX
Q18:	PROC
	BEGIN
	;[429] 
	SRCFILE "minty.bas",429
	;[430]     #xl = NOT #xl
	SRCFILE "minty.bas",430
	MVI V14,R0
	COMR R0
	MVO R0,V14
	;[431]     #xh = NOT #xh
	SRCFILE "minty.bas",431
	MVI V16,R0
	COMR R0
	MVO R0,V16
	;[432] 
	SRCFILE "minty.bas",432
	;[433]     RETURN
	SRCFILE "minty.bas",433
	RETURN
	;[434]     
	SRCFILE "minty.bas",434
	;[435]     END
	SRCFILE "minty.bas",435
	ENDP
	;[436] 
	SRCFILE "minty.bas",436
	;[437] 
	SRCFILE "minty.bas",437
	;[438] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",438
	;[439] REM Logical OR a 32 bit number in T to X storing the result in X
	SRCFILE "minty.bas",439
	;[440] ortx: PROCEDURE
	SRCFILE "minty.bas",440
	; ORTX
Q34:	PROC
	BEGIN
	;[441] 
	SRCFILE "minty.bas",441
	;[442]     #xl = #xl OR #tl
	SRCFILE "minty.bas",442
	MVI V14,R0
	MVI V23,R4
	COMR R4
	ANDR R4,R0
	XOR V23,R0
	MVO R0,V14
	;[443]     #xh = #xh OR #th
	SRCFILE "minty.bas",443
	MVI V16,R0
	MVI V24,R4
	COMR R4
	ANDR R4,R0
	XOR V24,R0
	MVO R0,V16
	;[444] 
	SRCFILE "minty.bas",444
	;[445]     RETURN
	SRCFILE "minty.bas",445
	RETURN
	;[446]     
	SRCFILE "minty.bas",446
	;[447]     END
	SRCFILE "minty.bas",447
	ENDP
	;[448] 
	SRCFILE "minty.bas",448
	;[449] 
	SRCFILE "minty.bas",449
	;[450] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",450
	;[451] REM Logical OR a 32 bit number in T to Y storing the result in Y
	SRCFILE "minty.bas",451
	;[452] orty: PROCEDURE
	SRCFILE "minty.bas",452
	; ORTY
Q35:	PROC
	BEGIN
	;[453] 
	SRCFILE "minty.bas",453
	;[454]     #yl = #yl OR #tl
	SRCFILE "minty.bas",454
	MVI V13,R0
	MVI V23,R4
	COMR R4
	ANDR R4,R0
	XOR V23,R0
	MVO R0,V13
	;[455]     #yh = #yh OR #th
	SRCFILE "minty.bas",455
	MVI V15,R0
	MVI V24,R4
	COMR R4
	ANDR R4,R0
	XOR V24,R0
	MVO R0,V15
	;[456] 
	SRCFILE "minty.bas",456
	;[457]     RETURN
	SRCFILE "minty.bas",457
	RETURN
	;[458]     
	SRCFILE "minty.bas",458
	;[459]     END
	SRCFILE "minty.bas",459
	ENDP
	;[460] 
	SRCFILE "minty.bas",460
	;[461] 
	SRCFILE "minty.bas",461
	;[462] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",462
	;[463] REM Rotate a 32 bit number in X right by n positions
	SRCFILE "minty.bas",463
	;[464] rotrxn: PROCEDURE
	SRCFILE "minty.bas",464
	; ROTRXN
Q22:	PROC
	BEGIN
	;[465] 
	SRCFILE "minty.bas",465
	;[466]     GOSUB mxt
	SRCFILE "minty.bas",466
	CALL Q30
	;[467]     GOSUB slrxn
	SRCFILE "minty.bas",467
	CALL Q37
	;[468]     n = 32 - n
	SRCFILE "minty.bas",468
	MVII #32,R0
	SUB V19,R0
	MVO R0,V19
	;[469]     GOSUB slltn
	SRCFILE "minty.bas",469
	CALL Q38
	;[470]     n = 32 - n
	SRCFILE "minty.bas",470
	MVII #32,R0
	SUB V19,R0
	MVO R0,V19
	;[471]     GOSUB ortx
	SRCFILE "minty.bas",471
	CALL Q34
	;[472]     
	SRCFILE "minty.bas",472
	;[473]     RETURN
	SRCFILE "minty.bas",473
	RETURN
	;[474] 
	SRCFILE "minty.bas",474
	;[475]     END
	SRCFILE "minty.bas",475
	ENDP
	;[476] 
	SRCFILE "minty.bas",476
	;[477] 
	SRCFILE "minty.bas",477
	;[478] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",478
	;[479] REM Rotate a 32 bit number in Y right by n positions
	SRCFILE "minty.bas",479
	;[480] rotryn: PROCEDURE
	SRCFILE "minty.bas",480
	; ROTRYN
Q23:	PROC
	BEGIN
	;[481] 
	SRCFILE "minty.bas",481
	;[482]     GOSUB myt
	SRCFILE "minty.bas",482
	CALL Q17
	;[483]     GOSUB slryn
	SRCFILE "minty.bas",483
	CALL Q40
	;[484]     n = 32 - n
	SRCFILE "minty.bas",484
	MVII #32,R0
	SUB V19,R0
	MVO R0,V19
	;[485]     GOSUB slltn
	SRCFILE "minty.bas",485
	CALL Q38
	;[486]     n = 32 - n
	SRCFILE "minty.bas",486
	MVII #32,R0
	SUB V19,R0
	MVO R0,V19
	;[487]     GOSUB orty
	SRCFILE "minty.bas",487
	CALL Q35
	;[488]     
	SRCFILE "minty.bas",488
	;[489]     RETURN
	SRCFILE "minty.bas",489
	RETURN
	;[490] 
	SRCFILE "minty.bas",490
	;[491]     END
	SRCFILE "minty.bas",491
	ENDP
	;[492] 
	SRCFILE "minty.bas",492
	;[493] 
	SRCFILE "minty.bas",493
	;[494] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",494
	;[495] REM Evaluate a SHA digest
	SRCFILE "minty.bas",495
	;[496] shaDigest: PROCEDURE  
	SRCFILE "minty.bas",496
	; SHADIGEST
Q6:	PROC
	BEGIN
	;[497]     
	SRCFILE "minty.bas",497
	;[498]     FOR i = 0 TO inpLen - 1
	SRCFILE "minty.bas",498
	CLRR R0
	MVO R0,V1
T26:
	;[499]         POKE $9100 + i, PEEK(#inpPtr + i)
	SRCFILE "minty.bas",499
	MVI V11,R1
	ADD V1,R1
	MVI@ R1,R0
	MVII #37120,R1
	ADD V1,R1
	MVO@ R0,R1
	;[500]     NEXT i
	SRCFILE "minty.bas",500
	MVI V1,R0
	INCR R0
	MVO R0,V1
	MVI V10,R1
	DECR R1
	CMPR R1,R0
	BLE T26
	;[501]     
	SRCFILE "minty.bas",501
	;[502]     GOSUB shaInit
	SRCFILE "minty.bas",502
	CALL Q42
	;[503]     GOSUB shaUpdate
	SRCFILE "minty.bas",503
	CALL Q43
	;[504]     GOSUB shaFinal
	SRCFILE "minty.bas",504
	CALL Q44
	;[505] 
	SRCFILE "minty.bas",505
	;[506]     #addr1 = $9040
	SRCFILE "minty.bas",506
	MVII #36928,R0
	MVO R0,V7
	;[507]     FOR j = 0 TO 14 STEP 2
	SRCFILE "minty.bas",507
	CLRR R0
	MVO R0,V2
T27:
	;[508]     
	SRCFILE "minty.bas",508
	;[509]         POKE #addr1, PEEK($9001 + j) / 256
	SRCFILE "minty.bas",509
	MVII #36865,R1
	ADD V2,R1
	MVI@ R1,R0
	SWAP R0
	ANDI #255,R0
	MVI V7,R1
	MVO@ R0,R1
	;[510]         #addr1 = #addr1 + 1
	SRCFILE "minty.bas",510
	MOVR R1,R0
	INCR R0
	MVO R0,V7
	;[511]         POKE #addr1, PEEK($9001 + j) AND 255
	SRCFILE "minty.bas",511
	MVII #36865,R1
	ADD V2,R1
	MVI@ R1,R0
	ANDI #255,R0
	MVI V7,R1
	MVO@ R0,R1
	;[512]         #addr1 = #addr1 + 1
	SRCFILE "minty.bas",512
	MOVR R1,R0
	INCR R0
	MVO R0,V7
	;[513]         POKE #addr1, PEEK($9000 + j) / 256
	SRCFILE "minty.bas",513
	MVII #36864,R1
	ADD V2,R1
	MVI@ R1,R0
	SWAP R0
	ANDI #255,R0
	MVI V7,R1
	MVO@ R0,R1
	;[514]         #addr1 = #addr1 + 1
	SRCFILE "minty.bas",514
	MOVR R1,R0
	INCR R0
	MVO R0,V7
	;[515]         POKE #addr1, PEEK($9000 + j) AND 255
	SRCFILE "minty.bas",515
	MVII #36864,R1
	ADD V2,R1
	MVI@ R1,R0
	ANDI #255,R0
	MVI V7,R1
	MVO@ R0,R1
	;[516]         #addr1 = #addr1 + 1
	SRCFILE "minty.bas",516
	MOVR R1,R0
	INCR R0
	MVO R0,V7
	;[517]         
	SRCFILE "minty.bas",517
	;[518]     NEXT j
	SRCFILE "minty.bas",518
	MVI V2,R0
	ADDI #2,R0
	MVO R0,V2
	CMPI #14,R0
	BLE T27
	;[519] 
	SRCFILE "minty.bas",519
	;[520]     RETURN
	SRCFILE "minty.bas",520
	RETURN
	;[521]     
	SRCFILE "minty.bas",521
	;[522]     END
	SRCFILE "minty.bas",522
	ENDP
	;[523] 
	SRCFILE "minty.bas",523
	;[524] 
	SRCFILE "minty.bas",524
	;[525] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",525
	;[526] REM Initialise the SHA algorithm
	SRCFILE "minty.bas",526
	;[527] shaInit: PROCEDURE
	SRCFILE "minty.bas",527
	; SHAINIT
Q42:	PROC
	BEGIN
	;[528] 
	SRCFILE "minty.bas",528
	;[529]     dataLen = 0
	SRCFILE "minty.bas",529
	CLRR R0
	MVO R0,V25
	;[530]     #bitLen = 0
	SRCFILE "minty.bas",530
	MVO R0,V26
	;[531]     
	SRCFILE "minty.bas",531
	;[532]     POKE $9000, $e667
	SRCFILE "minty.bas",532
	MVII #58983,R0
	MVII #36864,R1
	MVO@ R0,R1
	;[533]     POKE $9001, $6a09
	SRCFILE "minty.bas",533
	MVII #27145,R0
	MVII #36865,R1
	MVO@ R0,R1
	;[534] 
	SRCFILE "minty.bas",534
	;[535]     POKE $9002, $ae85
	SRCFILE "minty.bas",535
	MVII #44677,R0
	MVII #36866,R1
	MVO@ R0,R1
	;[536]     POKE $9003, $bb67
	SRCFILE "minty.bas",536
	MVII #47975,R0
	MVII #36867,R1
	MVO@ R0,R1
	;[537] 
	SRCFILE "minty.bas",537
	;[538]     POKE $9004, $f372
	SRCFILE "minty.bas",538
	MVII #62322,R0
	MVII #36868,R1
	MVO@ R0,R1
	;[539]     POKE $9005, $3c6e
	SRCFILE "minty.bas",539
	MVII #15470,R0
	MVII #36869,R1
	MVO@ R0,R1
	;[540] 
	SRCFILE "minty.bas",540
	;[541]     POKE $9006, $f53a
	SRCFILE "minty.bas",541
	MVII #62778,R0
	MVII #36870,R1
	MVO@ R0,R1
	;[542]     POKE $9007, $a54f
	SRCFILE "minty.bas",542
	MVII #42319,R0
	MVII #36871,R1
	MVO@ R0,R1
	;[543]     
	SRCFILE "minty.bas",543
	;[544]     POKE $9008, $527f
	SRCFILE "minty.bas",544
	MVII #21119,R0
	MVII #36872,R1
	MVO@ R0,R1
	;[545]     POKE $9009, $510e
	SRCFILE "minty.bas",545
	MVII #20750,R0
	MVII #36873,R1
	MVO@ R0,R1
	;[546]     
	SRCFILE "minty.bas",546
	;[547]     POKE $900a, $688c
	SRCFILE "minty.bas",547
	MVII #26764,R0
	MVII #36874,R1
	MVO@ R0,R1
	;[548]     POKE $900b, $9b05
	SRCFILE "minty.bas",548
	MVII #39685,R0
	MVII #36875,R1
	MVO@ R0,R1
	;[549]     
	SRCFILE "minty.bas",549
	;[550]     POKE $900c, $d9ab
	SRCFILE "minty.bas",550
	MVII #55723,R0
	MVII #36876,R1
	MVO@ R0,R1
	;[551]     POKE $900d, $1f83
	SRCFILE "minty.bas",551
	MVII #8067,R0
	MVII #36877,R1
	MVO@ R0,R1
	;[552]     
	SRCFILE "minty.bas",552
	;[553]     POKE $900e, $cd19
	SRCFILE "minty.bas",553
	MVII #52505,R0
	MVII #36878,R1
	MVO@ R0,R1
	;[554]     POKE $900f, $5be0
	SRCFILE "minty.bas",554
	MVII #23520,R0
	MVII #36879,R1
	MVO@ R0,R1
	;[555]     
	SRCFILE "minty.bas",555
	;[556]     RETURN
	SRCFILE "minty.bas",556
	RETURN
	;[557]     
	SRCFILE "minty.bas",557
	;[558]     END
	SRCFILE "minty.bas",558
	ENDP
	;[559] 
	SRCFILE "minty.bas",559
	;[560] 
	SRCFILE "minty.bas",560
	;[561] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",561
	;[562] REM Transform SHA state with additional data
	SRCFILE "minty.bas",562
	;[563] shaTransform: PROCEDURE
	SRCFILE "minty.bas",563
	; SHATRANSFORM
Q46:	PROC
	BEGIN
	;[564] 
	SRCFILE "minty.bas",564
	;[565]     #mPtr = $9300
	SRCFILE "minty.bas",565
	MVII #37632,R0
	MVO R0,V27
	;[566]     #dataPtr = $9200
	SRCFILE "minty.bas",566
	MVII #37376,R0
	MVO R0,V28
	;[567]     FOR j = 0 TO 15
	SRCFILE "minty.bas",567
	CLRR R0
	MVO R0,V2
T28:
	;[568]     
	SRCFILE "minty.bas",568
	;[569]         POKE #mPtr, PEEK(#dataPtr + 2) * 256 + PEEK(#dataPtr + 3)
	SRCFILE "minty.bas",569
	MVI V28,R1
	ADDI #2,R1
	MVI@ R1,R0
	SWAP R0
	ANDI #65280,R0
	MVI V28,R1
	ADDI #3,R1
	ADD@ R1,R0
	MVI V27,R1
	MVO@ R0,R1
	;[570]         #mPtr = #mPtr + 1
	SRCFILE "minty.bas",570
	MOVR R1,R0
	INCR R0
	MVO R0,V27
	;[571] 
	SRCFILE "minty.bas",571
	;[572]         POKE #mPtr,  PEEK(#dataPtr) * 256 + PEEK(#dataPtr + 1)
	SRCFILE "minty.bas",572
	MVI V28,R1
	MVI@ R1,R0
	SWAP R0
	ANDI #65280,R0
	INCR R1
	ADD@ R1,R0
	MVI V27,R1
	MVO@ R0,R1
	;[573]         #mPtr = #mPtr + 1
	SRCFILE "minty.bas",573
	MOVR R1,R0
	INCR R0
	MVO R0,V27
	;[574]         
	SRCFILE "minty.bas",574
	;[575]         #dataPtr = #dataPtr + 4
	SRCFILE "minty.bas",575
	MVI V28,R0
	ADDI #4,R0
	MVO R0,V28
	;[576]     
	SRCFILE "minty.bas",576
	;[577]     NEXT j
	SRCFILE "minty.bas",577
	MVI V2,R0
	INCR R0
	MVO R0,V2
	CMPI #15,R0
	BLE T28
	;[578]     
	SRCFILE "minty.bas",578
	;[579]     FOR j = 16 TO 63
	SRCFILE "minty.bas",579
	MVII #16,R0
	MVO R0,V2
T29:
	;[580]     
	SRCFILE "minty.bas",580
	;[581]         m = m + 1
	SRCFILE "minty.bas",581
	MVI V3,R0
	INCR R0
	MVO R0,V3
	;[582]         IF (m = 4) THEN GOSUB marqUpdate
	SRCFILE "minty.bas",582
	MVI V3,R0
	CMPI #4,R0
	BNE T30
	CALL Q3
T30:
	;[583]     
	SRCFILE "minty.bas",583
	;[584]         #addr1 = #mPtr - 4
	SRCFILE "minty.bas",584
	MVI V27,R0
	SUBI #4,R0
	MVO R0,V7
	;[585]         GOSUB sig1
	SRCFILE "minty.bas",585
	CALL Q47
	;[586] 
	SRCFILE "minty.bas",586
	;[587]         #xl = PEEK(#mPtr - 14)
	SRCFILE "minty.bas",587
	MVI V27,R1
	SUBI #14,R1
	MVI@ R1,R0
	MVO R0,V14
	;[588]         #xh = PEEK(#mPtr - 13)
	SRCFILE "minty.bas",588
	MVI V27,R1
	SUBI #13,R1
	MVI@ R1,R0
	MVO R0,V16
	;[589]         GOSUB addxy
	SRCFILE "minty.bas",589
	CALL Q12
	;[590]         
	SRCFILE "minty.bas",590
	;[591]         #t1l = #yl
	SRCFILE "minty.bas",591
	MVI V13,R0
	MVO R0,V29
	;[592]         #t1h = #yh
	SRCFILE "minty.bas",592
	MVI V15,R0
	MVO R0,V30
	;[593]                     
	SRCFILE "minty.bas",593
	;[594]         #addr1 = #mPtr - 30
	SRCFILE "minty.bas",594
	MVI V27,R0
	SUBI #30,R0
	MVO R0,V7
	;[595]         GOSUB sig0
	SRCFILE "minty.bas",595
	CALL Q48
	;[596]         
	SRCFILE "minty.bas",596
	;[597]         #xl = #t1l
	SRCFILE "minty.bas",597
	MVI V29,R0
	MVO R0,V14
	;[598]         #xh = #t1h
	SRCFILE "minty.bas",598
	MVI V30,R0
	MVO R0,V16
	;[599]         GOSUB addxy        
	SRCFILE "minty.bas",599
	CALL Q12
	;[600]         
	SRCFILE "minty.bas",600
	;[601]         #xl = PEEK(#mPtr - 32)
	SRCFILE "minty.bas",601
	MVI V27,R1
	SUBI #32,R1
	MVI@ R1,R0
	MVO R0,V14
	;[602]         #xh = PEEK(#mPtr - 31)
	SRCFILE "minty.bas",602
	MVI V27,R1
	SUBI #31,R1
	MVI@ R1,R0
	MVO R0,V16
	;[603]         GOSUB addxy
	SRCFILE "minty.bas",603
	CALL Q12
	;[604]         
	SRCFILE "minty.bas",604
	;[605]         POKE #mPtr, #yl
	SRCFILE "minty.bas",605
	MVI V13,R0
	MVI V27,R1
	MVO@ R0,R1
	;[606]         #mPtr = #mPtr + 1
	SRCFILE "minty.bas",606
	MOVR R1,R0
	INCR R0
	MVO R0,V27
	;[607]         
	SRCFILE "minty.bas",607
	;[608]         POKE #mPtr, #yh
	SRCFILE "minty.bas",608
	MVI V15,R0
	MVI V27,R1
	MVO@ R0,R1
	;[609]         #mPtr = #mPtr + 1
	SRCFILE "minty.bas",609
	MOVR R1,R0
	INCR R0
	MVO R0,V27
	;[610]         
	SRCFILE "minty.bas",610
	;[611]     NEXT j
	SRCFILE "minty.bas",611
	MVI V2,R0
	INCR R0
	MVO R0,V2
	CMPI #63,R0
	BLE T29
	;[612]     
	SRCFILE "minty.bas",612
	;[613]     REM a = ctx->state[0]; etc 
	SRCFILE "minty.bas",613
	;[614]     
	SRCFILE "minty.bas",614
	;[615]     FOR j = 0 TO 15
	SRCFILE "minty.bas",615
	CLRR R0
	MVO R0,V2
T31:
	;[616]         POKE $9010 + j, PEEK($9000 + j)
	SRCFILE "minty.bas",616
	MVII #36864,R1
	ADD V2,R1
	MVI@ R1,R0
	MVII #36880,R1
	ADD V2,R1
	MVO@ R0,R1
	;[617]     NEXT j
	SRCFILE "minty.bas",617
	MVI V2,R0
	INCR R0
	MVO R0,V2
	CMPI #15,R0
	BLE T31
	;[618] 
	SRCFILE "minty.bas",618
	;[619] 
	SRCFILE "minty.bas",619
	;[620]     FOR j = 0 TO 126 STEP 2
	SRCFILE "minty.bas",620
	CLRR R0
	MVO R0,V2
T32:
	;[621]     
	SRCFILE "minty.bas",621
	;[622]         m = m + 1
	SRCFILE "minty.bas",622
	MVI V3,R0
	INCR R0
	MVO R0,V3
	;[623]         IF (m = 3) THEN GOSUB marqUpdate
	SRCFILE "minty.bas",623
	MVI V3,R0
	CMPI #3,R0
	BNE T33
	CALL Q3
T33:
	;[624]         
	SRCFILE "minty.bas",624
	;[625]         REM t1 = h + EP1(e) + CH(e,f,g) + k[j] + m[j];
	SRCFILE "minty.bas",625
	;[626]         
	SRCFILE "minty.bas",626
	;[627]         #addr1 = $9018
	SRCFILE "minty.bas",627
	MVII #36888,R0
	MVO R0,V7
	;[628]         GOSUB ep1
	SRCFILE "minty.bas",628
	CALL Q25
	;[629]         
	SRCFILE "minty.bas",629
	;[630]         #xl = PEEK($901e)
	SRCFILE "minty.bas",630
	MVI 36894,R0
	MVO R0,V14
	;[631]         #xh = PEEK($901f)
	SRCFILE "minty.bas",631
	MVI 36895,R0
	MVO R0,V16
	;[632]         GOSUB addxy
	SRCFILE "minty.bas",632
	CALL Q12
	;[633]         #t1l = #yl
	SRCFILE "minty.bas",633
	MVI V13,R0
	MVO R0,V29
	;[634]         #t1h = #yh
	SRCFILE "minty.bas",634
	MVI V15,R0
	MVO R0,V30
	;[635]         
	SRCFILE "minty.bas",635
	;[636]         #addr1 = $9018
	SRCFILE "minty.bas",636
	MVII #36888,R0
	MVO R0,V7
	;[637]         #addr2 = $901a
	SRCFILE "minty.bas",637
	MVII #36890,R0
	MVO R0,V12
	;[638]         #addr3 = $901c
	SRCFILE "minty.bas",638
	MVII #36892,R0
	MVO R0,V18
	;[639]         GOSUB ch
	SRCFILE "minty.bas",639
	CALL Q14
	;[640]         #xl = #t1l
	SRCFILE "minty.bas",640
	MVI V29,R0
	MVO R0,V14
	;[641]         #xh = #t1h
	SRCFILE "minty.bas",641
	MVI V30,R0
	MVO R0,V16
	;[642]         GOSUB addxy
	SRCFILE "minty.bas",642
	CALL Q12
	;[643] 
	SRCFILE "minty.bas",643
	;[644]         #xl = PEEK($9800 + j)
	SRCFILE "minty.bas",644
	MVII #38912,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V14
	;[645]         #xh = PEEK($9801 + j)
	SRCFILE "minty.bas",645
	MVII #38913,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V16
	;[646]         GOSUB addxy
	SRCFILE "minty.bas",646
	CALL Q12
	;[647]         
	SRCFILE "minty.bas",647
	;[648]         #xl = PEEK($9300 + j)
	SRCFILE "minty.bas",648
	MVII #37632,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V14
	;[649]         #xh = PEEK($9301 + j)
	SRCFILE "minty.bas",649
	MVII #37633,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V16
	;[650]         GOSUB addxy
	SRCFILE "minty.bas",650
	CALL Q12
	;[651]         
	SRCFILE "minty.bas",651
	;[652]         #t1l = #yl
	SRCFILE "minty.bas",652
	MVI V13,R0
	MVO R0,V29
	;[653]         #t1h = #yh
	SRCFILE "minty.bas",653
	MVI V15,R0
	MVO R0,V30
	;[654]                
	SRCFILE "minty.bas",654
	;[655]         REM t2 = EP0(a) + MAJ(a,b,c);
	SRCFILE "minty.bas",655
	;[656]         
	SRCFILE "minty.bas",656
	;[657]         #addr1 = $9010
	SRCFILE "minty.bas",657
	MVII #36880,R0
	MVO R0,V7
	;[658]         GOSUB ep0
	SRCFILE "minty.bas",658
	CALL Q20
	;[659]         #t2l = #yl
	SRCFILE "minty.bas",659
	MVI V13,R0
	MVO R0,V31
	;[660]         #t2h = #yh
	SRCFILE "minty.bas",660
	MVI V15,R0
	MVO R0,V32
	;[661]         
	SRCFILE "minty.bas",661
	;[662]         #addr1 = $9010
	SRCFILE "minty.bas",662
	MVII #36880,R0
	MVO R0,V7
	;[663]         #addr2 = $9012
	SRCFILE "minty.bas",663
	MVII #36882,R0
	MVO R0,V12
	;[664]         #addr3 = $9014
	SRCFILE "minty.bas",664
	MVII #36884,R0
	MVO R0,V18
	;[665]         GOSUB maj
	SRCFILE "minty.bas",665
	CALL Q28
	;[666]         #xl = #t2l
	SRCFILE "minty.bas",666
	MVI V31,R0
	MVO R0,V14
	;[667]         #xh = #t2h
	SRCFILE "minty.bas",667
	MVI V32,R0
	MVO R0,V16
	;[668]         GOSUB addxy
	SRCFILE "minty.bas",668
	CALL Q12
	;[669]         #t2l = #yl
	SRCFILE "minty.bas",669
	MVI V13,R0
	MVO R0,V31
	;[670]         #t2h = #yh        
	SRCFILE "minty.bas",670
	MVI V15,R0
	MVO R0,V32
	;[671] 
	SRCFILE "minty.bas",671
	;[672]         REM h = g;
	SRCFILE "minty.bas",672
	;[673] 
	SRCFILE "minty.bas",673
	;[674]         POKE $901e, PEEK($901c)
	SRCFILE "minty.bas",674
	MVI 36892,R0
	MVII #36894,R1
	MVO@ R0,R1
	;[675]         POKE $901f, PEEK($901d)
	SRCFILE "minty.bas",675
	MVI 36893,R0
	MVII #36895,R1
	MVO@ R0,R1
	;[676]         
	SRCFILE "minty.bas",676
	;[677]         REM g = f;
	SRCFILE "minty.bas",677
	;[678] 	
	SRCFILE "minty.bas",678
	;[679]         POKE $901c, PEEK($901a)
	SRCFILE "minty.bas",679
	MVI 36890,R0
	MVII #36892,R1
	MVO@ R0,R1
	;[680]         POKE $901d, PEEK($901b)
	SRCFILE "minty.bas",680
	MVI 36891,R0
	MVII #36893,R1
	MVO@ R0,R1
	;[681] 
	SRCFILE "minty.bas",681
	;[682]         REM f = e;
	SRCFILE "minty.bas",682
	;[683]         
	SRCFILE "minty.bas",683
	;[684]         POKE $901a, PEEK($9018)
	SRCFILE "minty.bas",684
	MVI 36888,R0
	MVII #36890,R1
	MVO@ R0,R1
	;[685]         POKE $901b, PEEK($9019)
	SRCFILE "minty.bas",685
	MVI 36889,R0
	MVII #36891,R1
	MVO@ R0,R1
	;[686] 
	SRCFILE "minty.bas",686
	;[687] 	REM e = d + t1;
	SRCFILE "minty.bas",687
	;[688]         
	SRCFILE "minty.bas",688
	;[689]         #xl = PEEK($9016)
	SRCFILE "minty.bas",689
	MVI 36886,R0
	MVO R0,V14
	;[690]         #xh = PEEK($9017)
	SRCFILE "minty.bas",690
	MVI 36887,R0
	MVO R0,V16
	;[691]         #yl = #t1l
	SRCFILE "minty.bas",691
	MVI V29,R0
	MVO R0,V13
	;[692]         #yh = #t1h
	SRCFILE "minty.bas",692
	MVI V30,R0
	MVO R0,V15
	;[693]         GOSUB addxy
	SRCFILE "minty.bas",693
	CALL Q12
	;[694]         POKE $9018, #yl
	SRCFILE "minty.bas",694
	MVI V13,R0
	MVII #36888,R1
	MVO@ R0,R1
	;[695]         POKE $9019, #yh
	SRCFILE "minty.bas",695
	MVI V15,R0
	MVII #36889,R1
	MVO@ R0,R1
	;[696]         
	SRCFILE "minty.bas",696
	;[697]         REM d = c;
	SRCFILE "minty.bas",697
	;[698]                 
	SRCFILE "minty.bas",698
	;[699]         POKE $9016, PEEK($9014)
	SRCFILE "minty.bas",699
	MVI 36884,R0
	MVII #36886,R1
	MVO@ R0,R1
	;[700]         POKE $9017, PEEK($9015)
	SRCFILE "minty.bas",700
	MVI 36885,R0
	MVII #36887,R1
	MVO@ R0,R1
	;[701] 
	SRCFILE "minty.bas",701
	;[702]         REM c = b;
	SRCFILE "minty.bas",702
	;[703]                 
	SRCFILE "minty.bas",703
	;[704]         POKE $9014, PEEK($9012)
	SRCFILE "minty.bas",704
	MVI 36882,R0
	MVII #36884,R1
	MVO@ R0,R1
	;[705]         POKE $9015, PEEK($9013)
	SRCFILE "minty.bas",705
	MVI 36883,R0
	MVII #36885,R1
	MVO@ R0,R1
	;[706] 
	SRCFILE "minty.bas",706
	;[707]         REM b = a;
	SRCFILE "minty.bas",707
	;[708]                 
	SRCFILE "minty.bas",708
	;[709]         POKE $9012, PEEK($9010)
	SRCFILE "minty.bas",709
	MVI 36880,R0
	MVII #36882,R1
	MVO@ R0,R1
	;[710]         POKE $9013, PEEK($9011)
	SRCFILE "minty.bas",710
	MVI 36881,R0
	MVII #36883,R1
	MVO@ R0,R1
	;[711]                 
	SRCFILE "minty.bas",711
	;[712]         REM a = t1 + t2;
	SRCFILE "minty.bas",712
	;[713]         
	SRCFILE "minty.bas",713
	;[714]         #xl = #t1l
	SRCFILE "minty.bas",714
	MVI V29,R0
	MVO R0,V14
	;[715]         #xh = #t1h
	SRCFILE "minty.bas",715
	MVI V30,R0
	MVO R0,V16
	;[716]         #yl = #t2l
	SRCFILE "minty.bas",716
	MVI V31,R0
	MVO R0,V13
	;[717]         #yh = #t2h
	SRCFILE "minty.bas",717
	MVI V32,R0
	MVO R0,V15
	;[718]         GOSUB addxy
	SRCFILE "minty.bas",718
	CALL Q12
	;[719]         POKE $9010, #yl
	SRCFILE "minty.bas",719
	MVI V13,R0
	MVII #36880,R1
	MVO@ R0,R1
	;[720]         POKE $9011, #yh
	SRCFILE "minty.bas",720
	MVI V15,R0
	MVII #36881,R1
	MVO@ R0,R1
	;[721]         
	SRCFILE "minty.bas",721
	;[722]     NEXT j
	SRCFILE "minty.bas",722
	MVI V2,R0
	ADDI #2,R0
	MVO R0,V2
	CMPI #126,R0
	BLE T32
	;[723] 
	SRCFILE "minty.bas",723
	;[724]     REM ctx->state[0] += a; etc 
	SRCFILE "minty.bas",724
	;[725] 
	SRCFILE "minty.bas",725
	;[726]     FOR j = 0 TO 14 STEP 2
	SRCFILE "minty.bas",726
	CLRR R0
	MVO R0,V2
T34:
	;[727]     
	SRCFILE "minty.bas",727
	;[728]         #xl = PEEK($9010 + j)
	SRCFILE "minty.bas",728
	MVII #36880,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V14
	;[729]         #xh = PEEK($9011 + j)
	SRCFILE "minty.bas",729
	MVII #36881,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V16
	;[730]         #yl = PEEK($9000 + j)
	SRCFILE "minty.bas",730
	MVII #36864,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V13
	;[731]         #yh = PEEK($9001 + j)
	SRCFILE "minty.bas",731
	MVII #36865,R1
	ADD V2,R1
	MVI@ R1,R0
	MVO R0,V15
	;[732]         GOSUB addxy
	SRCFILE "minty.bas",732
	CALL Q12
	;[733]         POKE $9000 + j, #yl
	SRCFILE "minty.bas",733
	MVI V13,R0
	MVII #36864,R1
	ADD V2,R1
	MVO@ R0,R1
	;[734]         POKE $9001 + j, #yh
	SRCFILE "minty.bas",734
	MVI V15,R0
	MVII #36865,R1
	ADD V2,R1
	MVO@ R0,R1
	;[735]         
	SRCFILE "minty.bas",735
	;[736]     NEXT j
	SRCFILE "minty.bas",736
	MVI V2,R0
	ADDI #2,R0
	MVO R0,V2
	CMPI #14,R0
	BLE T34
	;[737] 
	SRCFILE "minty.bas",737
	;[738]     RETURN
	SRCFILE "minty.bas",738
	RETURN
	;[739]     
	SRCFILE "minty.bas",739
	;[740]     END
	SRCFILE "minty.bas",740
	ENDP
	;[741] 
	SRCFILE "minty.bas",741
	;[742] 
	SRCFILE "minty.bas",742
	;[743] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",743
	;[744] REM Finalise SHA digest
	SRCFILE "minty.bas",744
	;[745] shaFinal: PROCEDURE
	SRCFILE "minty.bas",745
	; SHAFINAL
Q44:	PROC
	BEGIN
	;[746] 
	SRCFILE "minty.bas",746
	;[747]     POKE $9200 + dataLen, $80
	SRCFILE "minty.bas",747
	MVII #128,R0
	MVII #37376,R1
	ADD V25,R1
	MVO@ R0,R1
	;[748]     IF (dataLen < 56) THEN
	SRCFILE "minty.bas",748
	MVI V25,R0
	CMPI #56,R0
	BGE T35
	;[749]     
	SRCFILE "minty.bas",749
	;[750]         FOR i = dataLen + 1 TO 55
	SRCFILE "minty.bas",750
	INCR R0
	MVO R0,V1
T36:
	;[751]             POKE $9200 + i, $00
	SRCFILE "minty.bas",751
	CLRR R0
	MVII #37376,R1
	ADD V1,R1
	MVO@ R0,R1
	;[752]         NEXT i
	SRCFILE "minty.bas",752
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMPI #55,R0
	BLE T36
	;[753]     
	SRCFILE "minty.bas",753
	;[754]     ELSE
	SRCFILE "minty.bas",754
	B T37
T35:
	;[755]     
	SRCFILE "minty.bas",755
	;[756]         FOR i = datalen + 1 TO 63
	SRCFILE "minty.bas",756
	MVI V25,R0
	INCR R0
	MVO R0,V1
T38:
	;[757]             POKE $9200 + i, $00
	SRCFILE "minty.bas",757
	CLRR R0
	MVII #37376,R1
	ADD V1,R1
	MVO@ R0,R1
	;[758]         NEXT i
	SRCFILE "minty.bas",758
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMPI #63,R0
	BLE T38
	;[759]         
	SRCFILE "minty.bas",759
	;[760]         GOSUB shaTransform
	SRCFILE "minty.bas",760
	CALL Q46
	;[761]         
	SRCFILE "minty.bas",761
	;[762]         FOR i = 0 TO 55
	SRCFILE "minty.bas",762
	CLRR R0
	MVO R0,V1
T39:
	;[763]             POKE $9200 + i, $00
	SRCFILE "minty.bas",763
	CLRR R0
	MVII #37376,R1
	ADD V1,R1
	MVO@ R0,R1
	;[764]         NEXT i        
	SRCFILE "minty.bas",764
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMPI #55,R0
	BLE T39
	;[765]     
	SRCFILE "minty.bas",765
	;[766]     END IF
	SRCFILE "minty.bas",766
T37:
	;[767]     
	SRCFILE "minty.bas",767
	;[768]     #bitLen = #bitLen + (8 * dataLen)
	SRCFILE "minty.bas",768
	MVI V25,R0
	SLL R0,2
	ADDR R0,R0
	ADD V26,R0
	MVO R0,V26
	;[769]     POKE $9200 + 63, #bitLen AND $ff
	SRCFILE "minty.bas",769
	ANDI #255,R0
	MVII #37439,R1
	MVO@ R0,R1
	;[770]     POKE $9200 + 62, #bitLen / 256
	SRCFILE "minty.bas",770
	MVI V26,R0
	SWAP R0
	ANDI #255,R0
	MVII #37438,R1
	MVO@ R0,R1
	;[771]     POKE $9200 + 61, 0
	SRCFILE "minty.bas",771
	CLRR R0
	MVII #37437,R1
	MVO@ R0,R1
	;[772]     POKE $9200 + 60, 0
	SRCFILE "minty.bas",772
	MVII #37436,R1
	MVO@ R0,R1
	;[773]     POKE $9200 + 59, 0
	SRCFILE "minty.bas",773
	MVII #37435,R1
	MVO@ R0,R1
	;[774]     POKE $9200 + 58, 0
	SRCFILE "minty.bas",774
	MVII #37434,R1
	MVO@ R0,R1
	;[775]     POKE $9200 + 57, 0
	SRCFILE "minty.bas",775
	MVII #37433,R1
	MVO@ R0,R1
	;[776]     POKE $9200 + 56, 0
	SRCFILE "minty.bas",776
	MVII #37432,R1
	MVO@ R0,R1
	;[777]     GOSUB shaTransform
	SRCFILE "minty.bas",777
	CALL Q46
	;[778]     
	SRCFILE "minty.bas",778
	;[779]     RETURN
	SRCFILE "minty.bas",779
	RETURN
	;[780]     
	SRCFILE "minty.bas",780
	;[781]     END
	SRCFILE "minty.bas",781
	ENDP
	;[782]     
	SRCFILE "minty.bas",782
	;[783] 
	SRCFILE "minty.bas",783
	;[784] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",784
	;[785] REM Update SHA state with additional data
	SRCFILE "minty.bas",785
	;[786] shaUpdate: PROCEDURE
	SRCFILE "minty.bas",786
	; SHAUPDATE
Q43:	PROC
	BEGIN
	;[787] 
	SRCFILE "minty.bas",787
	;[788]     FOR k = 0 TO inpLen - 1
	SRCFILE "minty.bas",788
	CLRR R0
	MVO R0,V33
T40:
	;[789]     
	SRCFILE "minty.bas",789
	;[790]         POKE $9200 + dataLen, PEEK($9100 + k)
	SRCFILE "minty.bas",790
	MVII #37120,R1
	ADD V33,R1
	MVI@ R1,R0
	MVII #37376,R1
	ADD V25,R1
	MVO@ R0,R1
	;[791]         dataLen = dataLen + 1
	SRCFILE "minty.bas",791
	MVI V25,R0
	INCR R0
	MVO R0,V25
	;[792]         IF dataLen = 64 THEN
	SRCFILE "minty.bas",792
	MVI V25,R0
	CMPI #64,R0
	BNE T41
	;[793]         
	SRCFILE "minty.bas",793
	;[794]             GOSUB shaTransform
	SRCFILE "minty.bas",794
	CALL Q46
	;[795]             #bitLen = #bitLen + 512
	SRCFILE "minty.bas",795
	MVI V26,R0
	ADDI #512,R0
	MVO R0,V26
	;[796]             dataLen = 0
	SRCFILE "minty.bas",796
	CLRR R0
	MVO R0,V25
	;[797]         
	SRCFILE "minty.bas",797
	;[798]         END IF
	SRCFILE "minty.bas",798
T41:
	;[799]     
	SRCFILE "minty.bas",799
	;[800]     NEXT k
	SRCFILE "minty.bas",800
	MVI V33,R0
	INCR R0
	MVO R0,V33
	MVI V10,R1
	DECR R1
	CMPR R1,R0
	BLE T40
	;[801] 
	SRCFILE "minty.bas",801
	;[802]     RETURN
	SRCFILE "minty.bas",802
	RETURN
	;[803]     
	SRCFILE "minty.bas",803
	;[804]     END
	SRCFILE "minty.bas",804
	ENDP
	;[805] 
	SRCFILE "minty.bas",805
	;[806] 
	SRCFILE "minty.bas",806
	;[807] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",807
	;[808] REM SIG0 - rotr(x, 7) ^ rotr(x, 18) ^ slr(x, 3)
	SRCFILE "minty.bas",808
	;[809] sig0: PROCEDURE
	SRCFILE "minty.bas",809
	; SIG0
Q48:	PROC
	BEGIN
	;[810] 
	SRCFILE "minty.bas",810
	;[811]     #ad = #addr1
	SRCFILE "minty.bas",811
	MVI V7,R0
	MVO R0,V17
	;[812]     GOSUB ldx
	SRCFILE "minty.bas",812
	CALL Q15
	;[813]     GOSUB mxy
	SRCFILE "minty.bas",813
	CALL Q21
	;[814]     n = 7
	SRCFILE "minty.bas",814
	MVII #7,R0
	MVO R0,V19
	;[815]     GOSUB rotrxn
	SRCFILE "minty.bas",815
	CALL Q22
	;[816]     n = 18
	SRCFILE "minty.bas",816
	MVII #18,R0
	MVO R0,V19
	;[817]     GOSUB rotryn
	SRCFILE "minty.bas",817
	CALL Q23
	;[818]     GOSUB xorxy
	SRCFILE "minty.bas",818
	CALL Q24
	;[819]     GOSUB ldx
	SRCFILE "minty.bas",819
	CALL Q15
	;[820]     n = 3
	SRCFILE "minty.bas",820
	MVII #3,R0
	MVO R0,V19
	;[821]     GOSUB slrxn
	SRCFILE "minty.bas",821
	CALL Q37
	;[822]     GOSUB xorxy
	SRCFILE "minty.bas",822
	CALL Q24
	;[823]             
	SRCFILE "minty.bas",823
	;[824]     RETURN
	SRCFILE "minty.bas",824
	RETURN
	;[825]     
	SRCFILE "minty.bas",825
	;[826]     END
	SRCFILE "minty.bas",826
	ENDP
	;[827] 
	SRCFILE "minty.bas",827
	;[828] 
	SRCFILE "minty.bas",828
	;[829] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",829
	;[830] REM SIG1 - rotr(x, 17) ^ rotr(x, 19) ^ slr(x, 10)
	SRCFILE "minty.bas",830
	;[831] sig1: PROCEDURE
	SRCFILE "minty.bas",831
	; SIG1
Q47:	PROC
	BEGIN
	;[832] 
	SRCFILE "minty.bas",832
	;[833]     #ad = #addr1
	SRCFILE "minty.bas",833
	MVI V7,R0
	MVO R0,V17
	;[834]     GOSUB ldx
	SRCFILE "minty.bas",834
	CALL Q15
	;[835]     GOSUB mxy
	SRCFILE "minty.bas",835
	CALL Q21
	;[836]     n = 17
	SRCFILE "minty.bas",836
	MVII #17,R0
	MVO R0,V19
	;[837]     GOSUB rotrxn
	SRCFILE "minty.bas",837
	CALL Q22
	;[838]     n = 19
	SRCFILE "minty.bas",838
	MVII #19,R0
	MVO R0,V19
	;[839]     GOSUB rotryn
	SRCFILE "minty.bas",839
	CALL Q23
	;[840]     GOSUB xorxy
	SRCFILE "minty.bas",840
	CALL Q24
	;[841]     GOSUB ldx
	SRCFILE "minty.bas",841
	CALL Q15
	;[842]     n = 10
	SRCFILE "minty.bas",842
	MVII #10,R0
	MVO R0,V19
	;[843]     GOSUB slrxn
	SRCFILE "minty.bas",843
	CALL Q37
	;[844]     GOSUB xorxy
	SRCFILE "minty.bas",844
	CALL Q24
	;[845]             
	SRCFILE "minty.bas",845
	;[846]     RETURN
	SRCFILE "minty.bas",846
	RETURN
	;[847]     
	SRCFILE "minty.bas",847
	;[848]     END
	SRCFILE "minty.bas",848
	ENDP
	;[849] 
	SRCFILE "minty.bas",849
	;[850] 
	SRCFILE "minty.bas",850
	;[851] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",851
	;[852] REM Shift a 32 bit number in T left by one position
	SRCFILE "minty.bas",852
	;[853] sllt: PROCEDURE
	SRCFILE "minty.bas",853
	; SLLT
Q53:	PROC
	BEGIN
	;[854] 
	SRCFILE "minty.bas",854
	;[855]     IF (#tl * 2 < #tl) THEN
	SRCFILE "minty.bas",855
	MVI V23,R0
	SLL R0,1
	CMP V23,R0
	BC T42
	;[856]         #th = #th * 2 + 1
	SRCFILE "minty.bas",856
	MVI V24,R0
	SLL R0,1
	INCR R0
	MVO R0,V24
	;[857]     ELSE
	SRCFILE "minty.bas",857
	B T43
T42:
	;[858]         #th = #th * 2
	SRCFILE "minty.bas",858
	MVI V24,R0
	SLL R0,1
	MVO R0,V24
	;[859]     END IF
	SRCFILE "minty.bas",859
T43:
	;[860]     #tl = #tl * 2      
	SRCFILE "minty.bas",860
	MVI V23,R0
	SLL R0,1
	MVO R0,V23
	;[861] 
	SRCFILE "minty.bas",861
	;[862]     RETURN
	SRCFILE "minty.bas",862
	RETURN
	;[863] 
	SRCFILE "minty.bas",863
	;[864]     END
	SRCFILE "minty.bas",864
	ENDP
	;[865] 
	SRCFILE "minty.bas",865
	;[866] 
	SRCFILE "minty.bas",866
	;[867] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",867
	;[868] REM Shift a 32 bit number in T left by n positions
	SRCFILE "minty.bas",868
	;[869] slltn: PROCEDURE
	SRCFILE "minty.bas",869
	; SLLTN
Q38:	PROC
	BEGIN
	;[870] 
	SRCFILE "minty.bas",870
	;[871]     FOR i = 1 to n
	SRCFILE "minty.bas",871
	MVII #1,R0
	MVO R0,V1
T44:
	;[872]         GOSUB sllt
	SRCFILE "minty.bas",872
	CALL Q53
	;[873]     NEXT i
	SRCFILE "minty.bas",873
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMP V19,R0
	BLE T44
	;[874]     
	SRCFILE "minty.bas",874
	;[875]     RETURN
	SRCFILE "minty.bas",875
	RETURN
	;[876] 
	SRCFILE "minty.bas",876
	;[877]     END
	SRCFILE "minty.bas",877
	ENDP
	;[878] 
	SRCFILE "minty.bas",878
	;[879] 
	SRCFILE "minty.bas",879
	;[880] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",880
	;[881] REM Logical shift a 32 bit number in X right by one position
	SRCFILE "minty.bas",881
	;[882] slrx: PROCEDURE
	SRCFILE "minty.bas",882
	; SLRX
Q55:	PROC
	BEGIN
	;[883] 
	SRCFILE "minty.bas",883
	;[884]     IF (#xh % 2 = 1) THEN
	SRCFILE "minty.bas",884
	MVI V16,R0
	ANDI #1,R0
	CMPI #1,R0
	BNE T45
	;[885]         #xl = #xl / 2 + $8000
	SRCFILE "minty.bas",885
	MVI V14,R0
	SLR R0,1
	ADDI #32768,R0
	MVO R0,V14
	;[886]     ELSE
	SRCFILE "minty.bas",886
	B T46
T45:
	;[887]         #xl = #xl / 2
	SRCFILE "minty.bas",887
	MVI V14,R0
	SLR R0,1
	MVO R0,V14
	;[888]     END IF
	SRCFILE "minty.bas",888
T46:
	;[889]     
	SRCFILE "minty.bas",889
	;[890]     #xh = #xh / 2
	SRCFILE "minty.bas",890
	MVI V16,R0
	SLR R0,1
	MVO R0,V16
	;[891]     
	SRCFILE "minty.bas",891
	;[892]     RETURN
	SRCFILE "minty.bas",892
	RETURN
	;[893]     
	SRCFILE "minty.bas",893
	;[894]     END
	SRCFILE "minty.bas",894
	ENDP
	;[895] 
	SRCFILE "minty.bas",895
	;[896] 
	SRCFILE "minty.bas",896
	;[897] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",897
	;[898] REM Logical shift a 32 bit number in X right by n positions
	SRCFILE "minty.bas",898
	;[899] slrxn: PROCEDURE
	SRCFILE "minty.bas",899
	; SLRXN
Q37:	PROC
	BEGIN
	;[900] 
	SRCFILE "minty.bas",900
	;[901]     FOR i = 1 to n
	SRCFILE "minty.bas",901
	MVII #1,R0
	MVO R0,V1
T47:
	;[902]         GOSUB slrx
	SRCFILE "minty.bas",902
	CALL Q55
	;[903]     NEXT i
	SRCFILE "minty.bas",903
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMP V19,R0
	BLE T47
	;[904]     
	SRCFILE "minty.bas",904
	;[905]     RETURN
	SRCFILE "minty.bas",905
	RETURN
	;[906] 
	SRCFILE "minty.bas",906
	;[907]     END
	SRCFILE "minty.bas",907
	ENDP
	;[908] 
	SRCFILE "minty.bas",908
	;[909] 
	SRCFILE "minty.bas",909
	;[910] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",910
	;[911] REM Logical shift a 32 bit number in X right by one position
	SRCFILE "minty.bas",911
	;[912] slry: PROCEDURE
	SRCFILE "minty.bas",912
	; SLRY
Q57:	PROC
	BEGIN
	;[913] 
	SRCFILE "minty.bas",913
	;[914]     IF (#yh % 2 = 1) THEN
	SRCFILE "minty.bas",914
	MVI V15,R0
	ANDI #1,R0
	CMPI #1,R0
	BNE T48
	;[915]         #yl = #yl / 2 + $8000
	SRCFILE "minty.bas",915
	MVI V13,R0
	SLR R0,1
	ADDI #32768,R0
	MVO R0,V13
	;[916]     ELSE
	SRCFILE "minty.bas",916
	B T49
T48:
	;[917]         #yl = #yl / 2
	SRCFILE "minty.bas",917
	MVI V13,R0
	SLR R0,1
	MVO R0,V13
	;[918]     END IF
	SRCFILE "minty.bas",918
T49:
	;[919]     
	SRCFILE "minty.bas",919
	;[920]     #yh = #yh / 2
	SRCFILE "minty.bas",920
	MVI V15,R0
	SLR R0,1
	MVO R0,V15
	;[921]     
	SRCFILE "minty.bas",921
	;[922]     RETURN
	SRCFILE "minty.bas",922
	RETURN
	;[923]     
	SRCFILE "minty.bas",923
	;[924]     END
	SRCFILE "minty.bas",924
	ENDP
	;[925] 
	SRCFILE "minty.bas",925
	;[926] 
	SRCFILE "minty.bas",926
	;[927] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",927
	;[928] REM Logical shift a 32 bit number in Y right by n positions
	SRCFILE "minty.bas",928
	;[929] slryn: PROCEDURE
	SRCFILE "minty.bas",929
	; SLRYN
Q40:	PROC
	BEGIN
	;[930] 
	SRCFILE "minty.bas",930
	;[931]     FOR i = 1 to n
	SRCFILE "minty.bas",931
	MVII #1,R0
	MVO R0,V1
T50:
	;[932]         GOSUB slry
	SRCFILE "minty.bas",932
	CALL Q57
	;[933]     NEXT i
	SRCFILE "minty.bas",933
	MVI V1,R0
	INCR R0
	MVO R0,V1
	CMP V19,R0
	BLE T50
	;[934]     
	SRCFILE "minty.bas",934
	;[935]     RETURN
	SRCFILE "minty.bas",935
	RETURN
	;[936] 
	SRCFILE "minty.bas",936
	;[937]     END
	SRCFILE "minty.bas",937
	ENDP
	;[938] 
	SRCFILE "minty.bas",938
	;[939] 
	SRCFILE "minty.bas",939
	;[940] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",940
	;[941] REM XOR a 32 bit number in X to Y storing the result in Y
	SRCFILE "minty.bas",941
	;[942] xorxy: PROCEDURE
	SRCFILE "minty.bas",942
	; XORXY
Q24:	PROC
	BEGIN
	;[943] 
	SRCFILE "minty.bas",943
	;[944]     #yl = #yl XOR #xl
	SRCFILE "minty.bas",944
	MVI V13,R0
	XOR V14,R0
	MVO R0,V13
	;[945]     #yh = #yh XOR #xh
	SRCFILE "minty.bas",945
	MVI V15,R0
	XOR V16,R0
	MVO R0,V15
	;[946] 
	SRCFILE "minty.bas",946
	;[947]     RETURN
	SRCFILE "minty.bas",947
	RETURN
	;[948]     
	SRCFILE "minty.bas",948
	;[949]     END
	SRCFILE "minty.bas",949
	ENDP
	;[950] 
	SRCFILE "minty.bas",950
	;[951] 
	SRCFILE "minty.bas",951
	;[952] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",952
	;[953] REM XOR a 32 bit number in T to Y storing the result in Y
	SRCFILE "minty.bas",953
	;[954] xorty: PROCEDURE
	SRCFILE "minty.bas",954
	; XORTY
Q19:	PROC
	BEGIN
	;[955] 
	SRCFILE "minty.bas",955
	;[956]     #yl = #yl XOR #tl
	SRCFILE "minty.bas",956
	MVI V13,R0
	XOR V23,R0
	MVO R0,V13
	;[957]     #yh = #yh XOR #th
	SRCFILE "minty.bas",957
	MVI V15,R0
	XOR V24,R0
	MVO R0,V15
	;[958] 
	SRCFILE "minty.bas",958
	;[959]     RETURN
	SRCFILE "minty.bas",959
	RETURN
	;[960]     
	SRCFILE "minty.bas",960
	;[961]     END
	SRCFILE "minty.bas",961
	ENDP
	;[962] 
	SRCFILE "minty.bas",962
	;[963] 
	SRCFILE "minty.bas",963
	;[964] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",964
	;[965] REM Write a hex byte to the screen
	SRCFILE "minty.bas",965
	;[966] writeByte: PROCEDURE
	SRCFILE "minty.bas",966
	; WRITEBYTE
Q7:	PROC
	BEGIN
	;[967] 
	SRCFILE "minty.bas",967
	;[968]     POKE #addr1, PEEK($9900 + ((#tmp1 / 16) AND 15))
	SRCFILE "minty.bas",968
	MVI V8,R1
	SLR R1,2
	SLR R1,2
	ANDI #15,R1
	ADDI #39168,R1
	MVI@ R1,R0
	MVI V7,R1
	MVO@ R0,R1
	;[969]     POKE #addr1 + 1, PEEK($9900 + (#tmp1 AND 15))
	SRCFILE "minty.bas",969
	MVI V8,R1
	ANDI #15,R1
	ADDI #39168,R1
	MVI@ R1,R0
	MVI V7,R1
	INCR R1
	MVO@ R0,R1
	;[970]     
	SRCFILE "minty.bas",970
	;[971]     RETURN
	SRCFILE "minty.bas",971
	RETURN
	;[972]     
	SRCFILE "minty.bas",972
	;[973]     END
	SRCFILE "minty.bas",973
	ENDP
	;[974] 
	SRCFILE "minty.bas",974
	;[975] 
	SRCFILE "minty.bas",975
	;[976] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",976
	;[977] REM Write a 16bit hex word to the screen
	SRCFILE "minty.bas",977
	;[978] writeWord: PROCEDURE
	SRCFILE "minty.bas",978
	; WRITEWORD
Q5:	PROC
	BEGIN
	;[979] 
	SRCFILE "minty.bas",979
	;[980]     POKE #addr1, PEEK($9900 + (#tmp1 / 4096))
	SRCFILE "minty.bas",980
	MVI V8,R1
	SWAP R1
	ANDI #240,R1
	SLR R1,2
	SLR R1,2
	ADDI #39168,R1
	MVI@ R1,R0
	MVI V7,R1
	MVO@ R0,R1
	;[981]     POKE #addr1 + 1, PEEK($9900 + ((#tmp1 / 256) AND 15))
	SRCFILE "minty.bas",981
	MVI V8,R1
	SWAP R1
	ANDI #15,R1
	ADDI #39168,R1
	MVI@ R1,R0
	MVI V7,R1
	INCR R1
	MVO@ R0,R1
	;[982]     POKE #addr1 + 2, PEEK($9900 + ((#tmp1 / 16) AND 15))
	SRCFILE "minty.bas",982
	MVI V8,R1
	SLR R1,2
	SLR R1,2
	ANDI #15,R1
	ADDI #39168,R1
	MVI@ R1,R0
	MVI V7,R1
	ADDI #2,R1
	MVO@ R0,R1
	;[983]     POKE #addr1 + 3, PEEK($9900 + (#tmp1 AND 15))
	SRCFILE "minty.bas",983
	MVI V8,R1
	ANDI #15,R1
	ADDI #39168,R1
	MVI@ R1,R0
	MVI V7,R1
	ADDI #3,R1
	MVO@ R0,R1
	;[984]     
	SRCFILE "minty.bas",984
	;[985]     RETURN
	SRCFILE "minty.bas",985
	RETURN
	;[986]     
	SRCFILE "minty.bas",986
	;[987]     END
	SRCFILE "minty.bas",987
	ENDP
	;[988] 
	SRCFILE "minty.bas",988
	;[989] 
	SRCFILE "minty.bas",989
	;[990] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",990
	;[991] REM Define workspace RAM
	SRCFILE "minty.bas",991
	;[992] 
	SRCFILE "minty.bas",992
	;[993] ASM ORG $9000, $9000, "+RW"
	SRCFILE "minty.bas",993
 ORG $9000, $9000, "+RW"
	;[994] ASM RMB $800
	SRCFILE "minty.bas",994
 RMB $800
	;[995] 
	SRCFILE "minty.bas",995
	;[996] REM $9000 - Internal state of the SHA256 hash
	SRCFILE "minty.bas",996
	;[997] REM $9010 - Internal temporary state of the SHA256 hash
	SRCFILE "minty.bas",997
	;[998] REM $9040 - Hash output
	SRCFILE "minty.bas",998
	;[999] REM $9100 - Hash input data
	SRCFILE "minty.bas",999
	;[1000] REM $9200 - Single hash block
	SRCFILE "minty.bas",1000
	;[1001] REM $9300 - Compressed single hash block
	SRCFILE "minty.bas",1001
	;[1002] 
	SRCFILE "minty.bas",1002
	;[1003] 
	SRCFILE "minty.bas",1003
	;[1004] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",1004
	;[1005] REM Initial hash value
	SRCFILE "minty.bas",1005
	;[1006] 
	SRCFILE "minty.bas",1006
	;[1007] ASM ORG $9400
	SRCFILE "minty.bas",1007
 ORG $9400
	;[1008] 
	SRCFILE "minty.bas",1008
	;[1009] REM bitcoin version
	SRCFILE "minty.bas",1009
	;[1010] 
	SRCFILE "minty.bas",1010
	;[1011]     DATA $02, $00, $00, $00
	SRCFILE "minty.bas",1011
	DECLE 2
	DECLE 0
	DECLE 0
	DECLE 0
	;[1012] 
	SRCFILE "minty.bas",1012
	;[1013] REM previous hash block
	SRCFILE "minty.bas",1013
	;[1014] 
	SRCFILE "minty.bas",1014
	;[1015]     DATA $17, $97, $5b, $97, $c1, $8e, $d1, $f7
	SRCFILE "minty.bas",1015
	DECLE 23
	DECLE 151
	DECLE 91
	DECLE 151
	DECLE 193
	DECLE 142
	DECLE 209
	DECLE 247
	;[1016]     DATA $e2, $55, $ad, $f2, $97, $59, $9b, $55
	SRCFILE "minty.bas",1016
	DECLE 226
	DECLE 85
	DECLE 173
	DECLE 242
	DECLE 151
	DECLE 89
	DECLE 155
	DECLE 85
	;[1017]     DATA $33, $0e, $da, $b8, $78, $03, $c8, $17
	SRCFILE "minty.bas",1017
	DECLE 51
	DECLE 14
	DECLE 218
	DECLE 184
	DECLE 120
	DECLE 3
	DECLE 200
	DECLE 23
	;[1018]     DATA $01, $00, $00, $00, $00, $00, $00, $00
	SRCFILE "minty.bas",1018
	DECLE 1
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[1019] 
	SRCFILE "minty.bas",1019
	;[1020] REM Merkel root
	SRCFILE "minty.bas",1020
	;[1021] 
	SRCFILE "minty.bas",1021
	;[1022]     DATA $8a, $97, $29, $5a, $27, $47, $b4, $f1
	SRCFILE "minty.bas",1022
	DECLE 138
	DECLE 151
	DECLE 41
	DECLE 90
	DECLE 39
	DECLE 71
	DECLE 180
	DECLE 241
	;[1023]     DATA $a0, $b3, $94, $8d, $f3, $99, $03, $44
	SRCFILE "minty.bas",1023
	DECLE 160
	DECLE 179
	DECLE 148
	DECLE 141
	DECLE 243
	DECLE 153
	DECLE 3
	DECLE 68
	;[1024]     DATA $c0, $e1, $9f, $a6, $b2, $b9, $2b, $3a
	SRCFILE "minty.bas",1024
	DECLE 192
	DECLE 225
	DECLE 159
	DECLE 166
	DECLE 178
	DECLE 185
	DECLE 43
	DECLE 58
	;[1025]     DATA $19, $c8, $e6, $ba, $dc, $14, $17, $87
	SRCFILE "minty.bas",1025
	DECLE 25
	DECLE 200
	DECLE 230
	DECLE 186
	DECLE 220
	DECLE 20
	DECLE 23
	DECLE 135
	;[1026] 
	SRCFILE "minty.bas",1026
	;[1027] REM date / time
	SRCFILE "minty.bas",1027
	;[1028] 
	SRCFILE "minty.bas",1028
	;[1029]     DATA $35, $8b, $05, $53
	SRCFILE "minty.bas",1029
	DECLE 53
	DECLE 139
	DECLE 5
	DECLE 83
	;[1030]        
	SRCFILE "minty.bas",1030
	;[1031] REM difficulty bits
	SRCFILE "minty.bas",1031
	;[1032] 
	SRCFILE "minty.bas",1032
	;[1033]     DATA $53, $5f, $01, $19
	SRCFILE "minty.bas",1033
	DECLE 83
	DECLE 95
	DECLE 1
	DECLE 25
	;[1034] 
	SRCFILE "minty.bas",1034
	;[1035] REM nonce value (REMed out so it is RAM rather than ROM)
	SRCFILE "minty.bas",1035
	;[1036] 
	SRCFILE "minty.bas",1036
	;[1037] REM DATA $0, $0, $0, $0
	SRCFILE "minty.bas",1037
	;[1038] 
	SRCFILE "minty.bas",1038
	;[1039] 
	SRCFILE "minty.bas",1039
	;[1040] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",1040
	;[1041] REM SHA 256 data table
	SRCFILE "minty.bas",1041
	;[1042] 
	SRCFILE "minty.bas",1042
	;[1043] ASM ORG $9800
	SRCFILE "minty.bas",1043
 ORG $9800
	;[1044] 
	SRCFILE "minty.bas",1044
	;[1045]     DATA $2f98, $428a, $4491, $7137, $fbcf, $b5c0, $dba5, $e9b5
	SRCFILE "minty.bas",1045
	DECLE 12184
	DECLE 17034
	DECLE 17553
	DECLE 28983
	DECLE 64463
	DECLE 46528
	DECLE 56229
	DECLE 59829
	;[1046]     DATA $c25b, $3956, $11f1, $59f1, $82a4, $923f, $5ed5, $ab1c
	SRCFILE "minty.bas",1046
	DECLE 49755
	DECLE 14678
	DECLE 4593
	DECLE 23025
	DECLE 33444
	DECLE 37439
	DECLE 24277
	DECLE 43804
	;[1047]     DATA $aa98, $d807, $5b01, $1283, $85be, $2431, $7dc3, $550c
	SRCFILE "minty.bas",1047
	DECLE 43672
	DECLE 55303
	DECLE 23297
	DECLE 4739
	DECLE 34238
	DECLE 9265
	DECLE 32195
	DECLE 21772
	;[1048]     DATA $5d74, $72be, $b1fe, $80de, $06a7, $9bdc, $f174, $c19b 
	SRCFILE "minty.bas",1048
	DECLE 23924
	DECLE 29374
	DECLE 45566
	DECLE 32990
	DECLE 1703
	DECLE 39900
	DECLE 61812
	DECLE 49563
	;[1049]     DATA $69c1, $e49b, $4786, $efbe, $9dc6, $0fc1, $a1cc, $240c
	SRCFILE "minty.bas",1049
	DECLE 27073
	DECLE 58523
	DECLE 18310
	DECLE 61374
	DECLE 40390
	DECLE 4033
	DECLE 41420
	DECLE 9228
	;[1050]     DATA $2c6f, $2de9, $84aa, $4a74, $a9dc, $5cb0, $88da, $76f9 
	SRCFILE "minty.bas",1050
	DECLE 11375
	DECLE 11753
	DECLE 33962
	DECLE 19060
	DECLE 43484
	DECLE 23728
	DECLE 35034
	DECLE 30457
	;[1051]     DATA $5152, $983e, $c66d, $a831, $27c8, $b003, $7fc7, $bf59
	SRCFILE "minty.bas",1051
	DECLE 20818
	DECLE 38974
	DECLE 50797
	DECLE 43057
	DECLE 10184
	DECLE 45059
	DECLE 32711
	DECLE 48985
	;[1052]     DATA $0bf3, $c6e0, $9147, $d5a7, $6351, $06ca, $2967, $1429 
	SRCFILE "minty.bas",1052
	DECLE 3059
	DECLE 50912
	DECLE 37191
	DECLE 54695
	DECLE 25425
	DECLE 1738
	DECLE 10599
	DECLE 5161
	;[1053]     DATA $0a85, $27b7, $2138, $2e1b, $6dfc, $4d2c, $0d13, $5338
	SRCFILE "minty.bas",1053
	DECLE 2693
	DECLE 10167
	DECLE 8504
	DECLE 11803
	DECLE 28156
	DECLE 19756
	DECLE 3347
	DECLE 21304
	;[1054]     DATA $7354, $650a, $0abb, $766a, $c92e, $81c2, $2c85, $9272 
	SRCFILE "minty.bas",1054
	DECLE 29524
	DECLE 25866
	DECLE 2747
	DECLE 30314
	DECLE 51502
	DECLE 33218
	DECLE 11397
	DECLE 37490
	;[1055]     DATA $e8a1, $a2bf, $664b, $a81a, $8b70, $c24b, $51a3, $c76c
	SRCFILE "minty.bas",1055
	DECLE 59553
	DECLE 41663
	DECLE 26187
	DECLE 43034
	DECLE 35696
	DECLE 49739
	DECLE 20899
	DECLE 51052
	;[1056]     DATA $e819, $d192, $0624, $d699, $3585, $f40e, $a070, $106a 
	SRCFILE "minty.bas",1056
	DECLE 59417
	DECLE 53650
	DECLE 1572
	DECLE 54937
	DECLE 13701
	DECLE 62478
	DECLE 41072
	DECLE 4202
	;[1057]     DATA $c116, $19a4, $6c08, $1e37, $774c, $2748, $bcb5, $34b0
	SRCFILE "minty.bas",1057
	DECLE 49430
	DECLE 6564
	DECLE 27656
	DECLE 7735
	DECLE 30540
	DECLE 10056
	DECLE 48309
	DECLE 13488
	;[1058]     DATA $0cb3, $391c, $aa4a, $4ed8, $ca4f, $5b9c, $6ff3, $682e 
	SRCFILE "minty.bas",1058
	DECLE 3251
	DECLE 14620
	DECLE 43594
	DECLE 20184
	DECLE 51791
	DECLE 23452
	DECLE 28659
	DECLE 26670
	;[1059]     DATA $82ee, $748f, $636f, $78a5, $7814, $84c8, $0208, $8cc7
	SRCFILE "minty.bas",1059
	DECLE 33518
	DECLE 29839
	DECLE 25455
	DECLE 30885
	DECLE 30740
	DECLE 33992
	DECLE 520
	DECLE 36039
	;[1060]     DATA $fffa, $90be, $6ceb, $a450, $a3f7, $bef9, $78f2, $c671
	SRCFILE "minty.bas",1060
	DECLE 65530
	DECLE 37054
	DECLE 27883
	DECLE 42064
	DECLE 41975
	DECLE 48889
	DECLE 30962
	DECLE 50801
	;[1061] 
	SRCFILE "minty.bas",1061
	;[1062] 
	SRCFILE "minty.bas",1062
	;[1063] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",1063
	;[1064] REM Hex alphabet in tan foreground
	SRCFILE "minty.bas",1064
	;[1065] 
	SRCFILE "minty.bas",1065
	;[1066] ASM ORG $9900
	SRCFILE "minty.bas",1066
 ORG $9900
	;[1067] 
	SRCFILE "minty.bas",1067
	;[1068]     DATA $83, $8b, $93, $9b, $a3, $ab, $b3, $bb
	SRCFILE "minty.bas",1068
	DECLE 131
	DECLE 139
	DECLE 147
	DECLE 155
	DECLE 163
	DECLE 171
	DECLE 179
	DECLE 187
	;[1069]     DATA $c3, $cb, $10b, $113, $11b, $123, $12b, $133
	SRCFILE "minty.bas",1069
	DECLE 195
	DECLE 203
	DECLE 267
	DECLE 275
	DECLE 283
	DECLE 291
	DECLE 299
	DECLE 307
	;[1070] 
	SRCFILE "minty.bas",1070
	;[1071] 
	SRCFILE "minty.bas",1071
	;[1072] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",1072
	;[1073] REM Marquee message
	SRCFILE "minty.bas",1073
	;[1074] 
	SRCFILE "minty.bas",1074
	;[1075] ASM ORG $9980
	SRCFILE "minty.bas",1075
 ORG $9980
	;[1076] 
	SRCFILE "minty.bas",1076
	;[1077]     DATA $007, $007, $007, $007, $007, $007, $007, $007
	SRCFILE "minty.bas",1077
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	;[1078]     DATA $007, $007, $007, $007, $007, $007, $007, $007
	SRCFILE "minty.bas",1078
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	;[1079]     DATA $227, $22f, $21f, $267, $22f, $007, $287, $297
	SRCFILE "minty.bas",1079
	DECLE 551
	DECLE 559
	DECLE 543
	DECLE 615
	DECLE 559
	DECLE 7
	DECLE 647
	DECLE 663
	;[1080]     DATA $22f, $29f, $22f, $277, $2a7, $29f, $077, $077
	SRCFILE "minty.bas",1080
	DECLE 559
	DECLE 671
	DECLE 559
	DECLE 631
	DECLE 679
	DECLE 671
	DECLE 119
	DECLE 119
	;[1081]     DATA $077, $007, $007, $007, $0ec, $003, $023, $003
	SRCFILE "minty.bas",1081
	DECLE 119
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 236
	DECLE 3
	DECLE 35
	DECLE 3
	;[1082]     DATA $0ec, $003, $023, $003, $0ec, $007, $007, $26f
	SRCFILE "minty.bas",1082
	DECLE 236
	DECLE 3
	DECLE 35
	DECLE 3
	DECLE 236
	DECLE 7
	DECLE 7
	DECLE 623
	;[1083]     DATA $14f, $177, $1a7, $1cf, $007, $007, $0ec, $003
	SRCFILE "minty.bas",1083
	DECLE 335
	DECLE 375
	DECLE 423
	DECLE 463
	DECLE 7
	DECLE 7
	DECLE 236
	DECLE 3
	;[1084]     DATA $023, $003, $0ec, $003, $023, $003, $0ec, $007
	SRCFILE "minty.bas",1084
	DECLE 35
	DECLE 3
	DECLE 236
	DECLE 3
	DECLE 35
	DECLE 3
	DECLE 236
	DECLE 7
	;[1085]     DATA $007, $007, $077, $077, $077, $20f, $007, $117
	SRCFILE "minty.bas",1085
	DECLE 7
	DECLE 7
	DECLE 119
	DECLE 119
	DECLE 119
	DECLE 527
	DECLE 7
	DECLE 279
	;[1086]     DATA $24f, $2a7, $21f, $27f, $24f, $277, $007, $26f
	SRCFILE "minty.bas",1086
	DECLE 591
	DECLE 679
	DECLE 543
	DECLE 639
	DECLE 591
	DECLE 631
	DECLE 7
	DECLE 623
	;[1087]     DATA $24f, $277, $22f, $297, $007, $237, $27f, $297
	SRCFILE "minty.bas",1087
	DECLE 591
	DECLE 631
	DECLE 559
	DECLE 663
	DECLE 7
	DECLE 567
	DECLE 639
	DECLE 663
	;[1088]     DATA $007, $2a7, $247, $22f, $007, $16f, $20f, $2a7
	SRCFILE "minty.bas",1088
	DECLE 7
	DECLE 679
	DECLE 583
	DECLE 559
	DECLE 7
	DECLE 367
	DECLE 527
	DECLE 679
	;[1089]     DATA $2a7, $22f, $267, $007, $14f, $277, $2a7, $22f
	SRCFILE "minty.bas",1089
	DECLE 679
	DECLE 559
	DECLE 615
	DECLE 7
	DECLE 335
	DECLE 631
	DECLE 679
	DECLE 559
	;[1090]     DATA $267, $267, $24f, $2b7, $24f, $29f, $24f, $27f
	SRCFILE "minty.bas",1090
	DECLE 615
	DECLE 615
	DECLE 591
	DECLE 695
	DECLE 591
	DECLE 671
	DECLE 591
	DECLE 639
	;[1091]     DATA $277, $007, $2bf, $297, $24f, $2a7, $2a7, $22f
	SRCFILE "minty.bas",1091
	DECLE 631
	DECLE 7
	DECLE 703
	DECLE 663
	DECLE 591
	DECLE 679
	DECLE 679
	DECLE 559
	;[1092]     DATA $277, $007, $047, $297, $20f, $2a7, $247, $22f
	SRCFILE "minty.bas",1092
	DECLE 631
	DECLE 7
	DECLE 71
	DECLE 663
	DECLE 527
	DECLE 679
	DECLE 583
	DECLE 559
	;[1093]     DATA $297, $007, $217, $20f, $227, $267, $2cf, $04f
	SRCFILE "minty.bas",1093
	DECLE 663
	DECLE 7
	DECLE 535
	DECLE 527
	DECLE 551
	DECLE 615
	DECLE 719
	DECLE 79
	;[1094]     DATA $007, $24f, $277, $007, $14f, $277, $2a7, $2cf
	SRCFILE "minty.bas",1094
	DECLE 7
	DECLE 591
	DECLE 631
	DECLE 7
	DECLE 335
	DECLE 631
	DECLE 679
	DECLE 719
	;[1095]     DATA $117, $10f, $19f, $14f, $11f, $077, $007, $007
	SRCFILE "minty.bas",1095
	DECLE 279
	DECLE 271
	DECLE 415
	DECLE 335
	DECLE 287
	DECLE 119
	DECLE 7
	DECLE 7
	;[1096]     DATA $26f, $14f, $177, $1a7, $1cf, $007, $2bf, $24f
	SRCFILE "minty.bas",1096
	DECLE 623
	DECLE 335
	DECLE 375
	DECLE 423
	DECLE 463
	DECLE 7
	DECLE 703
	DECLE 591
	;[1097]     DATA $267, $267, $007, $2a7, $20f, $25f, $22f, $007
	SRCFILE "minty.bas",1097
	DECLE 615
	DECLE 615
	DECLE 7
	DECLE 679
	DECLE 527
	DECLE 607
	DECLE 559
	DECLE 7
	;[1098]     DATA $0af, $087, $087, $007, $2cf, $22f, $20f, $297
	SRCFILE "minty.bas",1098
	DECLE 175
	DECLE 135
	DECLE 135
	DECLE 7
	DECLE 719
	DECLE 559
	DECLE 527
	DECLE 663
	;[1099]     DATA $29f, $007, $2a7, $27f, $007, $26f, $24f, $277
	SRCFILE "minty.bas",1099
	DECLE 671
	DECLE 7
	DECLE 679
	DECLE 639
	DECLE 7
	DECLE 623
	DECLE 591
	DECLE 631
	;[1100]     DATA $22f, $007, $20f, $007, $29f, $24f, $277, $23f
	SRCFILE "minty.bas",1100
	DECLE 559
	DECLE 7
	DECLE 527
	DECLE 7
	DECLE 671
	DECLE 591
	DECLE 631
	DECLE 575
	;[1101]     DATA $267, $22f, $007, $21f, $27f, $24f, $277, $00f
	SRCFILE "minty.bas",1101
	DECLE 615
	DECLE 559
	DECLE 7
	DECLE 543
	DECLE 639
	DECLE 591
	DECLE 631
	DECLE 15
	;[1102]     DATA $007, $007, $14f, $277, $007, $2a7, $247, $20f
	SRCFILE "minty.bas",1102
	DECLE 7
	DECLE 7
	DECLE 335
	DECLE 631
	DECLE 7
	DECLE 679
	DECLE 583
	DECLE 527
	;[1103]     DATA $2a7, $007, $2a7, $24f, $26f, $22f, $007, $24f
	SRCFILE "minty.bas",1103
	DECLE 679
	DECLE 7
	DECLE 679
	DECLE 591
	DECLE 623
	DECLE 559
	DECLE 7
	DECLE 591
	;[1104]     DATA $2a7, $007, $2bf, $24f, $267, $267, $007, $287
	SRCFILE "minty.bas",1104
	DECLE 679
	DECLE 7
	DECLE 703
	DECLE 591
	DECLE 615
	DECLE 615
	DECLE 7
	DECLE 647
	;[1105]     DATA $267, $20f, $2cf, $007, $16f, $27f, $277, $22f
	SRCFILE "minty.bas",1105
	DECLE 615
	DECLE 527
	DECLE 719
	DECLE 7
	DECLE 367
	DECLE 639
	DECLE 631
	DECLE 559
	;[1106]     DATA $2cf, $067, $007, $16f, $27f, $277, $22f, $2cf
	SRCFILE "minty.bas",1106
	DECLE 719
	DECLE 103
	DECLE 7
	DECLE 367
	DECLE 639
	DECLE 631
	DECLE 559
	DECLE 719
	;[1107]     DATA $067, $007, $16f, $27f, $277, $22f, $2cf, $007
	SRCFILE "minty.bas",1107
	DECLE 103
	DECLE 7
	DECLE 367
	DECLE 639
	DECLE 631
	DECLE 559
	DECLE 719
	DECLE 7
	;[1108]     DATA $20f, $287, $287, $297, $27f, $2c7, $26f, $24f
	SRCFILE "minty.bas",1108
	DECLE 527
	DECLE 647
	DECLE 647
	DECLE 663
	DECLE 639
	DECLE 711
	DECLE 623
	DECLE 591
	;[1109]     DATA $26f, $20f, $2a7, $22f, $267, $2cf, $007, $0cf
	SRCFILE "minty.bas",1109
	DECLE 623
	DECLE 527
	DECLE 679
	DECLE 559
	DECLE 615
	DECLE 719
	DECLE 7
	DECLE 207
	;[1110]     DATA $0af, $007, $26f, $24f, $267, $267, $24f, $27f
	SRCFILE "minty.bas",1110
	DECLE 175
	DECLE 7
	DECLE 623
	DECLE 591
	DECLE 615
	DECLE 615
	DECLE 591
	DECLE 639
	;[1111]     DATA $277, $007, $2a7, $24f, $26f, $22f, $29f, $007
	SRCFILE "minty.bas",1111
	DECLE 631
	DECLE 7
	DECLE 679
	DECLE 591
	DECLE 623
	DECLE 559
	DECLE 671
	DECLE 7
	;[1112]     DATA $20f, $277, $227, $007, $21f, $27f, $277, $29f
	SRCFILE "minty.bas",1112
	DECLE 527
	DECLE 631
	DECLE 551
	DECLE 7
	DECLE 543
	DECLE 639
	DECLE 631
	DECLE 671
	;[1113]     DATA $2af, $26f, $22f, $007, $277, $22f, $20f, $297
	SRCFILE "minty.bas",1113
	DECLE 687
	DECLE 623
	DECLE 559
	DECLE 7
	DECLE 631
	DECLE 559
	DECLE 527
	DECLE 663
	;[1114]     DATA $267, $2cf, $007, $08f, $007, $1a7, $157, $27f
	SRCFILE "minty.bas",1114
	DECLE 615
	DECLE 719
	DECLE 7
	DECLE 143
	DECLE 7
	DECLE 423
	DECLE 343
	DECLE 639
	;[1115]     DATA $2af, $267, $22f, $007, $27f, $237, $007, $22f
	SRCFILE "minty.bas",1115
	DECLE 687
	DECLE 615
	DECLE 559
	DECLE 7
	DECLE 639
	DECLE 567
	DECLE 7
	DECLE 559
	;[1116]     DATA $277, $22f, $297, $23f, $2cf, $067, $007, $22f
	SRCFILE "minty.bas",1116
	DECLE 631
	DECLE 559
	DECLE 663
	DECLE 575
	DECLE 719
	DECLE 103
	DECLE 7
	DECLE 559
	;[1117]     DATA $277, $27f, $2af, $23f, $247, $007, $2a7, $27f
	SRCFILE "minty.bas",1117
	DECLE 631
	DECLE 639
	DECLE 687
	DECLE 575
	DECLE 583
	DECLE 7
	DECLE 679
	DECLE 639
	;[1118]     DATA $007, $217, $27f, $24f, $267, $007, $20f, $007
	SRCFILE "minty.bas",1118
	DECLE 7
	DECLE 535
	DECLE 639
	DECLE 591
	DECLE 615
	DECLE 7
	DECLE 527
	DECLE 7
	;[1119]     DATA $25f, $22f, $2a7, $2a7, $267, $22f, $007, $26f
	SRCFILE "minty.bas",1119
	DECLE 607
	DECLE 559
	DECLE 679
	DECLE 679
	DECLE 615
	DECLE 559
	DECLE 7
	DECLE 623
	;[1120]     DATA $27f, $297, $22f, $007, $2a7, $247, $20f, $277
	SRCFILE "minty.bas",1120
	DECLE 639
	DECLE 663
	DECLE 559
	DECLE 7
	DECLE 679
	DECLE 583
	DECLE 527
	DECLE 631
	;[1121]     DATA $007, $097, $007, $26f, $24f, $267, $267, $24f
	SRCFILE "minty.bas",1121
	DECLE 7
	DECLE 151
	DECLE 7
	DECLE 623
	DECLE 591
	DECLE 615
	DECLE 615
	DECLE 591
	;[1122]     DATA $27f, $277, $007, $2a7, $24f, $26f, $22f, $29f
	SRCFILE "minty.bas",1122
	DECLE 639
	DECLE 631
	DECLE 7
	DECLE 679
	DECLE 591
	DECLE 623
	DECLE 559
	DECLE 671
	;[1123]     DATA $00f, $007, $007, $127, $27f, $277, $03f, $2a7
	SRCFILE "minty.bas",1123
	DECLE 15
	DECLE 7
	DECLE 7
	DECLE 295
	DECLE 639
	DECLE 631
	DECLE 63
	DECLE 679
	;[1124]     DATA $007, $23f, $24f, $2b7, $22f, $007, $2af, $287
	SRCFILE "minty.bas",1124
	DECLE 7
	DECLE 575
	DECLE 591
	DECLE 695
	DECLE 559
	DECLE 7
	DECLE 687
	DECLE 647
	;[1125]     DATA $007, $2a7, $247, $22f, $007, $227, $20f, $2cf
	SRCFILE "minty.bas",1125
	DECLE 7
	DECLE 679
	DECLE 583
	DECLE 559
	DECLE 7
	DECLE 551
	DECLE 527
	DECLE 719
	;[1126]     DATA $007, $257, $27f, $217, $077, $077, $077, $007
	SRCFILE "minty.bas",1126
	DECLE 7
	DECLE 599
	DECLE 639
	DECLE 535
	DECLE 119
	DECLE 119
	DECLE 119
	DECLE 7
	;[1127]     DATA $007, $007, $007, $007, $007, $007, $007, $007
	SRCFILE "minty.bas",1127
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	;[1128]     DATA $077, $077, $077, $11f, $20f, $277, $03f, $2a7
	SRCFILE "minty.bas",1128
	DECLE 119
	DECLE 119
	DECLE 119
	DECLE 287
	DECLE 527
	DECLE 631
	DECLE 63
	DECLE 679
	;[1129]     DATA $007, $2bf, $20f, $24f, $2a7, $007, $2a7, $247
	SRCFILE "minty.bas",1129
	DECLE 7
	DECLE 703
	DECLE 527
	DECLE 591
	DECLE 679
	DECLE 7
	DECLE 679
	DECLE 583
	;[1130]     DATA $20f, $2a7, $007, $267, $27f, $277, $23f, $0ff
	SRCFILE "minty.bas",1130
	DECLE 527
	DECLE 679
	DECLE 7
	DECLE 615
	DECLE 639
	DECLE 631
	DECLE 575
	DECLE 255
	;[1131]     DATA $007, $007, $007, $007, $007, $007, $007, $007
	SRCFILE "minty.bas",1131
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	;[1132]     DATA $077, $077, $077, $187, $297, $22f, $29f, $29f
	SRCFILE "minty.bas",1132
	DECLE 119
	DECLE 119
	DECLE 119
	DECLE 391
	DECLE 663
	DECLE 559
	DECLE 671
	DECLE 671
	;[1133]     DATA $007, $223, $27b, $2bb, $273, $007, $2a7, $27f
	SRCFILE "minty.bas",1133
	DECLE 7
	DECLE 547
	DECLE 635
	DECLE 699
	DECLE 627
	DECLE 7
	DECLE 679
	DECLE 639
	;[1134]     DATA $007, $03f, $29f, $25f, $24f, $287, $007, $2a7
	SRCFILE "minty.bas",1134
	DECLE 7
	DECLE 63
	DECLE 671
	DECLE 607
	DECLE 591
	DECLE 647
	DECLE 7
	DECLE 679
	;[1135]     DATA $27f, $007, $2a7, $247, $22f, $007, $22f, $277
	SRCFILE "minty.bas",1135
	DECLE 639
	DECLE 7
	DECLE 679
	DECLE 583
	DECLE 559
	DECLE 7
	DECLE 559
	DECLE 631
	;[1136]     DATA $227, $03f, $077, $077, $077, $007, $007, $007
	SRCFILE "minty.bas",1136
	DECLE 551
	DECLE 63
	DECLE 119
	DECLE 119
	DECLE 119
	DECLE 7
	DECLE 7
	DECLE 7
	;[1137]     DATA $007, $007, $007, $007, $007, $077, $077, $077
	SRCFILE "minty.bas",1137
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 7
	DECLE 119
	DECLE 119
	DECLE 119
	;[1138]     DATA $29f, $247, $20f, $26f, $22f, $007, $2a7, $247
	SRCFILE "minty.bas",1138
	DECLE 671
	DECLE 583
	DECLE 527
	DECLE 623
	DECLE 559
	DECLE 7
	DECLE 679
	DECLE 583
	;[1139]     DATA $24f, $29f, $007, $21f, $20f, $277, $03f, $2a7
	SRCFILE "minty.bas",1139
	DECLE 591
	DECLE 671
	DECLE 7
	DECLE 543
	DECLE 527
	DECLE 631
	DECLE 63
	DECLE 679
	;[1140]     DATA $007, $217, $22f, $007, $227, $27f, $277, $22f
	SRCFILE "minty.bas",1140
	DECLE 7
	DECLE 535
	DECLE 559
	DECLE 7
	DECLE 551
	DECLE 639
	DECLE 631
	DECLE 559
	;[1141]     DATA $007, $2bf, $247, $22f, $277, $007, $26f, $24f
	SRCFILE "minty.bas",1141
	DECLE 7
	DECLE 703
	DECLE 583
	DECLE 559
	DECLE 631
	DECLE 7
	DECLE 623
	DECLE 591
	;[1142]     DATA $277, $24f, $277, $23f, $007, $27f, $2a7, $247
	SRCFILE "minty.bas",1142
	DECLE 631
	DECLE 591
	DECLE 631
	DECLE 575
	DECLE 7
	DECLE 639
	DECLE 679
	DECLE 583
	;[1143]     DATA $22f, $297, $007, $21f, $27f, $24f, $277, $29f
	SRCFILE "minty.bas",1143
	DECLE 559
	DECLE 663
	DECLE 7
	DECLE 543
	DECLE 639
	DECLE 591
	DECLE 631
	DECLE 671
	;[1144]     DATA $00f, $000
	SRCFILE "minty.bas",1144
	DECLE 15
	DECLE 0
	;[1145] 
	SRCFILE "minty.bas",1145
	;[1146] 
	SRCFILE "minty.bas",1146
	;[1147] REM ----------------------------------------------------------------------------
	SRCFILE "minty.bas",1147
	;[1148] REM Music - Money, Money, Money, baby!
	SRCFILE "minty.bas",1148
	;[1149] REM MIDI source - http://home.freeuk.net/rr/music/midi/abba/index.html
	SRCFILE "minty.bas",1149
	;[1150] REM Converted to IntyBASIC using MusoCheat - 
	SRCFILE "minty.bas",1150
	;[1151] REM     http://atariage.com/forums/topic/264422-musocheat-adequate-inty-music-for-non-musicians/
	SRCFILE "minty.bas",1151
	;[1152] 
	SRCFILE "minty.bas",1152
	;[1153] Music:
	SRCFILE "minty.bas",1153
	; MUSIC
Q4:	;[1154]     DATA     2
	SRCFILE "minty.bas",1154
	DECLE 2
	;[1155]     MUSIC F2#Y,    -,    -
	SRCFILE "minty.bas",1155
	DECLE 135,0
	;[1156]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1156
	DECLE 63,0
	;[1157]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1157
	DECLE 0,0
	;[1158]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1158
	DECLE 0,0
	;[1159]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1159
	DECLE 0,0
	;[1160]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1160
	DECLE 0,0
	;[1161]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1161
	DECLE 0,0
	;[1162]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1162
	DECLE 0,0
	;[1163]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1163
	DECLE 0,0
	;[1164]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1164
	DECLE 0,0
	;[1165]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1165
	DECLE 0,0
	;[1166]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1166
	DECLE 0,0
	;[1167]     MUSIC  F2#,    -,    -
	SRCFILE "minty.bas",1167
	DECLE 135,0
	;[1168]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1168
	DECLE 63,0
	;[1169]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1169
	DECLE 0,0
	;[1170]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1170
	DECLE 0,0
	;[1171]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1171
	DECLE 0,0
	;[1172]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1172
	DECLE 0,0
	;[1173]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1173
	DECLE 0,0
	;[1174]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1174
	DECLE 0,0
	;[1175]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1175
	DECLE 0,0
	;[1176]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1176
	DECLE 0,0
	;[1177]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1177
	DECLE 0,0
	;[1178]     MUSIC  F2#,    -,    -
	SRCFILE "minty.bas",1178
	DECLE 135,0
	;[1179]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1179
	DECLE 63,0
	;[1180]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1180
	DECLE 0,0
	;[1181]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1181
	DECLE 0,0
	;[1182]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1182
	DECLE 0,0
	;[1183]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1183
	DECLE 0,0
	;[1184]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1184
	DECLE 0,0
	;[1185]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1185
	DECLE 0,0
	;[1186]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1186
	DECLE 0,0
	;[1187]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1187
	DECLE 0,0
	;[1188]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1188
	DECLE 0,0
	;[1189]     MUSIC  F2#,    -,    -
	SRCFILE "minty.bas",1189
	DECLE 135,0
	;[1190]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1190
	DECLE 63,0
	;[1191]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1191
	DECLE 0,0
	;[1192]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1192
	DECLE 0,0
	;[1193]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1193
	DECLE 0,0
	;[1194]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1194
	DECLE 0,0
	;[1195]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1195
	DECLE 0,0
	;[1196]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1196
	DECLE 0,0
	;[1197]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1197
	DECLE 0,0
	;[1198]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1198
	DECLE 0,0
	;[1199]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1199
	DECLE 0,0
	;[1200]     MUSIC   E6,  E4Y,  E5Y
	SRCFILE "minty.bas",1200
	DECLE 40373,169
	;[1201]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1201
	DECLE 16191,63
	;[1202]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1202
	DECLE 63,0
	;[1203]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1203
	DECLE 0,0
	;[1204]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1204
	DECLE 0,0
	;[1205] 
	SRCFILE "minty.bas",1205
	;[1206] REM Timing 100 frames, 2.00 secs
	SRCFILE "minty.bas",1206
	;[1207] 
	SRCFILE "minty.bas",1207
	;[1208]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1208
	DECLE 0,0
	;[1209]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",1209
	DECLE 40373,169
	;[1210]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1210
	DECLE 16191,63
	;[1211]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1211
	DECLE 63,0
	;[1212]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1212
	DECLE 0,0
	;[1213]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1213
	DECLE 0,0
	;[1214]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1214
	DECLE 0,0
	;[1215]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",1215
	DECLE 40373,169
	;[1216]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1216
	DECLE 16191,63
	;[1217]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1217
	DECLE 0,0
	;[1218]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1218
	DECLE 0,0
	;[1219]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1219
	DECLE 0,0
	;[1220]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",1220
	DECLE 40373,169
	;[1221]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1221
	DECLE 16191,63
	;[1222]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1222
	DECLE 63,0
	;[1223]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1223
	DECLE 0,0
	;[1224]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1224
	DECLE 0,0
	;[1225]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1225
	DECLE 0,0
	;[1226]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",1226
	DECLE 40373,169
	;[1227]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1227
	DECLE 16191,63
	;[1228]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1228
	DECLE 63,0
	;[1229]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1229
	DECLE 0,0
	;[1230]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1230
	DECLE 0,0
	;[1231]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",1231
	DECLE 40373,169
	;[1232]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1232
	DECLE 16191,63
	;[1233]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1233
	DECLE 16191,63
	;[1234]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1234
	DECLE 16128,63
	;[1235]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1235
	DECLE 16128,63
	;[1236]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1236
	DECLE 0,0
	;[1237]     MUSIC   E5,   E4,    -
	SRCFILE "minty.bas",1237
	DECLE 40361,0
	;[1238]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1238
	DECLE 16191,0
	;[1239]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1239
	DECLE 16191,0
	;[1240]     MUSIC   A5,   A4,    -
	SRCFILE "minty.bas",1240
	DECLE 41646,0
	;[1241]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1241
	DECLE 16191,0
	;[1242]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1242
	DECLE 16191,0
	;[1243]     MUSIC   C6,   C5,    -
	SRCFILE "minty.bas",1243
	DECLE 42417,0
	;[1244]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1244
	DECLE 16191,0
	;[1245]     MUSIC   E6,   E5,    -
	SRCFILE "minty.bas",1245
	DECLE 43445,0
	;[1246]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1246
	DECLE 16191,0
	;[1247]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1247
	DECLE 16191,0
	;[1248]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",1248
	DECLE 40628,168
	;[1249]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1249
	DECLE 16191,63
	;[1250]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1250
	DECLE 63,0
	;[1251]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1251
	DECLE 0,0
	;[1252]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1252
	DECLE 0,0
	;[1253]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1253
	DECLE 0,0
	;[1254]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",1254
	DECLE 40628,168
	;[1255]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1255
	DECLE 16191,63
	;[1256]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1256
	DECLE 63,0
	;[1257]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1257
	DECLE 0,0
	;[1258] 
	SRCFILE "minty.bas",1258
	;[1259] REM Timing 200 frames, 4.00 secs
	SRCFILE "minty.bas",1259
	;[1260] 
	SRCFILE "minty.bas",1260
	;[1261]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1261
	DECLE 0,0
	;[1262]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1262
	DECLE 0,0
	;[1263]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",1263
	DECLE 40628,168
	;[1264]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1264
	DECLE 16191,63
	;[1265]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1265
	DECLE 0,0
	;[1266]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1266
	DECLE 0,0
	;[1267]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1267
	DECLE 0,0
	;[1268]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",1268
	DECLE 40628,168
	;[1269]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1269
	DECLE 16191,63
	;[1270]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1270
	DECLE 63,0
	;[1271]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1271
	DECLE 0,0
	;[1272]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1272
	DECLE 0,0
	;[1273]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1273
	DECLE 0,0
	;[1274]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",1274
	DECLE 40628,168
	;[1275]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1275
	DECLE 16191,63
	;[1276]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1276
	DECLE 63,0
	;[1277]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1277
	DECLE 0,0
	;[1278]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1278
	DECLE 0,0
	;[1279]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",1279
	DECLE 40628,168
	;[1280]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1280
	DECLE 16191,63
	;[1281]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1281
	DECLE 16191,63
	;[1282]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1282
	DECLE 16128,63
	;[1283]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1283
	DECLE 16128,63
	;[1284]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1284
	DECLE 0,0
	;[1285]     MUSIC   F5,   F4,    -
	SRCFILE "minty.bas",1285
	DECLE 40618,0
	;[1286]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1286
	DECLE 16191,0
	;[1287]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1287
	DECLE 16191,0
	;[1288]     MUSIC   A5,   A4,    -
	SRCFILE "minty.bas",1288
	DECLE 41646,0
	;[1289]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1289
	DECLE 16191,0
	;[1290]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1290
	DECLE 16191,0
	;[1291]     MUSIC   C6,   C5,    -
	SRCFILE "minty.bas",1291
	DECLE 42417,0
	;[1292]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1292
	DECLE 16191,0
	;[1293]     MUSIC  D6#,  D5#,    -
	SRCFILE "minty.bas",1293
	DECLE 43188,0
	;[1294]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1294
	DECLE 16191,0
	;[1295]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1295
	DECLE 16191,0
	;[1296]     MUSIC   D6,   D3,   D5
	SRCFILE "minty.bas",1296
	DECLE 36787,167
	;[1297]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1297
	DECLE 16191,63
	;[1298]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1298
	DECLE 16191,63
	;[1299]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1299
	DECLE 16128,63
	;[1300]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1300
	DECLE 16128,63
	;[1301]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1301
	DECLE 16128,63
	;[1302]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1302
	DECLE 16128,63
	;[1303]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1303
	DECLE 16128,63
	;[1304]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1304
	DECLE 16128,63
	;[1305]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1305
	DECLE 16128,63
	;[1306]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1306
	DECLE 16128,63
	;[1307]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1307
	DECLE 16128,63
	;[1308]     MUSIC   C6,    S,   C5
	SRCFILE "minty.bas",1308
	DECLE 16305,165
	;[1309]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1309
	DECLE 16191,63
	;[1310]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1310
	DECLE 16128,63
	;[1311] 
	SRCFILE "minty.bas",1311
	;[1312] REM Timing 300 frames, 6.00 secs
	SRCFILE "minty.bas",1312
	;[1313] 
	SRCFILE "minty.bas",1313
	;[1314]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1314
	DECLE 16128,63
	;[1315]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1315
	DECLE 16128,0
	;[1316]     MUSIC   A5,    S,   A4
	SRCFILE "minty.bas",1316
	DECLE 16302,162
	;[1317]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1317
	DECLE 16191,63
	;[1318]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1318
	DECLE 16191,0
	;[1319]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1319
	DECLE 16128,0
	;[1320]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1320
	DECLE 16128,0
	;[1321]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1321
	DECLE 16128,0
	;[1322]     MUSIC   C6,   E3,   C5
	SRCFILE "minty.bas",1322
	DECLE 37297,165
	;[1323]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1323
	DECLE 16191,63
	;[1324]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1324
	DECLE 16191,0
	;[1325]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1325
	DECLE 16128,0
	;[1326]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1326
	DECLE 0,0
	;[1327]     MUSIC   C6,   E3,   C5
	SRCFILE "minty.bas",1327
	DECLE 37297,165
	;[1328]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1328
	DECLE 16191,63
	;[1329]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1329
	DECLE 16191,63
	;[1330]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1330
	DECLE 16128,63
	;[1331]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1331
	DECLE 16128,63
	;[1332]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1332
	DECLE 16128,63
	;[1333]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1333
	DECLE 16128,63
	;[1334]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1334
	DECLE 16128,63
	;[1335]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1335
	DECLE 16128,63
	;[1336]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1336
	DECLE 16128,0
	;[1337]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1337
	DECLE 16128,0
	;[1338]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1338
	DECLE 0,0
	;[1339]     MUSIC   A5,   C4,   A4
	SRCFILE "minty.bas",1339
	DECLE 39342,162
	;[1340]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1340
	DECLE 16191,63
	;[1341]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1341
	DECLE 16128,63
	;[1342]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1342
	DECLE 16128,63
	;[1343]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1343
	DECLE 16128,63
	;[1344]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1344
	DECLE 16128,63
	;[1345]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1345
	DECLE 16128,63
	;[1346]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1346
	DECLE 16128,63
	;[1347]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1347
	DECLE 16128,0
	;[1348]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1348
	DECLE 0,0
	;[1349]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1349
	DECLE 0,0
	;[1350]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1350
	DECLE 0,0
	;[1351]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1351
	DECLE 0,0
	;[1352]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1352
	DECLE 0,0
	;[1353]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1353
	DECLE 0,0
	;[1354]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1354
	DECLE 0,0
	;[1355]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1355
	DECLE 0,0
	;[1356]     MUSIC   A2,    -,    -
	SRCFILE "minty.bas",1356
	DECLE 138,0
	;[1357]     MUSIC    S,   E3,    -
	SRCFILE "minty.bas",1357
	DECLE 37183,0
	;[1358]     MUSIC    S,    S,   A3
	SRCFILE "minty.bas",1358
	DECLE 16191,150
	;[1359]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1359
	DECLE 16191,63
	;[1360]     MUSIC   C3,    -,    -
	SRCFILE "minty.bas",1360
	DECLE 141,0
	;[1361]     MUSIC    -,   E3,    -
	SRCFILE "minty.bas",1361
	DECLE 37120,0
	;[1362]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1362
	DECLE 16128,0
	;[1363]     MUSIC   A3,    -,    -
	SRCFILE "minty.bas",1363
	DECLE 150,0
	;[1364] 
	SRCFILE "minty.bas",1364
	;[1365] REM Timing 400 frames, 8.00 secs
	SRCFILE "minty.bas",1365
	;[1366] 
	SRCFILE "minty.bas",1366
	;[1367]     MUSIC    S,   C4,    -
	SRCFILE "minty.bas",1367
	DECLE 39231,0
	;[1368]     MUSIC   E4,    S,    -
	SRCFILE "minty.bas",1368
	DECLE 16285,0
	;[1369]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1369
	DECLE 16191,0
	;[1370]     MUSIC    -,   A6,   A4
	SRCFILE "minty.bas",1370
	DECLE 47616,162
	;[1371]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1371
	DECLE 16128,63
	;[1372]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1372
	DECLE 16128,0
	;[1373]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1373
	DECLE 0,0
	;[1374]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1374
	DECLE 0,0
	;[1375]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1375
	DECLE 0,0
	;[1376]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1376
	DECLE 0,0
	;[1377]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1377
	DECLE 0,0
	;[1378]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1378
	DECLE 0,0
	;[1379]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1379
	DECLE 0,0
	;[1380]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1380
	DECLE 0,0
	;[1381]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1381
	DECLE 0,0
	;[1382]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1382
	DECLE 0,0
	;[1383]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1383
	DECLE 0,0
	;[1384]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1384
	DECLE 0,0
	;[1385]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1385
	DECLE 0,0
	;[1386]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1386
	DECLE 0,0
	;[1387]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1387
	DECLE 0,0
	;[1388]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1388
	DECLE 0,0
	;[1389]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1389
	DECLE 0,0
	;[1390]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1390
	DECLE 0,0
	;[1391]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1391
	DECLE 0,0
	;[1392]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1392
	DECLE 35502,150
	;[1393]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1393
	DECLE 16191,63
	;[1394]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1394
	DECLE 16191,63
	;[1395]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1395
	DECLE 16304,152
	;[1396]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1396
	DECLE 16191,63
	;[1397]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1397
	DECLE 16191,63
	;[1398]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1398
	DECLE 35505,153
	;[1399]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1399
	DECLE 16191,63
	;[1400]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1400
	DECLE 63,63
	;[1401]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1401
	DECLE 40373,0
	;[1402]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1402
	DECLE 16191,0
	;[1403]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1403
	DECLE 16191,0
	;[1404]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1404
	DECLE 35502,150
	;[1405]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1405
	DECLE 16191,63
	;[1406]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1406
	DECLE 16304,152
	;[1407]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1407
	DECLE 16191,63
	;[1408]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1408
	DECLE 16191,63
	;[1409]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1409
	DECLE 35505,153
	;[1410]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1410
	DECLE 16191,63
	;[1411]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1411
	DECLE 16191,63
	;[1412]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1412
	DECLE 40373,0
	;[1413]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1413
	DECLE 16191,0
	;[1414]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1414
	DECLE 16191,0
	;[1415]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1415
	DECLE 35502,150
	;[1416]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1416
	DECLE 16191,63
	;[1417] 
	SRCFILE "minty.bas",1417
	;[1418] REM Timing 500 frames, 10.00 secs
	SRCFILE "minty.bas",1418
	;[1419] 
	SRCFILE "minty.bas",1419
	;[1420]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1420
	DECLE 16191,63
	;[1421]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1421
	DECLE 16304,152
	;[1422]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1422
	DECLE 16191,63
	;[1423]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1423
	DECLE 35505,153
	;[1424]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1424
	DECLE 16191,63
	;[1425]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1425
	DECLE 16191,63
	;[1426]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1426
	DECLE 40373,0
	;[1427]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1427
	DECLE 16191,0
	;[1428]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1428
	DECLE 16191,0
	;[1429]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1429
	DECLE 35502,150
	;[1430]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1430
	DECLE 16191,63
	;[1431]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1431
	DECLE 16191,63
	;[1432]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1432
	DECLE 16304,152
	;[1433]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1433
	DECLE 16191,63
	;[1434]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1434
	DECLE 16191,63
	;[1435]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1435
	DECLE 35505,153
	;[1436]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1436
	DECLE 16191,63
	;[1437]     MUSIC   E6,    -,   E4
	SRCFILE "minty.bas",1437
	DECLE 181,157
	;[1438]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1438
	DECLE 63,63
	;[1439]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1439
	DECLE 63,63
	;[1440]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1440
	DECLE 35502,150
	;[1441]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1441
	DECLE 16191,63
	;[1442]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1442
	DECLE 16191,63
	;[1443]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1443
	DECLE 16304,152
	;[1444]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1444
	DECLE 16191,63
	;[1445]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1445
	DECLE 16191,63
	;[1446]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1446
	DECLE 35505,153
	;[1447]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1447
	DECLE 16191,63
	;[1448]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1448
	DECLE 63,63
	;[1449]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1449
	DECLE 40373,0
	;[1450]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1450
	DECLE 16191,0
	;[1451]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1451
	DECLE 16191,0
	;[1452]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1452
	DECLE 35502,150
	;[1453]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1453
	DECLE 16191,63
	;[1454]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1454
	DECLE 16304,152
	;[1455]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1455
	DECLE 16191,63
	;[1456]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1456
	DECLE 16191,63
	;[1457]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1457
	DECLE 35505,153
	;[1458]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1458
	DECLE 16191,63
	;[1459]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1459
	DECLE 16191,63
	;[1460]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1460
	DECLE 40373,0
	;[1461]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1461
	DECLE 16191,0
	;[1462]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1462
	DECLE 16191,0
	;[1463]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1463
	DECLE 35502,150
	;[1464]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1464
	DECLE 16191,63
	;[1465]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1465
	DECLE 16191,63
	;[1466]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1466
	DECLE 16304,152
	;[1467]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1467
	DECLE 16191,63
	;[1468]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1468
	DECLE 35505,153
	;[1469]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1469
	DECLE 16191,63
	;[1470] 
	SRCFILE "minty.bas",1470
	;[1471] REM Timing 600 frames, 12.00 secs
	SRCFILE "minty.bas",1471
	;[1472] 
	SRCFILE "minty.bas",1472
	;[1473]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1473
	DECLE 63,63
	;[1474]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1474
	DECLE 40373,0
	;[1475]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1475
	DECLE 16191,0
	;[1476]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1476
	DECLE 16191,0
	;[1477]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1477
	DECLE 35502,150
	;[1478]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1478
	DECLE 16191,63
	;[1479]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1479
	DECLE 16191,63
	;[1480]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1480
	DECLE 16304,152
	;[1481]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1481
	DECLE 16191,63
	;[1482]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1482
	DECLE 16191,63
	;[1483]     MUSIC   C6,   A2,   E4
	SRCFILE "minty.bas",1483
	DECLE 35505,157
	;[1484]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1484
	DECLE 16191,63
	;[1485]     MUSIC   E6,    -,    -
	SRCFILE "minty.bas",1485
	DECLE 181,0
	;[1486]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1486
	DECLE 63,0
	;[1487]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1487
	DECLE 63,0
	;[1488]     MUSIC   A5,   A2,   E4
	SRCFILE "minty.bas",1488
	DECLE 35502,157
	;[1489]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1489
	DECLE 16191,63
	;[1490]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1490
	DECLE 16191,0
	;[1491]     MUSIC   B5,    S,    -
	SRCFILE "minty.bas",1491
	DECLE 16304,0
	;[1492]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1492
	DECLE 16191,0
	;[1493]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1493
	DECLE 16191,0
	;[1494]     MUSIC   C6,   A2,   F4
	SRCFILE "minty.bas",1494
	DECLE 35505,158
	;[1495]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1495
	DECLE 16191,63
	;[1496]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1496
	DECLE 63,0
	;[1497]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1497
	DECLE 0,0
	;[1498]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1498
	DECLE 0,0
	;[1499]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1499
	DECLE 0,0
	;[1500]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",1500
	DECLE 35486,153
	;[1501]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1501
	DECLE 16191,63
	;[1502]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1502
	DECLE 16191,63
	;[1503]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1503
	DECLE 16128,0
	;[1504]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1504
	DECLE 16128,0
	;[1505]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",1505
	DECLE 35485,153
	;[1506]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1506
	DECLE 16191,63
	;[1507]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1507
	DECLE 0,0
	;[1508]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1508
	DECLE 0,0
	;[1509]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1509
	DECLE 0,0
	;[1510]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1510
	DECLE 0,0
	;[1511]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",1511
	DECLE 35485,153
	;[1512]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1512
	DECLE 16191,63
	;[1513]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1513
	DECLE 16191,63
	;[1514]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1514
	DECLE 16128,0
	;[1515]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1515
	DECLE 16128,0
	;[1516]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",1516
	DECLE 35486,153
	;[1517]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1517
	DECLE 16191,63
	;[1518]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1518
	DECLE 0,0
	;[1519]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1519
	DECLE 0,0
	;[1520]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1520
	DECLE 0,0
	;[1521]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1521
	DECLE 0,0
	;[1522]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",1522
	DECLE 35486,153
	;[1523] 
	SRCFILE "minty.bas",1523
	;[1524] REM Timing 700 frames, 14.00 secs
	SRCFILE "minty.bas",1524
	;[1525] 
	SRCFILE "minty.bas",1525
	;[1526]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1526
	DECLE 16191,63
	;[1527]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1527
	DECLE 16191,63
	;[1528]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1528
	DECLE 16191,63
	;[1529]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1529
	DECLE 16128,63
	;[1530]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1530
	DECLE 16128,0
	;[1531]     MUSIC   E4,   A2,   A3
	SRCFILE "minty.bas",1531
	DECLE 35485,150
	;[1532]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1532
	DECLE 16191,63
	;[1533]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1533
	DECLE 0,0
	;[1534]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1534
	DECLE 0,0
	;[1535]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1535
	DECLE 0,0
	;[1536]     MUSIC   E4,  G2#,   B3
	SRCFILE "minty.bas",1536
	DECLE 35229,152
	;[1537]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1537
	DECLE 16191,63
	;[1538]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1538
	DECLE 16191,63
	;[1539]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1539
	DECLE 16191,63
	;[1540]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1540
	DECLE 16191,0
	;[1541]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1541
	DECLE 16128,0
	;[1542]     MUSIC   F4,  G2#,   B3
	SRCFILE "minty.bas",1542
	DECLE 35230,152
	;[1543]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1543
	DECLE 16191,63
	;[1544]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1544
	DECLE 0,0
	;[1545]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1545
	DECLE 0,0
	;[1546]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1546
	DECLE 0,0
	;[1547]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1547
	DECLE 0,0
	;[1548]     MUSIC   F4,  G2#,   B3
	SRCFILE "minty.bas",1548
	DECLE 35230,152
	;[1549]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1549
	DECLE 16191,63
	;[1550]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1550
	DECLE 16191,63
	;[1551]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1551
	DECLE 16128,63
	;[1552]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1552
	DECLE 16128,63
	;[1553]     MUSIC   E4,  G2#,    S
	SRCFILE "minty.bas",1553
	DECLE 35229,63
	;[1554]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1554
	DECLE 16191,63
	;[1555]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1555
	DECLE 0,0
	;[1556]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1556
	DECLE 0,0
	;[1557]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1557
	DECLE 0,0
	;[1558]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1558
	DECLE 0,0
	;[1559]     MUSIC   E4,  G2#,  G3#
	SRCFILE "minty.bas",1559
	DECLE 35229,149
	;[1560]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1560
	DECLE 16191,63
	;[1561]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1561
	DECLE 16191,0
	;[1562]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1562
	DECLE 16128,0
	;[1563]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1563
	DECLE 16128,0
	;[1564]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",1564
	DECLE 35234,157
	;[1565]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1565
	DECLE 16191,63
	;[1566]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1566
	DECLE 0,63
	;[1567]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1567
	DECLE 0,0
	;[1568]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1568
	DECLE 0,0
	;[1569]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1569
	DECLE 0,0
	;[1570]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",1570
	DECLE 35234,157
	;[1571]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1571
	DECLE 16191,63
	;[1572]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1572
	DECLE 16191,63
	;[1573]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1573
	DECLE 16191,63
	;[1574]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1574
	DECLE 16128,63
	;[1575]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1575
	DECLE 16128,0
	;[1576] 
	SRCFILE "minty.bas",1576
	;[1577] REM Timing 800 frames, 16.00 secs
	SRCFILE "minty.bas",1577
	;[1578] 
	SRCFILE "minty.bas",1578
	;[1579]     MUSIC  G4#,  G2#,   E4
	SRCFILE "minty.bas",1579
	DECLE 35233,157
	;[1580]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1580
	DECLE 16191,63
	;[1581]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1581
	DECLE 63,63
	;[1582]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1582
	DECLE 63,63
	;[1583]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1583
	DECLE 63,63
	;[1584]     MUSIC    S,   E2,    S
	SRCFILE "minty.bas",1584
	DECLE 34111,63
	;[1585]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1585
	DECLE 16191,63
	;[1586]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1586
	DECLE 63,63
	;[1587]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1587
	DECLE 0,63
	;[1588]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1588
	DECLE 0,63
	;[1589]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1589
	DECLE 0,63
	;[1590]     MUSIC   E2,    -,    S
	SRCFILE "minty.bas",1590
	DECLE 133,63
	;[1591]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1591
	DECLE 63,63
	;[1592]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1592
	DECLE 0,63
	;[1593]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1593
	DECLE 0,63
	;[1594]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1594
	DECLE 0,63
	;[1595]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1595
	DECLE 0,63
	;[1596]     MUSIC   E3,   D2,   E2
	SRCFILE "minty.bas",1596
	DECLE 33681,133
	;[1597]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1597
	DECLE 16191,63
	;[1598]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1598
	DECLE 16191,0
	;[1599]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1599
	DECLE 16191,0
	;[1600]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1600
	DECLE 16191,0
	;[1601]     MUSIC    S,   E4,   E2
	SRCFILE "minty.bas",1601
	DECLE 40255,133
	;[1602]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1602
	DECLE 16191,63
	;[1603]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1603
	DECLE 63,63
	;[1604]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1604
	DECLE 63,0
	;[1605]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1605
	DECLE 63,0
	;[1606]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1606
	DECLE 63,0
	;[1607]     MUSIC   B4,   D5,   B2
	SRCFILE "minty.bas",1607
	DECLE 42916,140
	;[1608]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1608
	DECLE 16191,63
	;[1609]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1609
	DECLE 0,0
	;[1610]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1610
	DECLE 0,0
	;[1611]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1611
	DECLE 0,0
	;[1612]     MUSIC   D5,   E3,   B4
	SRCFILE "minty.bas",1612
	DECLE 37287,164
	;[1613]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1613
	DECLE 16191,63
	;[1614]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1614
	DECLE 16191,63
	;[1615]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1615
	DECLE 16191,63
	;[1616]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1616
	DECLE 16191,63
	;[1617]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1617
	DECLE 16191,63
	;[1618]     MUSIC   E2,    S,    S
	SRCFILE "minty.bas",1618
	DECLE 16261,63
	;[1619]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1619
	DECLE 16191,63
	;[1620]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1620
	DECLE 16128,0
	;[1621]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1621
	DECLE 16128,0
	;[1622]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1622
	DECLE 16128,0
	;[1623]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1623
	DECLE 16128,0
	;[1624]     MUSIC   D5,   E2,   A4
	SRCFILE "minty.bas",1624
	DECLE 34215,162
	;[1625]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1625
	DECLE 16191,63
	;[1626]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1626
	DECLE 16191,63
	;[1627]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1627
	DECLE 63,63
	;[1628]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1628
	DECLE 63,63
	;[1629] 
	SRCFILE "minty.bas",1629
	;[1630] REM Timing 900 frames, 18.00 secs
	SRCFILE "minty.bas",1630
	;[1631] 
	SRCFILE "minty.bas",1631
	;[1632]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",1632
	DECLE 35502,165
	;[1633]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1633
	DECLE 16191,63
	;[1634]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1634
	DECLE 16191,63
	;[1635]     MUSIC   B5,    S,    S
	SRCFILE "minty.bas",1635
	DECLE 16304,63
	;[1636]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1636
	DECLE 16191,63
	;[1637]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1637
	DECLE 16191,63
	;[1638]     MUSIC   C6,   A2,    S
	SRCFILE "minty.bas",1638
	DECLE 35505,63
	;[1639]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1639
	DECLE 16191,63
	;[1640]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1640
	DECLE 63,63
	;[1641]     MUSIC   E6,   E4,    S
	SRCFILE "minty.bas",1641
	DECLE 40373,63
	;[1642]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1642
	DECLE 16191,63
	;[1643]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1643
	DECLE 16191,63
	;[1644]     MUSIC   A5,   A2,    -
	SRCFILE "minty.bas",1644
	DECLE 35502,0
	;[1645]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1645
	DECLE 16191,0
	;[1646]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1646
	DECLE 16304,152
	;[1647]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1647
	DECLE 16191,63
	;[1648]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1648
	DECLE 16191,63
	;[1649]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1649
	DECLE 35505,153
	;[1650]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1650
	DECLE 16191,63
	;[1651]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1651
	DECLE 16191,63
	;[1652]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1652
	DECLE 40373,0
	;[1653]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1653
	DECLE 16191,0
	;[1654]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1654
	DECLE 16191,0
	;[1655]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1655
	DECLE 35502,150
	;[1656]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1656
	DECLE 16191,63
	;[1657]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1657
	DECLE 16191,63
	;[1658]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1658
	DECLE 16304,152
	;[1659]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1659
	DECLE 16191,63
	;[1660]     MUSIC   C6,   B2,   C4
	SRCFILE "minty.bas",1660
	DECLE 36017,153
	;[1661]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1661
	DECLE 16191,63
	;[1662]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1662
	DECLE 63,63
	;[1663]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1663
	DECLE 40373,0
	;[1664]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1664
	DECLE 16191,0
	;[1665]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1665
	DECLE 63,0
	;[1666]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1666
	DECLE 35502,150
	;[1667]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1667
	DECLE 16191,63
	;[1668]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1668
	DECLE 16191,63
	;[1669]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1669
	DECLE 16304,152
	;[1670]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1670
	DECLE 16191,63
	;[1671]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1671
	DECLE 16191,63
	;[1672]     MUSIC   C6,   A2,   E4
	SRCFILE "minty.bas",1672
	DECLE 35505,157
	;[1673]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1673
	DECLE 16191,63
	;[1674]     MUSIC   E6,    -,    -
	SRCFILE "minty.bas",1674
	DECLE 181,0
	;[1675]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1675
	DECLE 63,0
	;[1676]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1676
	DECLE 63,0
	;[1677]     MUSIC   A5,   A2,   E4
	SRCFILE "minty.bas",1677
	DECLE 35502,157
	;[1678]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1678
	DECLE 16191,63
	;[1679]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1679
	DECLE 16191,0
	;[1680]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1680
	DECLE 16128,0
	;[1681]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1681
	DECLE 16128,0
	;[1682] 
	SRCFILE "minty.bas",1682
	;[1683] REM Timing 1000 frames, 20.00 secs
	SRCFILE "minty.bas",1683
	;[1684] 
	SRCFILE "minty.bas",1684
	;[1685]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1685
	DECLE 16128,0
	;[1686]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",1686
	DECLE 35486,153
	;[1687]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1687
	DECLE 16191,63
	;[1688]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1688
	DECLE 0,0
	;[1689]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1689
	DECLE 0,0
	;[1690]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1690
	DECLE 0,0
	;[1691]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1691
	DECLE 0,0
	;[1692]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",1692
	DECLE 35486,153
	;[1693]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1693
	DECLE 16191,63
	;[1694]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1694
	DECLE 16191,63
	;[1695]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1695
	DECLE 16191,0
	;[1696]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1696
	DECLE 16128,0
	;[1697]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",1697
	DECLE 35485,153
	;[1698]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1698
	DECLE 16191,63
	;[1699]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1699
	DECLE 0,0
	;[1700]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1700
	DECLE 0,0
	;[1701]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1701
	DECLE 0,0
	;[1702]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1702
	DECLE 0,0
	;[1703]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",1703
	DECLE 35485,153
	;[1704]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1704
	DECLE 16191,63
	;[1705]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1705
	DECLE 16191,63
	;[1706]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1706
	DECLE 16128,63
	;[1707]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1707
	DECLE 16128,0
	;[1708]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",1708
	DECLE 35486,153
	;[1709]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1709
	DECLE 16191,63
	;[1710]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1710
	DECLE 0,0
	;[1711]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1711
	DECLE 0,0
	;[1712]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1712
	DECLE 0,0
	;[1713]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1713
	DECLE 0,0
	;[1714]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",1714
	DECLE 35486,153
	;[1715]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1715
	DECLE 16191,63
	;[1716]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1716
	DECLE 16191,63
	;[1717]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1717
	DECLE 16191,63
	;[1718]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1718
	DECLE 16191,63
	;[1719]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1719
	DECLE 16128,63
	;[1720]     MUSIC   E4,   A2,    -
	SRCFILE "minty.bas",1720
	DECLE 35485,0
	;[1721]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1721
	DECLE 16191,0
	;[1722]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1722
	DECLE 0,0
	;[1723]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1723
	DECLE 0,0
	;[1724]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1724
	DECLE 0,0
	;[1725]     MUSIC   E4,  G2#,   B3
	SRCFILE "minty.bas",1725
	DECLE 35229,152
	;[1726]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1726
	DECLE 16191,63
	;[1727]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1727
	DECLE 16191,63
	;[1728]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1728
	DECLE 16191,63
	;[1729]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1729
	DECLE 16191,63
	;[1730]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1730
	DECLE 16191,63
	;[1731]     MUSIC   F4,  G2#,    S
	SRCFILE "minty.bas",1731
	DECLE 35230,63
	;[1732]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1732
	DECLE 16191,0
	;[1733]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1733
	DECLE 0,0
	;[1734]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1734
	DECLE 0,0
	;[1735] 
	SRCFILE "minty.bas",1735
	;[1736] REM Timing 1100 frames, 22.00 secs
	SRCFILE "minty.bas",1736
	;[1737] 
	SRCFILE "minty.bas",1737
	;[1738]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1738
	DECLE 0,0
	;[1739]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1739
	DECLE 0,0
	;[1740]     MUSIC   F4,  G2#,   B3
	SRCFILE "minty.bas",1740
	DECLE 35230,152
	;[1741]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1741
	DECLE 16191,63
	;[1742]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1742
	DECLE 16191,63
	;[1743]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1743
	DECLE 16191,63
	;[1744]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1744
	DECLE 16191,63
	;[1745]     MUSIC   E4,  G2#,    -
	SRCFILE "minty.bas",1745
	DECLE 35229,0
	;[1746]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1746
	DECLE 16191,0
	;[1747]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1747
	DECLE 0,0
	;[1748]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1748
	DECLE 0,0
	;[1749]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1749
	DECLE 0,0
	;[1750]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1750
	DECLE 0,0
	;[1751]     MUSIC   E4,  G2#,   B3
	SRCFILE "minty.bas",1751
	DECLE 35229,152
	;[1752]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1752
	DECLE 16191,63
	;[1753]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1753
	DECLE 16191,63
	;[1754]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1754
	DECLE 16191,63
	;[1755]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1755
	DECLE 16191,0
	;[1756]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",1756
	DECLE 35234,157
	;[1757]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1757
	DECLE 16191,63
	;[1758]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1758
	DECLE 0,0
	;[1759]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1759
	DECLE 0,0
	;[1760]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1760
	DECLE 0,0
	;[1761]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1761
	DECLE 0,0
	;[1762]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",1762
	DECLE 35234,157
	;[1763]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1763
	DECLE 16191,63
	;[1764]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1764
	DECLE 16191,63
	;[1765]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1765
	DECLE 16191,63
	;[1766]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1766
	DECLE 16191,63
	;[1767]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",1767
	DECLE 16128,63
	;[1768]     MUSIC  G4#,  G2#,    S
	SRCFILE "minty.bas",1768
	DECLE 35233,63
	;[1769]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1769
	DECLE 16191,63
	;[1770]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1770
	DECLE 63,63
	;[1771]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1771
	DECLE 63,63
	;[1772]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1772
	DECLE 63,63
	;[1773]     MUSIC    S,   E2,    S
	SRCFILE "minty.bas",1773
	DECLE 34111,63
	;[1774]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1774
	DECLE 16191,63
	;[1775]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1775
	DECLE 0,0
	;[1776]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1776
	DECLE 0,0
	;[1777]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1777
	DECLE 0,0
	;[1778]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1778
	DECLE 0,0
	;[1779]     MUSIC   E3,   E2,    -
	SRCFILE "minty.bas",1779
	DECLE 34193,0
	;[1780]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1780
	DECLE 16191,0
	;[1781]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1781
	DECLE 16128,0
	;[1782]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1782
	DECLE 0,0
	;[1783]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1783
	DECLE 0,0
	;[1784]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1784
	DECLE 0,0
	;[1785]     MUSIC   E2,   D2,    -
	SRCFILE "minty.bas",1785
	DECLE 33669,0
	;[1786]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1786
	DECLE 16191,0
	;[1787]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1787
	DECLE 16128,0
	;[1788] 
	SRCFILE "minty.bas",1788
	;[1789] REM Timing 1200 frames, 24.00 secs
	SRCFILE "minty.bas",1789
	;[1790] 
	SRCFILE "minty.bas",1790
	;[1791]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1791
	DECLE 16128,0
	;[1792]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1792
	DECLE 0,0
	;[1793]     MUSIC   E3,   E2,    -
	SRCFILE "minty.bas",1793
	DECLE 34193,0
	;[1794]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1794
	DECLE 16191,0
	;[1795]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1795
	DECLE 16191,0
	;[1796]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1796
	DECLE 0,0
	;[1797]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1797
	DECLE 0,0
	;[1798]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1798
	DECLE 0,0
	;[1799]     MUSIC   F5,   B2,   D5
	SRCFILE "minty.bas",1799
	DECLE 36010,167
	;[1800]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1800
	DECLE 16191,63
	;[1801]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1801
	DECLE 0,0
	;[1802]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1802
	DECLE 0,0
	;[1803]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1803
	DECLE 0,0
	;[1804]     MUSIC   F5,   E3,   D5
	SRCFILE "minty.bas",1804
	DECLE 37290,167
	;[1805]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1805
	DECLE 16191,63
	;[1806]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1806
	DECLE 16191,63
	;[1807]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1807
	DECLE 16191,63
	;[1808]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1808
	DECLE 16191,63
	;[1809]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1809
	DECLE 16191,63
	;[1810]     MUSIC   E2,    -,    -
	SRCFILE "minty.bas",1810
	DECLE 133,0
	;[1811]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1811
	DECLE 63,0
	;[1812]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1812
	DECLE 0,0
	;[1813]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1813
	DECLE 0,0
	;[1814]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1814
	DECLE 0,0
	;[1815]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1815
	DECLE 0,0
	;[1816]     MUSIC   F5,   E2,   C5
	SRCFILE "minty.bas",1816
	DECLE 34218,165
	;[1817]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1817
	DECLE 16191,63
	;[1818]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1818
	DECLE 16191,63
	;[1819]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1819
	DECLE 16191,63
	;[1820]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1820
	DECLE 0,63
	;[1821]     MUSIC   A5,   A2,   E5
	SRCFILE "minty.bas",1821
	DECLE 35502,169
	;[1822]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1822
	DECLE 16191,63
	;[1823]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1823
	DECLE 16191,63
	;[1824]     MUSIC   B5,    S,    S
	SRCFILE "minty.bas",1824
	DECLE 16304,63
	;[1825]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1825
	DECLE 16191,63
	;[1826]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1826
	DECLE 16191,63
	;[1827]     MUSIC   C6,   A2,    S
	SRCFILE "minty.bas",1827
	DECLE 35505,63
	;[1828]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1828
	DECLE 16191,63
	;[1829]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1829
	DECLE 63,63
	;[1830]     MUSIC   E6,   E4,    S
	SRCFILE "minty.bas",1830
	DECLE 40373,63
	;[1831]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1831
	DECLE 16191,63
	;[1832]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1832
	DECLE 16191,63
	;[1833]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1833
	DECLE 35502,150
	;[1834]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1834
	DECLE 16191,63
	;[1835]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1835
	DECLE 16304,152
	;[1836]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1836
	DECLE 16191,63
	;[1837]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1837
	DECLE 16191,63
	;[1838]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1838
	DECLE 35505,153
	;[1839]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1839
	DECLE 16191,63
	;[1840]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1840
	DECLE 16191,63
	;[1841] 
	SRCFILE "minty.bas",1841
	;[1842] REM Timing 1300 frames, 26.00 secs
	SRCFILE "minty.bas",1842
	;[1843] 
	SRCFILE "minty.bas",1843
	;[1844]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1844
	DECLE 40373,0
	;[1845]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1845
	DECLE 16191,0
	;[1846]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1846
	DECLE 16191,0
	;[1847]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1847
	DECLE 35502,150
	;[1848]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1848
	DECLE 16191,63
	;[1849]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1849
	DECLE 16191,63
	;[1850]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1850
	DECLE 16304,152
	;[1851]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1851
	DECLE 16191,63
	;[1852]     MUSIC   C6,   B2,   C4
	SRCFILE "minty.bas",1852
	DECLE 36017,153
	;[1853]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1853
	DECLE 16191,63
	;[1854]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1854
	DECLE 63,63
	;[1855]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",1855
	DECLE 40373,0
	;[1856]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1856
	DECLE 16191,0
	;[1857]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1857
	DECLE 16191,0
	;[1858]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",1858
	DECLE 35502,150
	;[1859]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1859
	DECLE 16191,63
	;[1860]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1860
	DECLE 16191,63
	;[1861]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",1861
	DECLE 16304,152
	;[1862]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1862
	DECLE 16191,63
	;[1863]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1863
	DECLE 16191,63
	;[1864]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",1864
	DECLE 35505,153
	;[1865]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1865
	DECLE 16191,63
	;[1866]     MUSIC   E6,    -,   E4
	SRCFILE "minty.bas",1866
	DECLE 181,157
	;[1867]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1867
	DECLE 63,63
	;[1868]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1868
	DECLE 63,63
	;[1869]     MUSIC   A5,   A2,   D5
	SRCFILE "minty.bas",1869
	DECLE 35502,167
	;[1870]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1870
	DECLE 16191,63
	;[1871]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1871
	DECLE 16191,0
	;[1872]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1872
	DECLE 16128,0
	;[1873]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1873
	DECLE 0,0
	;[1874]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1874
	DECLE 0,0
	;[1875]     MUSIC   D5,   A2,   B4
	SRCFILE "minty.bas",1875
	DECLE 35495,164
	;[1876]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1876
	DECLE 16191,63
	;[1877]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1877
	DECLE 63,63
	;[1878]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1878
	DECLE 63,63
	;[1879]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1879
	DECLE 0,63
	;[1880]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1880
	DECLE 0,63
	;[1881]     MUSIC   A2,   E2,    S
	SRCFILE "minty.bas",1881
	DECLE 34186,63
	;[1882]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1882
	DECLE 16191,63
	;[1883]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1883
	DECLE 63,63
	;[1884]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1884
	DECLE 63,0
	;[1885]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1885
	DECLE 0,0
	;[1886]     MUSIC   C5,   A2,   A4
	SRCFILE "minty.bas",1886
	DECLE 35493,162
	;[1887]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1887
	DECLE 16191,63
	;[1888]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1888
	DECLE 63,63
	;[1889]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1889
	DECLE 63,63
	;[1890]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1890
	DECLE 63,63
	;[1891]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1891
	DECLE 63,63
	;[1892]     MUSIC    S,   A2,    S
	SRCFILE "minty.bas",1892
	DECLE 35391,63
	;[1893]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1893
	DECLE 16191,63
	;[1894] 
	SRCFILE "minty.bas",1894
	;[1895] REM Timing 1400 frames, 28.00 secs
	SRCFILE "minty.bas",1895
	;[1896] 
	SRCFILE "minty.bas",1896
	;[1897]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1897
	DECLE 16191,63
	;[1898]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1898
	DECLE 16191,63
	;[1899]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1899
	DECLE 63,63
	;[1900]     MUSIC    S,   A2,    S
	SRCFILE "minty.bas",1900
	DECLE 35391,63
	;[1901]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1901
	DECLE 16191,63
	;[1902]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1902
	DECLE 63,63
	;[1903]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1903
	DECLE 63,63
	;[1904]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1904
	DECLE 63,63
	;[1905]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1905
	DECLE 63,63
	;[1906]     MUSIC   A2,   E2,    S
	SRCFILE "minty.bas",1906
	DECLE 34186,63
	;[1907]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1907
	DECLE 16191,63
	;[1908]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1908
	DECLE 63,63
	;[1909]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1909
	DECLE 63,0
	;[1910]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1910
	DECLE 63,0
	;[1911]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1911
	DECLE 0,0
	;[1912]     MUSIC   C5,   A2,   A4
	SRCFILE "minty.bas",1912
	DECLE 35493,162
	;[1913]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1913
	DECLE 16191,63
	;[1914]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1914
	DECLE 63,63
	;[1915]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1915
	DECLE 63,0
	;[1916]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1916
	DECLE 0,0
	;[1917]     MUSIC   B4,   A2,  G4#
	SRCFILE "minty.bas",1917
	DECLE 35492,161
	;[1918]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1918
	DECLE 16191,63
	;[1919]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1919
	DECLE 16128,0
	;[1920]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1920
	DECLE 16128,0
	;[1921]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",1921
	DECLE 16128,0
	;[1922]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1922
	DECLE 0,0
	;[1923]     MUSIC   B4,   A2,  G4#
	SRCFILE "minty.bas",1923
	DECLE 35492,161
	;[1924]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1924
	DECLE 16191,63
	;[1925]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1925
	DECLE 63,63
	;[1926]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1926
	DECLE 63,63
	;[1927]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1927
	DECLE 63,63
	;[1928]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1928
	DECLE 63,63
	;[1929]     MUSIC   A2,   E2,    S
	SRCFILE "minty.bas",1929
	DECLE 34186,63
	;[1930]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1930
	DECLE 16191,63
	;[1931]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1931
	DECLE 63,0
	;[1932]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1932
	DECLE 63,0
	;[1933]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",1933
	DECLE 0,0
	;[1934]     MUSIC   C5,   A2,   E4
	SRCFILE "minty.bas",1934
	DECLE 35493,157
	;[1935]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1935
	DECLE 16191,63
	;[1936]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1936
	DECLE 16191,63
	;[1937]     MUSIC   B4,    -,    S
	SRCFILE "minty.bas",1937
	DECLE 164,63
	;[1938]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1938
	DECLE 63,63
	;[1939]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1939
	DECLE 63,63
	;[1940]     MUSIC   A4,   A2,    S
	SRCFILE "minty.bas",1940
	DECLE 35490,63
	;[1941]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1941
	DECLE 16191,63
	;[1942]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1942
	DECLE 16191,63
	;[1943]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1943
	DECLE 16191,63
	;[1944]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1944
	DECLE 16191,63
	;[1945]     MUSIC    S,   B2,    S
	SRCFILE "minty.bas",1945
	DECLE 35903,63
	;[1946]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1946
	DECLE 16191,63
	;[1947] 
	SRCFILE "minty.bas",1947
	;[1948] REM Timing 1500 frames, 30.00 secs
	SRCFILE "minty.bas",1948
	;[1949] 
	SRCFILE "minty.bas",1949
	;[1950]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1950
	DECLE 63,63
	;[1951]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1951
	DECLE 63,63
	;[1952]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",1952
	DECLE 63,63
	;[1953]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1953
	DECLE 63,0
	;[1954]     MUSIC    S,   G2,   G3
	SRCFILE "minty.bas",1954
	DECLE 34879,148
	;[1955]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1955
	DECLE 16191,63
	;[1956]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1956
	DECLE 16191,63
	;[1957]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1957
	DECLE 16191,63
	;[1958]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1958
	DECLE 16191,63
	;[1959]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1959
	DECLE 16191,63
	;[1960]     MUSIC    S,   G2,    S
	SRCFILE "minty.bas",1960
	DECLE 34879,63
	;[1961]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1961
	DECLE 16191,63
	;[1962]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1962
	DECLE 0,63
	;[1963]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1963
	DECLE 0,63
	;[1964]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",1964
	DECLE 0,63
	;[1965]     MUSIC   F3,   F2,  F2#
	SRCFILE "minty.bas",1965
	DECLE 34450,135
	;[1966]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1966
	DECLE 16191,63
	;[1967]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1967
	DECLE 16191,0
	;[1968]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1968
	DECLE 16191,0
	;[1969]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1969
	DECLE 16191,0
	;[1970]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1970
	DECLE 16191,0
	;[1971]     MUSIC    S,   D5,  A4#
	SRCFILE "minty.bas",1971
	DECLE 42815,163
	;[1972]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1972
	DECLE 16191,63
	;[1973]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1973
	DECLE 63,0
	;[1974]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1974
	DECLE 63,0
	;[1975]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1975
	DECLE 63,0
	;[1976]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1976
	DECLE 63,0
	;[1977]     MUSIC    S,   D5,  A4#
	SRCFILE "minty.bas",1977
	DECLE 42815,163
	;[1978]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1978
	DECLE 16191,63
	;[1979]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1979
	DECLE 16191,63
	;[1980]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1980
	DECLE 16191,63
	;[1981]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1981
	DECLE 16191,63
	;[1982]     MUSIC    S,    S,   F2
	SRCFILE "minty.bas",1982
	DECLE 16191,134
	;[1983]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",1983
	DECLE 16191,0
	;[1984]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1984
	DECLE 63,0
	;[1985]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1985
	DECLE 63,0
	;[1986]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1986
	DECLE 63,0
	;[1987]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1987
	DECLE 63,0
	;[1988]     MUSIC    S,   C5,   A4
	SRCFILE "minty.bas",1988
	DECLE 42303,162
	;[1989]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1989
	DECLE 16191,63
	;[1990]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1990
	DECLE 63,0
	;[1991]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1991
	DECLE 63,0
	;[1992]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",1992
	DECLE 63,0
	;[1993]     MUSIC    S,   C5,   A4
	SRCFILE "minty.bas",1993
	DECLE 42303,162
	;[1994]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1994
	DECLE 16191,63
	;[1995]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1995
	DECLE 16191,63
	;[1996]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1996
	DECLE 16191,63
	;[1997]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1997
	DECLE 16191,63
	;[1998]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",1998
	DECLE 16191,63
	;[1999]     MUSIC    S,    S,   F2
	SRCFILE "minty.bas",1999
	DECLE 16191,134
	;[2000] 
	SRCFILE "minty.bas",2000
	;[2001] REM Timing 1600 frames, 32.00 secs
	SRCFILE "minty.bas",2001
	;[2002] 
	SRCFILE "minty.bas",2002
	;[2003]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2003
	DECLE 16191,0
	;[2004]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2004
	DECLE 63,0
	;[2005]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2005
	DECLE 63,0
	;[2006]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2006
	DECLE 63,0
	;[2007]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2007
	DECLE 63,0
	;[2008]     MUSIC    S,   C5,   A4
	SRCFILE "minty.bas",2008
	DECLE 42303,162
	;[2009]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2009
	DECLE 16191,63
	;[2010]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2010
	DECLE 16191,63
	;[2011]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2011
	DECLE 16191,0
	;[2012]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2012
	DECLE 63,0
	;[2013]     MUSIC    S,   B4,   A4
	SRCFILE "minty.bas",2013
	DECLE 42047,162
	;[2014]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2014
	DECLE 16191,63
	;[2015]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2015
	DECLE 63,0
	;[2016]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2016
	DECLE 63,0
	;[2017]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2017
	DECLE 63,0
	;[2018]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2018
	DECLE 63,0
	;[2019]     MUSIC    S,   B4,   A4
	SRCFILE "minty.bas",2019
	DECLE 42047,162
	;[2020]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2020
	DECLE 16191,63
	;[2021]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2021
	DECLE 16191,63
	;[2022]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2022
	DECLE 16191,63
	;[2023]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2023
	DECLE 16191,63
	;[2024]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2024
	DECLE 16191,63
	;[2025]     MUSIC    S,   F2,    S
	SRCFILE "minty.bas",2025
	DECLE 34367,63
	;[2026]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2026
	DECLE 16191,0
	;[2027]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2027
	DECLE 16191,0
	;[2028]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2028
	DECLE 16128,0
	;[2029]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2029
	DECLE 0,0
	;[2030]     MUSIC   C5,   F2,    -
	SRCFILE "minty.bas",2030
	DECLE 34469,0
	;[2031]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2031
	DECLE 16191,0
	;[2032]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2032
	DECLE 16191,0
	;[2033]     MUSIC   B4,    -,    -
	SRCFILE "minty.bas",2033
	DECLE 164,0
	;[2034]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2034
	DECLE 63,0
	;[2035]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2035
	DECLE 63,0
	;[2036]     MUSIC   A4,   F2,   F4
	SRCFILE "minty.bas",2036
	DECLE 34466,158
	;[2037]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2037
	DECLE 16191,63
	;[2038]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2038
	DECLE 16191,63
	;[2039]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2039
	DECLE 16191,63
	;[2040]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2040
	DECLE 16191,63
	;[2041]     MUSIC    S,   B2,    S
	SRCFILE "minty.bas",2041
	DECLE 35903,63
	;[2042]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2042
	DECLE 16191,63
	;[2043]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2043
	DECLE 63,63
	;[2044]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2044
	DECLE 63,63
	;[2045]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2045
	DECLE 63,63
	;[2046]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2046
	DECLE 63,0
	;[2047]     MUSIC    S,   E2,   E4
	SRCFILE "minty.bas",2047
	DECLE 34111,157
	;[2048]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2048
	DECLE 16191,63
	;[2049]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2049
	DECLE 16128,63
	;[2050]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2050
	DECLE 16128,63
	;[2051]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2051
	DECLE 16128,63
	;[2052]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2052
	DECLE 0,63
	;[2053] 
	SRCFILE "minty.bas",2053
	;[2054] REM Timing 1700 frames, 34.00 secs
	SRCFILE "minty.bas",2054
	;[2055] 
	SRCFILE "minty.bas",2055
	;[2056]     MUSIC   A4,   E2,    S
	SRCFILE "minty.bas",2056
	DECLE 34210,63
	;[2057]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2057
	DECLE 16191,63
	;[2058]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2058
	DECLE 0,63
	;[2059]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2059
	DECLE 0,63
	;[2060]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2060
	DECLE 0,63
	;[2061]     MUSIC   A4,   B2,   F4
	SRCFILE "minty.bas",2061
	DECLE 36002,158
	;[2062]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2062
	DECLE 16191,63
	;[2063]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2063
	DECLE 63,63
	;[2064]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2064
	DECLE 63,63
	;[2065]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2065
	DECLE 63,63
	;[2066]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2066
	DECLE 0,63
	;[2067]     MUSIC   B4,   D3,    S
	SRCFILE "minty.bas",2067
	DECLE 36772,63
	;[2068]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2068
	DECLE 16191,63
	;[2069]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2069
	DECLE 0,63
	;[2070]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2070
	DECLE 0,63
	;[2071]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2071
	DECLE 0,63
	;[2072]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2072
	DECLE 0,63
	;[2073]     MUSIC   B4,   D2,    S
	SRCFILE "minty.bas",2073
	DECLE 33700,63
	;[2074]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2074
	DECLE 16191,63
	;[2075]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2075
	DECLE 16191,63
	;[2076]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2076
	DECLE 16191,63
	;[2077]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2077
	DECLE 16191,63
	;[2078]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2078
	DECLE 16128,63
	;[2079]     MUSIC   A4,   D3,    S
	SRCFILE "minty.bas",2079
	DECLE 36770,63
	;[2080]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2080
	DECLE 16191,63
	;[2081]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2081
	DECLE 0,0
	;[2082]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2082
	DECLE 0,0
	;[2083]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2083
	DECLE 0,0
	;[2084]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2084
	DECLE 0,0
	;[2085]     MUSIC   A4,   B2,   D2
	SRCFILE "minty.bas",2085
	DECLE 36002,131
	;[2086]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2086
	DECLE 16191,63
	;[2087]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2087
	DECLE 63,63
	;[2088]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2088
	DECLE 63,63
	;[2089]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2089
	DECLE 63,63
	;[2090]     MUSIC   B4,   D3,    -
	SRCFILE "minty.bas",2090
	DECLE 36772,0
	;[2091]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2091
	DECLE 16191,0
	;[2092]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2092
	DECLE 0,0
	;[2093]     MUSIC   B4,    -,    -
	SRCFILE "minty.bas",2093
	DECLE 164,0
	;[2094]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2094
	DECLE 63,0
	;[2095]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2095
	DECLE 63,0
	;[2096]     MUSIC    S,   D2,   E2
	SRCFILE "minty.bas",2096
	DECLE 33599,133
	;[2097]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2097
	DECLE 16191,63
	;[2098]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2098
	DECLE 16191,0
	;[2099]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2099
	DECLE 16191,0
	;[2100]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2100
	DECLE 16191,0
	;[2101]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2101
	DECLE 16191,0
	;[2102]     MUSIC   A4,   D3,    -
	SRCFILE "minty.bas",2102
	DECLE 36770,0
	;[2103]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2103
	DECLE 16191,0
	;[2104]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2104
	DECLE 0,0
	;[2105]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2105
	DECLE 0,0
	;[2106] 
	SRCFILE "minty.bas",2106
	;[2107] REM Timing 1800 frames, 36.00 secs
	SRCFILE "minty.bas",2107
	;[2108] 
	SRCFILE "minty.bas",2108
	;[2109]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2109
	DECLE 0,0
	;[2110]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2110
	DECLE 0,0
	;[2111]     MUSIC   A4,   B2,  D4#
	SRCFILE "minty.bas",2111
	DECLE 36002,156
	;[2112]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2112
	DECLE 16191,63
	;[2113]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2113
	DECLE 63,63
	;[2114]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2114
	DECLE 63,63
	;[2115]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2115
	DECLE 63,63
	;[2116]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2116
	DECLE 63,63
	;[2117]     MUSIC   B4,  D3#,    S
	SRCFILE "minty.bas",2117
	DECLE 37028,63
	;[2118]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2118
	DECLE 16191,63
	;[2119]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2119
	DECLE 0,63
	;[2120]     MUSIC   B4,    -,    S
	SRCFILE "minty.bas",2120
	DECLE 164,63
	;[2121]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2121
	DECLE 63,63
	;[2122]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2122
	DECLE 63,63
	;[2123]     MUSIC    S,  D2#,    S
	SRCFILE "minty.bas",2123
	DECLE 33855,63
	;[2124]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2124
	DECLE 16191,63
	;[2125]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2125
	DECLE 16191,63
	;[2126]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2126
	DECLE 16191,63
	;[2127]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2127
	DECLE 16191,63
	;[2128]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2128
	DECLE 63,63
	;[2129]     MUSIC   A4,  D3#,    S
	SRCFILE "minty.bas",2129
	DECLE 37026,63
	;[2130]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2130
	DECLE 16191,63
	;[2131]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2131
	DECLE 0,63
	;[2132]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2132
	DECLE 0,63
	;[2133]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2133
	DECLE 0,63
	;[2134]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2134
	DECLE 0,63
	;[2135]     MUSIC   A4,   B2,    S
	SRCFILE "minty.bas",2135
	DECLE 36002,63
	;[2136]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2136
	DECLE 16191,63
	;[2137]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2137
	DECLE 63,63
	;[2138]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2138
	DECLE 63,63
	;[2139]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2139
	DECLE 63,63
	;[2140]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2140
	DECLE 63,63
	;[2141]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2141
	DECLE 63,63
	;[2142]     MUSIC   C5,  D3#,    S
	SRCFILE "minty.bas",2142
	DECLE 37029,63
	;[2143]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2143
	DECLE 16191,63
	;[2144]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2144
	DECLE 63,63
	;[2145]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2145
	DECLE 0,63
	;[2146]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2146
	DECLE 0,63
	;[2147]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2147
	DECLE 0,63
	;[2148]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2148
	DECLE 0,63
	;[2149]     MUSIC   C5,  D2#,    S
	SRCFILE "minty.bas",2149
	DECLE 33957,63
	;[2150]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2150
	DECLE 16191,63
	;[2151]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2151
	DECLE 16191,63
	;[2152]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2152
	DECLE 16191,63
	;[2153]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2153
	DECLE 16191,0
	;[2154]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2154
	DECLE 16191,0
	;[2155]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2155
	DECLE 16191,0
	;[2156]     MUSIC  D3#,    -,    -
	SRCFILE "minty.bas",2156
	DECLE 144,0
	;[2157]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2157
	DECLE 63,0
	;[2158]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2158
	DECLE 0,0
	;[2159] 
	SRCFILE "minty.bas",2159
	;[2160] REM Timing 1900 frames, 38.00 secs
	SRCFILE "minty.bas",2160
	;[2161] 
	SRCFILE "minty.bas",2161
	;[2162]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2162
	DECLE 0,0
	;[2163]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2163
	DECLE 0,0
	;[2164]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2164
	DECLE 0,0
	;[2165]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2165
	DECLE 0,0
	;[2166]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2166
	DECLE 0,0
	;[2167]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2167
	DECLE 0,0
	;[2168]     MUSIC  G3#,   B3,   E4
	SRCFILE "minty.bas",2168
	DECLE 39061,157
	;[2169]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2169
	DECLE 16191,63
	;[2170]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2170
	DECLE 16191,63
	;[2171]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2171
	DECLE 16191,63
	;[2172]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2172
	DECLE 16191,63
	;[2173]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2173
	DECLE 16191,63
	;[2174]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2174
	DECLE 16191,63
	;[2175]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2175
	DECLE 16191,63
	;[2176]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2176
	DECLE 16191,63
	;[2177]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2177
	DECLE 16191,63
	;[2178]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2178
	DECLE 16191,63
	;[2179]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2179
	DECLE 16191,63
	;[2180]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2180
	DECLE 16191,63
	;[2181]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2181
	DECLE 16191,63
	;[2182]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2182
	DECLE 16191,0
	;[2183]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2183
	DECLE 16191,0
	;[2184]     MUSIC   E2,    -,    -
	SRCFILE "minty.bas",2184
	DECLE 133,0
	;[2185]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2185
	DECLE 63,0
	;[2186]     MUSIC    S,   B2,    -
	SRCFILE "minty.bas",2186
	DECLE 35903,0
	;[2187]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2187
	DECLE 16191,0
	;[2188]     MUSIC    S,    S,   D3
	SRCFILE "minty.bas",2188
	DECLE 16191,143
	;[2189]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2189
	DECLE 16191,63
	;[2190]     MUSIC   E3,    -,    -
	SRCFILE "minty.bas",2190
	DECLE 145,0
	;[2191]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2191
	DECLE 63,0
	;[2192]     MUSIC  G3#,    -,    -
	SRCFILE "minty.bas",2192
	DECLE 149,0
	;[2193]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2193
	DECLE 63,0
	;[2194]     MUSIC    S,   B3,    -
	SRCFILE "minty.bas",2194
	DECLE 38975,0
	;[2195]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2195
	DECLE 16128,0
	;[2196]     MUSIC   E4,    -,    -
	SRCFILE "minty.bas",2196
	DECLE 157,0
	;[2197]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2197
	DECLE 63,0
	;[2198]     MUSIC  G3#,    -,    -
	SRCFILE "minty.bas",2198
	DECLE 149,0
	;[2199]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2199
	DECLE 63,0
	;[2200]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2200
	DECLE 63,0
	;[2201]     MUSIC    S,   B3,    -
	SRCFILE "minty.bas",2201
	DECLE 38975,0
	;[2202]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2202
	DECLE 16191,0
	;[2203]     MUSIC    S,    S,   D4
	SRCFILE "minty.bas",2203
	DECLE 16191,155
	;[2204]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2204
	DECLE 16191,63
	;[2205]     MUSIC   E4,  G4#,    S
	SRCFILE "minty.bas",2205
	DECLE 41373,63
	;[2206]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2206
	DECLE 16191,63
	;[2207]     MUSIC   B4,    S,    S
	SRCFILE "minty.bas",2207
	DECLE 16292,63
	;[2208]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2208
	DECLE 16191,63
	;[2209]     MUSIC    S,    S,   E5
	SRCFILE "minty.bas",2209
	DECLE 16191,169
	;[2210]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2210
	DECLE 16191,63
	;[2211]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2211
	DECLE 16191,63
	;[2212] 
	SRCFILE "minty.bas",2212
	;[2213] REM Timing 2000 frames, 40.00 secs
	SRCFILE "minty.bas",2213
	;[2214] 
	SRCFILE "minty.bas",2214
	;[2215]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2215
	DECLE 16191,63
	;[2216]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2216
	DECLE 16191,63
	;[2217]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2217
	DECLE 16191,63
	;[2218]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2218
	DECLE 16191,63
	;[2219]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2219
	DECLE 16191,63
	;[2220]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2220
	DECLE 63,63
	;[2221]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2221
	DECLE 63,63
	;[2222]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2222
	DECLE 0,63
	;[2223]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2223
	DECLE 0,0
	;[2224]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2224
	DECLE 0,0
	;[2225]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2225
	DECLE 0,0
	;[2226]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2226
	DECLE 0,0
	;[2227]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2227
	DECLE 0,0
	;[2228]     MUSIC   B2,   B3,    -
	SRCFILE "minty.bas",2228
	DECLE 39052,0
	;[2229]     MUSIC    S,    S,   C3
	SRCFILE "minty.bas",2229
	DECLE 16191,141
	;[2230]     MUSIC   C4,   D4,    S
	SRCFILE "minty.bas",2230
	DECLE 39833,63
	;[2231]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2231
	DECLE 16191,63
	;[2232]     MUSIC   E3,    S,   E4
	SRCFILE "minty.bas",2232
	DECLE 16273,157
	;[2233]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2233
	DECLE 63,63
	;[2234]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2234
	DECLE 63,0
	;[2235]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2235
	DECLE 0,0
	;[2236]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2236
	DECLE 0,0
	;[2237]     MUSIC   F4,   F3,    -
	SRCFILE "minty.bas",2237
	DECLE 37534,0
	;[2238]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2238
	DECLE 16191,0
	;[2239]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2239
	DECLE 16128,0
	;[2240]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2240
	DECLE 0,0
	;[2241]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2241
	DECLE 0,0
	;[2242]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2242
	DECLE 0,0
	;[2243]     MUSIC   D4,   D3,    -
	SRCFILE "minty.bas",2243
	DECLE 36763,0
	;[2244]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2244
	DECLE 16191,0
	;[2245]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2245
	DECLE 0,0
	;[2246]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2246
	DECLE 0,0
	;[2247]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2247
	DECLE 0,0
	;[2248]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2248
	DECLE 0,0
	;[2249]     MUSIC   E4,   E3,    -
	SRCFILE "minty.bas",2249
	DECLE 37277,0
	;[2250]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2250
	DECLE 16191,0
	;[2251]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2251
	DECLE 0,0
	;[2252]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2252
	DECLE 0,0
	;[2253]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2253
	DECLE 0,0
	;[2254]     MUSIC   C4,   C3,    -
	SRCFILE "minty.bas",2254
	DECLE 36249,0
	;[2255]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2255
	DECLE 16191,0
	;[2256]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2256
	DECLE 16191,0
	;[2257]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2257
	DECLE 16128,0
	;[2258]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2258
	DECLE 0,0
	;[2259]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2259
	DECLE 0,0
	;[2260]     MUSIC   D4,   D3,    -
	SRCFILE "minty.bas",2260
	DECLE 36763,0
	;[2261]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2261
	DECLE 16191,0
	;[2262]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2262
	DECLE 16191,0
	;[2263]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2263
	DECLE 16191,0
	;[2264]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2264
	DECLE 0,0
	;[2265] 
	SRCFILE "minty.bas",2265
	;[2266] REM Timing 2100 frames, 42.00 secs
	SRCFILE "minty.bas",2266
	;[2267] 
	SRCFILE "minty.bas",2267
	;[2268]     MUSIC   B3,   B2,    -
	SRCFILE "minty.bas",2268
	DECLE 35992,0
	;[2269]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2269
	DECLE 16191,0
	;[2270]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2270
	DECLE 0,0
	;[2271]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2271
	DECLE 0,0
	;[2272]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2272
	DECLE 0,0
	;[2273]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2273
	DECLE 0,0
	;[2274]     MUSIC   E4,   E2,   E3
	SRCFILE "minty.bas",2274
	DECLE 34205,145
	;[2275]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2275
	DECLE 16191,63
	;[2276]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2276
	DECLE 16191,63
	;[2277]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2277
	DECLE 16191,63
	;[2278]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2278
	DECLE 16191,63
	;[2279]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2279
	DECLE 16128,63
	;[2280]     MUSIC   F4,   F2,   F3
	SRCFILE "minty.bas",2280
	DECLE 34462,146
	;[2281]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2281
	DECLE 16191,63
	;[2282]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2282
	DECLE 0,0
	;[2283]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2283
	DECLE 0,0
	;[2284]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2284
	DECLE 0,0
	;[2285]     MUSIC   D4,   D2,   D3
	SRCFILE "minty.bas",2285
	DECLE 33691,143
	;[2286]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2286
	DECLE 16191,63
	;[2287]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2287
	DECLE 16191,63
	;[2288]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2288
	DECLE 16191,63
	;[2289]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2289
	DECLE 16191,63
	;[2290]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2290
	DECLE 16191,63
	;[2291]     MUSIC   E4,   E2,   E3
	SRCFILE "minty.bas",2291
	DECLE 34205,145
	;[2292]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2292
	DECLE 16191,63
	;[2293]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2293
	DECLE 0,0
	;[2294]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2294
	DECLE 0,0
	;[2295]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2295
	DECLE 0,0
	;[2296]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2296
	DECLE 0,0
	;[2297]     MUSIC   C4,   C2,   C3
	SRCFILE "minty.bas",2297
	DECLE 33177,141
	;[2298]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2298
	DECLE 16191,63
	;[2299]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2299
	DECLE 16191,63
	;[2300]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2300
	DECLE 16191,63
	;[2301]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2301
	DECLE 16128,0
	;[2302]     MUSIC   D4,   D2,   D3
	SRCFILE "minty.bas",2302
	DECLE 33691,143
	;[2303]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2303
	DECLE 16191,63
	;[2304]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2304
	DECLE 0,63
	;[2305]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2305
	DECLE 0,0
	;[2306]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2306
	DECLE 0,0
	;[2307]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2307
	DECLE 0,0
	;[2308]     MUSIC   B3,   B2,   B2
	SRCFILE "minty.bas",2308
	DECLE 35992,140
	;[2309]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2309
	DECLE 16191,63
	;[2310]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2310
	DECLE 16191,63
	;[2311]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2311
	DECLE 16191,63
	;[2312]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2312
	DECLE 16191,63
	;[2313]     MUSIC   C4,   C2,   C3
	SRCFILE "minty.bas",2313
	DECLE 33177,141
	;[2314]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2314
	DECLE 16191,63
	;[2315]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2315
	DECLE 16191,63
	;[2316]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2316
	DECLE 16191,63
	;[2317]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2317
	DECLE 16191,63
	;[2318] 
	SRCFILE "minty.bas",2318
	;[2319] REM Timing 2200 frames, 44.00 secs
	SRCFILE "minty.bas",2319
	;[2320] 
	SRCFILE "minty.bas",2320
	;[2321]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2321
	DECLE 63,63
	;[2322]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2322
	DECLE 63,0
	;[2323]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2323
	DECLE 0,0
	;[2324]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2324
	DECLE 0,0
	;[2325]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2325
	DECLE 0,0
	;[2326]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2326
	DECLE 0,0
	;[2327]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2327
	DECLE 0,0
	;[2328]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2328
	DECLE 35502,165
	;[2329]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2329
	DECLE 16191,63
	;[2330]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2330
	DECLE 16128,0
	;[2331]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2331
	DECLE 16275,0
	;[2332]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2332
	DECLE 16191,0
	;[2333]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2333
	DECLE 36016,167
	;[2334]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2334
	DECLE 16191,63
	;[2335]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2335
	DECLE 16128,0
	;[2336]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2336
	DECLE 147,0
	;[2337]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2337
	DECLE 63,0
	;[2338]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2338
	DECLE 63,0
	;[2339]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",2339
	DECLE 36017,169
	;[2340]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2340
	DECLE 16191,63
	;[2341]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2341
	DECLE 0,0
	;[2342]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2342
	DECLE 147,0
	;[2343]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2343
	DECLE 63,0
	;[2344]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2344
	DECLE 0,0
	;[2345]     MUSIC   A5,   A2,   G5
	SRCFILE "minty.bas",2345
	DECLE 35502,172
	;[2346]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2346
	DECLE 16191,63
	;[2347]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2347
	DECLE 147,0
	;[2348]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2348
	DECLE 63,0
	;[2349]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2349
	DECLE 0,0
	;[2350]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2350
	DECLE 36016,167
	;[2351]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2351
	DECLE 16191,63
	;[2352]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2352
	DECLE 0,63
	;[2353]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2353
	DECLE 147,0
	;[2354]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2354
	DECLE 63,0
	;[2355]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2355
	DECLE 63,0
	;[2356]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",2356
	DECLE 33201,169
	;[2357]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2357
	DECLE 16191,63
	;[2358]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2358
	DECLE 16191,0
	;[2359]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2359
	DECLE 16275,0
	;[2360]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2360
	DECLE 16191,0
	;[2361]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",2361
	DECLE 35997,153
	;[2362]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2362
	DECLE 16191,63
	;[2363]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2363
	DECLE 0,0
	;[2364]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2364
	DECLE 147,0
	;[2365]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2365
	DECLE 63,0
	;[2366]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2366
	DECLE 0,0
	;[2367]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",2367
	DECLE 37791,156
	;[2368]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2368
	DECLE 16191,63
	;[2369]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2369
	DECLE 16191,63
	;[2370]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2370
	DECLE 147,0
	;[2371] 
	SRCFILE "minty.bas",2371
	;[2372] REM Timing 2300 frames, 46.00 secs
	SRCFILE "minty.bas",2372
	;[2373] 
	SRCFILE "minty.bas",2373
	;[2374]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2374
	DECLE 63,0
	;[2375]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2375
	DECLE 0,0
	;[2376]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",2376
	DECLE 35999,156
	;[2377]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2377
	DECLE 16191,63
	;[2378]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2378
	DECLE 0,0
	;[2379]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2379
	DECLE 147,0
	;[2380]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2380
	DECLE 63,0
	;[2381]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",2381
	DECLE 37791,156
	;[2382]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2382
	DECLE 16191,63
	;[2383]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2383
	DECLE 0,0
	;[2384]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2384
	DECLE 147,0
	;[2385]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2385
	DECLE 63,0
	;[2386]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2386
	DECLE 63,0
	;[2387]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2387
	DECLE 36016,167
	;[2388]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2388
	DECLE 16191,63
	;[2389]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2389
	DECLE 63,63
	;[2390]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2390
	DECLE 147,0
	;[2391]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2391
	DECLE 63,0
	;[2392]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2392
	DECLE 0,0
	;[2393]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2393
	DECLE 35502,165
	;[2394]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2394
	DECLE 16191,63
	;[2395]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2395
	DECLE 147,0
	;[2396]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2396
	DECLE 63,0
	;[2397]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2397
	DECLE 0,0
	;[2398]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2398
	DECLE 36016,167
	;[2399]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2399
	DECLE 16191,63
	;[2400]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2400
	DECLE 0,63
	;[2401]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2401
	DECLE 147,63
	;[2402]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2402
	DECLE 63,0
	;[2403]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2403
	DECLE 63,0
	;[2404]     MUSIC   C6,   C2,  D5#
	SRCFILE "minty.bas",2404
	DECLE 33201,168
	;[2405]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2405
	DECLE 16191,63
	;[2406]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2406
	DECLE 16191,63
	;[2407]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2407
	DECLE 16275,0
	;[2408]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2408
	DECLE 16191,0
	;[2409]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",2409
	DECLE 35999,156
	;[2410]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2410
	DECLE 16191,63
	;[2411]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2411
	DECLE 0,0
	;[2412]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2412
	DECLE 147,0
	;[2413]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2413
	DECLE 63,0
	;[2414]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2414
	DECLE 0,0
	;[2415]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",2415
	DECLE 37790,155
	;[2416]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2416
	DECLE 16191,63
	;[2417]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2417
	DECLE 16191,63
	;[2418]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2418
	DECLE 147,0
	;[2419]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2419
	DECLE 63,0
	;[2420]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2420
	DECLE 0,0
	;[2421]     MUSIC   F4,   B2,   D4
	SRCFILE "minty.bas",2421
	DECLE 35998,155
	;[2422]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2422
	DECLE 16191,63
	;[2423]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2423
	DECLE 0,0
	;[2424] 
	SRCFILE "minty.bas",2424
	;[2425] REM Timing 2400 frames, 48.00 secs
	SRCFILE "minty.bas",2425
	;[2426] 
	SRCFILE "minty.bas",2426
	;[2427]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2427
	DECLE 147,0
	;[2428]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2428
	DECLE 63,0
	;[2429]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",2429
	DECLE 37790,155
	;[2430]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2430
	DECLE 16191,63
	;[2431]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2431
	DECLE 0,0
	;[2432]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2432
	DECLE 147,0
	;[2433]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2433
	DECLE 63,0
	;[2434]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2434
	DECLE 63,0
	;[2435]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2435
	DECLE 36016,167
	;[2436]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2436
	DECLE 16191,63
	;[2437]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2437
	DECLE 63,63
	;[2438]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2438
	DECLE 147,0
	;[2439]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2439
	DECLE 63,0
	;[2440]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2440
	DECLE 0,0
	;[2441]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2441
	DECLE 35502,165
	;[2442]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2442
	DECLE 16191,63
	;[2443]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2443
	DECLE 16275,0
	;[2444]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2444
	DECLE 16191,0
	;[2445]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2445
	DECLE 16128,0
	;[2446]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",2446
	DECLE 36017,169
	;[2447]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2447
	DECLE 16191,63
	;[2448]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2448
	DECLE 0,0
	;[2449]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2449
	DECLE 147,0
	;[2450]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2450
	DECLE 63,0
	;[2451]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2451
	DECLE 63,0
	;[2452]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",2452
	DECLE 33201,169
	;[2453]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2453
	DECLE 16191,63
	;[2454]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2454
	DECLE 16191,63
	;[2455]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2455
	DECLE 16275,63
	;[2456]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2456
	DECLE 16191,63
	;[2457]     MUSIC   F4,   B2,   D4
	SRCFILE "minty.bas",2457
	DECLE 35998,155
	;[2458]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2458
	DECLE 16191,63
	;[2459]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2459
	DECLE 0,0
	;[2460]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2460
	DECLE 147,0
	;[2461]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2461
	DECLE 63,0
	;[2462]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2462
	DECLE 0,0
	;[2463]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2463
	DECLE 35502,165
	;[2464]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2464
	DECLE 16191,63
	;[2465]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2465
	DECLE 16191,63
	;[2466]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2466
	DECLE 16275,63
	;[2467]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2467
	DECLE 16191,63
	;[2468]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2468
	DECLE 16128,63
	;[2469]     MUSIC   E4,    S,   C4
	SRCFILE "minty.bas",2469
	DECLE 16285,153
	;[2470]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2470
	DECLE 16191,63
	;[2471]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2471
	DECLE 16128,0
	;[2472]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2472
	DECLE 147,0
	;[2473]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2473
	DECLE 63,0
	;[2474]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",2474
	DECLE 37789,153
	;[2475]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2475
	DECLE 16191,63
	;[2476]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2476
	DECLE 0,0
	;[2477] 
	SRCFILE "minty.bas",2477
	;[2478] REM Timing 2500 frames, 50.00 secs
	SRCFILE "minty.bas",2478
	;[2479] 
	SRCFILE "minty.bas",2479
	;[2480]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2480
	DECLE 147,0
	;[2481]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2481
	DECLE 63,0
	;[2482]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2482
	DECLE 63,0
	;[2483]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",2483
	DECLE 35997,153
	;[2484]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2484
	DECLE 16191,63
	;[2485]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2485
	DECLE 0,0
	;[2486]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2486
	DECLE 147,0
	;[2487]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2487
	DECLE 63,0
	;[2488]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2488
	DECLE 0,0
	;[2489]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",2489
	DECLE 37789,153
	;[2490]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2490
	DECLE 16191,63
	;[2491]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2491
	DECLE 147,0
	;[2492]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2492
	DECLE 63,0
	;[2493]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2493
	DECLE 0,0
	;[2494]     MUSIC   E4,   B2,   D4
	SRCFILE "minty.bas",2494
	DECLE 35997,155
	;[2495]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2495
	DECLE 16191,63
	;[2496]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2496
	DECLE 0,63
	;[2497]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2497
	DECLE 147,63
	;[2498]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2498
	DECLE 63,63
	;[2499]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2499
	DECLE 63,63
	;[2500]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",2500
	DECLE 37789,153
	;[2501]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2501
	DECLE 16191,63
	;[2502]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2502
	DECLE 0,0
	;[2503]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2503
	DECLE 147,0
	;[2504]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2504
	DECLE 63,0
	;[2505]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",2505
	DECLE 35997,153
	;[2506]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2506
	DECLE 16191,63
	;[2507]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2507
	DECLE 0,0
	;[2508]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2508
	DECLE 147,0
	;[2509]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2509
	DECLE 63,0
	;[2510]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2510
	DECLE 0,0
	;[2511]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",2511
	DECLE 37789,153
	;[2512]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2512
	DECLE 16191,63
	;[2513]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2513
	DECLE 16191,63
	;[2514]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2514
	DECLE 147,0
	;[2515]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2515
	DECLE 63,0
	;[2516]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2516
	DECLE 0,0
	;[2517]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2517
	DECLE 35502,165
	;[2518]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2518
	DECLE 16191,63
	;[2519]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2519
	DECLE 16191,63
	;[2520]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2520
	DECLE 16275,0
	;[2521]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2521
	DECLE 16191,0
	;[2522]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2522
	DECLE 36016,167
	;[2523]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2523
	DECLE 16191,63
	;[2524]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2524
	DECLE 0,63
	;[2525]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2525
	DECLE 147,0
	;[2526]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2526
	DECLE 63,0
	;[2527]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2527
	DECLE 63,0
	;[2528]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",2528
	DECLE 36017,169
	;[2529]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2529
	DECLE 16191,63
	;[2530] 
	SRCFILE "minty.bas",2530
	;[2531] REM Timing 2600 frames, 52.00 secs
	SRCFILE "minty.bas",2531
	;[2532] 
	SRCFILE "minty.bas",2532
	;[2533]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2533
	DECLE 0,0
	;[2534]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2534
	DECLE 147,0
	;[2535]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2535
	DECLE 63,0
	;[2536]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2536
	DECLE 0,0
	;[2537]     MUSIC   A5,   A2,   G5
	SRCFILE "minty.bas",2537
	DECLE 35502,172
	;[2538]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2538
	DECLE 16191,63
	;[2539]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2539
	DECLE 147,0
	;[2540]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2540
	DECLE 63,0
	;[2541]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2541
	DECLE 0,0
	;[2542]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2542
	DECLE 36016,167
	;[2543]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2543
	DECLE 16191,63
	;[2544]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2544
	DECLE 0,63
	;[2545]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2545
	DECLE 147,63
	;[2546]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2546
	DECLE 63,63
	;[2547]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2547
	DECLE 63,0
	;[2548]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",2548
	DECLE 33201,169
	;[2549]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2549
	DECLE 16191,63
	;[2550]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2550
	DECLE 16128,0
	;[2551]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2551
	DECLE 16275,0
	;[2552]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2552
	DECLE 63,0
	;[2553]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",2553
	DECLE 35997,153
	;[2554]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2554
	DECLE 16191,63
	;[2555]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2555
	DECLE 0,0
	;[2556]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2556
	DECLE 147,0
	;[2557]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2557
	DECLE 63,0
	;[2558]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2558
	DECLE 0,0
	;[2559]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",2559
	DECLE 37791,156
	;[2560]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2560
	DECLE 16191,63
	;[2561]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2561
	DECLE 16191,63
	;[2562]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2562
	DECLE 147,0
	;[2563]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2563
	DECLE 63,0
	;[2564]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2564
	DECLE 0,0
	;[2565]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",2565
	DECLE 35999,156
	;[2566]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2566
	DECLE 16191,63
	;[2567]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2567
	DECLE 0,0
	;[2568]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2568
	DECLE 147,0
	;[2569]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2569
	DECLE 63,0
	;[2570]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",2570
	DECLE 37791,156
	;[2571]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2571
	DECLE 16191,63
	;[2572]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2572
	DECLE 0,0
	;[2573]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2573
	DECLE 147,0
	;[2574]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2574
	DECLE 63,0
	;[2575]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2575
	DECLE 63,0
	;[2576]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2576
	DECLE 36016,167
	;[2577]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2577
	DECLE 16191,63
	;[2578]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2578
	DECLE 63,63
	;[2579]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2579
	DECLE 147,0
	;[2580]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2580
	DECLE 63,0
	;[2581]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2581
	DECLE 0,0
	;[2582]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2582
	DECLE 35502,165
	;[2583] 
	SRCFILE "minty.bas",2583
	;[2584] REM Timing 2700 frames, 54.00 secs
	SRCFILE "minty.bas",2584
	;[2585] 
	SRCFILE "minty.bas",2585
	;[2586]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2586
	DECLE 16191,63
	;[2587]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2587
	DECLE 147,0
	;[2588]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2588
	DECLE 63,0
	;[2589]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2589
	DECLE 0,0
	;[2590]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2590
	DECLE 36016,167
	;[2591]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2591
	DECLE 16191,63
	;[2592]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2592
	DECLE 63,63
	;[2593]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2593
	DECLE 147,63
	;[2594]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2594
	DECLE 63,63
	;[2595]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2595
	DECLE 63,63
	;[2596]     MUSIC   C6,   C2,  D5#
	SRCFILE "minty.bas",2596
	DECLE 33201,168
	;[2597]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2597
	DECLE 16191,63
	;[2598]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2598
	DECLE 16128,63
	;[2599]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2599
	DECLE 16275,0
	;[2600]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2600
	DECLE 63,0
	;[2601]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",2601
	DECLE 35999,156
	;[2602]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2602
	DECLE 16191,63
	;[2603]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2603
	DECLE 0,0
	;[2604]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2604
	DECLE 147,0
	;[2605]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2605
	DECLE 63,0
	;[2606]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2606
	DECLE 0,0
	;[2607]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",2607
	DECLE 37790,155
	;[2608]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2608
	DECLE 16191,63
	;[2609]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2609
	DECLE 16191,63
	;[2610]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2610
	DECLE 147,0
	;[2611]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2611
	DECLE 63,0
	;[2612]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2612
	DECLE 0,0
	;[2613]     MUSIC   F4,   B2,   D4
	SRCFILE "minty.bas",2613
	DECLE 35998,155
	;[2614]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2614
	DECLE 16191,63
	;[2615]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2615
	DECLE 0,0
	;[2616]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2616
	DECLE 147,0
	;[2617]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2617
	DECLE 63,0
	;[2618]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",2618
	DECLE 37790,155
	;[2619]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2619
	DECLE 16191,63
	;[2620]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2620
	DECLE 0,0
	;[2621]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2621
	DECLE 147,0
	;[2622]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2622
	DECLE 63,0
	;[2623]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2623
	DECLE 63,0
	;[2624]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2624
	DECLE 36016,167
	;[2625]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2625
	DECLE 16191,63
	;[2626]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2626
	DECLE 63,63
	;[2627]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2627
	DECLE 147,0
	;[2628]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2628
	DECLE 63,0
	;[2629]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2629
	DECLE 0,0
	;[2630]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2630
	DECLE 35502,165
	;[2631]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2631
	DECLE 16191,63
	;[2632]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2632
	DECLE 147,0
	;[2633]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2633
	DECLE 63,0
	;[2634]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2634
	DECLE 0,0
	;[2635]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",2635
	DECLE 36017,169
	;[2636] 
	SRCFILE "minty.bas",2636
	;[2637] REM Timing 2800 frames, 56.00 secs
	SRCFILE "minty.bas",2637
	;[2638] 
	SRCFILE "minty.bas",2638
	;[2639]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2639
	DECLE 16191,63
	;[2640]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2640
	DECLE 0,0
	;[2641]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2641
	DECLE 147,0
	;[2642]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2642
	DECLE 63,0
	;[2643]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2643
	DECLE 63,0
	;[2644]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",2644
	DECLE 33201,169
	;[2645]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2645
	DECLE 16191,63
	;[2646]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2646
	DECLE 16191,63
	;[2647]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2647
	DECLE 16275,63
	;[2648]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2648
	DECLE 16191,63
	;[2649]     MUSIC   B2,   F4,    S
	SRCFILE "minty.bas",2649
	DECLE 40588,63
	;[2650]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2650
	DECLE 16191,63
	;[2651]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2651
	DECLE 0,0
	;[2652]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2652
	DECLE 147,0
	;[2653]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2653
	DECLE 63,0
	;[2654]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2654
	DECLE 0,0
	;[2655]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2655
	DECLE 35502,165
	;[2656]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2656
	DECLE 16191,63
	;[2657]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2657
	DECLE 16191,63
	;[2658]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2658
	DECLE 16275,63
	;[2659]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2659
	DECLE 16191,63
	;[2660]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2660
	DECLE 16128,63
	;[2661]     MUSIC   E4,    S,   C4
	SRCFILE "minty.bas",2661
	DECLE 16285,153
	;[2662]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2662
	DECLE 16191,63
	;[2663]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2663
	DECLE 16128,0
	;[2664]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2664
	DECLE 147,0
	;[2665]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2665
	DECLE 63,0
	;[2666]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",2666
	DECLE 37789,153
	;[2667]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2667
	DECLE 16191,63
	;[2668]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2668
	DECLE 0,0
	;[2669]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2669
	DECLE 147,0
	;[2670]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2670
	DECLE 63,0
	;[2671]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2671
	DECLE 63,0
	;[2672]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",2672
	DECLE 35997,153
	;[2673]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2673
	DECLE 16191,63
	;[2674]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2674
	DECLE 0,0
	;[2675]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2675
	DECLE 147,0
	;[2676]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2676
	DECLE 63,0
	;[2677]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2677
	DECLE 0,0
	;[2678]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",2678
	DECLE 37789,153
	;[2679]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2679
	DECLE 16191,63
	;[2680]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2680
	DECLE 147,0
	;[2681]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2681
	DECLE 63,0
	;[2682]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2682
	DECLE 0,0
	;[2683]     MUSIC   E4,   B2,   D4
	SRCFILE "minty.bas",2683
	DECLE 35997,155
	;[2684]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2684
	DECLE 16191,63
	;[2685]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2685
	DECLE 0,63
	;[2686]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2686
	DECLE 147,63
	;[2687]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2687
	DECLE 63,63
	;[2688]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2688
	DECLE 63,63
	;[2689] 
	SRCFILE "minty.bas",2689
	;[2690] REM Timing 2900 frames, 58.00 secs
	SRCFILE "minty.bas",2690
	;[2691] 
	SRCFILE "minty.bas",2691
	;[2692]     MUSIC   E4,   A2,    -
	SRCFILE "minty.bas",2692
	DECLE 35485,0
	;[2693]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2693
	DECLE 16191,0
	;[2694]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2694
	DECLE 16128,0
	;[2695]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2695
	DECLE 16275,0
	;[2696]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2696
	DECLE 16191,0
	;[2697]     MUSIC   A4,   B2,   E4
	SRCFILE "minty.bas",2697
	DECLE 36002,157
	;[2698]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2698
	DECLE 16191,63
	;[2699]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2699
	DECLE 63,0
	;[2700]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2700
	DECLE 37695,0
	;[2701]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2701
	DECLE 16191,0
	;[2702]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2702
	DECLE 63,0
	;[2703]     MUSIC   F5,   A2,   F4
	SRCFILE "minty.bas",2703
	DECLE 35498,158
	;[2704]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2704
	DECLE 16191,63
	;[2705]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2705
	DECLE 16191,63
	;[2706]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2706
	DECLE 37695,0
	;[2707]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2707
	DECLE 16191,0
	;[2708]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2708
	DECLE 63,0
	;[2709]     MUSIC    S,   B2,   D4
	SRCFILE "minty.bas",2709
	DECLE 35903,155
	;[2710]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2710
	DECLE 16191,63
	;[2711]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2711
	DECLE 63,0
	;[2712]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2712
	DECLE 37695,0
	;[2713]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2713
	DECLE 16191,0
	;[2714]     MUSIC    S,  F3#,   E4
	SRCFILE "minty.bas",2714
	DECLE 37695,157
	;[2715]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2715
	DECLE 16191,63
	;[2716]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2716
	DECLE 63,0
	;[2717]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2717
	DECLE 37695,0
	;[2718]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2718
	DECLE 16191,0
	;[2719]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2719
	DECLE 16191,0
	;[2720]     MUSIC    S,   D2,   F4
	SRCFILE "minty.bas",2720
	DECLE 33599,158
	;[2721]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2721
	DECLE 16191,63
	;[2722]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2722
	DECLE 16191,0
	;[2723]     MUSIC    S,    S,  F3#
	SRCFILE "minty.bas",2723
	DECLE 16191,147
	;[2724]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2724
	DECLE 63,63
	;[2725]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2725
	DECLE 63,0
	;[2726]     MUSIC    S,  F3#,   D4
	SRCFILE "minty.bas",2726
	DECLE 37695,155
	;[2727]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2727
	DECLE 16191,63
	;[2728]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2728
	DECLE 37695,0
	;[2729]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2729
	DECLE 16191,0
	;[2730]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2730
	DECLE 63,0
	;[2731]     MUSIC    S,   B2,   E4
	SRCFILE "minty.bas",2731
	DECLE 35903,157
	;[2732]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2732
	DECLE 16128,63
	;[2733]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2733
	DECLE 0,0
	;[2734]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2734
	DECLE 147,0
	;[2735]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2735
	DECLE 63,0
	;[2736]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2736
	DECLE 63,0
	;[2737]     MUSIC   G5,  F3#,   F4
	SRCFILE "minty.bas",2737
	DECLE 37804,158
	;[2738]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2738
	DECLE 16191,63
	;[2739]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2739
	DECLE 63,0
	;[2740]     MUSIC   F5,  F3#,    -
	SRCFILE "minty.bas",2740
	DECLE 37802,0
	;[2741]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2741
	DECLE 16191,0
	;[2742] 
	SRCFILE "minty.bas",2742
	;[2743] REM Timing 3000 frames, 60.00 secs
	SRCFILE "minty.bas",2743
	;[2744] 
	SRCFILE "minty.bas",2744
	;[2745]     MUSIC   D5,   C2,   F4
	SRCFILE "minty.bas",2745
	DECLE 33191,158
	;[2746]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2746
	DECLE 16191,63
	;[2747]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2747
	DECLE 16191,0
	;[2748]     MUSIC    S,    S,   F4
	SRCFILE "minty.bas",2748
	DECLE 16191,158
	;[2749]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2749
	DECLE 16191,63
	;[2750]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2750
	DECLE 63,63
	;[2751]     MUSIC   E5,   A2,   E4
	SRCFILE "minty.bas",2751
	DECLE 35497,157
	;[2752]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2752
	DECLE 16191,63
	;[2753]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2753
	DECLE 16191,63
	;[2754]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2754
	DECLE 37695,0
	;[2755]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2755
	DECLE 16191,0
	;[2756]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2756
	DECLE 63,0
	;[2757]     MUSIC    S,   B2,   E4
	SRCFILE "minty.bas",2757
	DECLE 35903,157
	;[2758]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2758
	DECLE 16191,63
	;[2759]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2759
	DECLE 63,0
	;[2760]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2760
	DECLE 37695,0
	;[2761]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2761
	DECLE 16191,0
	;[2762]     MUSIC    S,   E2,   E4
	SRCFILE "minty.bas",2762
	DECLE 34111,157
	;[2763]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2763
	DECLE 16191,63
	;[2764]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2764
	DECLE 16191,0
	;[2765]     MUSIC    S,    S,  F3#
	SRCFILE "minty.bas",2765
	DECLE 16191,147
	;[2766]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2766
	DECLE 16191,63
	;[2767]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2767
	DECLE 16191,63
	;[2768]     MUSIC    S,   D2,   E4
	SRCFILE "minty.bas",2768
	DECLE 33599,157
	;[2769]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2769
	DECLE 16191,63
	;[2770]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2770
	DECLE 16191,0
	;[2771]     MUSIC    S,    S,  F3#
	SRCFILE "minty.bas",2771
	DECLE 16191,147
	;[2772]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2772
	DECLE 63,63
	;[2773]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2773
	DECLE 63,0
	;[2774]     MUSIC    S,   B2,   D4
	SRCFILE "minty.bas",2774
	DECLE 35903,155
	;[2775]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2775
	DECLE 16191,63
	;[2776]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2776
	DECLE 37695,0
	;[2777]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2777
	DECLE 16191,0
	;[2778]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2778
	DECLE 63,0
	;[2779]     MUSIC    S,   B2,   E4
	SRCFILE "minty.bas",2779
	DECLE 35903,157
	;[2780]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2780
	DECLE 16191,63
	;[2781]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2781
	DECLE 63,0
	;[2782]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2782
	DECLE 37695,0
	;[2783]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2783
	DECLE 16191,0
	;[2784]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2784
	DECLE 16191,0
	;[2785]     MUSIC    S,   B2,   F4
	SRCFILE "minty.bas",2785
	DECLE 35903,158
	;[2786]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2786
	DECLE 16191,63
	;[2787]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2787
	DECLE 63,0
	;[2788]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2788
	DECLE 37695,0
	;[2789]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2789
	DECLE 16191,0
	;[2790]     MUSIC    S,   D2,   A4
	SRCFILE "minty.bas",2790
	DECLE 33599,162
	;[2791]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2791
	DECLE 16191,63
	;[2792]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2792
	DECLE 16128,63
	;[2793]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2793
	DECLE 16275,63
	;[2794]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2794
	DECLE 16191,63
	;[2795] 
	SRCFILE "minty.bas",2795
	;[2796] REM Timing 3100 frames, 62.00 secs
	SRCFILE "minty.bas",2796
	;[2797] 
	SRCFILE "minty.bas",2797
	;[2798]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2798
	DECLE 0,63
	;[2799]     MUSIC   B2,   E4,    S
	SRCFILE "minty.bas",2799
	DECLE 40332,63
	;[2800]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2800
	DECLE 16191,63
	;[2801]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2801
	DECLE 16191,63
	;[2802]     MUSIC    S,  F3#,    S
	SRCFILE "minty.bas",2802
	DECLE 37695,63
	;[2803]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2803
	DECLE 16128,63
	;[2804]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2804
	DECLE 0,63
	;[2805]     MUSIC   B2,   E4,    S
	SRCFILE "minty.bas",2805
	DECLE 40332,63
	;[2806]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2806
	DECLE 16191,63
	;[2807]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2807
	DECLE 0,63
	;[2808]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2808
	DECLE 147,63
	;[2809]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2809
	DECLE 63,63
	;[2810]     MUSIC   A2,   E4,    S
	SRCFILE "minty.bas",2810
	DECLE 40330,63
	;[2811]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2811
	DECLE 16191,63
	;[2812]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2812
	DECLE 63,63
	;[2813]     MUSIC    S,  F3#,    S
	SRCFILE "minty.bas",2813
	DECLE 37695,63
	;[2814]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2814
	DECLE 16191,63
	;[2815]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2815
	DECLE 16191,63
	;[2816]     MUSIC   F5,   E2,    S
	SRCFILE "minty.bas",2816
	DECLE 34218,63
	;[2817]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2817
	DECLE 16191,63
	;[2818]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2818
	DECLE 63,63
	;[2819]     MUSIC    S,  F3#,    S
	SRCFILE "minty.bas",2819
	DECLE 37695,63
	;[2820]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2820
	DECLE 16128,63
	;[2821]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2821
	DECLE 0,63
	;[2822]     MUSIC   E5,   A2,    S
	SRCFILE "minty.bas",2822
	DECLE 35497,63
	;[2823]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2823
	DECLE 16191,63
	;[2824]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2824
	DECLE 16275,63
	;[2825]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2825
	DECLE 16191,63
	;[2826]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2826
	DECLE 16128,63
	;[2827]     MUSIC   F5,   B2,    S
	SRCFILE "minty.bas",2827
	DECLE 36010,63
	;[2828]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2828
	DECLE 16191,63
	;[2829]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2829
	DECLE 63,63
	;[2830]     MUSIC    S,  F3#,    S
	SRCFILE "minty.bas",2830
	DECLE 37695,63
	;[2831]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2831
	DECLE 16191,63
	;[2832]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2832
	DECLE 16191,63
	;[2833]     MUSIC   E5,   A2,    S
	SRCFILE "minty.bas",2833
	DECLE 35497,63
	;[2834]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2834
	DECLE 16191,63
	;[2835]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2835
	DECLE 16128,0
	;[2836]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2836
	DECLE 16275,0
	;[2837]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2837
	DECLE 16191,0
	;[2838]     MUSIC   A4,   E2,  C4#
	SRCFILE "minty.bas",2838
	DECLE 34210,154
	;[2839]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2839
	DECLE 16191,63
	;[2840]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2840
	DECLE 63,0
	;[2841]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2841
	DECLE 37695,0
	;[2842]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2842
	DECLE 16191,0
	;[2843]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2843
	DECLE 63,0
	;[2844]     MUSIC   D5,  A2#,   D4
	SRCFILE "minty.bas",2844
	DECLE 35751,155
	;[2845]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2845
	DECLE 16191,63
	;[2846]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2846
	DECLE 16191,63
	;[2847]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2847
	DECLE 37695,0
	;[2848] 
	SRCFILE "minty.bas",2848
	;[2849] REM Timing 3200 frames, 64.00 secs
	SRCFILE "minty.bas",2849
	;[2850] 
	SRCFILE "minty.bas",2850
	;[2851]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2851
	DECLE 16191,0
	;[2852]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2852
	DECLE 63,0
	;[2853]     MUSIC    S,   B2,   A3
	SRCFILE "minty.bas",2853
	DECLE 35903,150
	;[2854]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2854
	DECLE 16191,63
	;[2855]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2855
	DECLE 63,0
	;[2856]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2856
	DECLE 37695,0
	;[2857]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2857
	DECLE 16191,0
	;[2858]     MUSIC    S,   D3,   D4
	SRCFILE "minty.bas",2858
	DECLE 36671,155
	;[2859]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2859
	DECLE 16191,63
	;[2860]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2860
	DECLE 63,0
	;[2861]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2861
	DECLE 37695,0
	;[2862]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2862
	DECLE 16191,0
	;[2863]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2863
	DECLE 16191,0
	;[2864]     MUSIC    S,   E2,   D4
	SRCFILE "minty.bas",2864
	DECLE 34111,155
	;[2865]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2865
	DECLE 16191,63
	;[2866]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2866
	DECLE 63,0
	;[2867]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",2867
	DECLE 37695,0
	;[2868]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2868
	DECLE 16191,0
	;[2869]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2869
	DECLE 63,0
	;[2870]     MUSIC  F3#,   D3,    -
	SRCFILE "minty.bas",2870
	DECLE 36755,0
	;[2871]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2871
	DECLE 16191,0
	;[2872]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2872
	DECLE 147,0
	;[2873]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2873
	DECLE 63,0
	;[2874]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2874
	DECLE 0,0
	;[2875]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",2875
	DECLE 36017,168
	;[2876]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2876
	DECLE 16191,63
	;[2877]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2877
	DECLE 63,63
	;[2878]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2878
	DECLE 147,63
	;[2879]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2879
	DECLE 63,63
	;[2880]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2880
	DECLE 63,63
	;[2881]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2881
	DECLE 147,63
	;[2882]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2882
	DECLE 63,0
	;[2883]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2883
	DECLE 0,0
	;[2884]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2884
	DECLE 147,0
	;[2885]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2885
	DECLE 63,0
	;[2886]     MUSIC   B5,   E2,   D5
	SRCFILE "minty.bas",2886
	DECLE 34224,167
	;[2887]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2887
	DECLE 16191,63
	;[2888]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2888
	DECLE 63,63
	;[2889]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2889
	DECLE 147,63
	;[2890]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2890
	DECLE 63,63
	;[2891]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2891
	DECLE 0,63
	;[2892]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2892
	DECLE 147,63
	;[2893]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2893
	DECLE 63,0
	;[2894]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2894
	DECLE 63,0
	;[2895]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2895
	DECLE 147,0
	;[2896]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2896
	DECLE 63,0
	;[2897]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2897
	DECLE 0,0
	;[2898]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2898
	DECLE 35502,165
	;[2899]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2899
	DECLE 16191,63
	;[2900]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2900
	DECLE 16128,63
	;[2901] 
	SRCFILE "minty.bas",2901
	;[2902] REM Timing 3300 frames, 66.00 secs
	SRCFILE "minty.bas",2902
	;[2903] 
	SRCFILE "minty.bas",2903
	;[2904]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2904
	DECLE 16275,0
	;[2905]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2905
	DECLE 63,0
	;[2906]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2906
	DECLE 36016,167
	;[2907]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2907
	DECLE 16191,63
	;[2908]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2908
	DECLE 16191,0
	;[2909]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2909
	DECLE 16275,0
	;[2910]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2910
	DECLE 16191,0
	;[2911]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2911
	DECLE 16191,0
	;[2912]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",2912
	DECLE 33201,169
	;[2913]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2913
	DECLE 16191,63
	;[2914]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2914
	DECLE 16191,0
	;[2915]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2915
	DECLE 16275,0
	;[2916]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2916
	DECLE 16191,0
	;[2917]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2917
	DECLE 0,0
	;[2918]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",2918
	DECLE 35502,165
	;[2919]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2919
	DECLE 16191,63
	;[2920]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2920
	DECLE 16275,0
	;[2921]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2921
	DECLE 16191,0
	;[2922]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2922
	DECLE 16128,0
	;[2923]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",2923
	DECLE 36016,167
	;[2924]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2924
	DECLE 16191,63
	;[2925]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2925
	DECLE 63,63
	;[2926]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2926
	DECLE 147,63
	;[2927]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2927
	DECLE 63,63
	;[2928]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2928
	DECLE 63,0
	;[2929]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",2929
	DECLE 33201,169
	;[2930]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2930
	DECLE 16191,63
	;[2931]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2931
	DECLE 16191,0
	;[2932]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2932
	DECLE 147,0
	;[2933]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2933
	DECLE 63,0
	;[2934]     MUSIC   E4,   E2,   D4
	SRCFILE "minty.bas",2934
	DECLE 34205,155
	;[2935]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2935
	DECLE 16191,63
	;[2936]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",2936
	DECLE 0,63
	;[2937]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",2937
	DECLE 147,63
	;[2938]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2938
	DECLE 63,63
	;[2939]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2939
	DECLE 0,0
	;[2940]     MUSIC   D4,   D2,   A3
	SRCFILE "minty.bas",2940
	DECLE 33691,150
	;[2941]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2941
	DECLE 16191,63
	;[2942]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2942
	DECLE 16191,63
	;[2943]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2943
	DECLE 16275,0
	;[2944]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2944
	DECLE 16191,0
	;[2945]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2945
	DECLE 16128,0
	;[2946]     MUSIC   D4,   A3,   B2
	SRCFILE "minty.bas",2946
	DECLE 38555,140
	;[2947]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2947
	DECLE 16191,63
	;[2948]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2948
	DECLE 0,0
	;[2949]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2949
	DECLE 147,0
	;[2950]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2950
	DECLE 63,0
	;[2951]     MUSIC   D4,   F3,   A3
	SRCFILE "minty.bas",2951
	DECLE 37531,150
	;[2952]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2952
	DECLE 16191,63
	;[2953]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2953
	DECLE 0,0
	;[2954] 
	SRCFILE "minty.bas",2954
	;[2955] REM Timing 3400 frames, 68.00 secs
	SRCFILE "minty.bas",2955
	;[2956] 
	SRCFILE "minty.bas",2956
	;[2957]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2957
	DECLE 147,0
	;[2958]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2958
	DECLE 63,0
	;[2959]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2959
	DECLE 63,0
	;[2960]     MUSIC   B5,   E2,   D5
	SRCFILE "minty.bas",2960
	DECLE 34224,167
	;[2961]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2961
	DECLE 16191,63
	;[2962]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",2962
	DECLE 63,63
	;[2963]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2963
	DECLE 147,0
	;[2964]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2964
	DECLE 63,0
	;[2965]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2965
	DECLE 0,0
	;[2966]     MUSIC   A5,   F3,   C5
	SRCFILE "minty.bas",2966
	DECLE 37550,165
	;[2967]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2967
	DECLE 16191,63
	;[2968]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2968
	DECLE 147,0
	;[2969]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2969
	DECLE 63,0
	;[2970]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2970
	DECLE 0,0
	;[2971]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",2971
	DECLE 36017,169
	;[2972]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2972
	DECLE 16191,63
	;[2973]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",2973
	DECLE 0,0
	;[2974]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",2974
	DECLE 147,0
	;[2975]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2975
	DECLE 63,0
	;[2976]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",2976
	DECLE 63,0
	;[2977]     MUSIC   C6,   D2,   E5
	SRCFILE "minty.bas",2977
	DECLE 33713,169
	;[2978]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2978
	DECLE 16191,63
	;[2979]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2979
	DECLE 16191,63
	;[2980]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2980
	DECLE 16275,63
	;[2981]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2981
	DECLE 16191,63
	;[2982]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",2982
	DECLE 16275,63
	;[2983]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2983
	DECLE 16191,63
	;[2984]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2984
	DECLE 16128,0
	;[2985]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",2985
	DECLE 16275,0
	;[2986]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2986
	DECLE 16191,0
	;[2987]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2987
	DECLE 16128,0
	;[2988]     MUSIC   A5,    S,   C5
	SRCFILE "minty.bas",2988
	DECLE 16302,165
	;[2989]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2989
	DECLE 16191,63
	;[2990]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2990
	DECLE 16191,63
	;[2991]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2991
	DECLE 16191,63
	;[2992]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2992
	DECLE 16191,63
	;[2993]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",2993
	DECLE 16128,63
	;[2994]     MUSIC   E6,   A2,   E5
	SRCFILE "minty.bas",2994
	DECLE 35509,169
	;[2995]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",2995
	DECLE 16191,63
	;[2996]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",2996
	DECLE 16191,0
	;[2997]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2997
	DECLE 16128,0
	;[2998]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",2998
	DECLE 16128,0
	;[2999]     MUSIC   E6,    S,   E5
	SRCFILE "minty.bas",2999
	DECLE 16309,169
	;[3000]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3000
	DECLE 16191,63
	;[3001]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3001
	DECLE 16191,0
	;[3002]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3002
	DECLE 16128,0
	;[3003]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3003
	DECLE 16128,0
	;[3004]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3004
	DECLE 16128,0
	;[3005]     MUSIC   E6,    S,   E5
	SRCFILE "minty.bas",3005
	DECLE 16309,169
	;[3006]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3006
	DECLE 16191,63
	;[3007] 
	SRCFILE "minty.bas",3007
	;[3008] REM Timing 3500 frames, 70.00 secs
	SRCFILE "minty.bas",3008
	;[3009] 
	SRCFILE "minty.bas",3009
	;[3010]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3010
	DECLE 63,0
	;[3011]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3011
	DECLE 0,0
	;[3012]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3012
	DECLE 0,0
	;[3013]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3013
	DECLE 0,0
	;[3014]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",3014
	DECLE 40373,169
	;[3015]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3015
	DECLE 16191,63
	;[3016]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3016
	DECLE 0,0
	;[3017]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3017
	DECLE 0,0
	;[3018]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3018
	DECLE 0,0
	;[3019]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",3019
	DECLE 40373,169
	;[3020]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3020
	DECLE 16191,63
	;[3021]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3021
	DECLE 63,0
	;[3022]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3022
	DECLE 0,0
	;[3023]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3023
	DECLE 0,0
	;[3024]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3024
	DECLE 0,0
	;[3025]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",3025
	DECLE 40373,169
	;[3026]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3026
	DECLE 16191,63
	;[3027]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3027
	DECLE 16191,63
	;[3028]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3028
	DECLE 16128,63
	;[3029]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3029
	DECLE 16128,63
	;[3030]     MUSIC   E5,   E2,   E4
	SRCFILE "minty.bas",3030
	DECLE 34217,157
	;[3031]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3031
	DECLE 16191,63
	;[3032]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3032
	DECLE 16191,63
	;[3033]     MUSIC   A5,   A2,   A4
	SRCFILE "minty.bas",3033
	DECLE 35502,162
	;[3034]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3034
	DECLE 16191,63
	;[3035]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3035
	DECLE 16191,63
	;[3036]     MUSIC   C6,   C3,   C5
	SRCFILE "minty.bas",3036
	DECLE 36273,165
	;[3037]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3037
	DECLE 16191,63
	;[3038]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3038
	DECLE 16191,63
	;[3039]     MUSIC   E6,   E3,   E5
	SRCFILE "minty.bas",3039
	DECLE 37301,169
	;[3040]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3040
	DECLE 16191,63
	;[3041]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3041
	DECLE 16191,63
	;[3042]     MUSIC  D6#,  D3#,  D5#
	SRCFILE "minty.bas",3042
	DECLE 37044,168
	;[3043]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3043
	DECLE 16191,63
	;[3044]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3044
	DECLE 16191,0
	;[3045]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3045
	DECLE 16128,0
	;[3046]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3046
	DECLE 16128,0
	;[3047]     MUSIC  D6#,    S,  D5#
	SRCFILE "minty.bas",3047
	DECLE 16308,168
	;[3048]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3048
	DECLE 16191,63
	;[3049]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3049
	DECLE 16191,0
	;[3050]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3050
	DECLE 16128,0
	;[3051]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3051
	DECLE 16128,0
	;[3052]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3052
	DECLE 16128,0
	;[3053]     MUSIC  D6#,    S,  D5#
	SRCFILE "minty.bas",3053
	DECLE 16308,168
	;[3054]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3054
	DECLE 16191,63
	;[3055]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3055
	DECLE 16191,0
	;[3056]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3056
	DECLE 16128,0
	;[3057]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3057
	DECLE 16128,0
	;[3058]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3058
	DECLE 16128,0
	;[3059]     MUSIC  D6#,    S,  D5#
	SRCFILE "minty.bas",3059
	DECLE 16308,168
	;[3060] 
	SRCFILE "minty.bas",3060
	;[3061] REM Timing 3600 frames, 72.00 secs
	SRCFILE "minty.bas",3061
	;[3062] 
	SRCFILE "minty.bas",3062
	;[3063]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3063
	DECLE 16191,63
	;[3064]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3064
	DECLE 16128,0
	;[3065]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3065
	DECLE 16128,0
	;[3066]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3066
	DECLE 16128,0
	;[3067]     MUSIC  D6#,    S,  D5#
	SRCFILE "minty.bas",3067
	DECLE 16308,168
	;[3068]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3068
	DECLE 16191,63
	;[3069]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3069
	DECLE 63,0
	;[3070]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3070
	DECLE 0,0
	;[3071]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3071
	DECLE 0,0
	;[3072]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3072
	DECLE 0,0
	;[3073]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",3073
	DECLE 40628,168
	;[3074]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3074
	DECLE 16191,63
	;[3075]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3075
	DECLE 16191,63
	;[3076]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3076
	DECLE 16128,63
	;[3077]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3077
	DECLE 16128,63
	;[3078]     MUSIC   F5,   F2,   F4
	SRCFILE "minty.bas",3078
	DECLE 34474,158
	;[3079]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3079
	DECLE 16191,63
	;[3080]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3080
	DECLE 16191,63
	;[3081]     MUSIC   A5,   A2,   A4
	SRCFILE "minty.bas",3081
	DECLE 35502,162
	;[3082]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3082
	DECLE 16191,63
	;[3083]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3083
	DECLE 16191,63
	;[3084]     MUSIC   C6,   C3,   C5
	SRCFILE "minty.bas",3084
	DECLE 36273,165
	;[3085]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3085
	DECLE 16191,63
	;[3086]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3086
	DECLE 16191,63
	;[3087]     MUSIC  D6#,  D3#,  D5#
	SRCFILE "minty.bas",3087
	DECLE 37044,168
	;[3088]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3088
	DECLE 16191,63
	;[3089]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3089
	DECLE 16191,63
	;[3090]     MUSIC   D6,   D3,   D5
	SRCFILE "minty.bas",3090
	DECLE 36787,167
	;[3091]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3091
	DECLE 16191,63
	;[3092]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3092
	DECLE 16191,63
	;[3093]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3093
	DECLE 16128,63
	;[3094]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3094
	DECLE 16128,63
	;[3095]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3095
	DECLE 16128,63
	;[3096]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3096
	DECLE 16128,63
	;[3097]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3097
	DECLE 16128,63
	;[3098]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3098
	DECLE 16128,63
	;[3099]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3099
	DECLE 16128,0
	;[3100]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3100
	DECLE 16128,0
	;[3101]     MUSIC   C6,    S,   E5
	SRCFILE "minty.bas",3101
	DECLE 16305,169
	;[3102]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3102
	DECLE 16191,63
	;[3103]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3103
	DECLE 63,63
	;[3104]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3104
	DECLE 0,0
	;[3105]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3105
	DECLE 0,0
	;[3106]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3106
	DECLE 0,0
	;[3107]     MUSIC   A5,   A4,   C5
	SRCFILE "minty.bas",3107
	DECLE 41646,165
	;[3108]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3108
	DECLE 16191,63
	;[3109]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3109
	DECLE 0,0
	;[3110]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3110
	DECLE 0,0
	;[3111]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3111
	DECLE 0,0
	;[3112]     MUSIC   C6,   E3,   E5
	SRCFILE "minty.bas",3112
	DECLE 37297,169
	;[3113] 
	SRCFILE "minty.bas",3113
	;[3114] REM Timing 3700 frames, 74.00 secs
	SRCFILE "minty.bas",3114
	;[3115] 
	SRCFILE "minty.bas",3115
	;[3116]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3116
	DECLE 16191,63
	;[3117]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3117
	DECLE 63,0
	;[3118]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3118
	DECLE 0,0
	;[3119]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3119
	DECLE 0,0
	;[3120]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3120
	DECLE 0,0
	;[3121]     MUSIC   C6,   E3,   E5
	SRCFILE "minty.bas",3121
	DECLE 37297,169
	;[3122]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3122
	DECLE 16191,63
	;[3123]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3123
	DECLE 16191,63
	;[3124]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3124
	DECLE 16128,63
	;[3125]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3125
	DECLE 16128,63
	;[3126]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3126
	DECLE 16128,63
	;[3127]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3127
	DECLE 16128,63
	;[3128]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3128
	DECLE 16128,63
	;[3129]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3129
	DECLE 16128,0
	;[3130]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3130
	DECLE 16128,0
	;[3131]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3131
	DECLE 16128,0
	;[3132]     MUSIC   A5,    S,   C5
	SRCFILE "minty.bas",3132
	DECLE 16302,165
	;[3133]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3133
	DECLE 63,63
	;[3134]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3134
	DECLE 63,63
	;[3135]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3135
	DECLE 0,63
	;[3136]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3136
	DECLE 0,63
	;[3137]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3137
	DECLE 0,63
	;[3138]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3138
	DECLE 35502,150
	;[3139]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3139
	DECLE 16191,63
	;[3140]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3140
	DECLE 16191,63
	;[3141]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3141
	DECLE 16304,152
	;[3142]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3142
	DECLE 16191,63
	;[3143]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3143
	DECLE 35505,153
	;[3144]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3144
	DECLE 16191,63
	;[3145]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3145
	DECLE 63,63
	;[3146]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3146
	DECLE 40373,0
	;[3147]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3147
	DECLE 16191,0
	;[3148]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3148
	DECLE 16191,0
	;[3149]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3149
	DECLE 35502,150
	;[3150]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3150
	DECLE 16191,63
	;[3151]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3151
	DECLE 16191,63
	;[3152]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3152
	DECLE 16304,152
	;[3153]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3153
	DECLE 16191,63
	;[3154]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3154
	DECLE 16191,63
	;[3155]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3155
	DECLE 35505,153
	;[3156]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3156
	DECLE 16191,63
	;[3157]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3157
	DECLE 40373,0
	;[3158]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3158
	DECLE 16191,0
	;[3159]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3159
	DECLE 63,0
	;[3160]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3160
	DECLE 35502,150
	;[3161]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3161
	DECLE 16191,63
	;[3162]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3162
	DECLE 16191,63
	;[3163]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3163
	DECLE 16304,152
	;[3164]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3164
	DECLE 16191,63
	;[3165]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3165
	DECLE 16191,63
	;[3166] 
	SRCFILE "minty.bas",3166
	;[3167] REM Timing 3800 frames, 76.00 secs
	SRCFILE "minty.bas",3167
	;[3168] 
	SRCFILE "minty.bas",3168
	;[3169]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3169
	DECLE 35505,153
	;[3170]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3170
	DECLE 16191,63
	;[3171]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3171
	DECLE 63,63
	;[3172]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3172
	DECLE 40373,0
	;[3173]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3173
	DECLE 16191,0
	;[3174]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3174
	DECLE 35502,150
	;[3175]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3175
	DECLE 16191,63
	;[3176]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3176
	DECLE 16191,63
	;[3177]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3177
	DECLE 16304,152
	;[3178]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3178
	DECLE 16191,63
	;[3179]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3179
	DECLE 16191,63
	;[3180]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3180
	DECLE 35505,153
	;[3181]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3181
	DECLE 16191,63
	;[3182]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3182
	DECLE 16191,63
	;[3183]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3183
	DECLE 40373,0
	;[3184]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3184
	DECLE 16191,0
	;[3185]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3185
	DECLE 16191,0
	;[3186]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3186
	DECLE 35502,150
	;[3187]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3187
	DECLE 16191,63
	;[3188]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3188
	DECLE 16191,63
	;[3189]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3189
	DECLE 16304,152
	;[3190]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3190
	DECLE 16191,63
	;[3191]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3191
	DECLE 35505,153
	;[3192]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3192
	DECLE 16191,63
	;[3193]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3193
	DECLE 63,63
	;[3194]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3194
	DECLE 40373,0
	;[3195]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3195
	DECLE 16191,0
	;[3196]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3196
	DECLE 16191,0
	;[3197]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3197
	DECLE 35502,150
	;[3198]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3198
	DECLE 16191,63
	;[3199]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3199
	DECLE 16191,63
	;[3200]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3200
	DECLE 16304,152
	;[3201]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3201
	DECLE 16191,63
	;[3202]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3202
	DECLE 16191,63
	;[3203]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3203
	DECLE 35505,153
	;[3204]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3204
	DECLE 16191,63
	;[3205]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3205
	DECLE 40373,0
	;[3206]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3206
	DECLE 16191,0
	;[3207]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3207
	DECLE 16191,0
	;[3208]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3208
	DECLE 35502,150
	;[3209]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3209
	DECLE 16191,63
	;[3210]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3210
	DECLE 16191,63
	;[3211]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3211
	DECLE 16304,152
	;[3212]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3212
	DECLE 16191,63
	;[3213]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3213
	DECLE 16191,63
	;[3214]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3214
	DECLE 35505,153
	;[3215]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3215
	DECLE 16191,63
	;[3216]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3216
	DECLE 63,63
	;[3217]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3217
	DECLE 40373,0
	;[3218]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3218
	DECLE 16191,0
	;[3219] 
	SRCFILE "minty.bas",3219
	;[3220] REM Timing 3900 frames, 78.00 secs
	SRCFILE "minty.bas",3220
	;[3221] 
	SRCFILE "minty.bas",3221
	;[3222]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3222
	DECLE 35502,150
	;[3223]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3223
	DECLE 16191,63
	;[3224]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3224
	DECLE 16191,63
	;[3225]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3225
	DECLE 16304,152
	;[3226]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3226
	DECLE 16191,63
	;[3227]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3227
	DECLE 16191,63
	;[3228]     MUSIC   C6,   A2,   E4
	SRCFILE "minty.bas",3228
	DECLE 35505,157
	;[3229]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3229
	DECLE 16191,63
	;[3230]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3230
	DECLE 16191,63
	;[3231]     MUSIC   E6,    -,    -
	SRCFILE "minty.bas",3231
	DECLE 181,0
	;[3232]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3232
	DECLE 63,0
	;[3233]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3233
	DECLE 63,0
	;[3234]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",3234
	DECLE 35485,153
	;[3235]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3235
	DECLE 16191,63
	;[3236]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3236
	DECLE 16128,63
	;[3237]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3237
	DECLE 16128,63
	;[3238]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3238
	DECLE 16128,63
	;[3239]     MUSIC   F4,   A2,    S
	SRCFILE "minty.bas",3239
	DECLE 35486,63
	;[3240]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3240
	DECLE 16191,0
	;[3241]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3241
	DECLE 16128,0
	;[3242]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3242
	DECLE 0,0
	;[3243]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3243
	DECLE 0,0
	;[3244]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3244
	DECLE 0,0
	;[3245]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",3245
	DECLE 35486,153
	;[3246]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3246
	DECLE 16191,63
	;[3247]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3247
	DECLE 16191,63
	;[3248]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3248
	DECLE 16191,63
	;[3249]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3249
	DECLE 16128,0
	;[3250]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3250
	DECLE 16128,0
	;[3251]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",3251
	DECLE 35485,153
	;[3252]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3252
	DECLE 16191,63
	;[3253]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3253
	DECLE 0,0
	;[3254]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3254
	DECLE 0,0
	;[3255]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3255
	DECLE 0,0
	;[3256]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",3256
	DECLE 35485,153
	;[3257]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3257
	DECLE 16191,63
	;[3258]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3258
	DECLE 16191,63
	;[3259]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3259
	DECLE 16191,63
	;[3260]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3260
	DECLE 16128,63
	;[3261]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3261
	DECLE 16128,63
	;[3262]     MUSIC   F4,   A2,    S
	SRCFILE "minty.bas",3262
	DECLE 35486,63
	;[3263]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3263
	DECLE 16191,0
	;[3264]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3264
	DECLE 0,0
	;[3265]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3265
	DECLE 0,0
	;[3266]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3266
	DECLE 0,0
	;[3267]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",3267
	DECLE 35486,153
	;[3268]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3268
	DECLE 16191,63
	;[3269]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3269
	DECLE 16191,63
	;[3270]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3270
	DECLE 16191,63
	;[3271]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3271
	DECLE 16191,63
	;[3272] 
	SRCFILE "minty.bas",3272
	;[3273] REM Timing 4000 frames, 80.00 secs
	SRCFILE "minty.bas",3273
	;[3274] 
	SRCFILE "minty.bas",3274
	;[3275]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3275
	DECLE 16128,63
	;[3276]     MUSIC   E4,   A2,    S
	SRCFILE "minty.bas",3276
	DECLE 35485,63
	;[3277]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3277
	DECLE 16191,0
	;[3278]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3278
	DECLE 0,0
	;[3279]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3279
	DECLE 0,0
	;[3280]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3280
	DECLE 0,0
	;[3281]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3281
	DECLE 0,0
	;[3282]     MUSIC   E4,  G2#,   B3
	SRCFILE "minty.bas",3282
	DECLE 35229,152
	;[3283]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3283
	DECLE 16191,63
	;[3284]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3284
	DECLE 16128,63
	;[3285]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3285
	DECLE 16128,63
	;[3286]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3286
	DECLE 16128,63
	;[3287]     MUSIC   F4,  G2#,    S
	SRCFILE "minty.bas",3287
	DECLE 35230,63
	;[3288]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3288
	DECLE 16191,63
	;[3289]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3289
	DECLE 0,0
	;[3290]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3290
	DECLE 0,0
	;[3291]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3291
	DECLE 0,0
	;[3292]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3292
	DECLE 0,0
	;[3293]     MUSIC   F4,  G2#,   B3
	SRCFILE "minty.bas",3293
	DECLE 35230,152
	;[3294]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3294
	DECLE 16191,63
	;[3295]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3295
	DECLE 16191,63
	;[3296]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3296
	DECLE 16191,63
	;[3297]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3297
	DECLE 16128,63
	;[3298]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3298
	DECLE 16128,63
	;[3299]     MUSIC   E4,  G2#,    S
	SRCFILE "minty.bas",3299
	DECLE 35229,63
	;[3300]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3300
	DECLE 16191,0
	;[3301]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3301
	DECLE 0,0
	;[3302]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3302
	DECLE 0,0
	;[3303]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3303
	DECLE 0,0
	;[3304]     MUSIC   E4,  G2#,   B3
	SRCFILE "minty.bas",3304
	DECLE 35229,152
	;[3305]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3305
	DECLE 16191,63
	;[3306]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3306
	DECLE 16191,0
	;[3307]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3307
	DECLE 16191,0
	;[3308]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3308
	DECLE 16128,0
	;[3309]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3309
	DECLE 16128,0
	;[3310]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",3310
	DECLE 35234,157
	;[3311]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3311
	DECLE 16191,63
	;[3312]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3312
	DECLE 0,0
	;[3313]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3313
	DECLE 0,0
	;[3314]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3314
	DECLE 0,0
	;[3315]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",3315
	DECLE 35234,157
	;[3316]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3316
	DECLE 16191,63
	;[3317]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3317
	DECLE 16191,63
	;[3318]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3318
	DECLE 16191,63
	;[3319]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3319
	DECLE 16191,63
	;[3320]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3320
	DECLE 16128,0
	;[3321]     MUSIC  G4#,  G2#,   E4
	SRCFILE "minty.bas",3321
	DECLE 35233,157
	;[3322]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3322
	DECLE 16191,63
	;[3323]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3323
	DECLE 63,63
	;[3324]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3324
	DECLE 63,63
	;[3325] 
	SRCFILE "minty.bas",3325
	;[3326] REM Timing 4100 frames, 82.00 secs
	SRCFILE "minty.bas",3326
	;[3327] 
	SRCFILE "minty.bas",3327
	;[3328]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3328
	DECLE 0,63
	;[3329]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3329
	DECLE 0,63
	;[3330]     MUSIC   E2,   E2,    -
	SRCFILE "minty.bas",3330
	DECLE 34181,0
	;[3331]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3331
	DECLE 16191,0
	;[3332]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3332
	DECLE 16128,0
	;[3333]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3333
	DECLE 16128,0
	;[3334]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3334
	DECLE 16128,0
	;[3335]     MUSIC   E2,    -,    -
	SRCFILE "minty.bas",3335
	DECLE 133,0
	;[3336]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3336
	DECLE 63,0
	;[3337]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3337
	DECLE 0,0
	;[3338]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3338
	DECLE 0,0
	;[3339]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3339
	DECLE 0,0
	;[3340]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3340
	DECLE 0,0
	;[3341]     MUSIC   E3,   D2,   E2
	SRCFILE "minty.bas",3341
	DECLE 33681,133
	;[3342]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3342
	DECLE 16191,63
	;[3343]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3343
	DECLE 16191,0
	;[3344]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3344
	DECLE 16191,0
	;[3345]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3345
	DECLE 16191,0
	;[3346]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3346
	DECLE 16191,0
	;[3347]     MUSIC   E2,    -,    -
	SRCFILE "minty.bas",3347
	DECLE 133,0
	;[3348]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3348
	DECLE 63,0
	;[3349]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3349
	DECLE 63,0
	;[3350]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3350
	DECLE 0,0
	;[3351]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3351
	DECLE 0,0
	;[3352]     MUSIC   D5,   B2,   B4
	SRCFILE "minty.bas",3352
	DECLE 36007,164
	;[3353]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3353
	DECLE 16191,63
	;[3354]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3354
	DECLE 0,0
	;[3355]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3355
	DECLE 0,0
	;[3356]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3356
	DECLE 0,0
	;[3357]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3357
	DECLE 0,0
	;[3358]     MUSIC   D5,   B4,    -
	SRCFILE "minty.bas",3358
	DECLE 42151,0
	;[3359]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3359
	DECLE 16191,0
	;[3360]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3360
	DECLE 16191,0
	;[3361]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3361
	DECLE 16191,0
	;[3362]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3362
	DECLE 16191,0
	;[3363]     MUSIC    S,    -,   E2
	SRCFILE "minty.bas",3363
	DECLE 63,133
	;[3364]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3364
	DECLE 63,63
	;[3365]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3365
	DECLE 0,0
	;[3366]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3366
	DECLE 0,0
	;[3367]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3367
	DECLE 0,0
	;[3368]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3368
	DECLE 0,0
	;[3369]     MUSIC   D5,   E2,   F4
	SRCFILE "minty.bas",3369
	DECLE 34215,158
	;[3370]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3370
	DECLE 16191,63
	;[3371]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3371
	DECLE 16128,63
	;[3372]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3372
	DECLE 16128,63
	;[3373]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3373
	DECLE 16128,63
	;[3374]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3374
	DECLE 16128,63
	;[3375]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",3375
	DECLE 35502,165
	;[3376]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3376
	DECLE 16191,63
	;[3377]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3377
	DECLE 16191,63
	;[3378] 
	SRCFILE "minty.bas",3378
	;[3379] REM Timing 4200 frames, 84.00 secs
	SRCFILE "minty.bas",3379
	;[3380] 
	SRCFILE "minty.bas",3380
	;[3381]     MUSIC   B5,    S,    S
	SRCFILE "minty.bas",3381
	DECLE 16304,63
	;[3382]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3382
	DECLE 16191,63
	;[3383]     MUSIC   C6,   A2,    S
	SRCFILE "minty.bas",3383
	DECLE 35505,63
	;[3384]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3384
	DECLE 16191,63
	;[3385]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3385
	DECLE 63,63
	;[3386]     MUSIC   E6,   E4,    S
	SRCFILE "minty.bas",3386
	DECLE 40373,63
	;[3387]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3387
	DECLE 16191,0
	;[3388]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3388
	DECLE 16191,0
	;[3389]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3389
	DECLE 35502,150
	;[3390]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3390
	DECLE 16191,63
	;[3391]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3391
	DECLE 16191,63
	;[3392]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3392
	DECLE 16304,152
	;[3393]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3393
	DECLE 16191,63
	;[3394]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3394
	DECLE 16191,63
	;[3395]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3395
	DECLE 35505,153
	;[3396]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3396
	DECLE 16191,63
	;[3397]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3397
	DECLE 40373,0
	;[3398]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3398
	DECLE 16191,0
	;[3399]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3399
	DECLE 16191,0
	;[3400]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3400
	DECLE 35502,150
	;[3401]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3401
	DECLE 16191,63
	;[3402]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3402
	DECLE 16191,63
	;[3403]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3403
	DECLE 16304,152
	;[3404]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3404
	DECLE 16191,63
	;[3405]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3405
	DECLE 16191,63
	;[3406]     MUSIC   C6,   B2,   C4
	SRCFILE "minty.bas",3406
	DECLE 36017,153
	;[3407]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3407
	DECLE 16191,63
	;[3408]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3408
	DECLE 63,63
	;[3409]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3409
	DECLE 40373,0
	;[3410]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3410
	DECLE 16191,0
	;[3411]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3411
	DECLE 35502,150
	;[3412]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3412
	DECLE 16191,63
	;[3413]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3413
	DECLE 16191,63
	;[3414]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3414
	DECLE 16304,152
	;[3415]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3415
	DECLE 16191,63
	;[3416]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3416
	DECLE 16191,63
	;[3417]     MUSIC   C6,   A2,   E4
	SRCFILE "minty.bas",3417
	DECLE 35505,157
	;[3418]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3418
	DECLE 16191,63
	;[3419]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3419
	DECLE 16191,63
	;[3420]     MUSIC   E6,    -,    -
	SRCFILE "minty.bas",3420
	DECLE 181,0
	;[3421]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3421
	DECLE 63,0
	;[3422]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3422
	DECLE 63,0
	;[3423]     MUSIC   A5,   A2,   E4
	SRCFILE "minty.bas",3423
	DECLE 35502,157
	;[3424]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3424
	DECLE 16191,63
	;[3425]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3425
	DECLE 16191,0
	;[3426]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3426
	DECLE 16128,0
	;[3427]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3427
	DECLE 16128,0
	;[3428]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",3428
	DECLE 35486,153
	;[3429]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3429
	DECLE 16191,63
	;[3430]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3430
	DECLE 0,0
	;[3431] 
	SRCFILE "minty.bas",3431
	;[3432] REM Timing 4300 frames, 86.00 secs
	SRCFILE "minty.bas",3432
	;[3433] 
	SRCFILE "minty.bas",3433
	;[3434]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3434
	DECLE 0,0
	;[3435]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3435
	DECLE 0,0
	;[3436]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3436
	DECLE 0,0
	;[3437]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",3437
	DECLE 35486,153
	;[3438]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3438
	DECLE 16191,63
	;[3439]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3439
	DECLE 16191,63
	;[3440]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3440
	DECLE 16191,0
	;[3441]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3441
	DECLE 16128,0
	;[3442]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3442
	DECLE 16128,0
	;[3443]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",3443
	DECLE 35485,153
	;[3444]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3444
	DECLE 16191,63
	;[3445]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3445
	DECLE 0,0
	;[3446]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3446
	DECLE 0,0
	;[3447]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3447
	DECLE 0,0
	;[3448]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",3448
	DECLE 35485,153
	;[3449]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3449
	DECLE 16191,63
	;[3450]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3450
	DECLE 16191,63
	;[3451]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3451
	DECLE 16191,63
	;[3452]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3452
	DECLE 16128,0
	;[3453]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3453
	DECLE 16128,0
	;[3454]     MUSIC   F4,   A2,   A3
	SRCFILE "minty.bas",3454
	DECLE 35486,150
	;[3455]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3455
	DECLE 16191,63
	;[3456]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3456
	DECLE 0,0
	;[3457]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3457
	DECLE 0,0
	;[3458]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3458
	DECLE 0,0
	;[3459]     MUSIC   F4,   A2,   C4
	SRCFILE "minty.bas",3459
	DECLE 35486,153
	;[3460]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3460
	DECLE 16191,63
	;[3461]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3461
	DECLE 16191,63
	;[3462]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3462
	DECLE 16191,63
	;[3463]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3463
	DECLE 16191,63
	;[3464]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3464
	DECLE 16128,63
	;[3465]     MUSIC   E4,   A2,    -
	SRCFILE "minty.bas",3465
	DECLE 35485,0
	;[3466]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3466
	DECLE 16191,0
	;[3467]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3467
	DECLE 0,0
	;[3468]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3468
	DECLE 0,0
	;[3469]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3469
	DECLE 0,0
	;[3470]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3470
	DECLE 0,0
	;[3471]     MUSIC   E4,  G2#,   B3
	SRCFILE "minty.bas",3471
	DECLE 35229,152
	;[3472]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3472
	DECLE 16191,63
	;[3473]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3473
	DECLE 16191,63
	;[3474]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3474
	DECLE 16191,63
	;[3475]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3475
	DECLE 16191,63
	;[3476]     MUSIC   F4,  G2#,    S
	SRCFILE "minty.bas",3476
	DECLE 35230,63
	;[3477]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3477
	DECLE 16191,63
	;[3478]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3478
	DECLE 0,0
	;[3479]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3479
	DECLE 0,0
	;[3480]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3480
	DECLE 0,0
	;[3481]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3481
	DECLE 0,0
	;[3482]     MUSIC   F4,  G2#,   B3
	SRCFILE "minty.bas",3482
	DECLE 35230,152
	;[3483]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3483
	DECLE 16191,63
	;[3484] 
	SRCFILE "minty.bas",3484
	;[3485] REM Timing 4400 frames, 88.00 secs
	SRCFILE "minty.bas",3485
	;[3486] 
	SRCFILE "minty.bas",3486
	;[3487]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3487
	DECLE 16191,63
	;[3488]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3488
	DECLE 16191,63
	;[3489]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3489
	DECLE 16128,63
	;[3490]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3490
	DECLE 16128,63
	;[3491]     MUSIC   E4,  G2#,    -
	SRCFILE "minty.bas",3491
	DECLE 35229,0
	;[3492]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3492
	DECLE 16191,0
	;[3493]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3493
	DECLE 0,0
	;[3494]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3494
	DECLE 0,0
	;[3495]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3495
	DECLE 0,0
	;[3496]     MUSIC   E4,  G2#,   B3
	SRCFILE "minty.bas",3496
	DECLE 35229,152
	;[3497]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3497
	DECLE 16191,63
	;[3498]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3498
	DECLE 16191,63
	;[3499]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3499
	DECLE 16191,63
	;[3500]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3500
	DECLE 16191,63
	;[3501]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3501
	DECLE 16128,0
	;[3502]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",3502
	DECLE 35234,157
	;[3503]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3503
	DECLE 16191,63
	;[3504]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3504
	DECLE 0,0
	;[3505]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3505
	DECLE 0,0
	;[3506]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3506
	DECLE 0,0
	;[3507]     MUSIC   A4,  G2#,   E4
	SRCFILE "minty.bas",3507
	DECLE 35234,157
	;[3508]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3508
	DECLE 16191,63
	;[3509]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3509
	DECLE 16191,63
	;[3510]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3510
	DECLE 16191,63
	;[3511]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3511
	DECLE 16191,63
	;[3512]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3512
	DECLE 16128,63
	;[3513]     MUSIC  G4#,  G2#,    S
	SRCFILE "minty.bas",3513
	DECLE 35233,63
	;[3514]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3514
	DECLE 16191,63
	;[3515]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3515
	DECLE 63,63
	;[3516]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3516
	DECLE 63,63
	;[3517]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3517
	DECLE 63,63
	;[3518]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3518
	DECLE 63,63
	;[3519]     MUSIC   E2,   E2,    S
	SRCFILE "minty.bas",3519
	DECLE 34181,63
	;[3520]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3520
	DECLE 16191,63
	;[3521]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3521
	DECLE 16128,63
	;[3522]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3522
	DECLE 16128,0
	;[3523]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3523
	DECLE 16128,0
	;[3524]     MUSIC   E2,    S,    -
	SRCFILE "minty.bas",3524
	DECLE 16261,0
	;[3525]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3525
	DECLE 16191,0
	;[3526]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3526
	DECLE 63,0
	;[3527]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3527
	DECLE 0,0
	;[3528]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3528
	DECLE 0,0
	;[3529]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3529
	DECLE 0,0
	;[3530]     MUSIC   E2,   D2,    -
	SRCFILE "minty.bas",3530
	DECLE 33669,0
	;[3531]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3531
	DECLE 16191,0
	;[3532]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3532
	DECLE 16128,0
	;[3533]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3533
	DECLE 16128,0
	;[3534]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3534
	DECLE 16128,0
	;[3535]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3535
	DECLE 16128,0
	;[3536]     MUSIC   E3,   E2,    -
	SRCFILE "minty.bas",3536
	DECLE 34193,0
	;[3537] 
	SRCFILE "minty.bas",3537
	;[3538] REM Timing 4500 frames, 90.00 secs
	SRCFILE "minty.bas",3538
	;[3539] 
	SRCFILE "minty.bas",3539
	;[3540]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3540
	DECLE 16191,0
	;[3541]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3541
	DECLE 16128,0
	;[3542]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3542
	DECLE 0,0
	;[3543]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3543
	DECLE 0,0
	;[3544]     MUSIC   F5,   B2,   D5
	SRCFILE "minty.bas",3544
	DECLE 36010,167
	;[3545]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3545
	DECLE 16191,63
	;[3546]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3546
	DECLE 0,0
	;[3547]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3547
	DECLE 0,0
	;[3548]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3548
	DECLE 0,0
	;[3549]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3549
	DECLE 0,0
	;[3550]     MUSIC   F5,   B2,   D5
	SRCFILE "minty.bas",3550
	DECLE 36010,167
	;[3551]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3551
	DECLE 16191,63
	;[3552]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3552
	DECLE 63,63
	;[3553]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3553
	DECLE 63,63
	;[3554]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3554
	DECLE 63,63
	;[3555]     MUSIC    S,   E2,    S
	SRCFILE "minty.bas",3555
	DECLE 34111,63
	;[3556]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3556
	DECLE 16191,63
	;[3557]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3557
	DECLE 0,63
	;[3558]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3558
	DECLE 0,63
	;[3559]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3559
	DECLE 0,0
	;[3560]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3560
	DECLE 0,0
	;[3561]     MUSIC   F5,   E2,   B4
	SRCFILE "minty.bas",3561
	DECLE 34218,164
	;[3562]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3562
	DECLE 16191,63
	;[3563]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3563
	DECLE 16191,63
	;[3564]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3564
	DECLE 63,63
	;[3565]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3565
	DECLE 63,63
	;[3566]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3566
	DECLE 63,63
	;[3567]     MUSIC   A5,   A2,   E5
	SRCFILE "minty.bas",3567
	DECLE 35502,169
	;[3568]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3568
	DECLE 16191,63
	;[3569]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3569
	DECLE 16191,63
	;[3570]     MUSIC   B5,    S,    S
	SRCFILE "minty.bas",3570
	DECLE 16304,63
	;[3571]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3571
	DECLE 16191,63
	;[3572]     MUSIC   C6,   A2,    S
	SRCFILE "minty.bas",3572
	DECLE 35505,63
	;[3573]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3573
	DECLE 16191,63
	;[3574]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3574
	DECLE 63,0
	;[3575]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3575
	DECLE 40373,0
	;[3576]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3576
	DECLE 16191,0
	;[3577]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3577
	DECLE 16191,0
	;[3578]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3578
	DECLE 35502,150
	;[3579]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3579
	DECLE 16191,63
	;[3580]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3580
	DECLE 16191,63
	;[3581]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3581
	DECLE 16304,152
	;[3582]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3582
	DECLE 16191,63
	;[3583]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3583
	DECLE 16191,63
	;[3584]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3584
	DECLE 35505,153
	;[3585]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3585
	DECLE 16191,63
	;[3586]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3586
	DECLE 40373,0
	;[3587]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3587
	DECLE 16191,0
	;[3588]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3588
	DECLE 16191,0
	;[3589]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3589
	DECLE 35502,150
	;[3590] 
	SRCFILE "minty.bas",3590
	;[3591] REM Timing 4600 frames, 92.00 secs
	SRCFILE "minty.bas",3591
	;[3592] 
	SRCFILE "minty.bas",3592
	;[3593]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3593
	DECLE 16191,63
	;[3594]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3594
	DECLE 16191,63
	;[3595]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3595
	DECLE 16304,152
	;[3596]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3596
	DECLE 16191,63
	;[3597]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3597
	DECLE 16191,63
	;[3598]     MUSIC   C6,   B2,   C4
	SRCFILE "minty.bas",3598
	DECLE 36017,153
	;[3599]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3599
	DECLE 16191,63
	;[3600]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3600
	DECLE 63,63
	;[3601]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3601
	DECLE 40373,0
	;[3602]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3602
	DECLE 16191,0
	;[3603]     MUSIC   A5,   A2,   A3
	SRCFILE "minty.bas",3603
	DECLE 35502,150
	;[3604]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3604
	DECLE 16191,63
	;[3605]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3605
	DECLE 16191,63
	;[3606]     MUSIC   B5,    S,   B3
	SRCFILE "minty.bas",3606
	DECLE 16304,152
	;[3607]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3607
	DECLE 16191,63
	;[3608]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3608
	DECLE 16191,63
	;[3609]     MUSIC   C6,   A2,   C4
	SRCFILE "minty.bas",3609
	DECLE 35505,153
	;[3610]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3610
	DECLE 16191,63
	;[3611]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3611
	DECLE 16191,63
	;[3612]     MUSIC   E6,   E4,    -
	SRCFILE "minty.bas",3612
	DECLE 40373,0
	;[3613]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3613
	DECLE 16191,0
	;[3614]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3614
	DECLE 16191,0
	;[3615]     MUSIC   A5,   A2,   D5
	SRCFILE "minty.bas",3615
	DECLE 35502,167
	;[3616]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3616
	DECLE 16191,63
	;[3617]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3617
	DECLE 16191,0
	;[3618]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3618
	DECLE 0,0
	;[3619]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3619
	DECLE 0,0
	;[3620]     MUSIC   D5,   A2,   B4
	SRCFILE "minty.bas",3620
	DECLE 35495,164
	;[3621]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3621
	DECLE 16191,63
	;[3622]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3622
	DECLE 16191,63
	;[3623]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3623
	DECLE 63,63
	;[3624]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3624
	DECLE 63,63
	;[3625]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3625
	DECLE 63,63
	;[3626]     MUSIC    S,   A2,    S
	SRCFILE "minty.bas",3626
	DECLE 35391,63
	;[3627]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3627
	DECLE 16191,63
	;[3628]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3628
	DECLE 16128,63
	;[3629]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3629
	DECLE 16128,63
	;[3630]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3630
	DECLE 16128,0
	;[3631]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3631
	DECLE 16128,0
	;[3632]     MUSIC   C5,   A2,   A4
	SRCFILE "minty.bas",3632
	DECLE 35493,162
	;[3633]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3633
	DECLE 16191,63
	;[3634]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3634
	DECLE 63,63
	;[3635]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3635
	DECLE 63,63
	;[3636]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3636
	DECLE 63,63
	;[3637]     MUSIC    S,   A2,    S
	SRCFILE "minty.bas",3637
	DECLE 35391,63
	;[3638]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3638
	DECLE 16191,63
	;[3639]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3639
	DECLE 16191,63
	;[3640]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3640
	DECLE 16191,63
	;[3641]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3641
	DECLE 16191,63
	;[3642]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3642
	DECLE 63,63
	;[3643] 
	SRCFILE "minty.bas",3643
	;[3644] REM Timing 4700 frames, 94.00 secs
	SRCFILE "minty.bas",3644
	;[3645] 
	SRCFILE "minty.bas",3645
	;[3646]     MUSIC    S,   A2,    S
	SRCFILE "minty.bas",3646
	DECLE 35391,63
	;[3647]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3647
	DECLE 16191,63
	;[3648]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3648
	DECLE 16191,63
	;[3649]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3649
	DECLE 63,63
	;[3650]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3650
	DECLE 63,63
	;[3651]     MUSIC   A2,   E2,    S
	SRCFILE "minty.bas",3651
	DECLE 34186,63
	;[3652]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3652
	DECLE 16191,63
	;[3653]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3653
	DECLE 63,0
	;[3654]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3654
	DECLE 63,0
	;[3655]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3655
	DECLE 63,0
	;[3656]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3656
	DECLE 0,0
	;[3657]     MUSIC   C5,   B2,   A4
	SRCFILE "minty.bas",3657
	DECLE 36005,162
	;[3658]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3658
	DECLE 16191,63
	;[3659]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3659
	DECLE 63,63
	;[3660]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3660
	DECLE 63,63
	;[3661]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3661
	DECLE 0,0
	;[3662]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3662
	DECLE 0,0
	;[3663]     MUSIC   B4,   A2,  G4#
	SRCFILE "minty.bas",3663
	DECLE 35492,161
	;[3664]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3664
	DECLE 16191,63
	;[3665]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3665
	DECLE 16128,0
	;[3666]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3666
	DECLE 16128,0
	;[3667]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3667
	DECLE 0,0
	;[3668]     MUSIC   B4,   A2,  G4#
	SRCFILE "minty.bas",3668
	DECLE 35492,161
	;[3669]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3669
	DECLE 16191,63
	;[3670]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3670
	DECLE 63,63
	;[3671]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3671
	DECLE 63,63
	;[3672]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3672
	DECLE 63,63
	;[3673]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3673
	DECLE 63,63
	;[3674]     MUSIC    S,   A2,    S
	SRCFILE "minty.bas",3674
	DECLE 35391,63
	;[3675]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3675
	DECLE 16191,63
	;[3676]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3676
	DECLE 16128,0
	;[3677]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3677
	DECLE 16128,0
	;[3678]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3678
	DECLE 16128,0
	;[3679]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3679
	DECLE 0,0
	;[3680]     MUSIC   C5,   A2,   E4
	SRCFILE "minty.bas",3680
	DECLE 35493,157
	;[3681]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3681
	DECLE 16191,63
	;[3682]     MUSIC   B4,    -,    S
	SRCFILE "minty.bas",3682
	DECLE 164,63
	;[3683]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3683
	DECLE 63,63
	;[3684]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3684
	DECLE 63,63
	;[3685]     MUSIC   A5,   A2,   A4
	SRCFILE "minty.bas",3685
	DECLE 35502,162
	;[3686]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3686
	DECLE 16191,63
	;[3687]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3687
	DECLE 16191,63
	;[3688]     MUSIC   B5,    S,    S
	SRCFILE "minty.bas",3688
	DECLE 16304,63
	;[3689]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3689
	DECLE 16191,63
	;[3690]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3690
	DECLE 16191,63
	;[3691]     MUSIC   C6,   B2,    S
	SRCFILE "minty.bas",3691
	DECLE 36017,63
	;[3692]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3692
	DECLE 16191,63
	;[3693]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3693
	DECLE 63,63
	;[3694]     MUSIC   E6,    -,    S
	SRCFILE "minty.bas",3694
	DECLE 181,63
	;[3695]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3695
	DECLE 63,63
	;[3696] 
	SRCFILE "minty.bas",3696
	;[3697] REM Timing 4800 frames, 96.00 secs
	SRCFILE "minty.bas",3697
	;[3698] 
	SRCFILE "minty.bas",3698
	;[3699]     MUSIC   A5,   G2,    S
	SRCFILE "minty.bas",3699
	DECLE 34990,63
	;[3700]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3700
	DECLE 16191,63
	;[3701]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3701
	DECLE 16191,63
	;[3702]     MUSIC   B5,    S,    S
	SRCFILE "minty.bas",3702
	DECLE 16304,63
	;[3703]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3703
	DECLE 16191,63
	;[3704]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3704
	DECLE 16191,63
	;[3705]     MUSIC   C6,   G2,    S
	SRCFILE "minty.bas",3705
	DECLE 34993,63
	;[3706]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3706
	DECLE 16191,63
	;[3707]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3707
	DECLE 16191,63
	;[3708]     MUSIC   E6,    -,    -
	SRCFILE "minty.bas",3708
	DECLE 181,0
	;[3709]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3709
	DECLE 63,0
	;[3710]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3710
	DECLE 63,0
	;[3711]     MUSIC   A5,   F2,   F3
	SRCFILE "minty.bas",3711
	DECLE 34478,146
	;[3712]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3712
	DECLE 16191,63
	;[3713]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3713
	DECLE 16191,63
	;[3714]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3714
	DECLE 16128,63
	;[3715]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3715
	DECLE 16128,63
	;[3716]     MUSIC   D5,   F2,  A4#
	SRCFILE "minty.bas",3716
	DECLE 34471,163
	;[3717]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3717
	DECLE 16191,63
	;[3718]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3718
	DECLE 0,0
	;[3719]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3719
	DECLE 0,0
	;[3720]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3720
	DECLE 0,0
	;[3721]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3721
	DECLE 0,0
	;[3722]     MUSIC   D5,   F2,  A4#
	SRCFILE "minty.bas",3722
	DECLE 34471,163
	;[3723]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3723
	DECLE 16191,63
	;[3724]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3724
	DECLE 16191,63
	;[3725]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3725
	DECLE 16191,63
	;[3726]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3726
	DECLE 16191,63
	;[3727]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3727
	DECLE 16191,63
	;[3728]     MUSIC    S,   F2,    S
	SRCFILE "minty.bas",3728
	DECLE 34367,63
	;[3729]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3729
	DECLE 16191,63
	;[3730]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3730
	DECLE 0,63
	;[3731]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3731
	DECLE 0,0
	;[3732]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3732
	DECLE 0,0
	;[3733]     MUSIC   C5,   F2,   A4
	SRCFILE "minty.bas",3733
	DECLE 34469,162
	;[3734]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3734
	DECLE 16191,63
	;[3735]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3735
	DECLE 16128,0
	;[3736]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3736
	DECLE 16128,0
	;[3737]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3737
	DECLE 16128,0
	;[3738]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3738
	DECLE 16128,0
	;[3739]     MUSIC   C5,   F2,   A4
	SRCFILE "minty.bas",3739
	DECLE 34469,162
	;[3740]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3740
	DECLE 16191,63
	;[3741]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3741
	DECLE 63,63
	;[3742]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3742
	DECLE 63,63
	;[3743]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3743
	DECLE 63,63
	;[3744]     MUSIC    S,   F2,    S
	SRCFILE "minty.bas",3744
	DECLE 34367,63
	;[3745]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3745
	DECLE 16191,63
	;[3746]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3746
	DECLE 16128,63
	;[3747]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3747
	DECLE 16128,0
	;[3748]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3748
	DECLE 16128,0
	;[3749] 
	SRCFILE "minty.bas",3749
	;[3750] REM Timing 4900 frames, 98.00 secs
	SRCFILE "minty.bas",3750
	;[3751] 
	SRCFILE "minty.bas",3751
	;[3752]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3752
	DECLE 16128,0
	;[3753]     MUSIC   C5,   B2,   A4
	SRCFILE "minty.bas",3753
	DECLE 36005,162
	;[3754]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3754
	DECLE 16191,63
	;[3755]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3755
	DECLE 63,0
	;[3756]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3756
	DECLE 0,0
	;[3757]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3757
	DECLE 0,0
	;[3758]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3758
	DECLE 0,0
	;[3759]     MUSIC   B4,   F2,   G4
	SRCFILE "minty.bas",3759
	DECLE 34468,160
	;[3760]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3760
	DECLE 16191,63
	;[3761]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3761
	DECLE 16128,0
	;[3762]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3762
	DECLE 16128,0
	;[3763]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3763
	DECLE 0,0
	;[3764]     MUSIC   B4,   F2,   G4
	SRCFILE "minty.bas",3764
	DECLE 34468,160
	;[3765]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3765
	DECLE 16191,63
	;[3766]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3766
	DECLE 16191,63
	;[3767]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3767
	DECLE 63,63
	;[3768]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3768
	DECLE 63,63
	;[3769]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3769
	DECLE 63,63
	;[3770]     MUSIC    S,   F2,    S
	SRCFILE "minty.bas",3770
	DECLE 34367,63
	;[3771]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3771
	DECLE 16128,63
	;[3772]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3772
	DECLE 16128,0
	;[3773]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3773
	DECLE 16128,0
	;[3774]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3774
	DECLE 0,0
	;[3775]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3775
	DECLE 0,0
	;[3776]     MUSIC   C5,   F2,   F4
	SRCFILE "minty.bas",3776
	DECLE 34469,158
	;[3777]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3777
	DECLE 16191,63
	;[3778]     MUSIC   B4,    -,    S
	SRCFILE "minty.bas",3778
	DECLE 164,63
	;[3779]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3779
	DECLE 63,63
	;[3780]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3780
	DECLE 63,63
	;[3781]     MUSIC   A4,   F2,    S
	SRCFILE "minty.bas",3781
	DECLE 34466,63
	;[3782]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3782
	DECLE 16191,63
	;[3783]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3783
	DECLE 16191,63
	;[3784]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3784
	DECLE 16191,63
	;[3785]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3785
	DECLE 16191,63
	;[3786]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3786
	DECLE 16191,63
	;[3787]     MUSIC    S,   B2,   F2
	SRCFILE "minty.bas",3787
	DECLE 35903,134
	;[3788]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3788
	DECLE 16191,63
	;[3789]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3789
	DECLE 63,0
	;[3790]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3790
	DECLE 63,0
	;[3791]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3791
	DECLE 63,0
	;[3792]     MUSIC    S,   E2,    -
	SRCFILE "minty.bas",3792
	DECLE 34111,0
	;[3793]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3793
	DECLE 16191,0
	;[3794]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3794
	DECLE 63,0
	;[3795]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3795
	DECLE 0,0
	;[3796]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3796
	DECLE 0,0
	;[3797]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3797
	DECLE 0,0
	;[3798]     MUSIC   A4,   E3,   E4
	SRCFILE "minty.bas",3798
	DECLE 37282,157
	;[3799]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3799
	DECLE 16191,63
	;[3800]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3800
	DECLE 0,0
	;[3801]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3801
	DECLE 0,0
	;[3802] 
	SRCFILE "minty.bas",3802
	;[3803] REM Timing 5000 frames, 100.00 secs
	SRCFILE "minty.bas",3803
	;[3804] 
	SRCFILE "minty.bas",3804
	;[3805]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3805
	DECLE 0,0
	;[3806]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3806
	DECLE 0,0
	;[3807]     MUSIC   A4,   B2,   F4
	SRCFILE "minty.bas",3807
	DECLE 36002,158
	;[3808]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3808
	DECLE 16191,63
	;[3809]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3809
	DECLE 63,63
	;[3810]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3810
	DECLE 63,63
	;[3811]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3811
	DECLE 0,63
	;[3812]     MUSIC   B4,   D3,   D4
	SRCFILE "minty.bas",3812
	DECLE 36772,155
	;[3813]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3813
	DECLE 16191,63
	;[3814]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3814
	DECLE 0,63
	;[3815]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",3815
	DECLE 0,63
	;[3816]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3816
	DECLE 0,0
	;[3817]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3817
	DECLE 0,0
	;[3818]     MUSIC   B4,   D2,   F4
	SRCFILE "minty.bas",3818
	DECLE 33700,158
	;[3819]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3819
	DECLE 16191,63
	;[3820]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3820
	DECLE 16191,63
	;[3821]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3821
	DECLE 16191,0
	;[3822]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3822
	DECLE 16128,0
	;[3823]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3823
	DECLE 16128,0
	;[3824]     MUSIC   A4,   D3,   F4
	SRCFILE "minty.bas",3824
	DECLE 36770,158
	;[3825]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3825
	DECLE 16191,63
	;[3826]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3826
	DECLE 0,0
	;[3827]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3827
	DECLE 0,0
	;[3828]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3828
	DECLE 0,0
	;[3829]     MUSIC   A4,   B2,   F4
	SRCFILE "minty.bas",3829
	DECLE 36002,158
	;[3830]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3830
	DECLE 16191,63
	;[3831]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3831
	DECLE 63,63
	;[3832]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3832
	DECLE 63,63
	;[3833]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3833
	DECLE 63,0
	;[3834]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3834
	DECLE 0,0
	;[3835]     MUSIC   B4,   B2,   F4
	SRCFILE "minty.bas",3835
	DECLE 36004,158
	;[3836]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3836
	DECLE 16191,63
	;[3837]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3837
	DECLE 0,0
	;[3838]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3838
	DECLE 0,0
	;[3839]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3839
	DECLE 0,0
	;[3840]     MUSIC   B4,   D2,   F4
	SRCFILE "minty.bas",3840
	DECLE 33700,158
	;[3841]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3841
	DECLE 16191,63
	;[3842]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3842
	DECLE 16191,63
	;[3843]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3843
	DECLE 16191,63
	;[3844]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3844
	DECLE 16191,63
	;[3845]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3845
	DECLE 16128,63
	;[3846]     MUSIC   A4,   B2,    S
	SRCFILE "minty.bas",3846
	DECLE 36002,63
	;[3847]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3847
	DECLE 16191,0
	;[3848]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3848
	DECLE 0,0
	;[3849]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3849
	DECLE 0,0
	;[3850]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3850
	DECLE 0,0
	;[3851]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3851
	DECLE 0,0
	;[3852]     MUSIC   A4,   B2,  F4#
	SRCFILE "minty.bas",3852
	DECLE 36002,159
	;[3853]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3853
	DECLE 16191,63
	;[3854]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3854
	DECLE 63,63
	;[3855] 
	SRCFILE "minty.bas",3855
	;[3856] REM Timing 5100 frames, 102.00 secs
	SRCFILE "minty.bas",3856
	;[3857] 
	SRCFILE "minty.bas",3857
	;[3858]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3858
	DECLE 63,63
	;[3859]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3859
	DECLE 63,63
	;[3860]     MUSIC   B4,  D3#,  F4#
	SRCFILE "minty.bas",3860
	DECLE 37028,159
	;[3861]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3861
	DECLE 16191,63
	;[3862]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3862
	DECLE 0,0
	;[3863]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3863
	DECLE 0,0
	;[3864]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3864
	DECLE 0,0
	;[3865]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3865
	DECLE 0,0
	;[3866]     MUSIC   B4,  D2#,  F4#
	SRCFILE "minty.bas",3866
	DECLE 33956,159
	;[3867]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3867
	DECLE 16191,63
	;[3868]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3868
	DECLE 16191,0
	;[3869]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3869
	DECLE 63,0
	;[3870]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3870
	DECLE 63,0
	;[3871]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3871
	DECLE 0,0
	;[3872]     MUSIC   A4,  D2#,  F4#
	SRCFILE "minty.bas",3872
	DECLE 33954,159
	;[3873]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3873
	DECLE 16191,63
	;[3874]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3874
	DECLE 16128,0
	;[3875]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3875
	DECLE 0,0
	;[3876]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3876
	DECLE 0,0
	;[3877]     MUSIC   A4,   B2,  F4#
	SRCFILE "minty.bas",3877
	DECLE 36002,159
	;[3878]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3878
	DECLE 16191,63
	;[3879]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3879
	DECLE 63,63
	;[3880]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3880
	DECLE 63,63
	;[3881]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3881
	DECLE 63,63
	;[3882]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",3882
	DECLE 63,63
	;[3883]     MUSIC   C5,  D3#,    S
	SRCFILE "minty.bas",3883
	DECLE 37029,63
	;[3884]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3884
	DECLE 16191,0
	;[3885]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3885
	DECLE 0,0
	;[3886]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3886
	DECLE 0,0
	;[3887]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3887
	DECLE 0,0
	;[3888]     MUSIC   C5,  D2#,   E2
	SRCFILE "minty.bas",3888
	DECLE 33957,133
	;[3889]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3889
	DECLE 16191,63
	;[3890]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3890
	DECLE 16191,0
	;[3891]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3891
	DECLE 16191,0
	;[3892]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3892
	DECLE 16191,0
	;[3893]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3893
	DECLE 16191,0
	;[3894]     MUSIC   B4,  D3#,    -
	SRCFILE "minty.bas",3894
	DECLE 37028,0
	;[3895]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3895
	DECLE 16191,0
	;[3896]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3896
	DECLE 16191,0
	;[3897]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3897
	DECLE 16191,0
	;[3898]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3898
	DECLE 16191,0
	;[3899]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3899
	DECLE 63,0
	;[3900]     MUSIC    S,   B2,   E4
	SRCFILE "minty.bas",3900
	DECLE 35903,157
	;[3901]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3901
	DECLE 16191,63
	;[3902]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3902
	DECLE 63,0
	;[3903]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3903
	DECLE 63,0
	;[3904]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3904
	DECLE 63,0
	;[3905]     MUSIC    S,   F3,   F4
	SRCFILE "minty.bas",3905
	DECLE 37439,158
	;[3906]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3906
	DECLE 16191,63
	;[3907]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3907
	DECLE 63,0
	;[3908] 
	SRCFILE "minty.bas",3908
	;[3909] REM Timing 5200 frames, 104.00 secs
	SRCFILE "minty.bas",3909
	;[3910] 
	SRCFILE "minty.bas",3910
	;[3911]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3911
	DECLE 63,0
	;[3912]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3912
	DECLE 63,0
	;[3913]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3913
	DECLE 63,0
	;[3914]     MUSIC    S,   D3,   D4
	SRCFILE "minty.bas",3914
	DECLE 36671,155
	;[3915]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3915
	DECLE 16191,63
	;[3916]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3916
	DECLE 63,0
	;[3917]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3917
	DECLE 63,0
	;[3918]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3918
	DECLE 63,0
	;[3919]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",3919
	DECLE 63,0
	;[3920]     MUSIC    S,   E3,   E4
	SRCFILE "minty.bas",3920
	DECLE 37183,157
	;[3921]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3921
	DECLE 16191,63
	;[3922]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3922
	DECLE 0,0
	;[3923]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3923
	DECLE 0,0
	;[3924]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3924
	DECLE 0,0
	;[3925]     MUSIC   C4,   C3,    -
	SRCFILE "minty.bas",3925
	DECLE 36249,0
	;[3926]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3926
	DECLE 16191,0
	;[3927]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3927
	DECLE 16128,0
	;[3928]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3928
	DECLE 0,0
	;[3929]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3929
	DECLE 0,0
	;[3930]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3930
	DECLE 0,0
	;[3931]     MUSIC   D4,   D3,    -
	SRCFILE "minty.bas",3931
	DECLE 36763,0
	;[3932]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3932
	DECLE 16191,0
	;[3933]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3933
	DECLE 0,0
	;[3934]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3934
	DECLE 0,0
	;[3935]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3935
	DECLE 0,0
	;[3936]     MUSIC   B3,   B2,    -
	SRCFILE "minty.bas",3936
	DECLE 35992,0
	;[3937]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3937
	DECLE 16191,0
	;[3938]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3938
	DECLE 0,0
	;[3939]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3939
	DECLE 0,0
	;[3940]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3940
	DECLE 0,0
	;[3941]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3941
	DECLE 0,0
	;[3942]     MUSIC   E5,   E2,   E4
	SRCFILE "minty.bas",3942
	DECLE 34217,157
	;[3943]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3943
	DECLE 16191,63
	;[3944]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3944
	DECLE 16191,63
	;[3945]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3945
	DECLE 16128,63
	;[3946]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3946
	DECLE 16128,63
	;[3947]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3947
	DECLE 16128,63
	;[3948]     MUSIC   F5,   F2,   F4
	SRCFILE "minty.bas",3948
	DECLE 34474,158
	;[3949]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3949
	DECLE 16191,63
	;[3950]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3950
	DECLE 16191,0
	;[3951]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3951
	DECLE 0,0
	;[3952]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3952
	DECLE 0,0
	;[3953]     MUSIC   D5,   D2,   D4
	SRCFILE "minty.bas",3953
	DECLE 33703,155
	;[3954]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3954
	DECLE 16191,63
	;[3955]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3955
	DECLE 16191,63
	;[3956]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3956
	DECLE 16128,63
	;[3957]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3957
	DECLE 16128,63
	;[3958]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3958
	DECLE 16128,63
	;[3959]     MUSIC   E5,   E2,   E4
	SRCFILE "minty.bas",3959
	DECLE 34217,157
	;[3960]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3960
	DECLE 16191,63
	;[3961] 
	SRCFILE "minty.bas",3961
	;[3962] REM Timing 5300 frames, 106.00 secs
	SRCFILE "minty.bas",3962
	;[3963] 
	SRCFILE "minty.bas",3963
	;[3964]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3964
	DECLE 16191,0
	;[3965]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3965
	DECLE 16128,0
	;[3966]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3966
	DECLE 0,0
	;[3967]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3967
	DECLE 0,0
	;[3968]     MUSIC   C5,   C2,   C4
	SRCFILE "minty.bas",3968
	DECLE 33189,153
	;[3969]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3969
	DECLE 16191,63
	;[3970]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3970
	DECLE 16128,63
	;[3971]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3971
	DECLE 16128,63
	;[3972]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3972
	DECLE 16128,0
	;[3973]     MUSIC   D5,   D2,   D4
	SRCFILE "minty.bas",3973
	DECLE 33703,155
	;[3974]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3974
	DECLE 16191,63
	;[3975]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",3975
	DECLE 16191,0
	;[3976]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3976
	DECLE 0,0
	;[3977]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3977
	DECLE 0,0
	;[3978]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3978
	DECLE 0,0
	;[3979]     MUSIC   B4,   B2,   B3
	SRCFILE "minty.bas",3979
	DECLE 36004,152
	;[3980]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3980
	DECLE 16191,63
	;[3981]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3981
	DECLE 16191,63
	;[3982]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3982
	DECLE 16128,63
	;[3983]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3983
	DECLE 16128,63
	;[3984]     MUSIC   C5,   C2,   C4
	SRCFILE "minty.bas",3984
	DECLE 33189,153
	;[3985]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3985
	DECLE 16191,63
	;[3986]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3986
	DECLE 16191,63
	;[3987]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3987
	DECLE 16128,63
	;[3988]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3988
	DECLE 16128,63
	;[3989]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3989
	DECLE 16128,63
	;[3990]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3990
	DECLE 16128,0
	;[3991]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",3991
	DECLE 16128,0
	;[3992]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3992
	DECLE 0,0
	;[3993]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3993
	DECLE 0,0
	;[3994]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3994
	DECLE 0,0
	;[3995]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",3995
	DECLE 0,0
	;[3996]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",3996
	DECLE 35502,165
	;[3997]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",3997
	DECLE 16191,63
	;[3998]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",3998
	DECLE 16128,63
	;[3999]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",3999
	DECLE 16275,0
	;[4000]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4000
	DECLE 16191,0
	;[4001]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4001
	DECLE 36016,167
	;[4002]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4002
	DECLE 16191,63
	;[4003]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4003
	DECLE 16191,63
	;[4004]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4004
	DECLE 147,0
	;[4005]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4005
	DECLE 63,0
	;[4006]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4006
	DECLE 63,0
	;[4007]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",4007
	DECLE 36017,169
	;[4008]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4008
	DECLE 16191,63
	;[4009]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4009
	DECLE 63,0
	;[4010]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4010
	DECLE 147,0
	;[4011]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4011
	DECLE 63,0
	;[4012]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4012
	DECLE 0,0
	;[4013]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4013
	DECLE 35502,165
	;[4014] 
	SRCFILE "minty.bas",4014
	;[4015] REM Timing 5400 frames, 108.00 secs
	SRCFILE "minty.bas",4015
	;[4016] 
	SRCFILE "minty.bas",4016
	;[4017]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4017
	DECLE 16191,63
	;[4018]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4018
	DECLE 147,0
	;[4019]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4019
	DECLE 63,0
	;[4020]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4020
	DECLE 0,0
	;[4021]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4021
	DECLE 36016,167
	;[4022]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4022
	DECLE 16191,63
	;[4023]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4023
	DECLE 63,63
	;[4024]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4024
	DECLE 147,63
	;[4025]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4025
	DECLE 63,63
	;[4026]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4026
	DECLE 63,0
	;[4027]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",4027
	DECLE 33201,169
	;[4028]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4028
	DECLE 16191,63
	;[4029]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4029
	DECLE 16191,0
	;[4030]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4030
	DECLE 16275,0
	;[4031]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4031
	DECLE 16191,0
	;[4032]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4032
	DECLE 35997,153
	;[4033]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4033
	DECLE 16191,63
	;[4034]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4034
	DECLE 0,0
	;[4035]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4035
	DECLE 147,0
	;[4036]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4036
	DECLE 63,0
	;[4037]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4037
	DECLE 0,0
	;[4038]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",4038
	DECLE 37791,156
	;[4039]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4039
	DECLE 16191,63
	;[4040]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4040
	DECLE 16191,63
	;[4041]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4041
	DECLE 147,0
	;[4042]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4042
	DECLE 63,0
	;[4043]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4043
	DECLE 0,0
	;[4044]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",4044
	DECLE 35999,156
	;[4045]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4045
	DECLE 16191,63
	;[4046]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4046
	DECLE 0,0
	;[4047]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4047
	DECLE 147,0
	;[4048]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4048
	DECLE 63,0
	;[4049]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",4049
	DECLE 37791,156
	;[4050]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4050
	DECLE 16191,63
	;[4051]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4051
	DECLE 0,0
	;[4052]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4052
	DECLE 147,0
	;[4053]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4053
	DECLE 63,0
	;[4054]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4054
	DECLE 63,0
	;[4055]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4055
	DECLE 36016,167
	;[4056]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4056
	DECLE 16191,63
	;[4057]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4057
	DECLE 63,63
	;[4058]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4058
	DECLE 147,0
	;[4059]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4059
	DECLE 63,0
	;[4060]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4060
	DECLE 0,0
	;[4061]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4061
	DECLE 35502,165
	;[4062]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4062
	DECLE 16191,63
	;[4063]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4063
	DECLE 147,0
	;[4064]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4064
	DECLE 63,0
	;[4065]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4065
	DECLE 0,0
	;[4066]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4066
	DECLE 36016,167
	;[4067] 
	SRCFILE "minty.bas",4067
	;[4068] REM Timing 5500 frames, 110.00 secs
	SRCFILE "minty.bas",4068
	;[4069] 
	SRCFILE "minty.bas",4069
	;[4070]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4070
	DECLE 16191,63
	;[4071]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",4071
	DECLE 0,63
	;[4072]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4072
	DECLE 147,63
	;[4073]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4073
	DECLE 63,63
	;[4074]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4074
	DECLE 63,63
	;[4075]     MUSIC   C6,   C2,  D5#
	SRCFILE "minty.bas",4075
	DECLE 33201,168
	;[4076]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4076
	DECLE 16191,63
	;[4077]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4077
	DECLE 16128,63
	;[4078]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4078
	DECLE 16275,0
	;[4079]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4079
	DECLE 16191,0
	;[4080]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",4080
	DECLE 35999,156
	;[4081]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4081
	DECLE 16191,63
	;[4082]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4082
	DECLE 0,0
	;[4083]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4083
	DECLE 147,0
	;[4084]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4084
	DECLE 63,0
	;[4085]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4085
	DECLE 0,0
	;[4086]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",4086
	DECLE 37790,155
	;[4087]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4087
	DECLE 16191,63
	;[4088]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4088
	DECLE 16191,63
	;[4089]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4089
	DECLE 147,0
	;[4090]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4090
	DECLE 63,0
	;[4091]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4091
	DECLE 0,0
	;[4092]     MUSIC   F4,   B2,   D4
	SRCFILE "minty.bas",4092
	DECLE 35998,155
	;[4093]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4093
	DECLE 16191,63
	;[4094]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4094
	DECLE 0,0
	;[4095]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4095
	DECLE 147,0
	;[4096]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4096
	DECLE 63,0
	;[4097]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",4097
	DECLE 37790,155
	;[4098]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4098
	DECLE 16191,63
	;[4099]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4099
	DECLE 0,0
	;[4100]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4100
	DECLE 147,0
	;[4101]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4101
	DECLE 63,0
	;[4102]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4102
	DECLE 63,0
	;[4103]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4103
	DECLE 36016,167
	;[4104]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4104
	DECLE 16191,63
	;[4105]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4105
	DECLE 63,63
	;[4106]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4106
	DECLE 147,63
	;[4107]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4107
	DECLE 63,0
	;[4108]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4108
	DECLE 0,0
	;[4109]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4109
	DECLE 35502,165
	;[4110]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4110
	DECLE 16191,63
	;[4111]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4111
	DECLE 16275,0
	;[4112]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4112
	DECLE 16191,0
	;[4113]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4113
	DECLE 0,0
	;[4114]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",4114
	DECLE 36017,169
	;[4115]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4115
	DECLE 16191,63
	;[4116]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4116
	DECLE 63,0
	;[4117]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4117
	DECLE 147,0
	;[4118]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4118
	DECLE 63,0
	;[4119]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4119
	DECLE 63,0
	;[4120] 
	SRCFILE "minty.bas",4120
	;[4121] REM Timing 5600 frames, 112.00 secs
	SRCFILE "minty.bas",4121
	;[4122] 
	SRCFILE "minty.bas",4122
	;[4123]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",4123
	DECLE 33201,169
	;[4124]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4124
	DECLE 16191,63
	;[4125]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4125
	DECLE 16191,63
	;[4126]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",4126
	DECLE 16275,63
	;[4127]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4127
	DECLE 16191,63
	;[4128]     MUSIC   F4,   B2,   D4
	SRCFILE "minty.bas",4128
	DECLE 35998,155
	;[4129]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4129
	DECLE 16191,63
	;[4130]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4130
	DECLE 0,0
	;[4131]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4131
	DECLE 147,0
	;[4132]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4132
	DECLE 63,0
	;[4133]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4133
	DECLE 0,0
	;[4134]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4134
	DECLE 35502,165
	;[4135]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4135
	DECLE 16191,63
	;[4136]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4136
	DECLE 16191,63
	;[4137]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",4137
	DECLE 16275,63
	;[4138]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4138
	DECLE 16191,63
	;[4139]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4139
	DECLE 16128,63
	;[4140]     MUSIC   E4,    S,   C4
	SRCFILE "minty.bas",4140
	DECLE 16285,153
	;[4141]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4141
	DECLE 16191,63
	;[4142]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4142
	DECLE 16128,0
	;[4143]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4143
	DECLE 16275,0
	;[4144]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4144
	DECLE 63,0
	;[4145]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",4145
	DECLE 37789,153
	;[4146]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4146
	DECLE 16191,63
	;[4147]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4147
	DECLE 0,0
	;[4148]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4148
	DECLE 147,0
	;[4149]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4149
	DECLE 63,0
	;[4150]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4150
	DECLE 63,0
	;[4151]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4151
	DECLE 35997,153
	;[4152]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4152
	DECLE 16191,63
	;[4153]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4153
	DECLE 0,0
	;[4154]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4154
	DECLE 147,0
	;[4155]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4155
	DECLE 63,0
	;[4156]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4156
	DECLE 0,0
	;[4157]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",4157
	DECLE 37789,153
	;[4158]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4158
	DECLE 16191,63
	;[4159]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4159
	DECLE 147,0
	;[4160]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4160
	DECLE 63,0
	;[4161]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4161
	DECLE 0,0
	;[4162]     MUSIC   E4,   B2,   D4
	SRCFILE "minty.bas",4162
	DECLE 35997,155
	;[4163]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4163
	DECLE 16191,63
	;[4164]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",4164
	DECLE 0,63
	;[4165]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4165
	DECLE 147,63
	;[4166]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4166
	DECLE 63,63
	;[4167]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4167
	DECLE 63,63
	;[4168]     MUSIC   E4,  F3#,    -
	SRCFILE "minty.bas",4168
	DECLE 37789,0
	;[4169]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4169
	DECLE 16191,0
	;[4170]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4170
	DECLE 0,0
	;[4171]     MUSIC   A3,  F3#,    -
	SRCFILE "minty.bas",4171
	DECLE 37782,0
	;[4172]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4172
	DECLE 16191,0
	;[4173] 
	SRCFILE "minty.bas",4173
	;[4174] REM Timing 5700 frames, 114.00 secs
	SRCFILE "minty.bas",4174
	;[4175] 
	SRCFILE "minty.bas",4175
	;[4176]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4176
	DECLE 35997,153
	;[4177]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4177
	DECLE 16191,63
	;[4178]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4178
	DECLE 0,0
	;[4179]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4179
	DECLE 147,0
	;[4180]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4180
	DECLE 63,0
	;[4181]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4181
	DECLE 0,0
	;[4182]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",4182
	DECLE 37789,153
	;[4183]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4183
	DECLE 16191,63
	;[4184]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4184
	DECLE 16191,63
	;[4185]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4185
	DECLE 147,0
	;[4186]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4186
	DECLE 63,0
	;[4187]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4187
	DECLE 0,0
	;[4188]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4188
	DECLE 35502,165
	;[4189]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4189
	DECLE 16191,63
	;[4190]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4190
	DECLE 16128,63
	;[4191]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4191
	DECLE 16275,0
	;[4192]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4192
	DECLE 16191,0
	;[4193]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4193
	DECLE 36016,167
	;[4194]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4194
	DECLE 16191,63
	;[4195]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4195
	DECLE 16128,63
	;[4196]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4196
	DECLE 147,0
	;[4197]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4197
	DECLE 63,0
	;[4198]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4198
	DECLE 63,0
	;[4199]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",4199
	DECLE 36017,169
	;[4200]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4200
	DECLE 16191,63
	;[4201]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4201
	DECLE 63,0
	;[4202]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4202
	DECLE 147,0
	;[4203]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4203
	DECLE 63,0
	;[4204]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4204
	DECLE 0,0
	;[4205]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4205
	DECLE 35502,165
	;[4206]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4206
	DECLE 16191,63
	;[4207]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4207
	DECLE 147,0
	;[4208]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4208
	DECLE 63,0
	;[4209]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4209
	DECLE 0,0
	;[4210]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4210
	DECLE 36016,167
	;[4211]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4211
	DECLE 16191,63
	;[4212]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4212
	DECLE 63,63
	;[4213]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4213
	DECLE 147,63
	;[4214]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4214
	DECLE 63,0
	;[4215]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4215
	DECLE 63,0
	;[4216]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",4216
	DECLE 33201,169
	;[4217]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4217
	DECLE 16191,63
	;[4218]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4218
	DECLE 16128,0
	;[4219]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4219
	DECLE 147,0
	;[4220]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4220
	DECLE 63,0
	;[4221]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4221
	DECLE 35997,153
	;[4222]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4222
	DECLE 16191,63
	;[4223]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4223
	DECLE 0,0
	;[4224]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4224
	DECLE 147,0
	;[4225]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4225
	DECLE 63,0
	;[4226] 
	SRCFILE "minty.bas",4226
	;[4227] REM Timing 5800 frames, 116.00 secs
	SRCFILE "minty.bas",4227
	;[4228] 
	SRCFILE "minty.bas",4228
	;[4229]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4229
	DECLE 0,0
	;[4230]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",4230
	DECLE 37791,156
	;[4231]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4231
	DECLE 16191,63
	;[4232]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4232
	DECLE 16191,63
	;[4233]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4233
	DECLE 147,0
	;[4234]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4234
	DECLE 63,0
	;[4235]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4235
	DECLE 0,0
	;[4236]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",4236
	DECLE 35999,156
	;[4237]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4237
	DECLE 16191,63
	;[4238]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4238
	DECLE 0,0
	;[4239]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4239
	DECLE 147,0
	;[4240]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4240
	DECLE 63,0
	;[4241]     MUSIC  F4#,  F3#,  D4#
	SRCFILE "minty.bas",4241
	DECLE 37791,156
	;[4242]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4242
	DECLE 16191,63
	;[4243]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4243
	DECLE 0,0
	;[4244]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4244
	DECLE 147,0
	;[4245]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4245
	DECLE 63,0
	;[4246]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4246
	DECLE 63,0
	;[4247]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4247
	DECLE 36016,167
	;[4248]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4248
	DECLE 16191,63
	;[4249]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4249
	DECLE 63,63
	;[4250]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4250
	DECLE 147,0
	;[4251]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4251
	DECLE 63,0
	;[4252]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4252
	DECLE 0,0
	;[4253]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4253
	DECLE 35502,165
	;[4254]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4254
	DECLE 16191,63
	;[4255]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4255
	DECLE 147,0
	;[4256]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4256
	DECLE 63,0
	;[4257]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4257
	DECLE 0,0
	;[4258]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4258
	DECLE 36016,167
	;[4259]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4259
	DECLE 16191,63
	;[4260]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4260
	DECLE 63,63
	;[4261]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4261
	DECLE 147,63
	;[4262]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4262
	DECLE 63,63
	;[4263]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4263
	DECLE 63,0
	;[4264]     MUSIC   C6,   C2,  D5#
	SRCFILE "minty.bas",4264
	DECLE 33201,168
	;[4265]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4265
	DECLE 16191,63
	;[4266]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4266
	DECLE 16128,63
	;[4267]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4267
	DECLE 16275,0
	;[4268]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4268
	DECLE 63,0
	;[4269]     MUSIC  F4#,   B2,  D4#
	SRCFILE "minty.bas",4269
	DECLE 35999,156
	;[4270]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4270
	DECLE 16191,63
	;[4271]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4271
	DECLE 0,0
	;[4272]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4272
	DECLE 147,0
	;[4273]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4273
	DECLE 63,0
	;[4274]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4274
	DECLE 0,0
	;[4275]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",4275
	DECLE 37790,155
	;[4276]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4276
	DECLE 16191,63
	;[4277]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4277
	DECLE 16191,63
	;[4278]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4278
	DECLE 147,0
	;[4279] 
	SRCFILE "minty.bas",4279
	;[4280] REM Timing 5900 frames, 118.00 secs
	SRCFILE "minty.bas",4280
	;[4281] 
	SRCFILE "minty.bas",4281
	;[4282]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4282
	DECLE 63,0
	;[4283]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4283
	DECLE 0,0
	;[4284]     MUSIC   F4,   B2,   D4
	SRCFILE "minty.bas",4284
	DECLE 35998,155
	;[4285]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4285
	DECLE 16191,63
	;[4286]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4286
	DECLE 0,0
	;[4287]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4287
	DECLE 147,0
	;[4288]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4288
	DECLE 63,0
	;[4289]     MUSIC   F4,  F3#,   D4
	SRCFILE "minty.bas",4289
	DECLE 37790,155
	;[4290]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4290
	DECLE 16191,63
	;[4291]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4291
	DECLE 0,0
	;[4292]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4292
	DECLE 147,0
	;[4293]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4293
	DECLE 63,0
	;[4294]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4294
	DECLE 63,0
	;[4295]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4295
	DECLE 36016,167
	;[4296]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4296
	DECLE 16191,63
	;[4297]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4297
	DECLE 63,63
	;[4298]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4298
	DECLE 147,0
	;[4299]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4299
	DECLE 63,0
	;[4300]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4300
	DECLE 0,0
	;[4301]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4301
	DECLE 35502,165
	;[4302]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4302
	DECLE 16191,63
	;[4303]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4303
	DECLE 16275,0
	;[4304]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4304
	DECLE 16191,0
	;[4305]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4305
	DECLE 0,0
	;[4306]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",4306
	DECLE 36017,169
	;[4307]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4307
	DECLE 16191,63
	;[4308]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4308
	DECLE 0,0
	;[4309]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4309
	DECLE 147,0
	;[4310]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4310
	DECLE 63,0
	;[4311]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4311
	DECLE 63,0
	;[4312]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",4312
	DECLE 33201,169
	;[4313]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4313
	DECLE 16191,63
	;[4314]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4314
	DECLE 16191,63
	;[4315]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",4315
	DECLE 16275,63
	;[4316]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4316
	DECLE 16191,63
	;[4317]     MUSIC   B2,   F4,    -
	SRCFILE "minty.bas",4317
	DECLE 40588,0
	;[4318]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4318
	DECLE 16191,0
	;[4319]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4319
	DECLE 0,0
	;[4320]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4320
	DECLE 147,0
	;[4321]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4321
	DECLE 63,0
	;[4322]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4322
	DECLE 0,0
	;[4323]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4323
	DECLE 35502,165
	;[4324]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4324
	DECLE 16191,63
	;[4325]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4325
	DECLE 16191,63
	;[4326]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",4326
	DECLE 16275,63
	;[4327]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4327
	DECLE 16191,63
	;[4328]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4328
	DECLE 16128,0
	;[4329]     MUSIC   E4,    S,   C4
	SRCFILE "minty.bas",4329
	DECLE 16285,153
	;[4330]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4330
	DECLE 16191,63
	;[4331]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4331
	DECLE 16128,0
	;[4332] 
	SRCFILE "minty.bas",4332
	;[4333] REM Timing 6000 frames, 120.00 secs
	SRCFILE "minty.bas",4333
	;[4334] 
	SRCFILE "minty.bas",4334
	;[4335]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4335
	DECLE 16275,0
	;[4336]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4336
	DECLE 16191,0
	;[4337]     MUSIC   E4,    -,   C4
	SRCFILE "minty.bas",4337
	DECLE 157,153
	;[4338]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4338
	DECLE 63,63
	;[4339]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4339
	DECLE 0,0
	;[4340]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4340
	DECLE 147,0
	;[4341]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4341
	DECLE 63,0
	;[4342]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4342
	DECLE 63,0
	;[4343]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4343
	DECLE 35997,153
	;[4344]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4344
	DECLE 16191,63
	;[4345]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4345
	DECLE 0,0
	;[4346]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4346
	DECLE 147,0
	;[4347]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4347
	DECLE 63,0
	;[4348]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4348
	DECLE 0,0
	;[4349]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",4349
	DECLE 37789,153
	;[4350]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4350
	DECLE 16191,63
	;[4351]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4351
	DECLE 147,0
	;[4352]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4352
	DECLE 63,0
	;[4353]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4353
	DECLE 0,0
	;[4354]     MUSIC   E4,   B2,   D4
	SRCFILE "minty.bas",4354
	DECLE 35997,155
	;[4355]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4355
	DECLE 16191,63
	;[4356]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",4356
	DECLE 0,63
	;[4357]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4357
	DECLE 147,63
	;[4358]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4358
	DECLE 63,63
	;[4359]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4359
	DECLE 63,63
	;[4360]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",4360
	DECLE 35485,153
	;[4361]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4361
	DECLE 16191,63
	;[4362]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4362
	DECLE 16128,0
	;[4363]     MUSIC   A3,    S,  F3#
	SRCFILE "minty.bas",4363
	DECLE 16278,147
	;[4364]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4364
	DECLE 63,63
	;[4365]     MUSIC   A4,   B2,   E4
	SRCFILE "minty.bas",4365
	DECLE 36002,157
	;[4366]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4366
	DECLE 16191,63
	;[4367]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4367
	DECLE 63,0
	;[4368]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4368
	DECLE 37695,0
	;[4369]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4369
	DECLE 16191,0
	;[4370]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4370
	DECLE 63,0
	;[4371]     MUSIC   E4,   A2,   C4
	SRCFILE "minty.bas",4371
	DECLE 35485,153
	;[4372]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4372
	DECLE 16191,63
	;[4373]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4373
	DECLE 16191,63
	;[4374]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4374
	DECLE 16275,0
	;[4375]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4375
	DECLE 63,0
	;[4376]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4376
	DECLE 0,0
	;[4377]     MUSIC   D6,   B2,   D5
	SRCFILE "minty.bas",4377
	DECLE 36019,167
	;[4378]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4378
	DECLE 16191,63
	;[4379]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4379
	DECLE 63,63
	;[4380]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4380
	DECLE 147,0
	;[4381]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4381
	DECLE 63,0
	;[4382]     MUSIC   E6,   F3,   E5
	SRCFILE "minty.bas",4382
	DECLE 37557,169
	;[4383]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4383
	DECLE 16191,63
	;[4384]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4384
	DECLE 63,0
	;[4385] 
	SRCFILE "minty.bas",4385
	;[4386] REM Timing 6100 frames, 122.00 secs
	SRCFILE "minty.bas",4386
	;[4387] 
	SRCFILE "minty.bas",4387
	;[4388]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4388
	DECLE 147,0
	;[4389]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4389
	DECLE 63,0
	;[4390]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4390
	DECLE 63,0
	;[4391]     MUSIC   F6,   D2,   F5
	SRCFILE "minty.bas",4391
	DECLE 33718,170
	;[4392]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4392
	DECLE 16191,63
	;[4393]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4393
	DECLE 16191,63
	;[4394]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4394
	DECLE 16275,0
	;[4395]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4395
	DECLE 16191,0
	;[4396]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4396
	DECLE 16128,0
	;[4397]     MUSIC   D6,    -,   D5
	SRCFILE "minty.bas",4397
	DECLE 179,167
	;[4398]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4398
	DECLE 63,63
	;[4399]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4399
	DECLE 147,0
	;[4400]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4400
	DECLE 63,0
	;[4401]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4401
	DECLE 0,0
	;[4402]     MUSIC   E6,   B2,   E5
	SRCFILE "minty.bas",4402
	DECLE 36021,169
	;[4403]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4403
	DECLE 16191,63
	;[4404]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4404
	DECLE 63,63
	;[4405]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4405
	DECLE 147,0
	;[4406]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4406
	DECLE 63,0
	;[4407]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4407
	DECLE 63,0
	;[4408]     MUSIC   F6,   D2,   G5
	SRCFILE "minty.bas",4408
	DECLE 33718,172
	;[4409]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4409
	DECLE 16191,63
	;[4410]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4410
	DECLE 16191,63
	;[4411]     MUSIC   F5,    S,  F3#
	SRCFILE "minty.bas",4411
	DECLE 16298,147
	;[4412]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4412
	DECLE 16191,63
	;[4413]     MUSIC   D5,   C2,   E4
	SRCFILE "minty.bas",4413
	DECLE 33191,157
	;[4414]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4414
	DECLE 16191,63
	;[4415]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4415
	DECLE 16191,63
	;[4416]     MUSIC    S,    S,   F4
	SRCFILE "minty.bas",4416
	DECLE 16191,158
	;[4417]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4417
	DECLE 16191,63
	;[4418]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4418
	DECLE 16191,63
	;[4419]     MUSIC   E6,   A2,   E4
	SRCFILE "minty.bas",4419
	DECLE 35509,157
	;[4420]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4420
	DECLE 16191,63
	;[4421]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4421
	DECLE 16191,63
	;[4422]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4422
	DECLE 16275,0
	;[4423]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4423
	DECLE 63,0
	;[4424]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4424
	DECLE 0,0
	;[4425]     MUSIC   B3,   B2,  G3#
	SRCFILE "minty.bas",4425
	DECLE 35992,149
	;[4426]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4426
	DECLE 16191,63
	;[4427]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4427
	DECLE 0,0
	;[4428]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4428
	DECLE 147,0
	;[4429]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4429
	DECLE 63,0
	;[4430]     MUSIC   B3,  F3#,  G3#
	SRCFILE "minty.bas",4430
	DECLE 37784,149
	;[4431]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4431
	DECLE 16191,63
	;[4432]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4432
	DECLE 0,0
	;[4433]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4433
	DECLE 147,0
	;[4434]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4434
	DECLE 63,0
	;[4435]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4435
	DECLE 63,0
	;[4436]     MUSIC   E6,   E2,   E5
	SRCFILE "minty.bas",4436
	DECLE 34229,169
	;[4437]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4437
	DECLE 16191,63
	;[4438] 
	SRCFILE "minty.bas",4438
	;[4439] REM Timing 6200 frames, 124.00 secs
	SRCFILE "minty.bas",4439
	;[4440] 
	SRCFILE "minty.bas",4440
	;[4441]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4441
	DECLE 63,63
	;[4442]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4442
	DECLE 147,0
	;[4443]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4443
	DECLE 63,0
	;[4444]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4444
	DECLE 0,0
	;[4445]     MUSIC   D6,   B2,   D5
	SRCFILE "minty.bas",4445
	DECLE 36019,167
	;[4446]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4446
	DECLE 16191,63
	;[4447]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4447
	DECLE 147,0
	;[4448]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4448
	DECLE 63,0
	;[4449]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4449
	DECLE 0,0
	;[4450]     MUSIC   E6,   B2,   E5
	SRCFILE "minty.bas",4450
	DECLE 36021,169
	;[4451]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4451
	DECLE 16191,63
	;[4452]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4452
	DECLE 63,63
	;[4453]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4453
	DECLE 147,0
	;[4454]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4454
	DECLE 63,0
	;[4455]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4455
	DECLE 63,0
	;[4456]     MUSIC   F6,   B2,   F5
	SRCFILE "minty.bas",4456
	DECLE 36022,170
	;[4457]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4457
	DECLE 16191,63
	;[4458]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4458
	DECLE 63,63
	;[4459]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4459
	DECLE 147,63
	;[4460]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4460
	DECLE 63,0
	;[4461]     MUSIC   A4,   D2,   E4
	SRCFILE "minty.bas",4461
	DECLE 33698,157
	;[4462]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4462
	DECLE 16191,63
	;[4463]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4463
	DECLE 16191,0
	;[4464]     MUSIC    S,    S,  F3#
	SRCFILE "minty.bas",4464
	DECLE 16191,147
	;[4465]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4465
	DECLE 16191,63
	;[4466]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4466
	DECLE 63,0
	;[4467]     MUSIC    S,   E6,   E5
	SRCFILE "minty.bas",4467
	DECLE 46399,169
	;[4468]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4468
	DECLE 16191,63
	;[4469]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4469
	DECLE 16191,63
	;[4470]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4470
	DECLE 37695,0
	;[4471]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4471
	DECLE 16191,0
	;[4472]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4472
	DECLE 63,0
	;[4473]     MUSIC    S,   B2,  C4#
	SRCFILE "minty.bas",4473
	DECLE 35903,154
	;[4474]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4474
	DECLE 16191,63
	;[4475]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4475
	DECLE 63,0
	;[4476]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4476
	DECLE 37695,0
	;[4477]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4477
	DECLE 16191,0
	;[4478]     MUSIC    S,   A2,  C4#
	SRCFILE "minty.bas",4478
	DECLE 35391,154
	;[4479]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4479
	DECLE 16191,63
	;[4480]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4480
	DECLE 63,0
	;[4481]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4481
	DECLE 37695,0
	;[4482]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4482
	DECLE 16191,0
	;[4483]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4483
	DECLE 16191,0
	;[4484]     MUSIC    S,   F6,   F5
	SRCFILE "minty.bas",4484
	DECLE 46655,170
	;[4485]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4485
	DECLE 16191,63
	;[4486]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4486
	DECLE 16191,63
	;[4487]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4487
	DECLE 37695,0
	;[4488]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4488
	DECLE 16191,0
	;[4489]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4489
	DECLE 63,0
	;[4490]     MUSIC    S,   E6,   E5
	SRCFILE "minty.bas",4490
	DECLE 46399,169
	;[4491] 
	SRCFILE "minty.bas",4491
	;[4492] REM Timing 6300 frames, 126.00 secs
	SRCFILE "minty.bas",4492
	;[4493] 
	SRCFILE "minty.bas",4493
	;[4494]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4494
	DECLE 16191,63
	;[4495]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4495
	DECLE 37695,0
	;[4496]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4496
	DECLE 16191,0
	;[4497]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4497
	DECLE 63,0
	;[4498]     MUSIC    S,   F6,   F5
	SRCFILE "minty.bas",4498
	DECLE 46655,170
	;[4499]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4499
	DECLE 16191,63
	;[4500]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4500
	DECLE 16191,63
	;[4501]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4501
	DECLE 37695,0
	;[4502]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4502
	DECLE 16191,0
	;[4503]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4503
	DECLE 16191,0
	;[4504]     MUSIC   E5,   E6,   A2
	SRCFILE "minty.bas",4504
	DECLE 46505,138
	;[4505]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4505
	DECLE 16191,63
	;[4506]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4506
	DECLE 16128,0
	;[4507]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4507
	DECLE 147,0
	;[4508]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4508
	DECLE 63,0
	;[4509]     MUSIC   A5,   E2,   A4
	SRCFILE "minty.bas",4509
	DECLE 34222,162
	;[4510]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4510
	DECLE 16191,63
	;[4511]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4511
	DECLE 63,63
	;[4512]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4512
	DECLE 147,0
	;[4513]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4513
	DECLE 63,0
	;[4514]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4514
	DECLE 0,0
	;[4515]     MUSIC   D6,   D2,   D5
	SRCFILE "minty.bas",4515
	DECLE 33715,167
	;[4516]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4516
	DECLE 16191,63
	;[4517]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4517
	DECLE 16191,63
	;[4518]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",4518
	DECLE 16275,63
	;[4519]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4519
	DECLE 16191,63
	;[4520]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4520
	DECLE 16128,63
	;[4521]     MUSIC   B2,   D4,    S
	SRCFILE "minty.bas",4521
	DECLE 39820,63
	;[4522]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4522
	DECLE 16191,63
	;[4523]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",4523
	DECLE 0,63
	;[4524]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4524
	DECLE 147,63
	;[4525]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4525
	DECLE 63,63
	;[4526]     MUSIC   D4,   F3,   A3
	SRCFILE "minty.bas",4526
	DECLE 37531,150
	;[4527]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4527
	DECLE 16191,63
	;[4528]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4528
	DECLE 0,0
	;[4529]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4529
	DECLE 147,0
	;[4530]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4530
	DECLE 63,0
	;[4531]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4531
	DECLE 63,0
	;[4532]     MUSIC   D4,   E2,   A3
	SRCFILE "minty.bas",4532
	DECLE 34203,150
	;[4533]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4533
	DECLE 16191,63
	;[4534]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4534
	DECLE 0,0
	;[4535]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4535
	DECLE 147,0
	;[4536]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4536
	DECLE 63,0
	;[4537]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4537
	DECLE 0,0
	;[4538]     MUSIC   A3,   D3,  F3#
	SRCFILE "minty.bas",4538
	DECLE 36758,147
	;[4539]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4539
	DECLE 16191,63
	;[4540]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4540
	DECLE 147,0
	;[4541]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4541
	DECLE 63,0
	;[4542]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4542
	DECLE 0,0
	;[4543]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",4543
	DECLE 36017,168
	;[4544] 
	SRCFILE "minty.bas",4544
	;[4545] REM Timing 6400 frames, 128.00 secs
	SRCFILE "minty.bas",4545
	;[4546] 
	SRCFILE "minty.bas",4546
	;[4547]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4547
	DECLE 16191,63
	;[4548]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4548
	DECLE 63,63
	;[4549]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4549
	DECLE 147,63
	;[4550]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4550
	DECLE 63,63
	;[4551]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4551
	DECLE 63,63
	;[4552]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4552
	DECLE 147,63
	;[4553]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4553
	DECLE 63,63
	;[4554]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4554
	DECLE 0,0
	;[4555]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4555
	DECLE 147,0
	;[4556]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4556
	DECLE 63,0
	;[4557]     MUSIC   B5,   E2,   D5
	SRCFILE "minty.bas",4557
	DECLE 34224,167
	;[4558]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4558
	DECLE 16191,63
	;[4559]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4559
	DECLE 63,63
	;[4560]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4560
	DECLE 147,63
	;[4561]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4561
	DECLE 63,63
	;[4562]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",4562
	DECLE 0,63
	;[4563]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4563
	DECLE 147,63
	;[4564]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4564
	DECLE 63,63
	;[4565]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4565
	DECLE 63,0
	;[4566]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4566
	DECLE 147,0
	;[4567]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4567
	DECLE 63,0
	;[4568]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4568
	DECLE 0,0
	;[4569]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4569
	DECLE 35502,165
	;[4570]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4570
	DECLE 16191,63
	;[4571]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4571
	DECLE 16191,63
	;[4572]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4572
	DECLE 16275,0
	;[4573]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4573
	DECLE 16191,0
	;[4574]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4574
	DECLE 36016,167
	;[4575]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4575
	DECLE 16191,63
	;[4576]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4576
	DECLE 16128,63
	;[4577]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4577
	DECLE 147,0
	;[4578]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4578
	DECLE 63,0
	;[4579]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4579
	DECLE 63,0
	;[4580]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",4580
	DECLE 33201,169
	;[4581]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4581
	DECLE 16191,63
	;[4582]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4582
	DECLE 16191,0
	;[4583]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4583
	DECLE 16275,0
	;[4584]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4584
	DECLE 16191,0
	;[4585]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4585
	DECLE 0,0
	;[4586]     MUSIC   A5,   A2,   C5
	SRCFILE "minty.bas",4586
	DECLE 35502,165
	;[4587]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4587
	DECLE 16191,63
	;[4588]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4588
	DECLE 16275,0
	;[4589]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4589
	DECLE 16191,0
	;[4590]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4590
	DECLE 0,0
	;[4591]     MUSIC   B5,   B2,   D5
	SRCFILE "minty.bas",4591
	DECLE 36016,167
	;[4592]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4592
	DECLE 16191,63
	;[4593]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4593
	DECLE 63,63
	;[4594]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4594
	DECLE 147,63
	;[4595]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4595
	DECLE 63,63
	;[4596]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4596
	DECLE 63,0
	;[4597] 
	SRCFILE "minty.bas",4597
	;[4598] REM Timing 6500 frames, 130.00 secs
	SRCFILE "minty.bas",4598
	;[4599] 
	SRCFILE "minty.bas",4599
	;[4600]     MUSIC   C6,   C2,   E5
	SRCFILE "minty.bas",4600
	DECLE 33201,169
	;[4601]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4601
	DECLE 16191,63
	;[4602]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4602
	DECLE 16191,0
	;[4603]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4603
	DECLE 16275,0
	;[4604]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4604
	DECLE 16191,0
	;[4605]     MUSIC   E4,   E2,   A3
	SRCFILE "minty.bas",4605
	DECLE 34205,150
	;[4606]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4606
	DECLE 16191,63
	;[4607]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4607
	DECLE 0,0
	;[4608]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4608
	DECLE 147,0
	;[4609]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4609
	DECLE 63,0
	;[4610]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4610
	DECLE 0,0
	;[4611]     MUSIC   D4,   D2,   A3
	SRCFILE "minty.bas",4611
	DECLE 33691,150
	;[4612]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4612
	DECLE 16191,63
	;[4613]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4613
	DECLE 16191,63
	;[4614]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4614
	DECLE 16275,0
	;[4615]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4615
	DECLE 16191,0
	;[4616]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4616
	DECLE 16128,0
	;[4617]     MUSIC   D4,   A3,   B2
	SRCFILE "minty.bas",4617
	DECLE 38555,140
	;[4618]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4618
	DECLE 16191,63
	;[4619]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4619
	DECLE 0,0
	;[4620]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4620
	DECLE 147,0
	;[4621]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4621
	DECLE 63,0
	;[4622]     MUSIC   D4,   F3,   A3
	SRCFILE "minty.bas",4622
	DECLE 37531,150
	;[4623]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4623
	DECLE 16191,63
	;[4624]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4624
	DECLE 0,0
	;[4625]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4625
	DECLE 147,0
	;[4626]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4626
	DECLE 63,0
	;[4627]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4627
	DECLE 63,0
	;[4628]     MUSIC   B5,   E2,   D5
	SRCFILE "minty.bas",4628
	DECLE 34224,167
	;[4629]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4629
	DECLE 16191,63
	;[4630]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4630
	DECLE 63,63
	;[4631]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4631
	DECLE 147,0
	;[4632]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4632
	DECLE 63,0
	;[4633]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4633
	DECLE 0,0
	;[4634]     MUSIC   A5,   F3,   C5
	SRCFILE "minty.bas",4634
	DECLE 37550,165
	;[4635]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4635
	DECLE 16191,63
	;[4636]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4636
	DECLE 147,0
	;[4637]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4637
	DECLE 63,0
	;[4638]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4638
	DECLE 0,0
	;[4639]     MUSIC   C6,   B2,   E5
	SRCFILE "minty.bas",4639
	DECLE 36017,169
	;[4640]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4640
	DECLE 16191,63
	;[4641]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4641
	DECLE 0,0
	;[4642]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4642
	DECLE 147,0
	;[4643]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4643
	DECLE 63,0
	;[4644]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4644
	DECLE 63,0
	;[4645]     MUSIC   C6,   E2,   E5
	SRCFILE "minty.bas",4645
	DECLE 34225,169
	;[4646]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4646
	DECLE 16191,63
	;[4647]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4647
	DECLE 16191,63
	;[4648]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",4648
	DECLE 16275,63
	;[4649]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4649
	DECLE 16191,63
	;[4650] 
	SRCFILE "minty.bas",4650
	;[4651] REM Timing 6600 frames, 132.00 secs
	SRCFILE "minty.bas",4651
	;[4652] 
	SRCFILE "minty.bas",4652
	;[4653]     MUSIC   D2,  F3#,    S
	SRCFILE "minty.bas",4653
	DECLE 37763,63
	;[4654]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4654
	DECLE 16191,63
	;[4655]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4655
	DECLE 63,0
	;[4656]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4656
	DECLE 37695,0
	;[4657]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4657
	DECLE 16191,0
	;[4658]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4658
	DECLE 63,0
	;[4659]     MUSIC   A5,   E2,   C5
	SRCFILE "minty.bas",4659
	DECLE 34222,165
	;[4660]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4660
	DECLE 16191,63
	;[4661]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4661
	DECLE 16191,63
	;[4662]     MUSIC    -,  F3#,    S
	SRCFILE "minty.bas",4662
	DECLE 37632,63
	;[4663]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4663
	DECLE 16128,0
	;[4664]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4664
	DECLE 0,0
	;[4665]     MUSIC   E6,   A2,   E5
	SRCFILE "minty.bas",4665
	DECLE 35509,169
	;[4666]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4666
	DECLE 16191,63
	;[4667]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4667
	DECLE 16191,0
	;[4668]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4668
	DECLE 16128,0
	;[4669]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4669
	DECLE 16128,0
	;[4670]     MUSIC   E6,    S,   E5
	SRCFILE "minty.bas",4670
	DECLE 16309,169
	;[4671]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4671
	DECLE 16191,63
	;[4672]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4672
	DECLE 63,0
	;[4673]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4673
	DECLE 0,0
	;[4674]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4674
	DECLE 0,0
	;[4675]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4675
	DECLE 0,0
	;[4676]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",4676
	DECLE 40373,169
	;[4677]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4677
	DECLE 16191,63
	;[4678]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4678
	DECLE 63,0
	;[4679]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4679
	DECLE 0,0
	;[4680]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4680
	DECLE 0,0
	;[4681]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4681
	DECLE 0,0
	;[4682]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",4682
	DECLE 40373,169
	;[4683]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4683
	DECLE 16191,63
	;[4684]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4684
	DECLE 0,0
	;[4685]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4685
	DECLE 0,0
	;[4686]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4686
	DECLE 0,0
	;[4687]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",4687
	DECLE 40373,169
	;[4688]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4688
	DECLE 16191,63
	;[4689]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4689
	DECLE 63,0
	;[4690]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4690
	DECLE 0,0
	;[4691]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4691
	DECLE 0,0
	;[4692]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4692
	DECLE 0,0
	;[4693]     MUSIC   E6,   E4,   E5
	SRCFILE "minty.bas",4693
	DECLE 40373,169
	;[4694]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4694
	DECLE 16191,63
	;[4695]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4695
	DECLE 63,63
	;[4696]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4696
	DECLE 0,0
	;[4697]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4697
	DECLE 0,0
	;[4698]     MUSIC   E5,   E4,    -
	SRCFILE "minty.bas",4698
	DECLE 40361,0
	;[4699]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4699
	DECLE 16191,0
	;[4700]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4700
	DECLE 16191,0
	;[4701]     MUSIC   A5,   A4,    -
	SRCFILE "minty.bas",4701
	DECLE 41646,0
	;[4702]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4702
	DECLE 16191,0
	;[4703] 
	SRCFILE "minty.bas",4703
	;[4704] REM Timing 6700 frames, 134.00 secs
	SRCFILE "minty.bas",4704
	;[4705] 
	SRCFILE "minty.bas",4705
	;[4706]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4706
	DECLE 16191,0
	;[4707]     MUSIC   C6,    S,   C5
	SRCFILE "minty.bas",4707
	DECLE 16305,165
	;[4708]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4708
	DECLE 16191,63
	;[4709]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4709
	DECLE 16191,63
	;[4710]     MUSIC   E6,   E5,    -
	SRCFILE "minty.bas",4710
	DECLE 43445,0
	;[4711]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4711
	DECLE 16191,0
	;[4712]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4712
	DECLE 16191,0
	;[4713]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",4713
	DECLE 40628,168
	;[4714]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4714
	DECLE 16191,63
	;[4715]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4715
	DECLE 63,0
	;[4716]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4716
	DECLE 0,0
	;[4717]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4717
	DECLE 0,0
	;[4718]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",4718
	DECLE 40628,168
	;[4719]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4719
	DECLE 16191,63
	;[4720]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4720
	DECLE 63,0
	;[4721]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4721
	DECLE 0,0
	;[4722]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4722
	DECLE 0,0
	;[4723]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4723
	DECLE 0,0
	;[4724]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",4724
	DECLE 40628,168
	;[4725]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4725
	DECLE 16191,63
	;[4726]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4726
	DECLE 63,0
	;[4727]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4727
	DECLE 0,0
	;[4728]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4728
	DECLE 0,0
	;[4729]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4729
	DECLE 0,0
	;[4730]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",4730
	DECLE 40628,168
	;[4731]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4731
	DECLE 16191,63
	;[4732]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4732
	DECLE 0,0
	;[4733]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4733
	DECLE 0,0
	;[4734]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4734
	DECLE 0,0
	;[4735]     MUSIC  D6#,   F4,  D5#
	SRCFILE "minty.bas",4735
	DECLE 40628,168
	;[4736]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4736
	DECLE 16191,63
	;[4737]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4737
	DECLE 16191,63
	;[4738]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4738
	DECLE 16128,63
	;[4739]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4739
	DECLE 16128,63
	;[4740]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4740
	DECLE 16128,63
	;[4741]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4741
	DECLE 16128,63
	;[4742]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4742
	DECLE 16128,63
	;[4743]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4743
	DECLE 16128,0
	;[4744]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4744
	DECLE 0,0
	;[4745]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4745
	DECLE 0,0
	;[4746]     MUSIC   G2,   F2,    -
	SRCFILE "minty.bas",4746
	DECLE 34440,0
	;[4747]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4747
	DECLE 16191,0
	;[4748]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4748
	DECLE 0,0
	;[4749]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4749
	DECLE 0,0
	;[4750]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4750
	DECLE 0,0
	;[4751]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4751
	DECLE 0,0
	;[4752]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4752
	DECLE 0,0
	;[4753]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4753
	DECLE 0,0
	;[4754]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4754
	DECLE 0,0
	;[4755]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4755
	DECLE 0,0
	;[4756] 
	SRCFILE "minty.bas",4756
	;[4757] REM Timing 6800 frames, 136.00 secs
	SRCFILE "minty.bas",4757
	;[4758] 
	SRCFILE "minty.bas",4758
	;[4759]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4759
	DECLE 0,0
	;[4760]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4760
	DECLE 0,0
	;[4761]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",4761
	DECLE 35759,166
	;[4762]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4762
	DECLE 16191,63
	;[4763]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4763
	DECLE 16191,63
	;[4764]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4764
	DECLE 16275,0
	;[4765]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4765
	DECLE 16191,0
	;[4766]     MUSIC   C6,   C2,  D5#
	SRCFILE "minty.bas",4766
	DECLE 33201,168
	;[4767]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4767
	DECLE 16191,63
	;[4768]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4768
	DECLE 16191,63
	;[4769]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4769
	DECLE 147,0
	;[4770]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4770
	DECLE 63,0
	;[4771]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4771
	DECLE 63,0
	;[4772]     MUSIC  C6#,   B2,   F5
	SRCFILE "minty.bas",4772
	DECLE 36018,170
	;[4773]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4773
	DECLE 16191,63
	;[4774]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4774
	DECLE 63,0
	;[4775]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4775
	DECLE 147,0
	;[4776]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4776
	DECLE 63,0
	;[4777]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4777
	DECLE 0,0
	;[4778]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",4778
	DECLE 35759,166
	;[4779]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4779
	DECLE 16191,63
	;[4780]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4780
	DECLE 16275,0
	;[4781]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4781
	DECLE 16191,0
	;[4782]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4782
	DECLE 0,0
	;[4783]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",4783
	DECLE 36017,168
	;[4784]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4784
	DECLE 16191,63
	;[4785]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4785
	DECLE 63,63
	;[4786]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4786
	DECLE 147,63
	;[4787]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4787
	DECLE 63,63
	;[4788]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4788
	DECLE 63,63
	;[4789]     MUSIC  C6#,  C2#,   F5
	SRCFILE "minty.bas",4789
	DECLE 33458,170
	;[4790]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4790
	DECLE 16191,63
	;[4791]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4791
	DECLE 16128,0
	;[4792]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4792
	DECLE 147,0
	;[4793]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4793
	DECLE 63,0
	;[4794]     MUSIC   F4,   B2,  C4#
	SRCFILE "minty.bas",4794
	DECLE 35998,154
	;[4795]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4795
	DECLE 16191,63
	;[4796]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4796
	DECLE 0,0
	;[4797]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4797
	DECLE 147,0
	;[4798]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4798
	DECLE 63,0
	;[4799]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4799
	DECLE 0,0
	;[4800]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",4800
	DECLE 37789,153
	;[4801]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4801
	DECLE 16191,63
	;[4802]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4802
	DECLE 16191,63
	;[4803]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4803
	DECLE 147,0
	;[4804]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4804
	DECLE 63,0
	;[4805]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4805
	DECLE 0,0
	;[4806]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4806
	DECLE 35997,153
	;[4807]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4807
	DECLE 16191,63
	;[4808]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4808
	DECLE 0,0
	;[4809] 
	SRCFILE "minty.bas",4809
	;[4810] REM Timing 6900 frames, 138.00 secs
	SRCFILE "minty.bas",4810
	;[4811] 
	SRCFILE "minty.bas",4811
	;[4812]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4812
	DECLE 147,0
	;[4813]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4813
	DECLE 63,0
	;[4814]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",4814
	DECLE 37789,153
	;[4815]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4815
	DECLE 16191,63
	;[4816]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4816
	DECLE 0,0
	;[4817]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4817
	DECLE 147,0
	;[4818]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4818
	DECLE 63,0
	;[4819]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4819
	DECLE 63,0
	;[4820]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",4820
	DECLE 36017,168
	;[4821]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4821
	DECLE 16191,63
	;[4822]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4822
	DECLE 63,63
	;[4823]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4823
	DECLE 147,0
	;[4824]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4824
	DECLE 63,0
	;[4825]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4825
	DECLE 0,0
	;[4826]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",4826
	DECLE 35759,166
	;[4827]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4827
	DECLE 16191,63
	;[4828]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4828
	DECLE 147,0
	;[4829]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4829
	DECLE 63,0
	;[4830]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4830
	DECLE 0,0
	;[4831]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",4831
	DECLE 36017,168
	;[4832]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4832
	DECLE 16191,63
	;[4833]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4833
	DECLE 63,63
	;[4834]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4834
	DECLE 147,63
	;[4835]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4835
	DECLE 63,63
	;[4836]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4836
	DECLE 63,63
	;[4837]     MUSIC  C6#,  C2#,   E5
	SRCFILE "minty.bas",4837
	DECLE 33458,169
	;[4838]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4838
	DECLE 16191,63
	;[4839]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4839
	DECLE 16128,0
	;[4840]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4840
	DECLE 16275,0
	;[4841]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4841
	DECLE 63,0
	;[4842]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4842
	DECLE 35997,153
	;[4843]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4843
	DECLE 16191,63
	;[4844]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4844
	DECLE 0,0
	;[4845]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4845
	DECLE 147,0
	;[4846]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4846
	DECLE 63,0
	;[4847]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4847
	DECLE 0,0
	;[4848]     MUSIC  D4#,  F3#,   C4
	SRCFILE "minty.bas",4848
	DECLE 37788,153
	;[4849]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4849
	DECLE 16191,63
	;[4850]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4850
	DECLE 16191,63
	;[4851]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4851
	DECLE 147,0
	;[4852]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4852
	DECLE 63,0
	;[4853]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4853
	DECLE 0,0
	;[4854]     MUSIC  D4#,   B2,   C4
	SRCFILE "minty.bas",4854
	DECLE 35996,153
	;[4855]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4855
	DECLE 16191,63
	;[4856]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4856
	DECLE 0,0
	;[4857]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4857
	DECLE 147,0
	;[4858]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4858
	DECLE 63,0
	;[4859]     MUSIC  D4#,  F3#,   C4
	SRCFILE "minty.bas",4859
	DECLE 37788,153
	;[4860]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4860
	DECLE 16191,63
	;[4861]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4861
	DECLE 0,0
	;[4862] 
	SRCFILE "minty.bas",4862
	;[4863] REM Timing 7000 frames, 140.00 secs
	SRCFILE "minty.bas",4863
	;[4864] 
	SRCFILE "minty.bas",4864
	;[4865]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4865
	DECLE 147,0
	;[4866]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4866
	DECLE 63,0
	;[4867]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4867
	DECLE 63,0
	;[4868]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",4868
	DECLE 36017,168
	;[4869]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4869
	DECLE 16191,63
	;[4870]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4870
	DECLE 63,63
	;[4871]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4871
	DECLE 147,0
	;[4872]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4872
	DECLE 63,0
	;[4873]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4873
	DECLE 0,0
	;[4874]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",4874
	DECLE 35759,166
	;[4875]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4875
	DECLE 16191,63
	;[4876]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4876
	DECLE 16275,0
	;[4877]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4877
	DECLE 16191,0
	;[4878]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4878
	DECLE 0,0
	;[4879]     MUSIC  C6#,   B2,   F5
	SRCFILE "minty.bas",4879
	DECLE 36018,170
	;[4880]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4880
	DECLE 16191,63
	;[4881]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4881
	DECLE 0,0
	;[4882]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4882
	DECLE 147,0
	;[4883]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4883
	DECLE 63,0
	;[4884]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4884
	DECLE 63,0
	;[4885]     MUSIC  C6#,  C2#,   F5
	SRCFILE "minty.bas",4885
	DECLE 33458,170
	;[4886]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4886
	DECLE 16191,63
	;[4887]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4887
	DECLE 16191,63
	;[4888]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4888
	DECLE 16275,0
	;[4889]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4889
	DECLE 16191,0
	;[4890]     MUSIC  D4#,   B2,  C4#
	SRCFILE "minty.bas",4890
	DECLE 35996,154
	;[4891]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4891
	DECLE 16191,63
	;[4892]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",4892
	DECLE 0,63
	;[4893]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4893
	DECLE 147,63
	;[4894]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4894
	DECLE 63,63
	;[4895]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",4895
	DECLE 0,63
	;[4896]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",4896
	DECLE 35759,166
	;[4897]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4897
	DECLE 16191,63
	;[4898]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4898
	DECLE 16191,63
	;[4899]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",4899
	DECLE 16275,63
	;[4900]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4900
	DECLE 16191,63
	;[4901]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4901
	DECLE 16128,63
	;[4902]     MUSIC  C4#,    S,  A3#
	SRCFILE "minty.bas",4902
	DECLE 16282,151
	;[4903]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4903
	DECLE 16191,63
	;[4904]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4904
	DECLE 16128,0
	;[4905]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4905
	DECLE 16275,0
	;[4906]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4906
	DECLE 16191,0
	;[4907]     MUSIC  C4#,   F3,  A3#
	SRCFILE "minty.bas",4907
	DECLE 37530,151
	;[4908]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4908
	DECLE 16191,63
	;[4909]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4909
	DECLE 0,0
	;[4910]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4910
	DECLE 147,0
	;[4911]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4911
	DECLE 63,0
	;[4912]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4912
	DECLE 63,0
	;[4913]     MUSIC  C4#,   B2,  A3#
	SRCFILE "minty.bas",4913
	DECLE 35994,151
	;[4914]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4914
	DECLE 16191,63
	;[4915] 
	SRCFILE "minty.bas",4915
	;[4916] REM Timing 7100 frames, 142.00 secs
	SRCFILE "minty.bas",4916
	;[4917] 
	SRCFILE "minty.bas",4917
	;[4918]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4918
	DECLE 0,0
	;[4919]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4919
	DECLE 147,0
	;[4920]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4920
	DECLE 63,0
	;[4921]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4921
	DECLE 0,0
	;[4922]     MUSIC  C4#,   F3,  A3#
	SRCFILE "minty.bas",4922
	DECLE 37530,151
	;[4923]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4923
	DECLE 16191,63
	;[4924]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4924
	DECLE 147,0
	;[4925]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4925
	DECLE 63,0
	;[4926]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4926
	DECLE 0,0
	;[4927]     MUSIC  D4#,   B2,  C4#
	SRCFILE "minty.bas",4927
	DECLE 35996,154
	;[4928]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4928
	DECLE 16191,63
	;[4929]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4929
	DECLE 63,0
	;[4930]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",4930
	DECLE 37695,0
	;[4931]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4931
	DECLE 16191,0
	;[4932]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4932
	DECLE 16191,0
	;[4933]     MUSIC  C4#,   F3,  A3#
	SRCFILE "minty.bas",4933
	DECLE 37530,151
	;[4934]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4934
	DECLE 16191,63
	;[4935]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4935
	DECLE 0,0
	;[4936]     MUSIC  A3#,  F3#,    -
	SRCFILE "minty.bas",4936
	DECLE 37783,0
	;[4937]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4937
	DECLE 16191,0
	;[4938]     MUSIC  C4#,   B2,  A3#
	SRCFILE "minty.bas",4938
	DECLE 35994,151
	;[4939]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4939
	DECLE 16191,63
	;[4940]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4940
	DECLE 0,0
	;[4941]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4941
	DECLE 147,0
	;[4942]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4942
	DECLE 63,0
	;[4943]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4943
	DECLE 0,0
	;[4944]     MUSIC  C4#,   F3,  A3#
	SRCFILE "minty.bas",4944
	DECLE 37530,151
	;[4945]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4945
	DECLE 16191,63
	;[4946]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4946
	DECLE 16191,63
	;[4947]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4947
	DECLE 147,0
	;[4948]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4948
	DECLE 63,0
	;[4949]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4949
	DECLE 0,0
	;[4950]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",4950
	DECLE 35759,166
	;[4951]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4951
	DECLE 16191,63
	;[4952]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4952
	DECLE 16191,63
	;[4953]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4953
	DECLE 16275,0
	;[4954]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4954
	DECLE 63,0
	;[4955]     MUSIC   C6,   C2,  D5#
	SRCFILE "minty.bas",4955
	DECLE 33201,168
	;[4956]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4956
	DECLE 16191,63
	;[4957]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",4957
	DECLE 16128,63
	;[4958]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4958
	DECLE 147,0
	;[4959]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4959
	DECLE 63,0
	;[4960]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4960
	DECLE 63,0
	;[4961]     MUSIC  C6#,   B2,   F5
	SRCFILE "minty.bas",4961
	DECLE 36018,170
	;[4962]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4962
	DECLE 16191,63
	;[4963]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4963
	DECLE 63,0
	;[4964]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4964
	DECLE 147,0
	;[4965]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4965
	DECLE 63,0
	;[4966]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4966
	DECLE 0,0
	;[4967]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",4967
	DECLE 35759,166
	;[4968] 
	SRCFILE "minty.bas",4968
	;[4969] REM Timing 7200 frames, 144.00 secs
	SRCFILE "minty.bas",4969
	;[4970] 
	SRCFILE "minty.bas",4970
	;[4971]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4971
	DECLE 16191,63
	;[4972]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4972
	DECLE 147,0
	;[4973]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4973
	DECLE 63,0
	;[4974]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4974
	DECLE 0,0
	;[4975]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",4975
	DECLE 36017,168
	;[4976]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4976
	DECLE 16191,63
	;[4977]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4977
	DECLE 63,63
	;[4978]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",4978
	DECLE 147,63
	;[4979]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",4979
	DECLE 63,63
	;[4980]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4980
	DECLE 63,0
	;[4981]     MUSIC  C6#,  C2#,   F5
	SRCFILE "minty.bas",4981
	DECLE 33458,170
	;[4982]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4982
	DECLE 16191,63
	;[4983]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",4983
	DECLE 16128,0
	;[4984]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",4984
	DECLE 16275,0
	;[4985]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",4985
	DECLE 16191,0
	;[4986]     MUSIC   F4,   B2,  C4#
	SRCFILE "minty.bas",4986
	DECLE 35998,154
	;[4987]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4987
	DECLE 16191,63
	;[4988]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4988
	DECLE 0,0
	;[4989]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4989
	DECLE 147,0
	;[4990]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4990
	DECLE 63,0
	;[4991]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4991
	DECLE 0,0
	;[4992]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",4992
	DECLE 37789,153
	;[4993]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4993
	DECLE 16191,63
	;[4994]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4994
	DECLE 16191,63
	;[4995]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",4995
	DECLE 147,0
	;[4996]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",4996
	DECLE 63,0
	;[4997]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",4997
	DECLE 0,0
	;[4998]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",4998
	DECLE 35997,153
	;[4999]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",4999
	DECLE 16191,63
	;[5000]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5000
	DECLE 0,0
	;[5001]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5001
	DECLE 147,0
	;[5002]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5002
	DECLE 63,0
	;[5003]     MUSIC   E4,  F3#,   C4
	SRCFILE "minty.bas",5003
	DECLE 37789,153
	;[5004]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5004
	DECLE 16191,63
	;[5005]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5005
	DECLE 0,0
	;[5006]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5006
	DECLE 147,0
	;[5007]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5007
	DECLE 63,0
	;[5008]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5008
	DECLE 63,0
	;[5009]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",5009
	DECLE 36017,168
	;[5010]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5010
	DECLE 16191,63
	;[5011]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5011
	DECLE 63,63
	;[5012]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5012
	DECLE 147,0
	;[5013]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5013
	DECLE 63,0
	;[5014]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5014
	DECLE 0,0
	;[5015]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",5015
	DECLE 35759,166
	;[5016]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5016
	DECLE 16191,63
	;[5017]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5017
	DECLE 147,0
	;[5018]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5018
	DECLE 63,0
	;[5019]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5019
	DECLE 0,0
	;[5020]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",5020
	DECLE 36017,168
	;[5021] 
	SRCFILE "minty.bas",5021
	;[5022] REM Timing 7300 frames, 146.00 secs
	SRCFILE "minty.bas",5022
	;[5023] 
	SRCFILE "minty.bas",5023
	;[5024]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5024
	DECLE 16191,63
	;[5025]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5025
	DECLE 63,63
	;[5026]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5026
	DECLE 147,63
	;[5027]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5027
	DECLE 63,63
	;[5028]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5028
	DECLE 63,63
	;[5029]     MUSIC  C6#,  C2#,   E5
	SRCFILE "minty.bas",5029
	DECLE 33458,169
	;[5030]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5030
	DECLE 16191,63
	;[5031]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5031
	DECLE 16128,0
	;[5032]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5032
	DECLE 16275,0
	;[5033]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5033
	DECLE 63,0
	;[5034]     MUSIC   E4,   B2,   C4
	SRCFILE "minty.bas",5034
	DECLE 35997,153
	;[5035]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5035
	DECLE 16191,63
	;[5036]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5036
	DECLE 0,0
	;[5037]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5037
	DECLE 147,0
	;[5038]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5038
	DECLE 63,0
	;[5039]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5039
	DECLE 0,0
	;[5040]     MUSIC  D4#,  F3#,   C4
	SRCFILE "minty.bas",5040
	DECLE 37788,153
	;[5041]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5041
	DECLE 16191,63
	;[5042]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5042
	DECLE 16191,63
	;[5043]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5043
	DECLE 147,0
	;[5044]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5044
	DECLE 63,0
	;[5045]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5045
	DECLE 0,0
	;[5046]     MUSIC  D4#,   B2,   C4
	SRCFILE "minty.bas",5046
	DECLE 35996,153
	;[5047]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5047
	DECLE 16191,63
	;[5048]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5048
	DECLE 0,0
	;[5049]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5049
	DECLE 147,0
	;[5050]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5050
	DECLE 63,0
	;[5051]     MUSIC  D4#,  F3#,   C4
	SRCFILE "minty.bas",5051
	DECLE 37788,153
	;[5052]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5052
	DECLE 16191,63
	;[5053]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5053
	DECLE 0,0
	;[5054]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5054
	DECLE 147,0
	;[5055]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5055
	DECLE 63,0
	;[5056]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5056
	DECLE 63,0
	;[5057]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",5057
	DECLE 36017,168
	;[5058]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5058
	DECLE 16191,63
	;[5059]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5059
	DECLE 63,63
	;[5060]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5060
	DECLE 147,0
	;[5061]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5061
	DECLE 63,0
	;[5062]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5062
	DECLE 0,0
	;[5063]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",5063
	DECLE 35759,166
	;[5064]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5064
	DECLE 16191,63
	;[5065]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5065
	DECLE 16275,0
	;[5066]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5066
	DECLE 16191,0
	;[5067]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5067
	DECLE 0,0
	;[5068]     MUSIC  C6#,   B2,   F5
	SRCFILE "minty.bas",5068
	DECLE 36018,170
	;[5069]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5069
	DECLE 16191,63
	;[5070]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5070
	DECLE 0,0
	;[5071]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5071
	DECLE 147,0
	;[5072]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5072
	DECLE 63,0
	;[5073]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5073
	DECLE 63,0
	;[5074] 
	SRCFILE "minty.bas",5074
	;[5075] REM Timing 7400 frames, 148.00 secs
	SRCFILE "minty.bas",5075
	;[5076] 
	SRCFILE "minty.bas",5076
	;[5077]     MUSIC  C6#,  C2#,   F5
	SRCFILE "minty.bas",5077
	DECLE 33458,170
	;[5078]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5078
	DECLE 16191,63
	;[5079]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5079
	DECLE 16191,63
	;[5080]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",5080
	DECLE 16275,63
	;[5081]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5081
	DECLE 63,63
	;[5082]     MUSIC  C4#,   B2,   C4
	SRCFILE "minty.bas",5082
	DECLE 35994,153
	;[5083]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5083
	DECLE 16191,63
	;[5084]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5084
	DECLE 63,0
	;[5085]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5085
	DECLE 37695,0
	;[5086]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5086
	DECLE 16191,0
	;[5087]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5087
	DECLE 63,0
	;[5088]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",5088
	DECLE 35759,166
	;[5089]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5089
	DECLE 16191,63
	;[5090]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5090
	DECLE 16191,63
	;[5091]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",5091
	DECLE 16275,63
	;[5092]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5092
	DECLE 16191,63
	;[5093]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5093
	DECLE 16128,0
	;[5094]     MUSIC  C4#,    S,  A3#
	SRCFILE "minty.bas",5094
	DECLE 16282,151
	;[5095]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5095
	DECLE 16191,63
	;[5096]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5096
	DECLE 16128,0
	;[5097]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5097
	DECLE 16275,0
	;[5098]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5098
	DECLE 16191,0
	;[5099]     MUSIC  C4#,    S,  A3#
	SRCFILE "minty.bas",5099
	DECLE 16282,151
	;[5100]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5100
	DECLE 63,63
	;[5101]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5101
	DECLE 0,0
	;[5102]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5102
	DECLE 147,0
	;[5103]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5103
	DECLE 63,0
	;[5104]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5104
	DECLE 63,0
	;[5105]     MUSIC  C4#,   B2,  A3#
	SRCFILE "minty.bas",5105
	DECLE 35994,151
	;[5106]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5106
	DECLE 16191,63
	;[5107]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5107
	DECLE 0,0
	;[5108]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5108
	DECLE 147,0
	;[5109]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5109
	DECLE 63,0
	;[5110]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5110
	DECLE 0,0
	;[5111]     MUSIC  C4#,   F3,  A3#
	SRCFILE "minty.bas",5111
	DECLE 37530,151
	;[5112]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5112
	DECLE 16191,63
	;[5113]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5113
	DECLE 147,0
	;[5114]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5114
	DECLE 63,0
	;[5115]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5115
	DECLE 0,0
	;[5116]     MUSIC  D4#,   B2,  C4#
	SRCFILE "minty.bas",5116
	DECLE 35996,154
	;[5117]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5117
	DECLE 16191,63
	;[5118]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5118
	DECLE 63,0
	;[5119]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5119
	DECLE 37695,0
	;[5120]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5120
	DECLE 16191,0
	;[5121]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5121
	DECLE 16191,0
	;[5122]     MUSIC    -,  A2#,  C4#
	SRCFILE "minty.bas",5122
	DECLE 35584,154
	;[5123]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5123
	DECLE 16128,63
	;[5124]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5124
	DECLE 16128,0
	;[5125]     MUSIC  A3#,    S,  F3#
	SRCFILE "minty.bas",5125
	DECLE 16279,147
	;[5126]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5126
	DECLE 16191,63
	;[5127] 
	SRCFILE "minty.bas",5127
	;[5128] REM Timing 7500 frames, 150.00 secs
	SRCFILE "minty.bas",5128
	;[5129] 
	SRCFILE "minty.bas",5129
	;[5130]     MUSIC  A4#,   B2,  C4#
	SRCFILE "minty.bas",5130
	DECLE 36003,154
	;[5131]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5131
	DECLE 16191,63
	;[5132]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5132
	DECLE 63,0
	;[5133]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5133
	DECLE 37695,0
	;[5134]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5134
	DECLE 16191,0
	;[5135]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5135
	DECLE 63,0
	;[5136]     MUSIC  C4#,  A2#,  A3#
	SRCFILE "minty.bas",5136
	DECLE 35738,151
	;[5137]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5137
	DECLE 16191,63
	;[5138]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5138
	DECLE 16191,63
	;[5139]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5139
	DECLE 16275,0
	;[5140]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5140
	DECLE 63,0
	;[5141]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5141
	DECLE 0,0
	;[5142]     MUSIC  D6#,   B2,  D5#
	SRCFILE "minty.bas",5142
	DECLE 36020,168
	;[5143]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5143
	DECLE 16191,63
	;[5144]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5144
	DECLE 63,63
	;[5145]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5145
	DECLE 147,0
	;[5146]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5146
	DECLE 63,0
	;[5147]     MUSIC   F6,  D2#,   F5
	SRCFILE "minty.bas",5147
	DECLE 33974,170
	;[5148]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5148
	DECLE 16191,63
	;[5149]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5149
	DECLE 16191,0
	;[5150]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5150
	DECLE 147,0
	;[5151]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5151
	DECLE 63,0
	;[5152]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5152
	DECLE 63,0
	;[5153]     MUSIC  F6#,  C2#,  F5#
	SRCFILE "minty.bas",5153
	DECLE 33463,171
	;[5154]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5154
	DECLE 16191,63
	;[5155]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5155
	DECLE 16191,63
	;[5156]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5156
	DECLE 16275,0
	;[5157]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5157
	DECLE 16191,0
	;[5158]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5158
	DECLE 16128,0
	;[5159]     MUSIC  D6#,  A2#,  D5#
	SRCFILE "minty.bas",5159
	DECLE 35764,168
	;[5160]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5160
	DECLE 16191,63
	;[5161]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5161
	DECLE 16275,0
	;[5162]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5162
	DECLE 63,0
	;[5163]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5163
	DECLE 0,0
	;[5164]     MUSIC   F6,   B2,   F5
	SRCFILE "minty.bas",5164
	DECLE 36022,170
	;[5165]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5165
	DECLE 16191,63
	;[5166]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5166
	DECLE 63,0
	;[5167]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5167
	DECLE 147,0
	;[5168]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5168
	DECLE 63,0
	;[5169]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5169
	DECLE 63,0
	;[5170]     MUSIC  F6#,   B2,  G5#
	SRCFILE "minty.bas",5170
	DECLE 36023,173
	;[5171]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5171
	DECLE 16191,63
	;[5172]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5172
	DECLE 63,63
	;[5173]     MUSIC  F5#,  F3#,    -
	SRCFILE "minty.bas",5173
	DECLE 37803,0
	;[5174]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5174
	DECLE 16191,0
	;[5175]     MUSIC  D5#,  C2#,   F4
	SRCFILE "minty.bas",5175
	DECLE 33448,158
	;[5176]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5176
	DECLE 16191,63
	;[5177]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5177
	DECLE 16191,63
	;[5178]     MUSIC    S,    S,  F4#
	SRCFILE "minty.bas",5178
	DECLE 16191,159
	;[5179]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5179
	DECLE 16191,63
	;[5180] 
	SRCFILE "minty.bas",5180
	;[5181] REM Timing 7600 frames, 152.00 secs
	SRCFILE "minty.bas",5181
	;[5182] 
	SRCFILE "minty.bas",5182
	;[5183]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5183
	DECLE 63,63
	;[5184]     MUSIC   F6,  A2#,   F4
	SRCFILE "minty.bas",5184
	DECLE 35766,158
	;[5185]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5185
	DECLE 16191,63
	;[5186]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5186
	DECLE 16191,63
	;[5187]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5187
	DECLE 16275,0
	;[5188]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5188
	DECLE 63,0
	;[5189]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5189
	DECLE 0,0
	;[5190]     MUSIC   C4,   B2,   A3
	SRCFILE "minty.bas",5190
	DECLE 35993,150
	;[5191]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5191
	DECLE 16191,63
	;[5192]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5192
	DECLE 0,0
	;[5193]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5193
	DECLE 147,0
	;[5194]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5194
	DECLE 63,0
	;[5195]     MUSIC  D4#,   F2,   C4
	SRCFILE "minty.bas",5195
	DECLE 34460,153
	;[5196]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5196
	DECLE 16191,63
	;[5197]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5197
	DECLE 16128,0
	;[5198]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5198
	DECLE 16275,0
	;[5199]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5199
	DECLE 16191,0
	;[5200]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5200
	DECLE 16191,0
	;[5201]     MUSIC   F6,  D2#,   F5
	SRCFILE "minty.bas",5201
	DECLE 33974,170
	;[5202]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5202
	DECLE 16191,63
	;[5203]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5203
	DECLE 16191,63
	;[5204]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5204
	DECLE 16275,0
	;[5205]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5205
	DECLE 16191,0
	;[5206]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5206
	DECLE 16128,0
	;[5207]     MUSIC  D6#,   C2,  D5#
	SRCFILE "minty.bas",5207
	DECLE 33204,168
	;[5208]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5208
	DECLE 16191,63
	;[5209]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5209
	DECLE 147,0
	;[5210]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5210
	DECLE 63,0
	;[5211]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5211
	DECLE 0,0
	;[5212]     MUSIC   F6,   B2,   F5
	SRCFILE "minty.bas",5212
	DECLE 36022,170
	;[5213]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5213
	DECLE 16191,63
	;[5214]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5214
	DECLE 63,63
	;[5215]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5215
	DECLE 147,0
	;[5216]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5216
	DECLE 63,0
	;[5217]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5217
	DECLE 63,0
	;[5218]     MUSIC  F6#,  F3#,  F5#
	SRCFILE "minty.bas",5218
	DECLE 37815,171
	;[5219]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5219
	DECLE 16191,63
	;[5220]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5220
	DECLE 63,0
	;[5221]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5221
	DECLE 147,0
	;[5222]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5222
	DECLE 63,0
	;[5223]     MUSIC  A4#,  D2#,  D4#
	SRCFILE "minty.bas",5223
	DECLE 33955,156
	;[5224]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5224
	DECLE 16191,63
	;[5225]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5225
	DECLE 16191,0
	;[5226]     MUSIC    S,    S,  F3#
	SRCFILE "minty.bas",5226
	DECLE 16191,147
	;[5227]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5227
	DECLE 16191,63
	;[5228]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5228
	DECLE 63,0
	;[5229]     MUSIC    S,   F6,   F5
	SRCFILE "minty.bas",5229
	DECLE 46655,170
	;[5230]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5230
	DECLE 16191,63
	;[5231]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5231
	DECLE 16191,63
	;[5232]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5232
	DECLE 37695,0
	;[5233] 
	SRCFILE "minty.bas",5233
	;[5234] REM Timing 7700 frames, 154.00 secs
	SRCFILE "minty.bas",5234
	;[5235] 
	SRCFILE "minty.bas",5235
	;[5236]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5236
	DECLE 16191,0
	;[5237]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5237
	DECLE 63,0
	;[5238]     MUSIC    S,   B2,   D4
	SRCFILE "minty.bas",5238
	DECLE 35903,155
	;[5239]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5239
	DECLE 16191,63
	;[5240]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5240
	DECLE 63,0
	;[5241]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5241
	DECLE 37695,0
	;[5242]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5242
	DECLE 16191,0
	;[5243]     MUSIC    S,  F3#,  G3#
	SRCFILE "minty.bas",5243
	DECLE 37695,149
	;[5244]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5244
	DECLE 16191,63
	;[5245]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5245
	DECLE 63,0
	;[5246]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5246
	DECLE 37695,0
	;[5247]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5247
	DECLE 16191,0
	;[5248]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5248
	DECLE 16191,0
	;[5249]     MUSIC    S,  F6#,  F5#
	SRCFILE "minty.bas",5249
	DECLE 46911,171
	;[5250]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5250
	DECLE 16191,63
	;[5251]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5251
	DECLE 16191,63
	;[5252]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5252
	DECLE 37695,0
	;[5253]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5253
	DECLE 16191,0
	;[5254]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5254
	DECLE 63,0
	;[5255]     MUSIC   F5,   F6,  F3#
	SRCFILE "minty.bas",5255
	DECLE 46762,147
	;[5256]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5256
	DECLE 16191,63
	;[5257]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5257
	DECLE 147,0
	;[5258]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5258
	DECLE 63,0
	;[5259]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5259
	DECLE 0,0
	;[5260]     MUSIC  F6#,   B2,  F5#
	SRCFILE "minty.bas",5260
	DECLE 36023,171
	;[5261]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5261
	DECLE 16191,63
	;[5262]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5262
	DECLE 63,63
	;[5263]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5263
	DECLE 147,63
	;[5264]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5264
	DECLE 63,0
	;[5265]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5265
	DECLE 63,0
	;[5266]     MUSIC   F6,   B2,   F5
	SRCFILE "minty.bas",5266
	DECLE 36022,170
	;[5267]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5267
	DECLE 16191,63
	;[5268]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5268
	DECLE 63,0
	;[5269]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5269
	DECLE 147,0
	;[5270]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5270
	DECLE 63,0
	;[5271]     MUSIC  A5#,   E2,  A4#
	SRCFILE "minty.bas",5271
	DECLE 34223,163
	;[5272]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5272
	DECLE 16191,63
	;[5273]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5273
	DECLE 63,63
	;[5274]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5274
	DECLE 147,0
	;[5275]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5275
	DECLE 63,0
	;[5276]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5276
	DECLE 0,0
	;[5277]     MUSIC  D6#,   B2,  D5#
	SRCFILE "minty.bas",5277
	DECLE 36020,168
	;[5278]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5278
	DECLE 16191,63
	;[5279]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5279
	DECLE 16191,63
	;[5280]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5280
	DECLE 147,63
	;[5281]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5281
	DECLE 63,63
	;[5282]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5282
	DECLE 0,63
	;[5283]     MUSIC   B2,  A3#,    S
	SRCFILE "minty.bas",5283
	DECLE 38796,63
	;[5284]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5284
	DECLE 16191,63
	;[5285]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5285
	DECLE 0,63
	;[5286] 
	SRCFILE "minty.bas",5286
	;[5287] REM Timing 7800 frames, 156.00 secs
	SRCFILE "minty.bas",5287
	;[5288] 
	SRCFILE "minty.bas",5288
	;[5289]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5289
	DECLE 147,63
	;[5290]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5290
	DECLE 63,63
	;[5291]     MUSIC  F3#,  D4#,    S
	SRCFILE "minty.bas",5291
	DECLE 40083,63
	;[5292]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5292
	DECLE 16191,63
	;[5293]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5293
	DECLE 0,63
	;[5294]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5294
	DECLE 147,63
	;[5295]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5295
	DECLE 63,0
	;[5296]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5296
	DECLE 63,0
	;[5297]     MUSIC  D4#,   E2,  A3#
	SRCFILE "minty.bas",5297
	DECLE 34204,151
	;[5298]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5298
	DECLE 16191,63
	;[5299]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5299
	DECLE 0,0
	;[5300]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5300
	DECLE 147,0
	;[5301]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5301
	DECLE 63,0
	;[5302]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5302
	DECLE 0,0
	;[5303]     MUSIC  D4#,  D2#,  F3#
	SRCFILE "minty.bas",5303
	DECLE 33948,147
	;[5304]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5304
	DECLE 16191,63
	;[5305]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5305
	DECLE 16275,0
	;[5306]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5306
	DECLE 63,0
	;[5307]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5307
	DECLE 0,0
	;[5308]     MUSIC  C6#,   B2,   E5
	SRCFILE "minty.bas",5308
	DECLE 36018,169
	;[5309]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5309
	DECLE 16191,63
	;[5310]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5310
	DECLE 63,63
	;[5311]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5311
	DECLE 147,63
	;[5312]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5312
	DECLE 63,63
	;[5313]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5313
	DECLE 63,63
	;[5314]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5314
	DECLE 147,0
	;[5315]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5315
	DECLE 63,0
	;[5316]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5316
	DECLE 0,0
	;[5317]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5317
	DECLE 147,0
	;[5318]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5318
	DECLE 63,0
	;[5319]     MUSIC   C6,   E2,  D5#
	SRCFILE "minty.bas",5319
	DECLE 34225,168
	;[5320]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5320
	DECLE 16191,63
	;[5321]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5321
	DECLE 63,63
	;[5322]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5322
	DECLE 147,63
	;[5323]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5323
	DECLE 63,63
	;[5324]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5324
	DECLE 0,63
	;[5325]     MUSIC  F3#,  A2#,    -
	SRCFILE "minty.bas",5325
	DECLE 35731,0
	;[5326]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5326
	DECLE 16191,0
	;[5327]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5327
	DECLE 16191,0
	;[5328]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5328
	DECLE 147,0
	;[5329]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5329
	DECLE 63,0
	;[5330]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5330
	DECLE 0,0
	;[5331]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",5331
	DECLE 35759,166
	;[5332]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5332
	DECLE 16191,63
	;[5333]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5333
	DECLE 16191,63
	;[5334]     MUSIC  F3#,    S,    S
	SRCFILE "minty.bas",5334
	DECLE 16275,63
	;[5335]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5335
	DECLE 16191,0
	;[5336]     MUSIC   C6,   C2,  D5#
	SRCFILE "minty.bas",5336
	DECLE 33201,168
	;[5337]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5337
	DECLE 16191,63
	;[5338]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5338
	DECLE 16128,63
	;[5339] 
	SRCFILE "minty.bas",5339
	;[5340] REM Timing 7900 frames, 158.00 secs
	SRCFILE "minty.bas",5340
	;[5341] 
	SRCFILE "minty.bas",5341
	;[5342]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5342
	DECLE 147,0
	;[5343]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5343
	DECLE 63,0
	;[5344]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5344
	DECLE 63,0
	;[5345]     MUSIC  C6#,  C2#,   F5
	SRCFILE "minty.bas",5345
	DECLE 33458,170
	;[5346]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5346
	DECLE 16191,63
	;[5347]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5347
	DECLE 16191,0
	;[5348]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5348
	DECLE 16275,0
	;[5349]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5349
	DECLE 16191,0
	;[5350]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5350
	DECLE 0,0
	;[5351]     MUSIC  A5#,  A2#,  C5#
	SRCFILE "minty.bas",5351
	DECLE 35759,166
	;[5352]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5352
	DECLE 16191,63
	;[5353]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5353
	DECLE 147,0
	;[5354]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5354
	DECLE 63,0
	;[5355]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5355
	DECLE 0,0
	;[5356]     MUSIC   C6,   B2,  D5#
	SRCFILE "minty.bas",5356
	DECLE 36017,168
	;[5357]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5357
	DECLE 16191,63
	;[5358]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5358
	DECLE 63,63
	;[5359]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5359
	DECLE 147,63
	;[5360]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5360
	DECLE 63,0
	;[5361]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5361
	DECLE 63,0
	;[5362]     MUSIC  C6#,   B2,   F5
	SRCFILE "minty.bas",5362
	DECLE 36018,170
	;[5363]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5363
	DECLE 16191,63
	;[5364]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5364
	DECLE 0,63
	;[5365]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5365
	DECLE 147,0
	;[5366]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5366
	DECLE 63,0
	;[5367]     MUSIC  D4#,   E2,  C4#
	SRCFILE "minty.bas",5367
	DECLE 34204,154
	;[5368]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5368
	DECLE 16191,63
	;[5369]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5369
	DECLE 63,0
	;[5370]     MUSIC    S,  F3#,    -
	SRCFILE "minty.bas",5370
	DECLE 37695,0
	;[5371]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5371
	DECLE 16191,0
	;[5372]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5372
	DECLE 0,0
	;[5373]     MUSIC  D4#,  D3#,  A3#
	SRCFILE "minty.bas",5373
	DECLE 37020,151
	;[5374]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5374
	DECLE 16191,63
	;[5375]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5375
	DECLE 16191,63
	;[5376]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5376
	DECLE 147,0
	;[5377]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5377
	DECLE 63,0
	;[5378]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5378
	DECLE 0,0
	;[5379]     MUSIC  A3#,   B2,  F3#
	SRCFILE "minty.bas",5379
	DECLE 35991,147
	;[5380]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5380
	DECLE 16191,63
	;[5381]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5381
	DECLE 0,0
	;[5382]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5382
	DECLE 147,0
	;[5383]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5383
	DECLE 63,0
	;[5384]     MUSIC  D4#,  F3#,  A3#
	SRCFILE "minty.bas",5384
	DECLE 37788,151
	;[5385]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5385
	DECLE 16191,63
	;[5386]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5386
	DECLE 0,0
	;[5387]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5387
	DECLE 147,0
	;[5388]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5388
	DECLE 63,0
	;[5389]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5389
	DECLE 63,0
	;[5390]     MUSIC   C6,   E2,  D5#
	SRCFILE "minty.bas",5390
	DECLE 34225,168
	;[5391]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5391
	DECLE 16191,63
	;[5392] 
	SRCFILE "minty.bas",5392
	;[5393] REM Timing 8000 frames, 160.00 secs
	SRCFILE "minty.bas",5393
	;[5394] 
	SRCFILE "minty.bas",5394
	;[5395]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5395
	DECLE 63,63
	;[5396]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5396
	DECLE 147,63
	;[5397]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5397
	DECLE 63,0
	;[5398]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5398
	DECLE 0,0
	;[5399]     MUSIC  A5#,  D2#,  C5#
	SRCFILE "minty.bas",5399
	DECLE 33967,166
	;[5400]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5400
	DECLE 16191,63
	;[5401]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5401
	DECLE 147,0
	;[5402]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5402
	DECLE 63,0
	;[5403]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5403
	DECLE 0,0
	;[5404]     MUSIC  C6#,   B2,   F5
	SRCFILE "minty.bas",5404
	DECLE 36018,170
	;[5405]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5405
	DECLE 16191,63
	;[5406]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5406
	DECLE 63,0
	;[5407]     MUSIC  F3#,    -,    -
	SRCFILE "minty.bas",5407
	DECLE 147,0
	;[5408]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5408
	DECLE 63,0
	;[5409]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5409
	DECLE 63,0
	;[5410]     MUSIC  C6#,   F2,   F5
	SRCFILE "minty.bas",5410
	DECLE 34482,170
	;[5411]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5411
	DECLE 16191,63
	;[5412]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5412
	DECLE 16191,63
	;[5413]     MUSIC  F3#,    -,    S
	SRCFILE "minty.bas",5413
	DECLE 147,63
	;[5414]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5414
	DECLE 63,63
	;[5415]     MUSIC  F3#,  D2#,  F2#
	SRCFILE "minty.bas",5415
	DECLE 33939,135
	;[5416]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5416
	DECLE 16191,63
	;[5417]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5417
	DECLE 16128,0
	;[5418]     MUSIC  F3#,    S,    -
	SRCFILE "minty.bas",5418
	DECLE 16275,0
	;[5419]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5419
	DECLE 16191,0
	;[5420]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5420
	DECLE 16128,0
	;[5421]     MUSIC  A5#,   B2,  C5#
	SRCFILE "minty.bas",5421
	DECLE 36015,166
	;[5422]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5422
	DECLE 16191,63
	;[5423]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5423
	DECLE 16191,63
	;[5424]     MUSIC    S,  F3#,    S
	SRCFILE "minty.bas",5424
	DECLE 37695,63
	;[5425]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5425
	DECLE 16128,63
	;[5426]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5426
	DECLE 0,63
	;[5427]     MUSIC   F6,  A2#,  A5#
	SRCFILE "minty.bas",5427
	DECLE 35766,175
	;[5428]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5428
	DECLE 16191,63
	;[5429]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5429
	DECLE 16191,63
	;[5430]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5430
	DECLE 16128,63
	;[5431]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5431
	DECLE 16128,0
	;[5432]     MUSIC   F6,    S,   F5
	SRCFILE "minty.bas",5432
	DECLE 16310,170
	;[5433]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5433
	DECLE 16191,63
	;[5434]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5434
	DECLE 16191,0
	;[5435]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5435
	DECLE 16128,0
	;[5436]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5436
	DECLE 16128,0
	;[5437]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5437
	DECLE 0,0
	;[5438]     MUSIC   F6,   F4,   F5
	SRCFILE "minty.bas",5438
	DECLE 40630,170
	;[5439]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5439
	DECLE 16191,63
	;[5440]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5440
	DECLE 63,0
	;[5441]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5441
	DECLE 0,0
	;[5442]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5442
	DECLE 0,0
	;[5443]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5443
	DECLE 0,0
	;[5444]     MUSIC   F6,   F4,   F5
	SRCFILE "minty.bas",5444
	DECLE 40630,170
	;[5445] 
	SRCFILE "minty.bas",5445
	;[5446] REM Timing 8100 frames, 162.00 secs
	SRCFILE "minty.bas",5446
	;[5447] 
	SRCFILE "minty.bas",5447
	;[5448]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5448
	DECLE 16191,63
	;[5449]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5449
	DECLE 0,0
	;[5450]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5450
	DECLE 0,0
	;[5451]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5451
	DECLE 0,0
	;[5452]     MUSIC   F6,   F4,   F5
	SRCFILE "minty.bas",5452
	DECLE 40630,170
	;[5453]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5453
	DECLE 16191,63
	;[5454]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5454
	DECLE 63,0
	;[5455]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5455
	DECLE 0,0
	;[5456]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5456
	DECLE 0,0
	;[5457]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5457
	DECLE 0,0
	;[5458]     MUSIC   F6,   F4,   F5
	SRCFILE "minty.bas",5458
	DECLE 40630,170
	;[5459]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5459
	DECLE 16191,63
	;[5460]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5460
	DECLE 63,63
	;[5461]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5461
	DECLE 0,63
	;[5462]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5462
	DECLE 0,63
	;[5463]     MUSIC   F5,   F2,   F4
	SRCFILE "minty.bas",5463
	DECLE 34474,158
	;[5464]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5464
	DECLE 16191,63
	;[5465]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5465
	DECLE 16191,63
	;[5466]     MUSIC  A5#,  A2#,  A4#
	SRCFILE "minty.bas",5466
	DECLE 35759,163
	;[5467]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5467
	DECLE 16191,63
	;[5468]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5468
	DECLE 16191,63
	;[5469]     MUSIC  C6#,  C3#,  C5#
	SRCFILE "minty.bas",5469
	DECLE 36530,166
	;[5470]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5470
	DECLE 16191,63
	;[5471]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5471
	DECLE 16191,63
	;[5472]     MUSIC   F6,   F3,   F5
	SRCFILE "minty.bas",5472
	DECLE 37558,170
	;[5473]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5473
	DECLE 16191,63
	;[5474]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5474
	DECLE 16191,63
	;[5475]     MUSIC   E6,   E3,   E5
	SRCFILE "minty.bas",5475
	DECLE 37301,169
	;[5476]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5476
	DECLE 16191,63
	;[5477]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5477
	DECLE 16191,0
	;[5478]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5478
	DECLE 16128,0
	;[5479]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5479
	DECLE 16128,0
	;[5480]     MUSIC   E6,    S,   E5
	SRCFILE "minty.bas",5480
	DECLE 16309,169
	;[5481]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5481
	DECLE 16191,63
	;[5482]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5482
	DECLE 16191,0
	;[5483]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5483
	DECLE 16128,0
	;[5484]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5484
	DECLE 16128,0
	;[5485]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5485
	DECLE 16128,0
	;[5486]     MUSIC   E6,    S,   E5
	SRCFILE "minty.bas",5486
	DECLE 16309,169
	;[5487]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5487
	DECLE 16191,63
	;[5488]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5488
	DECLE 16191,0
	;[5489]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5489
	DECLE 16128,0
	;[5490]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5490
	DECLE 16128,0
	;[5491]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5491
	DECLE 16128,0
	;[5492]     MUSIC   E6,    S,   E5
	SRCFILE "minty.bas",5492
	DECLE 16309,169
	;[5493]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5493
	DECLE 16191,63
	;[5494]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5494
	DECLE 16128,0
	;[5495]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5495
	DECLE 16128,0
	;[5496]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5496
	DECLE 16128,0
	;[5497]     MUSIC   E6,  F4#,   E5
	SRCFILE "minty.bas",5497
	DECLE 40885,169
	;[5498] 
	SRCFILE "minty.bas",5498
	;[5499] REM Timing 8200 frames, 164.00 secs
	SRCFILE "minty.bas",5499
	;[5500] 
	SRCFILE "minty.bas",5500
	;[5501]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5501
	DECLE 16191,63
	;[5502]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5502
	DECLE 63,0
	;[5503]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5503
	DECLE 0,0
	;[5504]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5504
	DECLE 0,0
	;[5505]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5505
	DECLE 0,0
	;[5506]     MUSIC   E6,  F4#,   E5
	SRCFILE "minty.bas",5506
	DECLE 40885,169
	;[5507]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5507
	DECLE 16191,63
	;[5508]     MUSIC    S,    -,    -
	SRCFILE "minty.bas",5508
	DECLE 63,0
	;[5509]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5509
	DECLE 0,0
	;[5510]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5510
	DECLE 0,0
	;[5511]     MUSIC  F5#,  F2#,  F4#
	SRCFILE "minty.bas",5511
	DECLE 34731,159
	;[5512]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5512
	DECLE 16191,63
	;[5513]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5513
	DECLE 16191,63
	;[5514]     MUSIC  A5#,  A2#,  A4#
	SRCFILE "minty.bas",5514
	DECLE 35759,163
	;[5515]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5515
	DECLE 16191,63
	;[5516]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5516
	DECLE 16191,63
	;[5517]     MUSIC  C6#,  C3#,  C5#
	SRCFILE "minty.bas",5517
	DECLE 36530,166
	;[5518]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5518
	DECLE 16191,63
	;[5519]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5519
	DECLE 16191,63
	;[5520]     MUSIC   E6,   E3,   E5
	SRCFILE "minty.bas",5520
	DECLE 37301,169
	;[5521]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5521
	DECLE 16191,63
	;[5522]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5522
	DECLE 16191,63
	;[5523]     MUSIC  D6#,  D3#,  D5#
	SRCFILE "minty.bas",5523
	DECLE 37044,168
	;[5524]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5524
	DECLE 16191,63
	;[5525]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5525
	DECLE 16191,63
	;[5526]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5526
	DECLE 16128,63
	;[5527]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5527
	DECLE 16128,63
	;[5528]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5528
	DECLE 16128,63
	;[5529]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5529
	DECLE 16128,63
	;[5530]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5530
	DECLE 16128,63
	;[5531]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5531
	DECLE 16128,63
	;[5532]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5532
	DECLE 16128,63
	;[5533]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5533
	DECLE 16128,63
	;[5534]     MUSIC   C6,    S,  D5#
	SRCFILE "minty.bas",5534
	DECLE 16305,168
	;[5535]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5535
	DECLE 16191,63
	;[5536]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5536
	DECLE 16191,63
	;[5537]     MUSIC    -,    -,    S
	SRCFILE "minty.bas",5537
	DECLE 0,63
	;[5538]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5538
	DECLE 0,0
	;[5539]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5539
	DECLE 0,0
	;[5540]     MUSIC  A5#,  A4#,  C5#
	SRCFILE "minty.bas",5540
	DECLE 41903,166
	;[5541]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5541
	DECLE 16191,63
	;[5542]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5542
	DECLE 0,0
	;[5543]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5543
	DECLE 0,0
	;[5544]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5544
	DECLE 0,0
	;[5545]     MUSIC  C6#,   F3,   F5
	SRCFILE "minty.bas",5545
	DECLE 37554,170
	;[5546]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5546
	DECLE 16191,63
	;[5547]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5547
	DECLE 0,0
	;[5548]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5548
	DECLE 0,0
	;[5549]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5549
	DECLE 0,0
	;[5550]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5550
	DECLE 0,0
	;[5551] 
	SRCFILE "minty.bas",5551
	;[5552] REM Timing 8300 frames, 166.00 secs
	SRCFILE "minty.bas",5552
	;[5553] 
	SRCFILE "minty.bas",5553
	;[5554]     MUSIC  C6#,   F3,   F5
	SRCFILE "minty.bas",5554
	DECLE 37554,170
	;[5555]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5555
	DECLE 16191,63
	;[5556]     MUSIC    S,    S,    S
	SRCFILE "minty.bas",5556
	DECLE 16191,63
	;[5557]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5557
	DECLE 16128,63
	;[5558]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5558
	DECLE 16128,63
	;[5559]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5559
	DECLE 16128,0
	;[5560]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5560
	DECLE 16128,0
	;[5561]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5561
	DECLE 16128,0
	;[5562]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5562
	DECLE 16128,0
	;[5563]     MUSIC    -,    S,    -
	SRCFILE "minty.bas",5563
	DECLE 16128,0
	;[5564]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5564
	DECLE 0,0
	;[5565]     MUSIC  A3#,    -,  A4#
	SRCFILE "minty.bas",5565
	DECLE 151,163
	;[5566]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5566
	DECLE 63,63
	;[5567]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5567
	DECLE 63,63
	;[5568]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5568
	DECLE 63,63
	;[5569]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5569
	DECLE 63,63
	;[5570]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5570
	DECLE 63,63
	;[5571]     MUSIC  A2#,    -,    S
	SRCFILE "minty.bas",5571
	DECLE 139,63
	;[5572]     MUSIC    -,  A2#,    S
	SRCFILE "minty.bas",5572
	DECLE 35584,63
	;[5573]     MUSIC    -,    S,    S
	SRCFILE "minty.bas",5573
	DECLE 16128,63
	;[5574]     MUSIC  A2#,    -,    S
	SRCFILE "minty.bas",5574
	DECLE 139,63
	;[5575]     MUSIC    S,  A2#,    S
	SRCFILE "minty.bas",5575
	DECLE 35647,63
	;[5576]     MUSIC  A2#,    -,    S
	SRCFILE "minty.bas",5576
	DECLE 139,63
	;[5577]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5577
	DECLE 63,63
	;[5578]     MUSIC    -,  A2#,    S
	SRCFILE "minty.bas",5578
	DECLE 35584,63
	;[5579]     MUSIC  A2#,    -,    S
	SRCFILE "minty.bas",5579
	DECLE 139,63
	;[5580]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5580
	DECLE 63,63
	;[5581]     MUSIC    -,  A2#,    S
	SRCFILE "minty.bas",5581
	DECLE 35584,63
	;[5582]     MUSIC   E2,  A2#,    -
	SRCFILE "minty.bas",5582
	DECLE 35717,0
	;[5583]     MUSIC    S,    S,  A2#
	SRCFILE "minty.bas",5583
	DECLE 16191,139
	;[5584]     MUSIC   E2,    -,    S
	SRCFILE "minty.bas",5584
	DECLE 133,63
	;[5585]     MUSIC    S,  A2#,    -
	SRCFILE "minty.bas",5585
	DECLE 35647,0
	;[5586]     MUSIC   E2,    -,  A2#
	SRCFILE "minty.bas",5586
	DECLE 133,139
	;[5587]     MUSIC    S,    -,    S
	SRCFILE "minty.bas",5587
	DECLE 63,63
	;[5588]     MUSIC  A2#,   E2,    -
	SRCFILE "minty.bas",5588
	DECLE 34187,0
	;[5589]     MUSIC    -,   E2,  A2#
	SRCFILE "minty.bas",5589
	DECLE 34048,139
	;[5590]     MUSIC  A2#,    S,    S
	SRCFILE "minty.bas",5590
	DECLE 16267,63
	;[5591]     MUSIC    S,   E2,    -
	SRCFILE "minty.bas",5591
	DECLE 34111,0
	;[5592]     MUSIC    -,    S,  A2#
	SRCFILE "minty.bas",5592
	DECLE 16128,139
	;[5593]     MUSIC  A6#,  A5#,    -
	SRCFILE "minty.bas",5593
	DECLE 44987,0
	;[5594]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5594
	DECLE 16191,0
	;[5595]     MUSIC    S,    S,    -
	SRCFILE "minty.bas",5595
	DECLE 16191,0
	;[5596]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5596
	DECLE 0,0
	;[5597]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5597
	DECLE 0,0
	;[5598]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5598
	DECLE 0,0
	;[5599]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5599
	DECLE 0,0
	;[5600]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5600
	DECLE 0,0
	;[5601]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5601
	DECLE 0,0
	;[5602]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5602
	DECLE 0,0
	;[5603]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5603
	DECLE 0,0
	;[5604]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5604
	DECLE 0,0
	;[5605]     MUSIC    -,    -,    -
	SRCFILE "minty.bas",5605
	DECLE 0,0
	;[5606]     MUSIC REPEAT
	SRCFILE "minty.bas",5606
	DECLE 253,0
	;[5607] 
	SRCFILE "minty.bas",5607
	;[5608] 
	SRCFILE "minty.bas",5608
	;[5609] ASM ORG $6000
	SRCFILE "minty.bas",5609
 ORG $6000
	;ENDFILE
	SRCFILE "",0
intybasic_music:	equ 1	; Forces to include music library
        ;
        ; Epilogue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Moved GRAM code below MOB updates.
        ;                        Added comments.
        ; Revision: Feb/26/2014. Optimized access to collision registers
        ;                        per DZ-Jay suggestion. Added scrolling
        ;                        routines with optimization per intvnut
        ;                        suggestion. Added border/mask support.
        ; Revision: Apr/02/2014. Added support to set MODE (color stack
        ;                        or foreground/background), added support
        ;                        for SCREEN statement.
        ; Revision: Aug/19/2014. Solved bug in bottom scroll, moved an
        ;                        extra unneeded line.
        ; Revision: Aug/26/2014. Integrated music player and NTSC/PAL
        ;                        detection.
        ; Revision: Oct/24/2014. Adjust in some comments.
        ; Revision: Nov/13/2014. Integrated Joseph Zbiciak's routines
        ;                        for printing numbers.
        ; Revision: Nov/17/2014. Redesigned MODE support to use a single
        ;                        variable.
        ; Revision: Nov/21/2014. Added Intellivoice support routines made
        ;                        by Joseph Zbiciak.
	; Revision: Dec/11/2014. Optimized keypad decode routines.
	; Revision: Jan/25/2015. Added marker for insertion of ON FRAME GOSUB
	; Revision: Feb/17/2015. Allows to deactivate music player (PLAY NONE)
	; Revision: Apr/21/2015. Accelerates common case of keypad not pressed.
	;                        Added ECS ROM disable code.
	; Revision: Apr/22/2015. Added Joseph Zbiciak accelerated multiplication
	;                        routines.
	; Revision: Jun/04/2015. Optimized play_music (per GroovyBee suggestion)
	; Revision: Jul/25/2015. Added infinite loop at start to avoid crashing
	;                        with empty programs. Solved bug where _color
	;                        didn't started with white.
	; Revision: Aug/20/2015. Moved ECS mapper disable code so nothing gets
	;                        after it (GroovyBee 42K sample code)
	; Revision: Aug/21/2015. Added Joseph Zbiciak routines for JLP Flash
	;                        handling.
	; Revision: Aug/31/2015. Added CPYBLK2 for SCREEN fifth argument.
	; Revision: Sep/01/2015. Defined labels Q1 and Q2 as alias.
	; Revision: Jan/22/2016. Music player allows not to use noise channel
	;                        for drums. Allows setting music volume.
	; Revision: Jan/23/2016. Added jump inside of music (for MUSIC JUMP)
	; Revision: May/03/2016. Preserves current mode in bit 0 of _mode_select
        ; Revision: Oct/21/2016. Added C7 in notes table, it was missing. (thanks
        ;                        mmarrero)

	;
	; Avoids empty programs to crash
	; 
stuck:	B stuck

	;
	; Copy screen helper for SCREEN wide statement
	;

CPYBLK2:	PROC
	MOVR R0,R3		; Offset
	MOVR R5,R2
	PULR R0
	PULR R1
	PULR R5
	PULR R4
	PSHR R2
	SUBR R1,R3

@@1:    PSHR R3
        MOVR R1,R3              ; Init line copy
@@2:    MVI@ R4,R2              ; Copy line
        MVO@ R2,R5
        DECR R3
        BNE @@2
        PULR R3                 ; Add offset to start in next line
        ADDR R3,R4
	SUBR R1,R5
        ADDI #20,R5
        DECR R0                 ; Count lines
        BNE @@1

	RETURN
	ENDP

        ;
        ; Copy screen helper for SCREEN statement
        ;
CPYBLK: PROC
        BEGIN
        MOVR R3,R4
        MOVR R2,R5

@@1:    MOVR R1,R3              ; Init line copy
@@2:    MVI@ R4,R2              ; Copy line
        MVO@ R2,R5
        DECR R3
        BNE @@2
        MVII #20,R3             ; Add offset to start in next line
        SUBR R1,R3
        ADDR R3,R4
        ADDR R3,R5
        DECR R0                 ; Count lines
        BNE @@1
	RETURN
        ENDP

        ;
        ; Wait for interruption
        ;
_wait:  PROC

    IF DEFINED intybasic_keypad
        MVI $01FF,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt1_p0,R0
        BNE @@2
        CMP _cnt1_p1,R0
        BNE @@2
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@4
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@4
	CMP@ R4,R0
        BEQ @@4
    ENDR
	INCR R4
@@4:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt1_key

@@2:    MVI _cnt1_p1,R1
        MVO R1,_cnt1_p0
        MVO R0,_cnt1_p1

        MVI $01FE,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt2_p0,R0
        BNE @@5
        CMP _cnt2_p1,R0
        BNE @@5
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@7
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@7
	CMP@ R4,R0
	BEQ @@7
    ENDR

	INCR R4
@@7:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt2_key

@@5:    MVI _cnt2_p1,R1
        MVO R1,_cnt2_p0
        MVO R0,_cnt2_p1
    ENDI

        CLRR    R0
        MVO     R0,_int         ; Clears waiting flag
@@1:    CMP     _int,  R0       ; Waits for change
        BEQ     @@1
        JR      R5              ; Returns
        ENDP

        ;
        ; Keypad table
        ;
_keypad_table:          PROC
        DECLE $48,$81,$41,$21,$82,$42,$22,$84,$44,$24,$88,$28
        ENDP

_pal1_vector:    PROC
        MVII #_pal2_vector,R0
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #3,R0
        MVO R0,_ntsc
        JR R5
        ENDP

_pal2_vector:    PROC
        MVII #_int_vector,R0     ; Point to "real" interruption handler
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #4,R0
        MVO R0,_ntsc
	CLRR R0
	CLRR R4
	MVII #$18,R1
@@1:	MVO@ R0,R4
	DECR R1
	BNE @@1
        JR R5
        ENDP

        ;
        ; Interruption routine
        ;
_int_vector:     PROC
        BEGIN

        MVO     R0,     $20     ; Activates display

    IF DEFINED intybasic_stack
	CMPI #$308,R6
	BNC @@vs
	MVI $21,R0	; Activates Color Stack mode
	CLRR R0
	MVO R0,$28
	MVO R0,$29
	MVO R0,$2A
	MVO R0,$2B
	MVII #@@vs1,R4
	MVII #$200,R5
	MVII #20,R1
@@vs2:	MVI@ R4,R0
	MVO@ R0,R5
	DECR R1
	BNE @@vs2
	RETURN

	; Stack Overflow message
@@vs1:	DECLE 0,0,0,$33*8+7,$54*8+7,$41*8+7,$43*8+7,$4B*8+7,$00*8+7
	DECLE $4F*8+7,$56*8+7,$45*8+7,$52*8+7,$46*8+7,$4C*8+7
	DECLE $4F*8+7,$57*8+7,0,0,0

@@vs:
    ENDI
        MVII    #1,     R0
        MVO     R0,     _int    ; Indicates interrupt happened

        MVI _mode_select,R0
        SARC R0,2
        BNOV @@vi0
	CLRR R1
        BNC @@vi14
        MVO R0,$21  ; Activates Foreground/Background mode
        INCR R1
	B @@vi15

@@vi14: MVI $21,R0  ; Activates Color Stack mode
        MVI _color,R0
        MVO R0,$28
        SWAP R0
        MVO R0,$29
        SLR R0,2
        SLR R0,2
        MVO R0,$2A
        SWAP R0
        MVO R0,$2B
@@vi15: MVO R1,_mode_select
	MVII #7,R0
        MVO R0,_color           ; Default color for PRINT "string"
@@vi0:
        MVI _border_color,R0
        MVO     R0,     $2C     ; Border color
        MVI _border_mask,R0
        MVO     R0,     $32     ; Border mask
        ;
        ; Save collision registers for further use and clear them
        ;
        MVII #$18,R4
        MVII #_col0,R5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col0
        MVI@ R4,R0
        MVO@ R0,R5  ; _col1
        MVI@ R4,R0
        MVO@ R0,R5  ; _col2
        MVI@ R4,R0
        MVO@ R0,R5  ; _col3
        MVI@ R4,R0
        MVO@ R0,R5  ; _col4
        MVI@ R4,R0
        MVO@ R0,R5  ; _col5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col6
        MVI@ R4,R0
        MVO@ R0,R5  ; _col7
        MVII #$18,R5
        CLRR R0
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        
    IF DEFINED intybasic_scroll

        ;
        ; Scrolling things
        ;
        MVI _scroll_x,R0
        MVO R0,$30
        MVI _scroll_y,R0
        MVO R0,$31
    ENDI

        ;
        ; Updates sprites (MOBs)
        ;
        MVII #_mobs,R4
        MVII #$0,R5     ; X-coordinates
        MVII #8,R1
@@vi2:  MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        DECR R1
        BNE @@vi2

    IF DEFINED intybasic_music
     	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo97      ; Yes, always emit sound
	MVI _music_frame,R0
	INCR R0
	CMPI #6,R0
	BNE @@vo14
	CLRR R0
@@vo14:	MVO R0,_music_frame
	BEQ @@vo15
@@vo97:	CALL _emit_sound
@@vo15:
    ENDI

        ;
        ; Detect GRAM definition
        ;
        MVI _gram_bitmap,R4
        TSTR R4
        BEQ @@vi1
        MVI _gram_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram_total,R0
@@vi3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vi3
        MVO R0,_gram_bitmap
@@vi1:
        MVI _gram2_bitmap,R4
        TSTR R4
        BEQ @@vii1
        MVI _gram2_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram2_total,R0
@@vii3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vii3
        MVO R0,_gram2_bitmap
@@vii1:

    IF DEFINED intybasic_scroll
        ;
        ; Frame scroll support
        ;
        MVI _scroll_d,R0
        TSTR R0
        BEQ @@vi4
        CLRR R1
        MVO R1,_scroll_d
        DECR R0     ; Left
        BEQ @@vi5
        DECR R0     ; Right
        BEQ @@vi6
        DECR R0     ; Top
        BEQ @@vi7
        DECR R0     ; Bottom
        BEQ @@vi8
        B @@vi4

@@vi5:  MVII #$0200,R4
        MOVR R4,R5
        INCR R5
        MVII #12,R1
@@vi12: MVI@ R4,R2
        MVI@ R4,R3
        REPEAT 8
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVI@ R4,R3
        ENDR
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVO@ R2,R5
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi12
        B @@vi4

@@vi6:  MVII #$0201,R4
        MVII #$0200,R5
        MVII #12,R1
@@vi11:
        REPEAT 19
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi11
        B @@vi4
    
        ;
        ; Complex routine to be ahead of STIC display
        ; Moves first the top 6 lines, saves intermediate line
        ; Then moves the bottom 6 lines and restores intermediate line
        ;
@@vi7:  MVII #$0264,R4
        MVII #5,R1
        MVII #_scroll_buffer,R5
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        MOVR R4,R5
        ADDI #20,R5
@@vi10:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi10
        MVII #$02C8,R4
        MVII #$02DC,R5
        MVII #5,R1
@@vi13:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi13
        MVII #_scroll_buffer,R4
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        B @@vi4

@@vi8:  MVII #$0214,R4
        MVII #$0200,R5
        MVII #$DC/4,R1
@@vi9:  
        REPEAT 4
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        DECR R1
        BNE @@vi9
        B @@vi4

@@vi4:
    ENDI

    IF DEFINED intybasic_voice
        ;
        ; Intellivoice support
        ;
        CALL IV_ISR
    ENDI

        ;
        ; Random number generator
        ;
	CALL _next_random

    IF DEFINED intybasic_music
	; Generate sound for next frame
       	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo98      ; Yes, always generate sound
	MVI _music_frame,R0
	TSTR R0
	BEQ @@vo16
@@vo98: CALL _generate_music
@@vo16:
    ENDI

        ; Increase frame number
        MVI _frame,R0
        INCR R0
        MVO R0,_frame

	; This mark is for ON FRAME GOSUB support

        RETURN
        ENDP

	;
	; Generates the next random number
	;
_next_random:	PROC

MACRO _ROR
	RRC R0,1
	MOVR R0,R2
	SLR R2,2
	SLR R2,2
	ANDI #$0800,R2
	SLR R2,2
	SLR R2,2
	ANDI #$007F,R0
	XORR R2,R0
ENDM
        MVI _rand,R0
        SETC
        _ROR
        XOR _frame,R0
        _ROR
        XOR _rand,R0
        _ROR
        XORI #9,R0
        MVO R0,_rand
	JR R5
	ENDP

    IF DEFINED intybasic_music

        ;
        ; Music player, comes from my game Princess Quest for Intellivision
        ; so it's a practical tracker used in a real game ;) and with enough
        ; features.
        ;

        ; NTSC frequency for notes (based on 3.579545 mhz)
ntsc_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octave 2 - 1
        DECLE 1721,1621,1532,1434,1364,1286,1216,1141,1076,1017,956,909
        ; Octave 3 - 13
        DECLE 854,805,761,717,678,639,605,571,538,508,480,453
        ; Octave 4 - 25
        DECLE 427,404,380,360,339,321,302,285,270,254,240,226
        ; Octave 5 - 37
        DECLE 214,202,191,180,170,160,151,143,135,127,120,113
        ; Octave 6 - 49
        DECLE 107,101,95,90,85,80,76,71,67,64,60,57
        ; Octave 7 - 61
        DECLE 54
        ; Space for two notes more
	ENDP

        ; PAL frequency for notes (based on 4 mhz)
pal_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octava 2 - 1
        DECLE 1923,1812,1712,1603,1524,1437,1359,1276,1202,1136,1068,1016
        ; Octava 3 - 13
        DECLE 954,899,850,801,758,714,676,638,601,568,536,506
        ; Octava 4 - 25
        DECLE 477,451,425,402,379,358,338,319,301,284,268,253
        ; Octava 5 - 37
        DECLE 239,226,213,201,190,179,169,159,150,142,134,127
        ; Octava 6 - 49
        DECLE 120,113,106,100,95,89,84,80,75,71,67,63
        ; Octava 7 - 61
        DECLE 60
        ; Space for two notes more
	ENDP
    ENDI

        ;
        ; Music tracker init
        ;
_init_music:	PROC
    IF DEFINED intybasic_music
        MVI _ntsc,R0
        CMPI #1,R0
        MVII #ntsc_note_table,R0
        BEQ @@0
        MVII #pal_note_table,R0
@@0:    MVO R0,_music_table
        MVII #$38,R0	; $B8 blocks controllers o.O!
	MVO R0,_music_mix
        CLRR R0
    ELSE
	JR R5
    ENDI
	ENDP

    IF DEFINED intybasic_music
        ;
        ; Start music
        ; R0 = Pointer to music
        ;
_play_music:	PROC
	MOVR R0,R2
        MVII #1,R0
	MOVR R0,R3
	TSTR R2
	BEQ @@1
	MVI@ R2,R3
	INCR R2
@@1:	MVO R2,_music_start
	MVO R2,_music_p
	MVO R3,_music_t
	MVO R0,_music_tc
        JR R5

	ENDP

        ;
        ; Generate music
        ;
_generate_music:	PROC
	BEGIN
	MVI _music_mix,R0
	ANDI #$C0,R0
	XORI #$38,R0
	MVO R0,_music_mix
	CLRR R1			; Turn off volume for the three sound channels
	MVO R1,_music_vol1
	MVO R1,_music_vol2
	NOP
	MVO R1,_music_vol3
	MVI _music_tc,R3
	DECR R3
	MVO R3,_music_tc
	BNE @@6
	; R3 is zero from here up to @@6
	MVI _music_p,R4
@@15:	TSTR R4		; Silence?
	BEQ @@000	; Keep quiet
	MVI@ R4,R0
	MVI@ R4,R1
	MVI _music_t,R2
        CMPI #$FE,R0	; The end?
	BEQ @@001       ; Keep quiet
	CMPI #$FD,R0	; Repeat?
	BNE @@00
	MVI _music_start,R4
	B @@15

@@001:	MOVR R1,R4	; Jump, zero will make it quiet
	B @@15

@@000:  MVII #1,R0
        MVO R0,_music_tc
        B @@0
        
@@00: 	MVO R2,_music_tc    ; Restart note time
     	MVO R4,_music_p
     	
	MOVR R0,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@1
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n1	; Note
	MVO R3,_music_s1	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i1	; Instrument
	
@@1:	MOVR R0,R2
	SWAP R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@2
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n2	; Note
	MVO R3,_music_s2	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i2	; Instrument
	
@@2:	MOVR R1,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@3
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n3	; Note
	MVO R3,_music_s3	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i3	; Instrument
	
@@3:	MOVR R1,R2
	SWAP R2
	MVO R2,_music_n4
	MVO R3,_music_s4
	
        ;
        ; Construct main voice
        ;
@@6:	MVI _music_n1,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@7		; No, jump
	MVI _music_s1,R1
	MVI _music_i1,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq10	; Note in voice A
	SWAP R3
	MVO R3,_music_freq11
	MVO R1,_music_vol1
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@20
	SUBI #$08,R0
@@20:	MVO R0,_music_s1

@@7:	MVI _music_n2,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@8		; No, jump
	MVI _music_s2,R1
	MVI _music_i2,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq20	; Note in voice B
	SWAP R3
	MVO R3,_music_freq21
	MVO R1,_music_vol2
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@21
	SUBI #$08,R0
@@21:	MVO R0,_music_s2

@@8:	MVI _music_n3,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@9		; No, jump
	MVI _music_s3,R1
	MVI _music_i3,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq30	; Note in voice C
	SWAP R3
	MVO R3,_music_freq31
	MVO R1,_music_vol3
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@22
	SUBI #$08,R0
@@22:	MVO R0,_music_s3

@@9:	MVI _music_n4,R0	; Read drum
	DECR R0		; There is drum?
	BMI @@4		; No, jump
	MVI _music_s4,R1
	       		; 1 - Strong
	BNE @@5
	CMPI #3,R1
	BGE @@12
@@10:	MVII #5,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@5:	DECR R0		;2 - Short
	BNE @@11
	TSTR R1
	BNE @@12
	MVII #8,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@11:	;DECR R0	; 3 - Rolling
	;BNE @@12
	CMPI #2,R1
	BLT @@10
	MVI _music_t,R0
	SLR R0,1
	CMPR R0,R1
	BLT @@12
        ADDI #2,R0
	CMPR R0,R1
	BLT @@10
        ; Increase time for drum waveform
@@12:   INCR R1
	MVO R1,_music_s4
@@4:
@@0:	RETURN
	ENDP

        ;
	; Translates note number to frequency
        ; R3 = Note
        ; R1 = Position in waveform for instrument
        ; R2 = Instrument
        ;
_note2freq:	PROC
        ADD _music_table,R3
	MVI@ R3,R3
        SWAP R2
	BEQ _piano_instrument
	RLC R2,1
	BNC _clarinet_instrument
	BPL _flute_instrument
;	BMI _bass_instrument
	ENDP

        ;
        ; Generates a bass
        ;
_bass_instrument:	PROC
	SLL R3,2	; Lower 2 octaves
	ADDI #_bass_volume,R1
	MVI@ R1,R1	; Bass effect
    IF DEFINED intybasic_music_volume
	B _global_volume
    ELSE
	JR R5
    ENDI
	ENDP

_bass_volume:	PROC
        DECLE 12,13,14,14,13,12,12,12
        DECLE 11,11,12,12,11,11,12,12
	DECLE 11,11,12,12,11,11,12,12
	ENDP

        ;
        ; Generates a piano
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency.
        ; R1 = Volume.
        ;
_piano_instrument:	PROC
	ADDI #_piano_volume,R1
	MVI@ R1,R1
    IF DEFINED intybasic_music_volume
	B _global_volume
    ELSE
	JR R5
    ENDI
	ENDP

_piano_volume:	PROC
        DECLE 14,13,13,12,12,11,11,10
        DECLE 10,9,9,8,8,7,7,6
        DECLE 6,6,7,7,6,6,5,5
	ENDP

        ;
        ; Generate a clarinet
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_clarinet_instrument:	PROC
	ADDI #_clarinet_vibrato,R1
	ADD@ R1,R3
	CLRC
	RRC R3,1	; Duplicates frequency
	ADCR R3
        ADDI #_clarinet_volume-_clarinet_vibrato,R1
	MVI@ R1,R1
    IF DEFINED intybasic_music_volume
	B _global_volume
    ELSE
	JR R5
    ENDI
	ENDP

_clarinet_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
	ENDP

_clarinet_volume:	PROC
        DECLE 13,14,14,13,13,12,12,12
        DECLE 11,11,11,11,12,12,12,12
        DECLE 11,11,11,11,12,12,12,12
	ENDP

        ;
        ; Generates a flute
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_flute_instrument:	PROC
	ADDI #_flute_vibrato,R1
	ADD@ R1,R3
	ADDI #_flute_volume-_flute_vibrato,R1
	MVI@ R1,R1
    IF DEFINED intybasic_music_volume
	B _global_volume
    ELSE
	JR R5
    ENDI
	ENDP

_flute_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
	ENDP
                 
_flute_volume:	PROC
        DECLE 10,12,13,13,12,12,12,12
        DECLE 11,11,11,11,10,10,10,10
        DECLE 11,11,11,11,10,10,10,10
	ENDP

    IF DEFINED intybasic_music_volume

_global_volume:	PROC
	MVI _music_vol,R2
	ANDI #$0F,R2
	SLL R2,2
	SLL R2,2
	ADDR R1,R2
	ADDI #@@table,R2
	MVI@ R2,R1
	JR R5

@@table:
	DECLE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	DECLE 0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1
	DECLE 0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,2
	DECLE 0,0,0,1,1,1,1,1,2,2,2,2,2,3,3,3
	DECLE 0,0,1,1,1,1,2,2,2,2,3,3,3,4,4,4
	DECLE 0,0,1,1,1,2,2,2,3,3,3,4,4,4,5,5
	DECLE 0,0,1,1,2,2,2,3,3,4,4,4,5,5,6,6
	DECLE 0,1,1,1,2,2,3,3,4,4,5,5,6,6,7,7
	DECLE 0,1,1,2,2,3,3,4,4,5,5,6,6,7,8,8
	DECLE 0,1,1,2,2,3,4,4,5,5,6,7,7,8,8,9
	DECLE 0,1,1,2,3,3,4,5,5,6,7,7,8,9,9,10
	DECLE 0,1,2,2,3,4,4,5,6,7,7,8,9,10,10,11
	DECLE 0,1,2,2,3,4,5,6,6,7,8,9,10,10,11,12
	DECLE 0,1,2,3,4,4,5,6,7,8,9,10,10,11,12,13
	DECLE 0,1,2,3,4,5,6,7,8,8,9,10,11,12,13,14
	DECLE 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15

	ENDP

    ENDI

        ;
        ; Emits sound
        ;
_emit_sound:	PROC
        MOVR R5,R1
	MVI _music_mode,R2
	SARC R2,1
	BEQ @@6
	MVII #_music_freq10,R4
	MVII #$01F0,R5
        MVI@ R4,R0
	MVO@ R0,R5	; $01F0 - Channel A Period (Low 8 bits of 12)
        MVI@ R4,R0
	MVO@ R0,R5	; $01F1 - Channel B Period (Low 8 bits of 12)
	DECR R2
	BEQ @@1
        MVI@ R4,R0	
	MVO@ R0,R5	; $01F2 - Channel C Period (Low 8 bits of 12)
	INCR R5		; Avoid $01F3 - Enveloped Period (Low 8 bits of 16)
        MVI@ R4,R0
	MVO@ R0,R5	; $01F4 - Channel A Period (High 4 bits of 12)
        MVI@ R4,R0
	MVO@ R0,R5	; $01F5 - Channel B Period (High 4 bits of 12)
        MVI@ R4,R0
	MVO@ R0,R5	; $01F6 - Channel C Period (High 4 bits of 12)
	INCR R5		; Avoid $01F7 - Envelope Period (High 8 bits of 16)
	BC @@2		; Jump if playing with drums
	ADDI #2,R4
	ADDI #3,R5
	B @@3

@@2:	MVI@ R4,R0
	MVO@ R0,R5	; $01F8 - Enable Noise/Tone (bits 3-5 Noise : 0-2 Tone)
        MVI@ R4,R0	
	MVO@ R0,R5	; $01F9 - Noise Period (5 bits)
	INCR R5		; Avoid $01FA - Envelope Type (4 bits)
@@3:    MVI@ R4,R0
	MVO@ R0,R5	; $01FB - Channel A Volume
        MVI@ R4,R0
	MVO@ R0,R5	; $01FC - Channel B Volume
        MVI@ R4,R0
	MVO@ R0,R5	; $01FD - Channel C Volume
        JR R1

@@1:	INCR R4		
	ADDI #2,R5	; Avoid $01F2 and $01F3
        MVI@ R4,R0
	MVO@ R0,R5	; $01F4
        MVI@ R4,R0
	MVO@ R0,R5	; $01F5
	INCR R4
	ADDI #2,R5	; Avoid $01F6 and $01F7
	BC @@4		; Jump if playing with drums
	ADDI #2,R4
	ADDI #3,R5
	B @@5

@@4:	MVI@ R4,R0
	MVO@ R0,R5	; $01F8
        MVI@ R4,R0
	MVO@ R0,R5	; $01F9
	INCR R5		; Avoid $01FA
@@5:    MVI@ R4,R0
	MVO@ R0,R5	; $01FB
        MVI@ R4,R0
	MVO@ R0,R5	; $01FD
@@6:    JR R1
	ENDP

        ;
        ; Activates drum
        ;
_activate_drum:	PROC
    IF DEFINED intybasic_music_volume
	BEGIN
    ENDI
	MVI _music_mode,R2
	SARC R2,1	; PLAY NO DRUMS?
	BNC @@0		; Yes, jump
	MVI _music_vol1,R0
	TSTR R0
	BNE @@1
        MVII #11,R1
    IF DEFINED intybasic_music_volume
	CALL _global_volume
    ENDI
	MVO R1,_music_vol1
	MVI _music_mix,R0
	ANDI #$F6,R0
	XORI #$01,R0
	MVO R0,_music_mix
    IF DEFINED intybasic_music_volume
	RETURN
    ELSE
	JR R5
    ENDI

@@1:    MVI _music_vol2,R0
	TSTR R0
	BNE @@2
        MVII #11,R1
    IF DEFINED intybasic_music_volume
	CALL _global_volume
    ENDI
	MVO R1,_music_vol2
	MVI _music_mix,R0
	ANDI #$ED,R0
	XORI #$02,R0
	MVO R0,_music_mix
    IF DEFINED intybasic_music_volume
	RETURN
    ELSE
	JR R5
    ENDI

@@2:    DECR R2		; PLAY SIMPLE?
        BEQ @@3		; Yes, jump
        MVI _music_vol3,R0
	TSTR R0
	BNE @@3
        MVII #11,R1
    IF DEFINED intybasic_music_volume
	CALL _global_volume
    ENDI
	MVO R1,_music_vol3
	MVI _music_mix,R0
	ANDI #$DB,R0
	XORI #$04,R0
	MVO R0,_music_mix
    IF DEFINED intybasic_music_volume
	RETURN
    ELSE
	JR R5
    ENDI

@@3:    MVI _music_mix,R0
        ANDI #$EF,R0
	MVO R0,_music_mix
@@0:	
    IF DEFINED intybasic_music_volume
	RETURN
    ELSE
	JR R5
    ENDI

	ENDP

    ENDI
    
    IF DEFINED intybasic_numbers

	;
	; Following code from as1600 libraries, prnum16.asm
        ; Public domain by Joseph Zbiciak
	;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  _PW10                                                                   ;;
;;      Lookup table holding the first 5 powers of 10 (1 thru 10000) as     ;;
;;      16-bit numbers.                                                     ;;
;; ======================================================================== ;;
_PW10   PROC    ; 0 thru 10000
        DECLE   10000, 1000, 100, 10, 1, 0
        ENDP

;; ======================================================================== ;;
;;  PRNUM16.l     -- Print an unsigned 16-bit number left-justified.        ;;
;;  PRNUM16.b     -- Print an unsigned 16-bit number with leading blanks.   ;;
;;  PRNUM16.z     -- Print an unsigned 16-bit number with leading zeros.    ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak  <im14u2c AT globalcrossing DOT net>                 ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      30-Mar-2003 Initial complete revision                               ;;
;;                                                                          ;;
;;  INPUTS for all variants                                                 ;;
;;      R0  Number to print.                                                ;;
;;      R2  Width of field.  Ignored by PRNUM16.l.                          ;;
;;      R3  Format word, added to digits to set the color.                  ;;
;;          Note:  Bit 15 MUST be cleared when building with PRNUM32.       ;;
;;      R4  Pointer to location on screen to print number                   ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0  Zeroed                                                          ;;
;;      R1  Unmodified                                                      ;;
;;      R2  Unmodified                                                      ;;
;;      R3  Unmodified                                                      ;;
;;      R4  Points to first character after field.                          ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      These routines print unsigned 16-bit numbers in a field up to 5     ;;
;;      positions wide.  The number is printed either in left-justified     ;;
;;      or right-justified format.  Right-justified numbers are padded      ;;
;;      with leading blanks or leading zeros.  Left-justified numbers       ;;
;;      are not padded on the right.                                        ;;
;;                                                                          ;;
;;      This code handles fields wider than 5 characters, padding with      ;;
;;      zeros or blanks as necessary.                                       ;;
;;                                                                          ;;
;;              Routine      Value(hex)     Field        Output             ;;
;;              ----------   ----------   ----------   ----------           ;;
;;              PRNUM16.l      $0045         n/a        "69"                ;;
;;              PRNUM16.b      $0045          4         "  69"              ;;
;;              PRNUM16.b      $0045          6         "    69"            ;;
;;              PRNUM16.z      $0045          4         "0069"              ;;
;;              PRNUM16.z      $0045          6         "000069"            ;;
;;                                                                          ;;
;;  TECHNIQUES                                                              ;;
;;      This routine uses repeated subtraction to divide the number         ;;
;;      to display by various powers of 10.  This is cheaper than a         ;;
;;      full divide, at least when the input number is large.  It's         ;;
;;      also easier to get right.  :-)                                      ;;
;;                                                                          ;;
;;      The printing routine first pads out fields wider than 5 spaces      ;;
;;      with zeros or blanks as requested.  It then scans the power-of-10   ;;
;;      table looking for the first power of 10 that is <= the number to    ;;
;;      display.  While scanning for this power of 10, it outputs leading   ;;
;;      blanks or zeros, if requested.  This eliminates "leading digit"     ;;
;;      logic from the main digit loop.                                     ;;
;;                                                                          ;;
;;      Once in the main digit loop, we discover the value of each digit    ;;
;;      by repeated subtraction.  We build up our digit value while         ;;
;;      subtracting the power-of-10 repeatedly.  We iterate until we go     ;;
;;      a step too far, and then we add back on power-of-10 to restore      ;;
;;      the remainder.                                                      ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      The left-justified variant ignores field width.                     ;;
;;                                                                          ;;
;;      The code is fully reentrant.                                        ;;
;;                                                                          ;;
;;      This code does not handle numbers which are too large to be         ;;
;;      displayed in the provided field.  If the number is too large,       ;;
;;      non-digit characters will be displayed in the initial digit         ;;
;;      position.  Also, the run time of this routine may get excessively   ;;
;;      large, depending on the magnitude of the overflow.                  ;;
;;                                                                          ;;
;;      When using with PRNUM32, one must either include PRNUM32 before     ;;
;;      this function, or define the symbol _WITH_PRNUM32.  PRNUM32         ;;
;;      needs a tiny bit of support from PRNUM16 to handle numbers in       ;;
;;      the range 65536...99999 correctly.                                  ;;
;;                                                                          ;;
;;  CODESIZE                                                                ;;
;;      73 words, including power-of-10 table                               ;;
;;      80 words, if compiled with PRNUM32.                                 ;;
;;                                                                          ;;
;;      To save code size, you can define the following symbols to omit     ;;
;;      some variants:                                                      ;;
;;                                                                          ;;
;;          _NO_PRNUM16.l:   Disables PRNUM16.l.  Saves 10 words            ;;
;;          _NO_PRNUM16.b:   Disables PRNUM16.b.  Saves 3 words.            ;;
;;                                                                          ;;
;;      Defining both symbols saves 17 words total, because it omits        ;;
;;      some code shared by both routines.                                  ;;
;;                                                                          ;;
;;  STACK USAGE                                                             ;;
;;      This function uses up to 4 words of stack space.                    ;;
;; ======================================================================== ;;

PRNUM16 PROC

    
        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.l:  Print unsigned, left-justified.                     ;;
        ;; ---------------------------------------------------------------- ;;
@@l:    PSHR    R5              ; save return address
@@l1:   MVII    #$1,    R5      ; set R5 to 1 to counteract screen ptr update
                                ; in the 'find initial power of 10' loop
        PSHR    R2
        MVII    #5,     R2      ; force effective field width to 5.
        B       @@z2

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.b:  Print unsigned with leading blanks.                 ;;
        ;; ---------------------------------------------------------------- ;;
@@b:    PSHR    R5
@@b1:   CLRR    R5              ; let the blank loop do its thing
        INCR    PC              ; skip the PSHR R5

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.z:  Print unsigned with leading zeros.                  ;;
        ;; ---------------------------------------------------------------- ;;
@@z:    PSHR    R5
@@z1:   PSHR    R2
@@z2:   PSHR    R1

        ;; ---------------------------------------------------------------- ;;
        ;;  Find the initial power of 10 to use for display.                ;;
        ;;  Note:  For fields wider than 5, fill the extra spots above 5    ;;
        ;;  with blanks or zeros as needed.                                 ;;
        ;; ---------------------------------------------------------------- ;;
        MVII    #_PW10+5,R1     ; Point to end of power-of-10 table
        SUBR    R2,     R1      ; Subtract the field width to get right power
        PSHR    R3              ; save format word

        CMPI    #2,     R5      ; are we leading with zeros?
        BNC     @@lblnk         ; no:  then do the loop w/ blanks

        CLRR    R5              ; force R5==0
        ADDI    #$80,   R3      ; yes: do the loop with zeros
        B       @@lblnk
    

@@llp   MVO@    R3,     R4      ; print a blank/zero

        SUBR    R5,     R4      ; rewind pointer if needed.

        INCR    R1              ; get next power of 10
@@lblnk DECR    R2              ; decrement available digits
        BEQ     @@ldone
        CMPI    #5,     R2      ; field too wide?
        BGE     @@llp           ; just force blanks/zeros 'till we're narrower.
        CMP@    R1,     R0      ; Is this power of 10 too big?
        BNC     @@llp           ; Yes:  Put a blank and go to next

@@ldone PULR    R3              ; restore format word

        ;; ---------------------------------------------------------------- ;;
        ;;  The digit loop prints at least one digit.  It discovers digits  ;;
        ;;  by repeated subtraction.                                        ;;
        ;; ---------------------------------------------------------------- ;;
@@digit TSTR    R0              ; If the number is zero, print zero and leave
        BNEQ    @@dig1          ; no: print the number

        MOVR    R3,     R5      ;\    
        ADDI    #$80,   R5      ; |-- print a 0 there.
        MVO@    R5,     R4      ;/    
        B       @@done

@@dig1:
    
@@nxdig MOVR    R3,     R5      ; save display format word
@@cont: ADDI    #$80-8, R5      ; start our digit as one just before '0'
@@spcl:
 
        ;; ---------------------------------------------------------------- ;;
        ;;  Divide by repeated subtraction.  This divide is constructed     ;;
        ;;  to go "one step too far" and then back up.                      ;;
        ;; ---------------------------------------------------------------- ;;
@@div:  ADDI    #8,     R5      ; increment our digit
        SUB@    R1,     R0      ; subtract power of 10
        BC      @@div           ; loop until we go too far
        ADD@    R1,     R0      ; add back the extra power of 10.

        MVO@    R5,     R4      ; display the digit.

        INCR    R1              ; point to next power of 10
        DECR    R2              ; any room left in field?
        BPL     @@nxdig         ; keep going until R2 < 0.

@@done: PULR    R1              ; restore R1
        PULR    R2              ; restore R2
        PULR    PC              ; return

        ENDP
        
    ENDI

    IF DEFINED intybasic_voice
;;==========================================================================;;
;;  SP0256-AL2 Allophones                                                   ;;
;;                                                                          ;;
;;  This file contains the allophone set that was obtained from an          ;;
;;  SP0256-AL2.  It is being provided for your convenience.                 ;;
;;                                                                          ;;
;;  The directory "al2" contains a series of assembly files, each one       ;;
;;  containing a single allophone.  This series of files may be useful in   ;;
;;  situations where space is at a premium.                                 ;;
;;                                                                          ;;
;;  Consult the Archer SP0256-AL2 documentation (under doc/programming)     ;;
;;  for more information about SP0256-AL2's allophone library.              ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The allophone data below was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;; ------------------------------------------------------------------------ ;;
_AA:
    DECLE   _AA.end - _AA - 1
    DECLE   $0318, $014C, $016F, $02CE, $03AF, $015F, $01B1, $008E
    DECLE   $0088, $0392, $01EA, $024B, $03AA, $039B, $000F, $0000
_AA.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_AE1:
    DECLE   _AE1.end - _AE1 - 1
    DECLE   $0118, $038E, $016E, $01FC, $0149, $0043, $026F, $036E
    DECLE   $01CC, $0005, $0000
_AE1.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AO:
    DECLE   _AO.end - _AO - 1
    DECLE   $0018, $010E, $016F, $0225, $00C6, $02C4, $030F, $0160
    DECLE   $024B, $0005, $0000
_AO.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AR:
    DECLE   _AR.end - _AR - 1
    DECLE   $0218, $010C, $016E, $001E, $000B, $0091, $032F, $00DE
    DECLE   $018B, $0095, $0003, $0238, $0027, $01E0, $03E8, $0090
    DECLE   $0003, $01C7, $0020, $03DE, $0100, $0190, $01CA, $02AB
    DECLE   $00B7, $004A, $0386, $0100, $0144, $02B6, $0024, $0320
    DECLE   $0011, $0041, $01DF, $0316, $014C, $016E, $001E, $00C4
    DECLE   $02B2, $031E, $0264, $02AA, $019D, $01BE, $000B, $00F0
    DECLE   $006A, $01CE, $00D6, $015B, $03B5, $03E4, $0000, $0380
    DECLE   $0007, $0312, $03E8, $030C, $016D, $02EE, $0085, $03C2
    DECLE   $03EC, $0283, $024A, $0005, $0000
_AR.end:  ; 69 decles
;; ------------------------------------------------------------------------ ;;
_AW:
    DECLE   _AW.end - _AW - 1
    DECLE   $0010, $01CE, $016E, $02BE, $0375, $034F, $0220, $0290
    DECLE   $008A, $026D, $013F, $01D5, $0316, $029F, $02E2, $018A
    DECLE   $0170, $0035, $00BD, $0000, $0000
_AW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_AX:
    DECLE   _AX.end - _AX - 1
    DECLE   $0218, $02CD, $016F, $02F5, $0386, $00C2, $00CD, $0094
    DECLE   $010C, $0005, $0000
_AX.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AY:
    DECLE   _AY.end - _AY - 1
    DECLE   $0110, $038C, $016E, $03B7, $03B3, $02AF, $0221, $009E
    DECLE   $01AA, $01B3, $00BF, $02E7, $025B, $0354, $00DA, $017F
    DECLE   $018A, $03F3, $00AF, $02D5, $0356, $027F, $017A, $01FB
    DECLE   $011E, $01B9, $03E5, $029F, $025A, $0076, $0148, $0124
    DECLE   $003D, $0000
_AY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_BB1:
    DECLE   _BB1.end - _BB1 - 1
    DECLE   $0318, $004C, $016C, $00FB, $00C7, $0144, $002E, $030C
    DECLE   $010E, $018C, $01DC, $00AB, $00C9, $0268, $01F7, $021D
    DECLE   $01B3, $0098, $0000
_BB1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_BB2:
    DECLE   _BB2.end - _BB2 - 1
    DECLE   $00F4, $0046, $0062, $0200, $0221, $03E4, $0087, $016F
    DECLE   $02A6, $02B7, $0212, $0326, $0368, $01BF, $0338, $0196
    DECLE   $0002
_BB2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_CH:
    DECLE   _CH.end - _CH - 1
    DECLE   $00F5, $0146, $0052, $0000, $032A, $0049, $0032, $02F2
    DECLE   $02A5, $0000, $026D, $0119, $0124, $00F6, $0000
_CH.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_DD1:
    DECLE   _DD1.end - _DD1 - 1
    DECLE   $0318, $034C, $016E, $0397, $01B9, $0020, $02B1, $008E
    DECLE   $0349, $0291, $01D8, $0072, $0000
_DD1.end:  ; 13 decles
;; ------------------------------------------------------------------------ ;;
_DD2:
    DECLE   _DD2.end - _DD2 - 1
    DECLE   $00F4, $00C6, $00F2, $0000, $0129, $00A6, $0246, $01F3
    DECLE   $02C6, $02B7, $028E, $0064, $0362, $01CF, $0379, $01D5
    DECLE   $0002
_DD2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_DH1:
    DECLE   _DH1.end - _DH1 - 1
    DECLE   $0018, $034F, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_DH2:
    DECLE   _DH2.end - _DH2 - 1
    DECLE   $0119, $034C, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_EH:
    DECLE   _EH.end - _EH - 1
    DECLE   $0218, $02CD, $016F, $0105, $014B, $0224, $02CF, $0274
    DECLE   $014C, $0005, $0000
_EH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_EL:
    DECLE   _EL.end - _EL - 1
    DECLE   $0118, $038D, $016E, $011C, $008B, $03D2, $030F, $0262
    DECLE   $006C, $019D, $01CC, $022B, $0170, $0078, $03FE, $0018
    DECLE   $0183, $03A3, $010D, $016E, $012E, $00C6, $00C3, $0300
    DECLE   $0060, $000D, $0005, $0000
_EL.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_ER1:
    DECLE   _ER1.end - _ER1 - 1
    DECLE   $0118, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0188
    DECLE   $01DA, $00CB, $00E7, $0048, $03A6, $0244, $016C, $01A8
    DECLE   $03E4, $0000, $0002, $0001, $00FC, $01DA, $02E4, $0000
    DECLE   $0002, $0008, $0200, $0217, $0164, $0000, $000E, $0038
    DECLE   $0014, $01EA, $0264, $0000, $0002, $0048, $01EC, $02F1
    DECLE   $03CC, $016D, $021E, $0048, $00C2, $034E, $036A, $000D
    DECLE   $008D, $000B, $0200, $0047, $0022, $03A8, $0000, $0000
_ER1.end:  ; 64 decles
;; ------------------------------------------------------------------------ ;;
_ER2:
    DECLE   _ER2.end - _ER2 - 1
    DECLE   $0218, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0190
    DECLE   $01D8, $00CB, $00E7, $0058, $01A6, $0244, $0164, $02A9
    DECLE   $0024, $0000, $0000, $0007, $0201, $02F8, $02E4, $0000
    DECLE   $0002, $0001, $00FC, $02DA, $0024, $0000, $0002, $0008
    DECLE   $0200, $0217, $0024, $0000, $000E, $0038, $0014, $03EA
    DECLE   $03A4, $0000, $0002, $0048, $01EC, $03F1, $038C, $016D
    DECLE   $021E, $0048, $00C2, $034E, $036A, $000D, $009D, $0003
    DECLE   $0200, $0047, $0022, $03A8, $0000, $0000
_ER2.end:  ; 70 decles
;; ------------------------------------------------------------------------ ;;
_EY:
    DECLE   _EY.end - _EY - 1
    DECLE   $0310, $038C, $016E, $02A7, $00BB, $0160, $0290, $0094
    DECLE   $01CA, $03A9, $00C1, $02D7, $015B, $01D4, $03CE, $02FF
    DECLE   $00EA, $03E7, $0041, $0277, $025B, $0355, $03C9, $0103
    DECLE   $02EA, $03E4, $003F, $0000
_EY.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_FF:
    DECLE   _FF.end - _FF - 1
    DECLE   $0119, $03C8, $0000, $00A7, $0094, $0138, $01C6, $0000
_FF.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_GG1:
    DECLE   _GG1.end - _GG1 - 1
    DECLE   $00F4, $00C6, $00C2, $0200, $0015, $03FE, $0283, $01FD
    DECLE   $01E6, $00B7, $030A, $0364, $0331, $017F, $033D, $0215
    DECLE   $0002
_GG1.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG2:
    DECLE   _GG2.end - _GG2 - 1
    DECLE   $00F4, $0106, $0072, $0300, $0021, $0308, $0039, $0173
    DECLE   $00C6, $00B7, $037E, $03A3, $0319, $0177, $0036, $0217
    DECLE   $0002
_GG2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG3:
    DECLE   _GG3.end - _GG3 - 1
    DECLE   $00F8, $0146, $00F2, $0100, $0132, $03A8, $0055, $01F5
    DECLE   $00A6, $02B7, $0291, $0326, $0368, $0167, $023A, $01C6
    DECLE   $0002
_GG3.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_HH1:
    DECLE   _HH1.end - _HH1 - 1
    DECLE   $0218, $01C9, $0000, $0095, $0127, $0060, $01D6, $0213
    DECLE   $0002, $01AE, $033E, $01A0, $03C4, $0122, $0001, $0218
    DECLE   $01E4, $03FD, $0019, $0000
_HH1.end:  ; 20 decles
;; ------------------------------------------------------------------------ ;;
_HH2:
    DECLE   _HH2.end - _HH2 - 1
    DECLE   $0218, $00CB, $0000, $0086, $000F, $0240, $0182, $031A
    DECLE   $02DB, $0008, $0293, $0067, $00BD, $01E0, $0092, $000C
    DECLE   $0000
_HH2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_IH:
    DECLE   _IH.end - _IH - 1
    DECLE   $0118, $02CD, $016F, $0205, $0144, $02C3, $00FE, $031A
    DECLE   $000D, $0005, $0000
_IH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_IY:
    DECLE   _IY.end - _IY - 1
    DECLE   $0318, $02CC, $016F, $0008, $030B, $01C3, $0330, $0178
    DECLE   $002B, $019D, $01F6, $018B, $01E1, $0010, $020D, $0358
    DECLE   $015F, $02A4, $02CC, $016F, $0109, $030B, $0193, $0320
    DECLE   $017A, $034C, $009C, $0017, $0001, $0200, $03C1, $0020
    DECLE   $00A7, $001D, $0001, $0104, $003D, $0040, $01A7, $01CA
    DECLE   $018B, $0160, $0078, $01F6, $0343, $01C7, $0090, $0000
_IY.end:  ; 48 decles
;; ------------------------------------------------------------------------ ;;
_JH:
    DECLE   _JH.end - _JH - 1
    DECLE   $0018, $0149, $0001, $00A4, $0321, $0180, $01F4, $039A
    DECLE   $02DC, $023C, $011A, $0047, $0200, $0001, $018E, $034E
    DECLE   $0394, $0356, $02C1, $010C, $03FD, $0129, $00B7, $01BA
    DECLE   $0000
_JH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_KK1:
    DECLE   _KK1.end - _KK1 - 1
    DECLE   $00F4, $00C6, $00D2, $0000, $023A, $03E0, $02D1, $02E5
    DECLE   $0184, $0200, $0041, $0210, $0188, $00C5, $0000
_KK1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_KK2:
    DECLE   _KK2.end - _KK2 - 1
    DECLE   $021D, $023C, $0211, $003C, $0180, $024D, $0008, $032B
    DECLE   $025B, $002D, $01DC, $01E3, $007A, $0000
_KK2.end:  ; 14 decles
;; ------------------------------------------------------------------------ ;;
_KK3:
    DECLE   _KK3.end - _KK3 - 1
    DECLE   $00F7, $0046, $01D2, $0300, $0131, $006C, $006E, $00F1
    DECLE   $00E4, $0000, $025A, $010D, $0110, $01F9, $014A, $0001
    DECLE   $00B5, $01A2, $00D8, $01CE, $0000
_KK3.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_LL:
    DECLE   _LL.end - _LL - 1
    DECLE   $0318, $038C, $016D, $029E, $0333, $0260, $0221, $0294
    DECLE   $01C4, $0299, $025A, $00E6, $014C, $012C, $0031, $0000
_LL.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_MM:
    DECLE   _MM.end - _MM - 1
    DECLE   $0210, $034D, $016D, $03F5, $00B0, $002E, $0220, $0290
    DECLE   $03CE, $02B6, $03AA, $00F3, $00CF, $015D, $016E, $0000
_MM.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_NG1:
    DECLE   _NG1.end - _NG1 - 1
    DECLE   $0118, $03CD, $016E, $00DC, $032F, $01BF, $01E0, $0116
    DECLE   $02AB, $029A, $0358, $01DB, $015B, $01A7, $02FD, $02B1
    DECLE   $03D2, $0356, $0000
_NG1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_NN1:
    DECLE   _NN1.end - _NN1 - 1
    DECLE   $0318, $03CD, $016C, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $009D, $000D, $0248, $01B4, $0120, $01E1, $00C8
    DECLE   $0003, $0040, $0000, $0080, $015F, $0006, $0000
_NN1.end:  ; 23 decles
;; ------------------------------------------------------------------------ ;;
_NN2:
    DECLE   _NN2.end - _NN2 - 1
    DECLE   $0018, $034D, $016D, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $0095, $0003, $0248, $01B4, $0120, $01E1, $0090
    DECLE   $000B, $0040, $0000, $0080, $015F, $019E, $01F6, $028B
    DECLE   $00E0, $0266, $03F6, $01D8, $0143, $01A8, $0024, $00C0
    DECLE   $0080, $0000, $01E6, $0321, $0024, $0260, $000A, $0008
    DECLE   $03FE, $0000, $0000
_NN2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_OR2:
    DECLE   _OR2.end - _OR2 - 1
    DECLE   $0218, $018C, $016D, $02A6, $03AB, $004F, $0301, $0390
    DECLE   $02EA, $0289, $0228, $0356, $01CF, $02D5, $0135, $007D
    DECLE   $02B5, $02AF, $024A, $02E2, $0153, $0167, $0333, $02A9
    DECLE   $02B3, $039A, $0351, $0147, $03CD, $0339, $02DA, $0000
_OR2.end:  ; 32 decles
;; ------------------------------------------------------------------------ ;;
_OW:
    DECLE   _OW.end - _OW - 1
    DECLE   $0310, $034C, $016E, $02AE, $03B1, $00CF, $0304, $0192
    DECLE   $018A, $022B, $0041, $0277, $015B, $0395, $03D1, $0082
    DECLE   $03CE, $00B6, $03BB, $02DA, $0000
_OW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_OY:
    DECLE   _OY.end - _OY - 1
    DECLE   $0310, $014C, $016E, $02A6, $03AF, $00CF, $0304, $0192
    DECLE   $03CA, $01A8, $007F, $0155, $02B4, $027F, $00E2, $036A
    DECLE   $031F, $035D, $0116, $01D5, $02F4, $025F, $033A, $038A
    DECLE   $014F, $01B5, $03D5, $0297, $02DA, $03F2, $0167, $0124
    DECLE   $03FB, $0001
_OY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_PA1:
    DECLE   _PA1.end - _PA1 - 1
    DECLE   $00F1, $0000
_PA1.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA2:
    DECLE   _PA2.end - _PA2 - 1
    DECLE   $00F4, $0000
_PA2.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA3:
    DECLE   _PA3.end - _PA3 - 1
    DECLE   $00F7, $0000
_PA3.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA4:
    DECLE   _PA4.end - _PA4 - 1
    DECLE   $00FF, $0000
_PA4.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA5:
    DECLE   _PA5.end - _PA5 - 1
    DECLE   $031D, $003F, $0000
_PA5.end:  ; 3 decles
;; ------------------------------------------------------------------------ ;;
_PP:
    DECLE   _PP.end - _PP - 1
    DECLE   $00FD, $0106, $0052, $0000, $022A, $03A5, $0277, $035F
    DECLE   $0184, $0000, $0055, $0391, $00EB, $00CF, $0000
_PP.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_RR1:
    DECLE   _RR1.end - _RR1 - 1
    DECLE   $0118, $01CD, $016C, $029E, $0171, $038E, $01E0, $0190
    DECLE   $0245, $0299, $01AA, $02E2, $01C7, $02DE, $0125, $00B5
    DECLE   $02C5, $028F, $024E, $035E, $01CB, $02EC, $0005, $0000
_RR1.end:  ; 24 decles
;; ------------------------------------------------------------------------ ;;
_RR2:
    DECLE   _RR2.end - _RR2 - 1
    DECLE   $0218, $03CC, $016C, $030C, $02C8, $0393, $02CD, $025E
    DECLE   $008A, $019D, $01AC, $02CB, $00BE, $0046, $017E, $01C2
    DECLE   $0174, $00A1, $01E5, $00E0, $010E, $0007, $0313, $0017
    DECLE   $0000
_RR2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SH:
    DECLE   _SH.end - _SH - 1
    DECLE   $0218, $0109, $0000, $007A, $0187, $02E0, $03F6, $0311
    DECLE   $0002, $0126, $0242, $0161, $03E9, $0219, $016C, $0300
    DECLE   $0013, $0045, $0124, $0005, $024C, $005C, $0182, $03C2
    DECLE   $0001
_SH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SS:
    DECLE   _SS.end - _SS - 1
    DECLE   $0218, $01CA, $0001, $0128, $001C, $0149, $01C6, $0000
_SS.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TH:
    DECLE   _TH.end - _TH - 1
    DECLE   $0019, $0349, $0000, $00C6, $0212, $01D8, $01CA, $0000
_TH.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TT1:
    DECLE   _TT1.end - _TT1 - 1
    DECLE   $00F6, $0046, $0142, $0100, $0042, $0088, $027E, $02EF
    DECLE   $01A4, $0200, $0049, $0290, $00FC, $00E8, $0000
_TT1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_TT2:
    DECLE   _TT2.end - _TT2 - 1
    DECLE   $00F5, $00C6, $01D2, $0100, $0335, $00E9, $0042, $027A
    DECLE   $02A4, $0000, $0062, $01D1, $014C, $03EA, $02EC, $01E0
    DECLE   $0007, $03A7, $0000
_TT2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_UH:
    DECLE   _UH.end - _UH - 1
    DECLE   $0018, $034E, $016E, $01FF, $0349, $00D2, $003C, $030C
    DECLE   $008B, $0005, $0000
_UH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_UW1:
    DECLE   _UW1.end - _UW1 - 1
    DECLE   $0318, $014C, $016F, $029E, $03BD, $03BD, $0271, $0212
    DECLE   $0325, $0291, $016A, $027B, $014A, $03B4, $0133, $0001
_UW1.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_UW2:
    DECLE   _UW2.end - _UW2 - 1
    DECLE   $0018, $034E, $016E, $02F6, $0107, $02C2, $006D, $0090
    DECLE   $03AC, $01A4, $01DC, $03AB, $0128, $0076, $03E6, $0119
    DECLE   $014F, $03A6, $03A5, $0020, $0090, $0001, $02EE, $00BB
    DECLE   $0000
_UW2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_VV:
    DECLE   _VV.end - _VV - 1
    DECLE   $0218, $030D, $016C, $010B, $010B, $0095, $034F, $03E4
    DECLE   $0108, $01B5, $01BE, $028B, $0160, $00AA, $03E4, $0106
    DECLE   $00EB, $02DE, $014C, $016E, $00F6, $0107, $00D2, $00CD
    DECLE   $0296, $00E4, $0006, $0000
_VV.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_WH:
    DECLE   _WH.end - _WH - 1
    DECLE   $0218, $00C9, $0000, $0084, $038E, $0147, $03A4, $0195
    DECLE   $0000, $012E, $0118, $0150, $02D1, $0232, $01B7, $03F1
    DECLE   $0237, $01C8, $03B1, $0227, $01AE, $0254, $0329, $032D
    DECLE   $01BF, $0169, $019A, $0307, $0181, $028D, $0000
_WH.end:  ; 31 decles
;; ------------------------------------------------------------------------ ;;
_WW:
    DECLE   _WW.end - _WW - 1
    DECLE   $0118, $034D, $016C, $00FA, $02C7, $0072, $03CC, $0109
    DECLE   $000B, $01AD, $019E, $016B, $0130, $0278, $01F8, $0314
    DECLE   $017E, $029E, $014D, $016D, $0205, $0147, $02E2, $001A
    DECLE   $010A, $026E, $0004, $0000
_WW.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_XR2:
    DECLE   _XR2.end - _XR2 - 1
    DECLE   $0318, $034C, $016E, $02A6, $03BB, $002F, $0290, $008E
    DECLE   $004B, $0392, $01DA, $024B, $013A, $01DA, $012F, $00B5
    DECLE   $02E5, $0297, $02DC, $0372, $014B, $016D, $0377, $00E7
    DECLE   $0376, $038A, $01CE, $026B, $02FA, $01AA, $011E, $0071
    DECLE   $00D5, $0297, $02BC, $02EA, $01C7, $02D7, $0135, $0155
    DECLE   $01DD, $0007, $0000
_XR2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_YR:
    DECLE   _YR.end - _YR - 1
    DECLE   $0318, $03CC, $016E, $0197, $00FD, $0130, $0270, $0094
    DECLE   $0328, $0291, $0168, $007E, $01CC, $02F5, $0125, $02B5
    DECLE   $00F4, $0298, $01DA, $03F6, $0153, $0126, $03B9, $00AB
    DECLE   $0293, $03DB, $0175, $01B9, $0001
_YR.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY1:
    DECLE   _YY1.end - _YY1 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0001, $0000
_YY1.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY2:
    DECLE   _YY2.end - _YY2 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0199, $01EE, $008B, $0161, $0232
    DECLE   $0004, $0318, $01A7, $0198, $0124, $03E0, $0001, $0001
    DECLE   $030F, $0027, $0000
_YY2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_ZH:
    DECLE   _ZH.end - _ZH - 1
    DECLE   $0310, $014D, $016E, $00C3, $03B9, $01BF, $0241, $0012
    DECLE   $0163, $00E1, $0000, $0080, $0084, $023F, $003F, $0000
_ZH.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_ZZ:
    DECLE   _ZZ.end - _ZZ - 1
    DECLE   $0218, $010D, $016F, $0225, $0351, $00B5, $02A0, $02EE
    DECLE   $00E9, $014D, $002C, $0360, $0008, $00EC, $004C, $0342
    DECLE   $03D4, $0156, $0052, $0131, $0008, $03B0, $01BE, $0172
    DECLE   $0000
_ZZ.end:  ; 25 decles

;;==========================================================================;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The above allophone data was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  INTELLIVOICE DRIVER ROUTINES                                            ;;
;;  Written in 2002 by Joe Zbiciak <intvnut AT gmail.com>                   ;;
;;  http://spatula-city.org/~im14u2c/intv/                                  ;;
;; ======================================================================== ;;

;; ======================================================================== ;;
;;  GLOBAL VARIABLES USED BY THESE ROUTINES                                 ;;
;;                                                                          ;;
;;  Note that some of these routines may use one or more global variables.  ;;
;;  If you use these routines, you will need to allocate the appropriate    ;;
;;  space in either 16-bit or 8-bit memory as appropriate.  Each global     ;;
;;  variable is listed with the routines which use it and the required      ;;
;;  memory width.                                                           ;;
;;                                                                          ;;
;;  Example declarations for these routines are shown below, commented out. ;;
;;  You should uncomment these and add them to your program to make use of  ;;
;;  the routine that needs them.  Make sure to assign these variables to    ;;
;;  locations that aren't used for anything else.                           ;;
;; ======================================================================== ;;

                        ; Used by       Req'd Width     Description
                        ;-----------------------------------------------------
;IV.QH      EQU $110    ; IV_xxx        8-bit           Voice queue head
;IV.QT      EQU $111    ; IV_xxx        8-bit           Voice queue tail
;IV.Q       EQU $112    ; IV_xxx        8-bit           Voice queue  (8 bytes)
;IV.FLEN    EQU $11A    ; IV_xxx        8-bit           Length of FIFO data
;IV.FPTR    EQU $320    ; IV_xxx        16-bit          Current FIFO ptr.
;IV.PPTR    EQU $321    ; IV_xxx        16-bit          Current Phrase ptr.

;; ======================================================================== ;;
;;  MEMORY USAGE                                                            ;;
;;                                                                          ;;
;;  These routines implement a queue of "pending phrases" that will be      ;;
;;  played by the Intellivoice.  The user calls IV_PLAY to enqueue a        ;;
;;  phrase number.  Phrase numbers indicate either a RESROM sample or       ;;
;;  a compiled in phrase to be spoken.                                      ;;
;;                                                                          ;;
;;  The user must compose an "IV_PHRASE_TBL", which is composed of          ;;
;;  pointers to phrases to be spoken.  Phrases are strings of pointers      ;;
;;  and RESROM triggers, terminated by a NUL.                               ;;
;;                                                                          ;;
;;  Phrase numbers 1 through 42 are RESROM samples.  Phrase numbers         ;;
;;  43 through 255 index into the IV_PHRASE_TBL.                            ;;
;;                                                                          ;;
;;  SPECIAL NOTES                                                           ;;
;;                                                                          ;;
;;  Bit 7 of IV.QH and IV.QT is used to denote whether the Intellivoice     ;;
;;  is present.  If Intellivoice is present, this bit is clear.             ;;
;;                                                                          ;;
;;  Bit 6 of IV.QT is used to denote that we still need to do an ALD $00    ;;
;;  for FIFO'd voice data.                                                  ;;
;; ======================================================================== ;;
            

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_INIT     Initialize the Intellivoice                             ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      0 if Intellivoice found, -1 if not.                         ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      Resets Intellivoice, determines if it is actually there, and        ;;
;;      then initializes the IV structure.                                  ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;

IV_INIT     PROC
            MVII    #$0400, R0          ;
            MVO     R0,     $0081       ; Reset the Intellivoice

            MVI     $0081,  R0          ; \
            RLC     R0,     2           ;  |-- See if we detect Intellivoice
            BOV     @@no_ivoice         ; /    once we've reset it.

            CLRR    R0                  ; 
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            MVO     R0,     IV.QH       ; Clear our queue
            MVO     R0,     IV.QT       ; Clear our queue
            JR      R5                  ; Done!

@@no_ivoice:
            CLRR    R0
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            DECR    R0
            MVO     R0,     IV.QH       ; Set queue to -1 ("No Intellivoice")
            MVO     R0,     IV.QT       ; Set queue to -1 ("No Intellivoice")
            JR      R5                  ; Done!
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_ISR      Interrupt service routine to feed Intellivoice          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_ISR                                                       ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1, R4 trashed.                                                 ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      Call this from your main interrupt service routine.                 ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_ISR      PROC
            ;; ------------------------------------------------------------ ;;
            ;;  Check for Intellivoice.  Leave if none present.             ;;
            ;; ------------------------------------------------------------ ;;
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2
            BPL     @@ok                ; Bit 7 set? If yes: No Intellivoice
@@ald_busy:
@@leave     JR      R5                  ; Exit if no Intellivoice.

     
            ;; ------------------------------------------------------------ ;;
            ;;  Check to see if we pump samples into the FIFO.
            ;; ------------------------------------------------------------ ;;
@@ok:       MVI     IV.FPTR, R4         ; Get FIFO data pointer
            TSTR    R4                  ; is it zero?
            BEQ     @@no_fifodata       ; Yes:  No data for FIFO.
@@fifo_fill:
            MVI     $0081,  R0          ; Read speech FIFO ready bit
            SLLC    R0,     1           ; 
            BC      @@fifo_busy     

            MVI@    R4,     R0          ; Get next word
            MVO     R0,     $0081       ; write it to the FIFO

            MVI     IV.FLEN, R0         ;\
            DECR    R0                  ; |-- Decrement our FIFO'd data length
            MVO     R0,     IV.FLEN     ;/
            BEQ     @@last_fifo         ; If zero, we're done w/ FIFO
            MVO     R4,     IV.FPTR     ; Otherwise, save new pointer
            B       @@fifo_fill         ; ...and keep trying to load FIFO

@@last_fifo MVO     R0,     IV.FPTR     ; done with FIFO loading.
                                        ; fall into ALD processing.


            ;; ------------------------------------------------------------ ;;
            ;;  Try to do an Address Load.  We do this in two settings:     ;;
            ;;   -- We have no FIFO data to load.                           ;;
            ;;   -- We've loaded as much FIFO data as we can, but we        ;;
            ;;      might have an address load command to send for it.      ;;
            ;; ------------------------------------------------------------ ;;
@@fifo_busy:
@@no_fifodata:
            MVI     $0080,  R0          ; Read LRQ bit from ALD register
            SLLC    R0,     1
            BNC     @@ald_busy          ; LRQ is low, meaning we can't ALD.
                                        ; So, leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We can do an address load (ALD) on the SP0256.  Give FIFO   ;;
            ;;  driven ALDs priority, since we already started the FIFO     ;;
            ;;  load.  The "need ALD" bit is stored in bit 6 of IV.QT.      ;;
            ;; ------------------------------------------------------------ ;;
            ANDI    #$40,   R1          ; Is "Need FIFO ALD" bit set?
            BEQ     @@no_fifo_ald
            XOR     IV.QT,  R1          ;\__ Clear the "Need FIFO ALD" bit.
            MVO     R1,     IV.QT       ;/
            CLRR    R1
            MVO     R1,     $80         ; Load a 0 into ALD (trigger FIFO rd.)
            JR      R5                  ; done!

            ;; ------------------------------------------------------------ ;;
            ;;  We don't need to ALD on behalf of the FIFO.  So, we grab    ;;
            ;;  the next thing off our phrase list.                         ;;
            ;; ------------------------------------------------------------ ;;
@@no_fifo_ald:
            MVI     IV.PPTR, R4         ; Get phrase pointer.
            TSTR    R4                  ; Is it zero?
            BEQ     @@next_phrase       ; Yes:  Get next phrase from queue.

            MVI@    R4,     R0
            TSTR    R0                  ; Is it end of phrase?
            BNEQ    @@process_phrase    ; !=0:  Go do it.

            MVO     R0,     IV.PPTR     ; 
@@next_phrase:
            MVI     IV.QT,  R1          ; reload queue tail (was trashed above)
            MOVR    R1,     R0          ; copy QT to R0 so we can increment it
            ANDI    #$7,    R1          ; Mask away flags in queue head
            CMP     IV.QH,  R1          ; Is it same as queue tail?
            BEQ     @@leave             ; Yes:  No more speech for now.

            INCR    R0
            ANDI    #$F7,   R0          ; mask away the possible 'carry'
            MVO     R0,     IV.QT       ; save updated queue tail

            ADDI    #IV.Q,  R1          ; Index into queue
            MVI@    R1,     R4          ; get next value from queue
            CMPI    #43,    R4          ; Is it a RESROM or Phrase?
            BNC     @@play_resrom_r4
@@new_phrase:
;            ADDI    #IV_PHRASE_TBL - 43, R4 ; Index into phrase table
;            MVI@    R4,     R4          ; Read from phrase table
            MVO     R4,     IV.PPTR
            JR      R5                  ; we'll get to this phrase next time.

@@play_resrom_r4:
            MVO     R4,     $0080       ; Just ALD it
            JR      R5                  ; and leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We're in the middle of a phrase, so continue interpreting.  ;;
            ;; ------------------------------------------------------------ ;;
@@process_phrase:
            
            MVO     R4,     IV.PPTR     ; save new phrase pointer
            CMPI    #43,    R0          ; Is it a RESROM cue?
            BC      @@play_fifo         ; Just ALD it and leave.
@@play_resrom_r0
            MVO     R0,     $0080       ; Just ALD it
            JR      R5                  ; and leave.
@@play_fifo:
            MVI     IV.FPTR,R1          ; Make sure not to stomp existing FIFO
            TSTR    R1                  ; data.
            BEQ     @@new_fifo_ok
            DECR    R4                  ; Oops, FIFO data still playing,
            MVO     R4,     IV.PPTR     ; so rewind.
            JR      R5                  ; and leave.

@@new_fifo_ok:
            MOVR    R0,     R4          ;
            MVI@    R4,     R0          ; Get chunk length
            MVO     R0,     IV.FLEN     ; Init FIFO chunk length
            MVO     R4,     IV.FPTR     ; Init FIFO pointer
            MVI     IV.QT,  R0          ;\
            XORI    #$40,   R0          ; |- Set "Need ALD" bit in QT
            MVO     R0,     IV.QT       ;/

  IF 1      ; debug code                ;\
            ANDI    #$40,   R0          ; |   Debug code:  We should only
            BNEQ    @@qtok              ; |-- be here if "Need FIFO ALD" 
            HLT     ;BUG!!              ; |   was already clear.         
@@qtok                                  ;/    
  ENDI
            JR      R5                  ; leave.

            ENDP


;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAY     Play a voice sample sequence.                           ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;      Z==0    if item not successfully queued.                            ;;
;;      Z==1    if successfully queued.                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will drop phrases if the queue is full.                   ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAY     PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     @@leave             ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@leave             ; Leave if we're full

@@2:        MVI     IV.QH,  R1          ; Get our queue head pointer
            PSHR    R1                  ;\
            INCR    R1                  ; |
            ANDI    #$F7,   R1          ; |-- Increment it, removing
            MVO     R1,     IV.QH       ; |   carry but preserving flags.
            PULR    R1                  ;/

            ADDI    #IV.Q,  R1          ;\__ Store phrase to queue
            MVO@    R0,     R1          ;/

@@leave:    JR      R5                  ; Leave.
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAYW    Play a voice sample sequence.  Wait for queue room.     ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will wait for a queue slot to open if queue is full.      ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAYW    PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     IV_PLAY.leave       ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@1                 ; wait for room
            B       IV_PLAY.2

            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_WAIT     Wait for voice queue to empty.                          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_WAIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      trashed.                                                    ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This waits until the Intellivoice is nearly completely quiescent.   ;;
;;      Some voice data may still be spoken from the last triggered         ;;
;;      phrase.  To truly wait for *that* to be spoken, speak a 'pause'     ;;
;;      (eg. RESROM.pa1) and then call IV_WAIT.                             ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_WAIT     PROC
            MVI     IV.QH,  R0
            SWAP    R0                  ;\___ test bit 7, leave if set.
            SWAP    R0                  ;/    (SWAP2 corrupts upper byte.)
            BMI     @@leave

            ; Wait for queue to drain.
@@q_loop:   CMP     IV.QT,  R0
            BNEQ    @@q_loop

            ; Wait for FIFO and LRQ to say ready.
@@s_loop:   MVI     $81,    R0          ; Read FIFO status.  0 == ready.
            COMR    R0
            AND     $80,    R0          ; Merge w/ ALD status.  1 == ready
            TSTR    R0
            BPL     @@s_loop            ; if bit 15 == 0, not ready.
            
@@leave:    JR      R5
            ENDP

;; ======================================================================== ;;
;;  End of File:  ivoice.asm                                                ;;
;; ======================================================================== ;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_SAYNUM16 Say a 16-bit unsigned number using RESROM digits        ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      16-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R0      Number to "speak"                                           ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      "Says" a 16-bit number using IV_PLAYW to queue up the phrase.       ;;
;;      Because the number may be built from several segments, it could     ;;
;;      easily eat up the queue.  I believe the longest number will take    ;;
;;      7 queue entries -- that is, fill the queue.  Thus, this code        ;;
;;      could block, waiting for slots in the queue.                        ;;
;; ======================================================================== ;;

IV_SAYNUM16 PROC
            PSHR    R5

            TSTR    R0
            BEQ     @@zero          ; Special case:  Just say "zero"

            ;; ------------------------------------------------------------ ;;
            ;;  First, try to pull off 'thousands'.  We call ourselves      ;;
            ;;  recursively to play the the number of thousands.            ;;
            ;; ------------------------------------------------------------ ;;
            CLRR    R1
@@thloop:   INCR    R1
            SUBI    #1000,  R0
            BC      @@thloop

            ADDI    #1000,  R0
            PSHR    R0
            DECR    R1
            BEQ     @@no_thousand

            CALL    IV_SAYNUM16.recurse

            CALL    IV_PLAYW
            DECLE   36  ; THOUSAND
            
@@no_thousand
            PULR    R1

            ;; ------------------------------------------------------------ ;;
            ;;  Now try to play hundreds.                                   ;;
            ;; ------------------------------------------------------------ ;;
            MVII    #7-1, R0    ; ZERO
            CMPI    #100,   R1
            BNC     @@no_hundred

@@hloop:    INCR    R0
            SUBI    #100,   R1
            BC      @@hloop
            ADDI    #100,   R1

            PSHR    R1

            CALL    IV_PLAYW.1

            CALL    IV_PLAYW
            DECLE   35  ; HUNDRED

            PULR    R1
            B       @@notrecurse    ; skip "PSHR R5"
@@recurse:  PSHR    R5              ; recursive entry point for 'thousand'

@@no_hundred:
@@notrecurse:
            MOVR    R1,     R0
            BEQ     @@leave

            SUBI    #20,    R1
            BNC     @@teens

            MVII    #27-1, R0   ; TWENTY
@@tyloop    INCR    R0
            SUBI    #10,    R1
            BC      @@tyloop
            ADDI    #10,    R1

            PSHR    R1
            CALL    IV_PLAYW.1

            PULR    R0
            TSTR    R0
            BEQ     @@leave

@@teens:
@@zero:     ADDI    #7, R0  ; ZERO

            CALL    IV_PLAYW.1

@@leave     PULR    PC
            ENDP

;; ======================================================================== ;;
;;  End of File:  saynum16.asm                                              ;;
;; ======================================================================== ;;

    ENDI

        IF DEFINED intybasic_flash

;; ======================================================================== ;;
;;  JLP "Save Game" support                                                 ;;
;; ======================================================================== ;;
JF.first    EQU     $8023
JF.last     EQU     $8024
JF.addr     EQU     $8025
JF.row      EQU     $8026
                   
JF.wrcmd    EQU     $802D
JF.rdcmd    EQU     $802E
JF.ercmd    EQU     $802F
JF.wrkey    EQU     $C0DE
JF.rdkey    EQU     $DEC0
JF.erkey    EQU     $BEEF

JF.write:   DECLE   JF.wrcmd,   JF.wrkey    ; Copy JLP RAM to flash row  
JF.read:    DECLE   JF.rdcmd,   JF.rdkey    ; Copy flash row to JLP RAM  
JF.erase:   DECLE   JF.ercmd,   JF.erkey    ; Erase flash sector 

;; ======================================================================== ;;
;;  JF.INIT         Copy JLP save-game support routine to System RAM        ;;
;; ======================================================================== ;;
JF.INIT     PROC
            PSHR    R5            
            MVII    #@@__code,  R5
            MVII    #JF.SYSRAM, R4
            REPEAT  5       
            MVI@    R5,         R0      ; \_ Copy code fragment to System RAM
            MVO@    R0,         R4      ; /
            ENDR
            PULR    PC

            ;; === start of code that will run from RAM
@@__code:   MVO@    R0,         R1      ; JF.SYSRAM + 0: initiate command
            ADD@    R1,         PC      ; JF.SYSRAM + 1: Wait for JLP to return
            JR      R5                  ; JF.SYSRAM + 2:
            MVO@    R2,         R2      ; JF.SYSRAM + 3: \__ simple ISR
            JR      R5                  ; JF.SYSRAM + 4: /
            ;; === end of code that will run from RAM
            ENDP

;; ======================================================================== ;;
;;  JF.CMD          Issue a JLP Flash command                               ;;
;;                                                                          ;;
;;  INPUT                                                                   ;;
;;      R0  Slot number to operate on                                       ;;
;;      R1  Address to copy to/from in JLP RAM                              ;;
;;      @R5 Command to invoke:                                              ;;
;;                                                                          ;;
;;              JF.write -- Copy JLP RAM to Flash                           ;;
;;              JF.read  -- Copy Flash to JLP RAM                           ;;
;;              JF.erase -- Erase flash sector                              ;;
;;                                                                          ;;
;;  OUTPUT                                                                  ;;
;;      R0 - R4 not modified.  (Saved and restored across call)             ;;
;;      JLP command executed                                                ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code requires two short routines in the console's System RAM.  ;;
;;      It also requires that the system stack reside in System RAM.        ;;
;;      Because an interrupt may occur during the code's execution, there   ;;
;;      must be sufficient stack space to service the interrupt (8 words).  ;;
;;                                                                          ;;
;;      The code also relies on the fact that the EXEC ISR dispatch does    ;;
;;      not modify R2.  This allows us to initialize R2 for the ISR ahead   ;;
;;      of time, rather than in the ISR.                                    ;;
;; ======================================================================== ;;
JF.CMD      PROC

            MVO     R4,         JF.SV.R4    ; \
            MVII    #JF.SV.R0,  R4          ;  |
            MVO@    R0,         R4          ;  |- Save registers, but not on
            MVO@    R1,         R4          ;  |  the stack.  (limit stack use)
            MVO@    R2,         R4          ; /

            MVI@    R5,         R4          ; Get command to invoke

            MVO     R5,         JF.SV.R5    ; save return address

            DIS
            MVO     R1,         JF.addr     ; \_ Save SG arguments in JLP
            MVO     R0,         JF.row      ; /
                                          
            MVI@    R4,         R1          ; Get command address
            MVI@    R4,         R0          ; Get unlock word
                                          
            MVII    #$100,      R4          ; \
            SDBD                            ;  |_ Save old ISR in save area
            MVI@    R4,         R2          ;  |
            MVO     R2,         JF.SV.ISR   ; /
                                          
            MVII    #JF.SYSRAM + 3, R2      ; \
            MVO     R2,         $100        ;  |_ Set up new ISR in RAM
            SWAP    R2                      ;  |
            MVO     R2,         $101        ; / 
                                          
            MVII    #$20,       R2          ; Address of STIC handshake
            JSRE    R5,  JF.SYSRAM          ; Invoke the command
                                          
            MVI     JF.SV.ISR,  R2          ; \
            MVO     R2,         $100        ;  |_ Restore old ISR 
            SWAP    R2                      ;  |
            MVO     R2,         $101        ; /
                                          
            MVII    #JF.SV.R0,  R5          ; \
            MVI@    R5,         R0          ;  |
            MVI@    R5,         R1          ;  |- Restore registers
            MVI@    R5,         R2          ;  |
            MVI@    R5,         R4          ; /
            MVI@    R5,         PC          ; Return

            ENDP


        ENDI

	IF DEFINED intybasic_fastmult

; Quarter Square Multiplication
; Assembly code by Joe Zbiciak, 2015
; Released to public domain.

QSQR8_TBL:  PROC
            DECLE   $3F80, $3F01, $3E82, $3E04, $3D86, $3D09, $3C8C, $3C10
            DECLE   $3B94, $3B19, $3A9E, $3A24, $39AA, $3931, $38B8, $3840
            DECLE   $37C8, $3751, $36DA, $3664, $35EE, $3579, $3504, $3490
            DECLE   $341C, $33A9, $3336, $32C4, $3252, $31E1, $3170, $3100
            DECLE   $3090, $3021, $2FB2, $2F44, $2ED6, $2E69, $2DFC, $2D90
            DECLE   $2D24, $2CB9, $2C4E, $2BE4, $2B7A, $2B11, $2AA8, $2A40
            DECLE   $29D8, $2971, $290A, $28A4, $283E, $27D9, $2774, $2710
            DECLE   $26AC, $2649, $25E6, $2584, $2522, $24C1, $2460, $2400
            DECLE   $23A0, $2341, $22E2, $2284, $2226, $21C9, $216C, $2110
            DECLE   $20B4, $2059, $1FFE, $1FA4, $1F4A, $1EF1, $1E98, $1E40
            DECLE   $1DE8, $1D91, $1D3A, $1CE4, $1C8E, $1C39, $1BE4, $1B90
            DECLE   $1B3C, $1AE9, $1A96, $1A44, $19F2, $19A1, $1950, $1900
            DECLE   $18B0, $1861, $1812, $17C4, $1776, $1729, $16DC, $1690
            DECLE   $1644, $15F9, $15AE, $1564, $151A, $14D1, $1488, $1440
            DECLE   $13F8, $13B1, $136A, $1324, $12DE, $1299, $1254, $1210
            DECLE   $11CC, $1189, $1146, $1104, $10C2, $1081, $1040, $1000
            DECLE   $0FC0, $0F81, $0F42, $0F04, $0EC6, $0E89, $0E4C, $0E10
            DECLE   $0DD4, $0D99, $0D5E, $0D24, $0CEA, $0CB1, $0C78, $0C40
            DECLE   $0C08, $0BD1, $0B9A, $0B64, $0B2E, $0AF9, $0AC4, $0A90
            DECLE   $0A5C, $0A29, $09F6, $09C4, $0992, $0961, $0930, $0900
            DECLE   $08D0, $08A1, $0872, $0844, $0816, $07E9, $07BC, $0790
            DECLE   $0764, $0739, $070E, $06E4, $06BA, $0691, $0668, $0640
            DECLE   $0618, $05F1, $05CA, $05A4, $057E, $0559, $0534, $0510
            DECLE   $04EC, $04C9, $04A6, $0484, $0462, $0441, $0420, $0400
            DECLE   $03E0, $03C1, $03A2, $0384, $0366, $0349, $032C, $0310
            DECLE   $02F4, $02D9, $02BE, $02A4, $028A, $0271, $0258, $0240
            DECLE   $0228, $0211, $01FA, $01E4, $01CE, $01B9, $01A4, $0190
            DECLE   $017C, $0169, $0156, $0144, $0132, $0121, $0110, $0100
            DECLE   $00F0, $00E1, $00D2, $00C4, $00B6, $00A9, $009C, $0090
            DECLE   $0084, $0079, $006E, $0064, $005A, $0051, $0048, $0040
            DECLE   $0038, $0031, $002A, $0024, $001E, $0019, $0014, $0010
            DECLE   $000C, $0009, $0006, $0004, $0002, $0001, $0000
@@mid:
            DECLE   $0000, $0000, $0001, $0002, $0004, $0006, $0009, $000C
            DECLE   $0010, $0014, $0019, $001E, $0024, $002A, $0031, $0038
            DECLE   $0040, $0048, $0051, $005A, $0064, $006E, $0079, $0084
            DECLE   $0090, $009C, $00A9, $00B6, $00C4, $00D2, $00E1, $00F0
            DECLE   $0100, $0110, $0121, $0132, $0144, $0156, $0169, $017C
            DECLE   $0190, $01A4, $01B9, $01CE, $01E4, $01FA, $0211, $0228
            DECLE   $0240, $0258, $0271, $028A, $02A4, $02BE, $02D9, $02F4
            DECLE   $0310, $032C, $0349, $0366, $0384, $03A2, $03C1, $03E0
            DECLE   $0400, $0420, $0441, $0462, $0484, $04A6, $04C9, $04EC
            DECLE   $0510, $0534, $0559, $057E, $05A4, $05CA, $05F1, $0618
            DECLE   $0640, $0668, $0691, $06BA, $06E4, $070E, $0739, $0764
            DECLE   $0790, $07BC, $07E9, $0816, $0844, $0872, $08A1, $08D0
            DECLE   $0900, $0930, $0961, $0992, $09C4, $09F6, $0A29, $0A5C
            DECLE   $0A90, $0AC4, $0AF9, $0B2E, $0B64, $0B9A, $0BD1, $0C08
            DECLE   $0C40, $0C78, $0CB1, $0CEA, $0D24, $0D5E, $0D99, $0DD4
            DECLE   $0E10, $0E4C, $0E89, $0EC6, $0F04, $0F42, $0F81, $0FC0
            DECLE   $1000, $1040, $1081, $10C2, $1104, $1146, $1189, $11CC
            DECLE   $1210, $1254, $1299, $12DE, $1324, $136A, $13B1, $13F8
            DECLE   $1440, $1488, $14D1, $151A, $1564, $15AE, $15F9, $1644
            DECLE   $1690, $16DC, $1729, $1776, $17C4, $1812, $1861, $18B0
            DECLE   $1900, $1950, $19A1, $19F2, $1A44, $1A96, $1AE9, $1B3C
            DECLE   $1B90, $1BE4, $1C39, $1C8E, $1CE4, $1D3A, $1D91, $1DE8
            DECLE   $1E40, $1E98, $1EF1, $1F4A, $1FA4, $1FFE, $2059, $20B4
            DECLE   $2110, $216C, $21C9, $2226, $2284, $22E2, $2341, $23A0
            DECLE   $2400, $2460, $24C1, $2522, $2584, $25E6, $2649, $26AC
            DECLE   $2710, $2774, $27D9, $283E, $28A4, $290A, $2971, $29D8
            DECLE   $2A40, $2AA8, $2B11, $2B7A, $2BE4, $2C4E, $2CB9, $2D24
            DECLE   $2D90, $2DFC, $2E69, $2ED6, $2F44, $2FB2, $3021, $3090
            DECLE   $3100, $3170, $31E1, $3252, $32C4, $3336, $33A9, $341C
            DECLE   $3490, $3504, $3579, $35EE, $3664, $36DA, $3751, $37C8
            DECLE   $3840, $38B8, $3931, $39AA, $3A24, $3A9E, $3B19, $3B94
            DECLE   $3C10, $3C8C, $3D09, $3D86, $3E04, $3E82, $3F01, $3F80
            DECLE   $4000, $4080, $4101, $4182, $4204, $4286, $4309, $438C
            DECLE   $4410, $4494, $4519, $459E, $4624, $46AA, $4731, $47B8
            DECLE   $4840, $48C8, $4951, $49DA, $4A64, $4AEE, $4B79, $4C04
            DECLE   $4C90, $4D1C, $4DA9, $4E36, $4EC4, $4F52, $4FE1, $5070
            DECLE   $5100, $5190, $5221, $52B2, $5344, $53D6, $5469, $54FC
            DECLE   $5590, $5624, $56B9, $574E, $57E4, $587A, $5911, $59A8
            DECLE   $5A40, $5AD8, $5B71, $5C0A, $5CA4, $5D3E, $5DD9, $5E74
            DECLE   $5F10, $5FAC, $6049, $60E6, $6184, $6222, $62C1, $6360
            DECLE   $6400, $64A0, $6541, $65E2, $6684, $6726, $67C9, $686C
            DECLE   $6910, $69B4, $6A59, $6AFE, $6BA4, $6C4A, $6CF1, $6D98
            DECLE   $6E40, $6EE8, $6F91, $703A, $70E4, $718E, $7239, $72E4
            DECLE   $7390, $743C, $74E9, $7596, $7644, $76F2, $77A1, $7850
            DECLE   $7900, $79B0, $7A61, $7B12, $7BC4, $7C76, $7D29, $7DDC
            DECLE   $7E90, $7F44, $7FF9, $80AE, $8164, $821A, $82D1, $8388
            DECLE   $8440, $84F8, $85B1, $866A, $8724, $87DE, $8899, $8954
            DECLE   $8A10, $8ACC, $8B89, $8C46, $8D04, $8DC2, $8E81, $8F40
            DECLE   $9000, $90C0, $9181, $9242, $9304, $93C6, $9489, $954C
            DECLE   $9610, $96D4, $9799, $985E, $9924, $99EA, $9AB1, $9B78
            DECLE   $9C40, $9D08, $9DD1, $9E9A, $9F64, $A02E, $A0F9, $A1C4
            DECLE   $A290, $A35C, $A429, $A4F6, $A5C4, $A692, $A761, $A830
            DECLE   $A900, $A9D0, $AAA1, $AB72, $AC44, $AD16, $ADE9, $AEBC
            DECLE   $AF90, $B064, $B139, $B20E, $B2E4, $B3BA, $B491, $B568
            DECLE   $B640, $B718, $B7F1, $B8CA, $B9A4, $BA7E, $BB59, $BC34
            DECLE   $BD10, $BDEC, $BEC9, $BFA6, $C084, $C162, $C241, $C320
            DECLE   $C400, $C4E0, $C5C1, $C6A2, $C784, $C866, $C949, $CA2C
            DECLE   $CB10, $CBF4, $CCD9, $CDBE, $CEA4, $CF8A, $D071, $D158
            DECLE   $D240, $D328, $D411, $D4FA, $D5E4, $D6CE, $D7B9, $D8A4
            DECLE   $D990, $DA7C, $DB69, $DC56, $DD44, $DE32, $DF21, $E010
            DECLE   $E100, $E1F0, $E2E1, $E3D2, $E4C4, $E5B6, $E6A9, $E79C
            DECLE   $E890, $E984, $EA79, $EB6E, $EC64, $ED5A, $EE51, $EF48
            DECLE   $F040, $F138, $F231, $F32A, $F424, $F51E, $F619, $F714
            DECLE   $F810, $F90C, $FA09, $FB06, $FC04, $FD02, $FE01
            ENDP

; R0 = R0 * R1, where R0 and R1 are unsigned 8-bit values
; Destroys R1, R4
qs_mpy8:    PROC
            MOVR    R0,             R4      ;   6
            ADDI    #QSQR8_TBL.mid, R1      ;   8
            ADDR    R1,             R4      ;   6   a + b
            SUBR    R0,             R1      ;   6   a - b
@@ok:       MVI@    R4,             R0      ;   8
            SUB@    R1,             R0      ;   8
            JR      R5                      ;   7
                                            ;----
                                            ;  49
            ENDP
            

; R1 = R0 * R1, where R0 and R1 are 16-bit values
; destroys R0, R2, R3, R4, R5
qs_mpy16:   PROC
            PSHR    R5                  ;   9
                                   
            ; Unpack lo/hi
            MOVR    R0,         R2      ;   6   
            ANDI    #$FF,       R0      ;   8   R0 is lo(a)
            XORR    R0,         R2      ;   6   
            SWAP    R2                  ;   6   R2 is hi(a)

            MOVR    R1,         R3      ;   6   R3 is orig 16-bit b
            ANDI    #$FF,       R1      ;   8   R1 is lo(b)
            MOVR    R1,         R5      ;   6   R5 is lo(b)
            XORR    R1,         R3      ;   6   
            SWAP    R3                  ;   6   R3 is hi(b)
                                        ;----
                                        ;  67
                                        
            ; lo * lo                   
            MOVR    R0,         R4      ;   6   R4 is lo(a)
            ADDI    #QSQR8_TBL.mid, R1  ;   8
            ADDR    R1,         R4      ;   6   R4 = lo(a) + lo(b)
            SUBR    R0,         R1      ;   6   R1 = lo(a) - lo(b)
                                        
@@pos_ll:   MVI@    R4,         R4      ;   8   R4 = qstbl[lo(a)+lo(b)]
            SUB@    R1,         R4      ;   8   R4 = lo(a)*lo(b)
                                        ;----
                                        ;  42
                                        ;  67 (carried forward)
                                        ;----
                                        ; 109
                                       
            ; lo * hi                  
            MOVR    R0,         R1      ;   6   R0 = R1 = lo(a)
            ADDI    #QSQR8_TBL.mid, R3  ;   8
            ADDR    R3,         R1      ;   6   R1 = hi(b) + lo(a)
            SUBR    R0,         R3      ;   6   R3 = hi(b) - lo(a)
                                       
@@pos_lh:   MVI@    R1,         R1      ;   8   R1 = qstbl[hi(b)-lo(a)]
            SUB@    R3,         R1      ;   8   R1 = lo(a)*hi(b)
                                        ;----
                                        ;  42
                                        ; 109 (carried forward)
                                        ;----
                                        ; 151
                                       
            ; hi * lo                  
            MOVR    R5,         R0      ;   6   R5 = R0 = lo(b)
            ADDI    #QSQR8_TBL.mid, R2  ;   8
            ADDR    R2,         R5      ;   6   R3 = hi(a) + lo(b)
            SUBR    R0,         R2      ;   6   R2 = hi(a) - lo(b)
                                       
@@pos_hl:   ADD@    R5,         R1      ;   8   \_ R1 = lo(a)*hi(b)+hi(a)*lo(b)
            SUB@    R2,         R1      ;   8   /
                                        ;----
                                        ;  42
                                        ; 151 (carried forward)
                                        ;----
                                        ; 193
                                       
            SWAP    R1                  ;   6   \_ shift upper product left 8
            ANDI    #$FF00,     R1      ;   8   /
            ADDR    R4,         R1      ;   6   final product
            PULR    PC                  ;  12
                                        ;----
                                        ;  32
                                        ; 193 (carried forward)
                                        ;----
                                        ; 225
            ENDP

	ENDI

	IF DEFINED intybasic_fastdiv

; Fast unsigned division/remainder
; Assembly code by Oscar Toledo G. Jul/10/2015
; Released to public domain.

	; Ultrafast unsigned division/remainder operation
	; Entry: R0 = Dividend
	;        R1 = Divisor
	; Output: R0 = Quotient
	;         R2 = Remainder
	; Worst case: 6 + 6 + 9 + 496 = 517 cycles
	; Best case: 6 + (6 + 7) * 16 = 214 cycles

uf_udiv16:	PROC
	CLRR R2		; 6
	SLLC R0,1	; 6
	BC @@1		; 7/9
	SLLC R0,1	; 6
	BC @@2		; 7/9
	SLLC R0,1	; 6
	BC @@3		; 7/9
	SLLC R0,1	; 6
	BC @@4		; 7/9
	SLLC R0,1	; 6
	BC @@5		; 7/9
	SLLC R0,1	; 6
	BC @@6		; 7/9
	SLLC R0,1	; 6
	BC @@7		; 7/9
	SLLC R0,1	; 6
	BC @@8		; 7/9
	SLLC R0,1	; 6
	BC @@9		; 7/9
	SLLC R0,1	; 6
	BC @@10		; 7/9
	SLLC R0,1	; 6
	BC @@11		; 7/9
	SLLC R0,1	; 6
	BC @@12		; 7/9
	SLLC R0,1	; 6
	BC @@13		; 7/9
	SLLC R0,1	; 6
	BC @@14		; 7/9
	SLLC R0,1	; 6
	BC @@15		; 7/9
	SLLC R0,1	; 6
	BC @@16		; 7/9
	JR R5

@@1:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@2:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@3:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@4:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@5:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@6:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@7:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@8:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@9:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@10:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@11:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@12:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@13:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@14:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@15:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@16:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
	JR R5
	
	ENDP

	ENDI

	IF DEFINED intybasic_ecs
	ORG $4800	; Available up to $4FFF

        ; Disable ECS ROMs so that they don't conflict with us
        MVII    #$2A5F, R0
        MVO     R0,     $2FFF
        MVII    #$7A5F, R0
        MVO     R0,     $7FFF
        MVII    #$EA5F, R0
        MVO     R0,     $EFFF

        B       $1041       ; resume boot

	ENDI

        ORG $200,$200,"-RWB"

Q2:	; Reserved label for #BACKTAB

	ORG $319,$319,"-RWB"
        ;
        ; 16-bits variables
	; Note IntyBASIC variables grow up starting in $308.
        ;
        IF DEFINED intybasic_voice
IV.Q:      RMB 8    ; IV_xxx        16-bit          Voice queue  (8 words)
IV.FPTR:   RMB 1    ; IV_xxx        16-bit          Current FIFO ptr.
IV.PPTR:   RMB 1    ; IV_xxx        16-bit          Current Phrase ptr.
        ENDI

        ORG $323,$323,"-RWB"

_scroll_buffer: RMB 20  ; Sometimes this is unused
_music_table:	RMB 1	; Note table
_music_start:	RMB 1	; Start of music
_music_p:	RMB 1	; Pointer to music
_frame:         RMB 1   ; Current frame
_read:          RMB 1   ; Pointer to DATA
_gram_bitmap:   RMB 1   ; Bitmap for definition
_gram2_bitmap:  RMB 1   ; Secondary bitmap for definition
_screen:    RMB 1       ; Pointer to current screen position
_color:     RMB 1       ; Current color

Q1:			; Reserved label for #MOBSHADOW
_mobs:      RMB 3*8     ; MOB buffer

_col0:      RMB 1       ; Collision status for MOB0
_col1:      RMB 1       ; Collision status for MOB1
_col2:      RMB 1       ; Collision status for MOB2
_col3:      RMB 1       ; Collision status for MOB3
_col4:      RMB 1       ; Collision status for MOB4
_col5:      RMB 1       ; Collision status for MOB5
_col6:      RMB 1       ; Collision status for MOB6
_col7:      RMB 1       ; Collision status for MOB7

SCRATCH:    ORG $100,$100,"-RWBN"
        ;
        ; 8-bits variables
        ;
ISRVEC:     RMB 2       ; Pointer to ISR vector (required by Intellivision ROM)
_int:       RMB 1       ; Signals interrupt received
_ntsc:      RMB 1       ; Signals NTSC Intellivision
_rand:      RMB 1       ; Pseudo-random value
_gram_target:   RMB 1   ; Contains GRAM card number
_gram_total:    RMB 1   ; Contains total GRAM cards for definition
_gram2_target:  RMB 1   ; Contains GRAM card number
_gram2_total:   RMB 1   ; Contains total GRAM cards for definition
_mode_select:   RMB 1   ; Graphics mode selection
_border_color:  RMB 1   ; Border color
_border_mask:   RMB 1   ; Border mask
    IF DEFINED intybasic_keypad
_cnt1_p0:   RMB 1       ; Debouncing 1
_cnt1_p1:   RMB 1       ; Debouncing 2
_cnt1_key:  RMB 1       ; Currently pressed key
_cnt2_p0:   RMB 1       ; Debouncing 1
_cnt2_p1:   RMB 1       ; Debouncing 2
_cnt2_key:  RMB 1       ; Currently pressed key
    ENDI
    IF DEFINED intybasic_scroll
_scroll_x:  RMB 1       ; Scroll X offset
_scroll_y:  RMB 1       ; Scroll Y offset
_scroll_d:  RMB 1       ; Scroll direction
    ENDI
    IF DEFINED intybasic_music
_music_mode: RMB 1      ; Music mode (0= Not using PSG, 2= Simple, 4= Full, add 1 if using noise channel for drums)
_music_frame: RMB 1     ; Music frame (for 50 hz fixed)
_music_tc:  RMB 1       ; Time counter
_music_t:   RMB 1       ; Time base
_music_i1:  RMB 1       ; Instrument 1 
_music_s1:  RMB 1       ; Sample pointer 1
_music_n1:  RMB 1       ; Note 1
_music_i2:  RMB 1       ; Instrument 2
_music_s2:  RMB 1       ; Sample pointer 2
_music_n2:  RMB 1       ; Note 2
_music_i3:  RMB 1       ; Instrument 3
_music_s3:  RMB 1       ; Sample pointer 3
_music_n3:  RMB 1       ; Note 3
_music_s4:  RMB 1       ; Sample pointer 4
_music_n4:  RMB 1       ; Note 4 (really it's drum)

_music_freq10:	RMB 1   ; Low byte frequency A
_music_freq20:	RMB 1   ; Low byte frequency B
_music_freq30:	RMB 1   ; Low byte frequency C
_music_freq11:	RMB 1   ; High byte frequency A
_music_freq21:	RMB 1   ; High byte frequency B
_music_freq31:	RMB 1   ; High byte frequency C
_music_mix:	RMB 1   ; Mixer
_music_noise:	RMB 1   ; Noise
_music_vol1:	RMB 1   ; Volume A
_music_vol2:	RMB 1   ; Volume B
_music_vol3:	RMB 1   ; Volume C
    ENDI
    IF DEFINED intybasic_music_volume
_music_vol:	RMB 1	; Global music volume
    ENDI
    IF DEFINED intybasic_voice
IV.QH:     RMB 1    ; IV_xxx        8-bit           Voice queue head
IV.QT:     RMB 1    ; IV_xxx        8-bit           Voice queue tail
IV.FLEN:   RMB 1    ; IV_xxx        8-bit           Length of FIFO data
    ENDI


V25:	RMB 1	; DATALEN
V1:	RMB 1	; I
V10:	RMB 1	; INPLEN
V2:	RMB 1	; J
V33:	RMB 1	; K
V3:	RMB 1	; M
V21:	RMB 1	; MARQIT
V19:	RMB 1	; N
V5:	RMB 1	; SKIPTOEND
_SCRATCH:	EQU $

SYSTEM:	ORG $2F0, $2F0, "-RWBN"
STACK:	RMB 24
V17:	RMB 1	; #AD
V7:	RMB 1	; #ADDR1
V12:	RMB 1	; #ADDR2
V18:	RMB 1	; #ADDR3
V26:	RMB 1	; #BITLEN
V28:	RMB 1	; #DATAPTR
V11:	RMB 1	; #INPPTR
V20:	RMB 1	; #MARQOFF
V4:	RMB 1	; #MARQPTR
V22:	RMB 1	; #MARQTEMP
V27:	RMB 1	; #MPTR
V6:	RMB 1	; #NONCEH
V9:	RMB 1	; #NONCEL
V30:	RMB 1	; #T1H
V29:	RMB 1	; #T1L
V32:	RMB 1	; #T2H
V31:	RMB 1	; #T2L
V24:	RMB 1	; #TH
V23:	RMB 1	; #TL
V8:	RMB 1	; #TMP1
V16:	RMB 1	; #XH
V14:	RMB 1	; #XL
V15:	RMB 1	; #YH
V13:	RMB 1	; #YL
_SYSTEM:	EQU $
