REM ----------------------------------------------------------------------------
REM mINTY - the IntyBASIC Bitcoin miner 
REM
REM Bitcoin miner implementation taken from "Bitcoin mining the Hard Way" 
REM http://www.righto.com/2014/02/bitcoin-mining-hard-way-algorithms.html
REM
REM SHA256 implementation taken from
REM https://github.com/B-Con/crypto-algorithms/blob/master/sha256.c
REM
REM ----------------------------------------------------------------------------

    INCLUDE "constants.bas"

REM ----------------------------------------------------------------------------
REM Most of the maths is unsigned 

    UNSIGNED dataLen, i, inpLen, j, k, n, m, #marqPtr, marqIt
    UNSIGNED #xl, #xh, #yl, #yh, #tl, #th
    UNSIGNED #addr1, #addr2, #addr3, #tmp1
    UNSIGNED #bitLen, #dataPtr, #inpPtr, #t1l, #t1h, #t2l, #t2h
    UNSIGNED #noncel, #nonceh
    UNSIGNED #marqOff, #marqTemp
    

REM ----------------------------------------------------------------------------
REM Draw the screen, colour-stack with two tone green background

    Mode 0, 0, 0, 0, 0
    FOR i = 0 TO 59
        WAIT
    NEXT i

    Mode 0, 4, 5, 4, 5
    WAIT

    i = 0
    FOR j = 0 TO 11
    
        POKE $201 + i, $2000
        POKE $200 + i, $25       
        POKE $213 + i, $2025
        i = i + 20        
    
    NEXT j
    
    FOR j = 0 TO 15
        POKE $200 + 42 + j, $648 + 4
    NEXT j

    Print At 82 Color 7, "Nonce:"
    Print At 122 Color 7, "Last hash:"
    
    m = 0
    #marqPtr = 0 
    
    GOSUB marqUpdate

    skipToEnd = 0
    

REM ----------------------------------------------------------------------------
REM Play the music

    Wait
    Play Full
    Play Music


REM ----------------------------------------------------------------------------
REM MAIN LOOP interating over nonce values hashing

REM Outer, high word nonce loop

    FOR #nonceh = $0 TO $ffff
    
        #addr1 = $200 + 89
        #tmp1 = #nonceh
        GOSUB writeWord

        POKE $944f, #nonceh / 256
        POKE $944e, #nonceh AND 255
    
REM Inner, low word nonce loop

        FOR #noncel = $0 TO $ffff
        
            IF skipToEnd = 1 THEN

                #nonceh = $3308
                #addr1 = $200 + 89
                #tmp1 = #nonceh
                GOSUB writeWord

                POKE $944f, #nonceh / 256
                POKE $944e, #nonceh AND 255

                #noncel = $7548

                PRINT At 102 Color 3, "Skip to the end"

            END IF

            #addr1 = $200 + 93
            #tmp1 = #noncel
            GOSUB writeWord

            POKE $944d, #noncel / 256
            POKE $944c, #noncel AND 255
        
REM Go hash!

            inpLen = 80
            #inpPtr = $9400
            GOSUB shaDigest

            inpLen = 32
            #inpPtr = $9040
            GOSUB shaDigest
            
REM Write resulting has to the screen

            #addr1 = $905f
            i = 0
            
            #addr2 = $905f
            #addr1 = $200 + 142
            FOR i = 0 TO 3
            
                FOR j = 0 TO 7

                    #tmp1 = PEEK(#addr2)
                    GOSUB writeByte
                    #addr1 = #addr1 + 2
                    #addr2 = #addr2 - 1
                    
                NEXT j
                
                #addr1 = #addr1 + 4                
                
            NEXT i
            
            #addr1 = $905f
            
REM Check for leading zeros in the hash

leadingZero:

            IF (PEEK(#addr1) = 0) THEN
                i = i + 1
                #addr1 = #addr1 - 1
                GOTO leadingZero
            END IF
            
            IF (i > 7) THEN
                GOTO found
            END IF
            
        NEXT #noncel
        
    NEXT #nonceh
                
done:

    FOR i = 0 TO 12
        WAIT
    NEXT i
    
    GOSUB marqUpdate
    GOTO done


REM ----------------------------------------------------------------------------
REM A coin is found!

found:

    #yl = 0
    PRINT At 102 Color 6, "!! COIN FOUND !!"
    GOTO done



REM DONE MAIN LOOP
REM ----------------------------------------------------------------------------
REM SUBROUTINES FROM HERE ON



REM ----------------------------------------------------------------------------
REM Add a 32 bit number in X to Y storing the result in Y
addxy: PROCEDURE

    IF (#xl + #yl < #xl) THEN #yh = #yh + #xh + 1 ELSE #yh = #yh + #xh
    #yl = #yl + #xl

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM AND a 32 bit number in X to Y storing the result in Y
andxy: PROCEDURE

    #yl = #yl AND #xl
    #yh = #yh AND #xh

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM CH - (x & y) ^ (~x & z) 
ch: PROCEDURE

    #ad = #addr1
    GOSUB ldx
    #ad = #addr2
    GOSUB ldy
    GOSUB andxy
    GOSUB myt
    GOSUB notx
    #ad = #addr3
    GOSUB ldy
    GOSUB andxy
    GOSUB xorty
    
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM EPO - rotr(x, 2) ^ rotr(x, 13) ^ rotr(x, 22)
ep0: PROCEDURE

    #ad = #addr1
    GOSUB ldx
    GOSUB mxy
    n = 2
    GOSUB rotrxn
    n = 13
    GOSUB rotryn
    GOSUB xorxy
    GOSUB ldx
    n = 22
    GOSUB rotrxn
    GOSUB xorxy
            
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM EP1 - rotr(x, 6) ^ rotr(x, 11) ^ rotr(x, 25)
ep1: PROCEDURE

    #ad = #addr1
    GOSUB ldx
    GOSUB mxy
    n = 6
    GOSUB rotrxn
    n = 11
    GOSUB rotryn
    GOSUB xorxy
    GOSUB ldx
    n = 25
    GOSUB rotrxn
    GOSUB xorxy
            
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Load a 32bit number from #ad into X
ldx: PROCEDURE

    #xl = PEEK(#ad)
    #xh = PEEK(#ad + 1)

    RETURN

    END


REM ----------------------------------------------------------------------------
REM Load a 32bit number from #ad into Y
ldy: PROCEDURE

    #yl = PEEK(#ad)
    #yh = PEEK(#ad + 1)

    RETURN

    END


REM ----------------------------------------------------------------------------
REM MAJ - (x & y) ^ (x & z)  ^ (y & z)
maj: PROCEDURE

    #ad = #addr1
    GOSUB ldx
    #ad = #addr2
    GOSUB ldy
    GOSUB andxy
    GOSUB myt
    
    #ad = #addr3
    GOSUB ldy
    GOSUB andxy
    GOSUB xorty
    GOSUB myt
    
    #ad = #addr2
    GOSUB ldx
    #ad = #addr3
    GOSUB ldy
    GOSUB andxy
    GOSUB xorty
        
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Update the marquee
marqUpdate: PROCEDURE

    #marqOff = $9980 + #marqPtr
    FOR marqIt = 0 TO 15
    
        #marqTemp = PEEK(#marqOff + marqIt)
        IF (#marqTemp = 0) THEN
            #marqOff = $9980 - marqIt
            #marqTemp = PEEK(#marqOff + marqIt)    
        END IF
        
        POKE $200 + 22 + marqIt, #marqTemp 
        
    NEXT marqIt
    
    IF (#yl AND 1) = 0 THEN
    
        FOR m = 220 TO 20 STEP - 20
            POKE $200 + m, PEEK($1ec + m)
        NEXT m
        
        IF ((#yl AND 6) = 0) OR (CONT1.LEFT <> 0) OR (CONT2.LEFT <> 0) THEN 
            POKE $200, $27 
        ELSE
            POKE $200, $25
        END IF
    
    END IF

    IF (#yl AND $10) = 0 THEN
    
        FOR m = 220 TO 20 STEP - 20
            POKE $213 + m, PEEK($1ff + m)
        NEXT m
        
        IF ((#yl AND $60) = 0) OR (CONT1.RIGHT <> 0) OR (CONT2.RIGHT <> 0) THEN 
            POKE $213, $2027
        ELSE 
            POKE $213, $2025
        END IF
    
    END IF

    #marqPtr = #marqPtr + 1
    IF (PEEK($9980 + #marqPtr) = 0) THEN #marqPtr = 0
    m = 0
    
    if (CONT1.DOWN <> 0) OR (CONT2.DOWN <> 0) THEN
        skipToEnd = 1
        PRINT At 103 Color 3, "Skip requested"
    END IF

    RETURN
    
    END
    

REM ----------------------------------------------------------------------------
REM Move a 32bit number from X to T
mxt: PROCEDURE

    #tl = #xl
    #th = #xh

    RETURN

    END


REM ----------------------------------------------------------------------------
REM Move a 32bit number from X to Y
mxy: PROCEDURE

    #yl = #xl
    #yh = #xh

    RETURN

    END


REM ----------------------------------------------------------------------------
REM Move a 32bit number from Y to T
myt: PROCEDURE

    #tl = #yl
    #th = #yh

    RETURN

    END


REM ----------------------------------------------------------------------------
REM Logical NOT a 32 bit number in X
notx: PROCEDURE

    #xl = NOT #xl
    #xh = NOT #xh

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Logical OR a 32 bit number in T to X storing the result in X
ortx: PROCEDURE

    #xl = #xl OR #tl
    #xh = #xh OR #th

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Logical OR a 32 bit number in T to Y storing the result in Y
orty: PROCEDURE

    #yl = #yl OR #tl
    #yh = #yh OR #th

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Rotate a 32 bit number in X right by n positions
rotrxn: PROCEDURE

    GOSUB mxt
    GOSUB slrxn
    n = 32 - n
    GOSUB slltn
    n = 32 - n
    GOSUB ortx
    
    RETURN

    END


REM ----------------------------------------------------------------------------
REM Rotate a 32 bit number in Y right by n positions
rotryn: PROCEDURE

    GOSUB myt
    GOSUB slryn
    n = 32 - n
    GOSUB slltn
    n = 32 - n
    GOSUB orty
    
    RETURN

    END


REM ----------------------------------------------------------------------------
REM Evaluate a SHA digest
shaDigest: PROCEDURE  
    
    FOR i = 0 TO inpLen - 1
        POKE $9100 + i, PEEK(#inpPtr + i)
    NEXT i
    
    GOSUB shaInit
    GOSUB shaUpdate
    GOSUB shaFinal

    #addr1 = $9040
    FOR j = 0 TO 14 STEP 2
    
        POKE #addr1, PEEK($9001 + j) / 256
        #addr1 = #addr1 + 1
        POKE #addr1, PEEK($9001 + j) AND 255
        #addr1 = #addr1 + 1
        POKE #addr1, PEEK($9000 + j) / 256
        #addr1 = #addr1 + 1
        POKE #addr1, PEEK($9000 + j) AND 255
        #addr1 = #addr1 + 1
        
    NEXT j

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Initialise the SHA algorithm
shaInit: PROCEDURE

    dataLen = 0
    #bitLen = 0
    
    POKE $9000, $e667
    POKE $9001, $6a09

    POKE $9002, $ae85
    POKE $9003, $bb67

    POKE $9004, $f372
    POKE $9005, $3c6e

    POKE $9006, $f53a
    POKE $9007, $a54f
    
    POKE $9008, $527f
    POKE $9009, $510e
    
    POKE $900a, $688c
    POKE $900b, $9b05
    
    POKE $900c, $d9ab
    POKE $900d, $1f83
    
    POKE $900e, $cd19
    POKE $900f, $5be0
    
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Transform SHA state with additional data
shaTransform: PROCEDURE

    #mPtr = $9300
    #dataPtr = $9200
    FOR j = 0 TO 15
    
        POKE #mPtr, PEEK(#dataPtr + 2) * 256 + PEEK(#dataPtr + 3)
        #mPtr = #mPtr + 1

        POKE #mPtr,  PEEK(#dataPtr) * 256 + PEEK(#dataPtr + 1)
        #mPtr = #mPtr + 1
        
        #dataPtr = #dataPtr + 4
    
    NEXT j
    
    FOR j = 16 TO 63
    
        m = m + 1
        IF (m = 4) THEN GOSUB marqUpdate
    
        #addr1 = #mPtr - 4
        GOSUB sig1

        #xl = PEEK(#mPtr - 14)
        #xh = PEEK(#mPtr - 13)
        GOSUB addxy
        
        #t1l = #yl
        #t1h = #yh
                    
        #addr1 = #mPtr - 30
        GOSUB sig0
        
        #xl = #t1l
        #xh = #t1h
        GOSUB addxy        
        
        #xl = PEEK(#mPtr - 32)
        #xh = PEEK(#mPtr - 31)
        GOSUB addxy
        
        POKE #mPtr, #yl
        #mPtr = #mPtr + 1
        
        POKE #mPtr, #yh
        #mPtr = #mPtr + 1
        
    NEXT j
    
    REM a = ctx->state[0]; etc 
    
    FOR j = 0 TO 15
        POKE $9010 + j, PEEK($9000 + j)
    NEXT j


    FOR j = 0 TO 126 STEP 2
    
        m = m + 1
        IF (m = 3) THEN GOSUB marqUpdate
        
        REM t1 = h + EP1(e) + CH(e,f,g) + k[j] + m[j];
        
        #addr1 = $9018
        GOSUB ep1
        
        #xl = PEEK($901e)
        #xh = PEEK($901f)
        GOSUB addxy
        #t1l = #yl
        #t1h = #yh
        
        #addr1 = $9018
        #addr2 = $901a
        #addr3 = $901c
        GOSUB ch
        #xl = #t1l
        #xh = #t1h
        GOSUB addxy

        #xl = PEEK($9800 + j)
        #xh = PEEK($9801 + j)
        GOSUB addxy
        
        #xl = PEEK($9300 + j)
        #xh = PEEK($9301 + j)
        GOSUB addxy
        
        #t1l = #yl
        #t1h = #yh
               
        REM t2 = EP0(a) + MAJ(a,b,c);
        
        #addr1 = $9010
        GOSUB ep0
        #t2l = #yl
        #t2h = #yh
        
        #addr1 = $9010
        #addr2 = $9012
        #addr3 = $9014
        GOSUB maj
        #xl = #t2l
        #xh = #t2h
        GOSUB addxy
        #t2l = #yl
        #t2h = #yh        

        REM h = g;

        POKE $901e, PEEK($901c)
        POKE $901f, PEEK($901d)
        
        REM g = f;
	
        POKE $901c, PEEK($901a)
        POKE $901d, PEEK($901b)

        REM f = e;
        
        POKE $901a, PEEK($9018)
        POKE $901b, PEEK($9019)

	REM e = d + t1;
        
        #xl = PEEK($9016)
        #xh = PEEK($9017)
        #yl = #t1l
        #yh = #t1h
        GOSUB addxy
        POKE $9018, #yl
        POKE $9019, #yh
        
        REM d = c;
                
        POKE $9016, PEEK($9014)
        POKE $9017, PEEK($9015)

        REM c = b;
                
        POKE $9014, PEEK($9012)
        POKE $9015, PEEK($9013)

        REM b = a;
                
        POKE $9012, PEEK($9010)
        POKE $9013, PEEK($9011)
                
        REM a = t1 + t2;
        
        #xl = #t1l
        #xh = #t1h
        #yl = #t2l
        #yh = #t2h
        GOSUB addxy
        POKE $9010, #yl
        POKE $9011, #yh
        
    NEXT j

    REM ctx->state[0] += a; etc 

    FOR j = 0 TO 14 STEP 2
    
        #xl = PEEK($9010 + j)
        #xh = PEEK($9011 + j)
        #yl = PEEK($9000 + j)
        #yh = PEEK($9001 + j)
        GOSUB addxy
        POKE $9000 + j, #yl
        POKE $9001 + j, #yh
        
    NEXT j

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Finalise SHA digest
shaFinal: PROCEDURE

    POKE $9200 + dataLen, $80
    IF (dataLen < 56) THEN
    
        FOR i = dataLen + 1 TO 55
            POKE $9200 + i, $00
        NEXT i
    
    ELSE
    
        FOR i = datalen + 1 TO 63
            POKE $9200 + i, $00
        NEXT i
        
        GOSUB shaTransform
        
        FOR i = 0 TO 55
            POKE $9200 + i, $00
        NEXT i        
    
    END IF
    
    #bitLen = #bitLen + (8 * dataLen)
    POKE $9200 + 63, #bitLen AND $ff
    POKE $9200 + 62, #bitLen / 256
    POKE $9200 + 61, 0
    POKE $9200 + 60, 0
    POKE $9200 + 59, 0
    POKE $9200 + 58, 0
    POKE $9200 + 57, 0
    POKE $9200 + 56, 0
    GOSUB shaTransform
    
    RETURN
    
    END
    

REM ----------------------------------------------------------------------------
REM Update SHA state with additional data
shaUpdate: PROCEDURE

    FOR k = 0 TO inpLen - 1
    
        POKE $9200 + dataLen, PEEK($9100 + k)
        dataLen = dataLen + 1
        IF dataLen = 64 THEN
        
            GOSUB shaTransform
            #bitLen = #bitLen + 512
            dataLen = 0
        
        END IF
    
    NEXT k

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM SIG0 - rotr(x, 7) ^ rotr(x, 18) ^ slr(x, 3)
sig0: PROCEDURE

    #ad = #addr1
    GOSUB ldx
    GOSUB mxy
    n = 7
    GOSUB rotrxn
    n = 18
    GOSUB rotryn
    GOSUB xorxy
    GOSUB ldx
    n = 3
    GOSUB slrxn
    GOSUB xorxy
            
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM SIG1 - rotr(x, 17) ^ rotr(x, 19) ^ slr(x, 10)
sig1: PROCEDURE

    #ad = #addr1
    GOSUB ldx
    GOSUB mxy
    n = 17
    GOSUB rotrxn
    n = 19
    GOSUB rotryn
    GOSUB xorxy
    GOSUB ldx
    n = 10
    GOSUB slrxn
    GOSUB xorxy
            
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Shift a 32 bit number in T left by one position
sllt: PROCEDURE

    IF (#tl * 2 < #tl) THEN
        #th = #th * 2 + 1
    ELSE
        #th = #th * 2
    END IF
    #tl = #tl * 2      

    RETURN

    END


REM ----------------------------------------------------------------------------
REM Shift a 32 bit number in T left by n positions
slltn: PROCEDURE

    FOR i = 1 to n
        GOSUB sllt
    NEXT i
    
    RETURN

    END


REM ----------------------------------------------------------------------------
REM Logical shift a 32 bit number in X right by one position
slrx: PROCEDURE

    IF (#xh % 2 = 1) THEN
        #xl = #xl / 2 + $8000
    ELSE
        #xl = #xl / 2
    END IF
    
    #xh = #xh / 2
    
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Logical shift a 32 bit number in X right by n positions
slrxn: PROCEDURE

    FOR i = 1 to n
        GOSUB slrx
    NEXT i
    
    RETURN

    END


REM ----------------------------------------------------------------------------
REM Logical shift a 32 bit number in X right by one position
slry: PROCEDURE

    IF (#yh % 2 = 1) THEN
        #yl = #yl / 2 + $8000
    ELSE
        #yl = #yl / 2
    END IF
    
    #yh = #yh / 2
    
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Logical shift a 32 bit number in Y right by n positions
slryn: PROCEDURE

    FOR i = 1 to n
        GOSUB slry
    NEXT i
    
    RETURN

    END


REM ----------------------------------------------------------------------------
REM XOR a 32 bit number in X to Y storing the result in Y
xorxy: PROCEDURE

    #yl = #yl XOR #xl
    #yh = #yh XOR #xh

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM XOR a 32 bit number in T to Y storing the result in Y
xorty: PROCEDURE

    #yl = #yl XOR #tl
    #yh = #yh XOR #th

    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Write a hex byte to the screen
writeByte: PROCEDURE

    POKE #addr1, PEEK($9900 + ((#tmp1 / 16) AND 15))
    POKE #addr1 + 1, PEEK($9900 + (#tmp1 AND 15))
    
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Write a 16bit hex word to the screen
writeWord: PROCEDURE

    POKE #addr1, PEEK($9900 + (#tmp1 / 4096))
    POKE #addr1 + 1, PEEK($9900 + ((#tmp1 / 256) AND 15))
    POKE #addr1 + 2, PEEK($9900 + ((#tmp1 / 16) AND 15))
    POKE #addr1 + 3, PEEK($9900 + (#tmp1 AND 15))
    
    RETURN
    
    END


REM ----------------------------------------------------------------------------
REM Define workspace RAM

ASM ORG $9000, $9000, "+RW"
ASM RMB $800

REM $9000 - Internal state of the SHA256 hash
REM $9010 - Internal temporary state of the SHA256 hash
REM $9040 - Hash output
REM $9100 - Hash input data
REM $9200 - Single hash block
REM $9300 - Compressed single hash block


REM ----------------------------------------------------------------------------
REM Initial hash value

ASM ORG $9400

REM bitcoin version

    DATA $02, $00, $00, $00

REM previous hash block

    DATA $17, $97, $5b, $97, $c1, $8e, $d1, $f7
    DATA $e2, $55, $ad, $f2, $97, $59, $9b, $55
    DATA $33, $0e, $da, $b8, $78, $03, $c8, $17
    DATA $01, $00, $00, $00, $00, $00, $00, $00

REM Merkel root

    DATA $8a, $97, $29, $5a, $27, $47, $b4, $f1
    DATA $a0, $b3, $94, $8d, $f3, $99, $03, $44
    DATA $c0, $e1, $9f, $a6, $b2, $b9, $2b, $3a
    DATA $19, $c8, $e6, $ba, $dc, $14, $17, $87

REM date / time

    DATA $35, $8b, $05, $53
       
REM difficulty bits

    DATA $53, $5f, $01, $19

REM nonce value (REMed out so it is RAM rather than ROM)

REM DATA $0, $0, $0, $0


REM ----------------------------------------------------------------------------
REM SHA 256 data table

ASM ORG $9800

    DATA $2f98, $428a, $4491, $7137, $fbcf, $b5c0, $dba5, $e9b5
    DATA $c25b, $3956, $11f1, $59f1, $82a4, $923f, $5ed5, $ab1c
    DATA $aa98, $d807, $5b01, $1283, $85be, $2431, $7dc3, $550c
    DATA $5d74, $72be, $b1fe, $80de, $06a7, $9bdc, $f174, $c19b 
    DATA $69c1, $e49b, $4786, $efbe, $9dc6, $0fc1, $a1cc, $240c
    DATA $2c6f, $2de9, $84aa, $4a74, $a9dc, $5cb0, $88da, $76f9 
    DATA $5152, $983e, $c66d, $a831, $27c8, $b003, $7fc7, $bf59
    DATA $0bf3, $c6e0, $9147, $d5a7, $6351, $06ca, $2967, $1429 
    DATA $0a85, $27b7, $2138, $2e1b, $6dfc, $4d2c, $0d13, $5338
    DATA $7354, $650a, $0abb, $766a, $c92e, $81c2, $2c85, $9272 
    DATA $e8a1, $a2bf, $664b, $a81a, $8b70, $c24b, $51a3, $c76c
    DATA $e819, $d192, $0624, $d699, $3585, $f40e, $a070, $106a 
    DATA $c116, $19a4, $6c08, $1e37, $774c, $2748, $bcb5, $34b0
    DATA $0cb3, $391c, $aa4a, $4ed8, $ca4f, $5b9c, $6ff3, $682e 
    DATA $82ee, $748f, $636f, $78a5, $7814, $84c8, $0208, $8cc7
    DATA $fffa, $90be, $6ceb, $a450, $a3f7, $bef9, $78f2, $c671


REM ----------------------------------------------------------------------------
REM Hex alphabet in tan foreground

ASM ORG $9900

    DATA $83, $8b, $93, $9b, $a3, $ab, $b3, $bb
    DATA $c3, $cb, $10b, $113, $11b, $123, $12b, $133


REM ----------------------------------------------------------------------------
REM Marquee message

ASM ORG $9980

    DATA $007, $007, $007, $007, $007, $007, $007, $007
    DATA $007, $007, $007, $007, $007, $007, $007, $007
    DATA $227, $22f, $21f, $267, $22f, $007, $287, $297
    DATA $22f, $29f, $22f, $277, $2a7, $29f, $077, $077
    DATA $077, $007, $007, $007, $0ec, $003, $023, $003
    DATA $0ec, $003, $023, $003, $0ec, $007, $007, $26f
    DATA $14f, $177, $1a7, $1cf, $007, $007, $0ec, $003
    DATA $023, $003, $0ec, $003, $023, $003, $0ec, $007
    DATA $007, $007, $077, $077, $077, $20f, $007, $117
    DATA $24f, $2a7, $21f, $27f, $24f, $277, $007, $26f
    DATA $24f, $277, $22f, $297, $007, $237, $27f, $297
    DATA $007, $2a7, $247, $22f, $007, $16f, $20f, $2a7
    DATA $2a7, $22f, $267, $007, $14f, $277, $2a7, $22f
    DATA $267, $267, $24f, $2b7, $24f, $29f, $24f, $27f
    DATA $277, $007, $2bf, $297, $24f, $2a7, $2a7, $22f
    DATA $277, $007, $047, $297, $20f, $2a7, $247, $22f
    DATA $297, $007, $217, $20f, $227, $267, $2cf, $04f
    DATA $007, $24f, $277, $007, $14f, $277, $2a7, $2cf
    DATA $117, $10f, $19f, $14f, $11f, $077, $007, $007
    DATA $26f, $14f, $177, $1a7, $1cf, $007, $2bf, $24f
    DATA $267, $267, $007, $2a7, $20f, $25f, $22f, $007
    DATA $0af, $087, $087, $007, $2cf, $22f, $20f, $297
    DATA $29f, $007, $2a7, $27f, $007, $26f, $24f, $277
    DATA $22f, $007, $20f, $007, $29f, $24f, $277, $23f
    DATA $267, $22f, $007, $21f, $27f, $24f, $277, $00f
    DATA $007, $007, $14f, $277, $007, $2a7, $247, $20f
    DATA $2a7, $007, $2a7, $24f, $26f, $22f, $007, $24f
    DATA $2a7, $007, $2bf, $24f, $267, $267, $007, $287
    DATA $267, $20f, $2cf, $007, $16f, $27f, $277, $22f
    DATA $2cf, $067, $007, $16f, $27f, $277, $22f, $2cf
    DATA $067, $007, $16f, $27f, $277, $22f, $2cf, $007
    DATA $20f, $287, $287, $297, $27f, $2c7, $26f, $24f
    DATA $26f, $20f, $2a7, $22f, $267, $2cf, $007, $0cf
    DATA $0af, $007, $26f, $24f, $267, $267, $24f, $27f
    DATA $277, $007, $2a7, $24f, $26f, $22f, $29f, $007
    DATA $20f, $277, $227, $007, $21f, $27f, $277, $29f
    DATA $2af, $26f, $22f, $007, $277, $22f, $20f, $297
    DATA $267, $2cf, $007, $08f, $007, $1a7, $157, $27f
    DATA $2af, $267, $22f, $007, $27f, $237, $007, $22f
    DATA $277, $22f, $297, $23f, $2cf, $067, $007, $22f
    DATA $277, $27f, $2af, $23f, $247, $007, $2a7, $27f
    DATA $007, $217, $27f, $24f, $267, $007, $20f, $007
    DATA $25f, $22f, $2a7, $2a7, $267, $22f, $007, $26f
    DATA $27f, $297, $22f, $007, $2a7, $247, $20f, $277
    DATA $007, $097, $007, $26f, $24f, $267, $267, $24f
    DATA $27f, $277, $007, $2a7, $24f, $26f, $22f, $29f
    DATA $00f, $007, $007, $127, $27f, $277, $03f, $2a7
    DATA $007, $23f, $24f, $2b7, $22f, $007, $2af, $287
    DATA $007, $2a7, $247, $22f, $007, $227, $20f, $2cf
    DATA $007, $257, $27f, $217, $077, $077, $077, $007
    DATA $007, $007, $007, $007, $007, $007, $007, $007
    DATA $077, $077, $077, $11f, $20f, $277, $03f, $2a7
    DATA $007, $2bf, $20f, $24f, $2a7, $007, $2a7, $247
    DATA $20f, $2a7, $007, $267, $27f, $277, $23f, $0ff
    DATA $007, $007, $007, $007, $007, $007, $007, $007
    DATA $077, $077, $077, $187, $297, $22f, $29f, $29f
    DATA $007, $223, $27b, $2bb, $273, $007, $2a7, $27f
    DATA $007, $03f, $29f, $25f, $24f, $287, $007, $2a7
    DATA $27f, $007, $2a7, $247, $22f, $007, $22f, $277
    DATA $227, $03f, $077, $077, $077, $007, $007, $007
    DATA $007, $007, $007, $007, $007, $077, $077, $077
    DATA $29f, $247, $20f, $26f, $22f, $007, $2a7, $247
    DATA $24f, $29f, $007, $21f, $20f, $277, $03f, $2a7
    DATA $007, $217, $22f, $007, $227, $27f, $277, $22f
    DATA $007, $2bf, $247, $22f, $277, $007, $26f, $24f
    DATA $277, $24f, $277, $23f, $007, $27f, $2a7, $247
    DATA $22f, $297, $007, $21f, $27f, $24f, $277, $29f
    DATA $00f, $000


REM ----------------------------------------------------------------------------
REM Music - Money, Money, Money, baby!
REM MIDI source - http://home.freeuk.net/rr/music/midi/abba/index.html
REM Converted to IntyBASIC using MusoCheat - 
REM     http://atariage.com/forums/topic/264422-musocheat-adequate-inty-music-for-non-musicians/

Music:
    DATA     2
    MUSIC F2#Y,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F2#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F2#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F2#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,  E4Y,  E5Y
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -

REM Timing 100 frames, 2.00 secs

    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    -,    -
    MUSIC   E5,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   C6,   C5,    -
    MUSIC    S,    S,    -
    MUSIC   E6,   E5,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -

REM Timing 200 frames, 4.00 secs

    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    -,    -
    MUSIC   F5,   F4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   C6,   C5,    -
    MUSIC    S,    S,    -
    MUSIC  D6#,  D5#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   D6,   D3,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   C6,    S,   C5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S

REM Timing 300 frames, 6.00 secs

    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC   A5,    S,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   C6,   E3,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   E3,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   C4,   A4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A2,    -,    -
    MUSIC    S,   E3,    -
    MUSIC    S,    S,   A3
    MUSIC    S,    S,    S
    MUSIC   C3,    -,    -
    MUSIC    -,   E3,    -
    MUSIC    -,    S,    -
    MUSIC   A3,    -,    -

REM Timing 400 frames, 8.00 secs

    MUSIC    S,   C4,    -
    MUSIC   E4,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,   A6,   A4
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S

REM Timing 500 frames, 10.00 secs

    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC   E6,    -,   E4
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S

REM Timing 600 frames, 12.00 secs

    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC   E6,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC   B5,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   C6,   A2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4

REM Timing 700 frames, 14.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC   E4,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   F4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,  G2#,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,  G3#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -

REM Timing 800 frames, 16.00 secs

    MUSIC  G4#,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   E2,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   E3,   D2,   E2
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,   E4,   E2
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B4,   D5,   B2
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   E3,   B4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E2,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   D5,   E2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S

REM Timing 900 frames, 18.00 secs

    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   A5,   A2,    -
    MUSIC    S,    S,    -
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC   C6,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC   E6,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -

REM Timing 1000 frames, 20.00 secs

    MUSIC    -,    S,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,   A2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   F4,  G2#,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -

REM Timing 1100 frames, 22.00 secs

    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E4,  G2#,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  G4#,  G2#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E3,   E2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E2,   D2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -

REM Timing 1200 frames, 24.00 secs

    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   E3,   E2,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F5,   E3,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E2,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F5,   E2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC   A5,   A2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S

REM Timing 1300 frames, 26.00 secs

    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC   C6,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC   E6,    -,   E4
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A5,   A2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   A2,   B4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   A2,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   A2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   A2,    S
    MUSIC    S,    S,    S

REM Timing 1400 frames, 28.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A2,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   A2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   A2,  G4#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   A2,  G4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A2,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B4,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A4,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,   B2,    S
    MUSIC    S,    S,    S

REM Timing 1500 frames, 30.00 secs

    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,   G2,   G3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,   G2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   F3,   F2,  F2#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,   D5,  A4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   D5,  A4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,   F2
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   C5,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   C5,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,   F2

REM Timing 1600 frames, 32.00 secs

    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   C5,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B4,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B4,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,   F2,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   F2,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   B4,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   A4,   F2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,   B2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,   E2,   E4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    -,    S

REM Timing 1700 frames, 34.00 secs

    MUSIC   A4,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   A4,   B2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC   B4,   D3,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   B4,   D2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   A4,   D3,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,   B2,   D2
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   B4,   D3,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   B4,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   D2,   E2
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A4,   D3,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -

REM Timing 1800 frames, 36.00 secs

    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   B4,  D3#,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC   B4,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,  D2#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   A4,  D3#,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   A4,   B2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   C5,  D3#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   C5,  D2#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC  D3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -

REM Timing 1900 frames, 38.00 secs

    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  G3#,   B3,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   E2,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,   D3
    MUSIC    S,    S,    S
    MUSIC   E3,    -,    -
    MUSIC    S,    -,    -
    MUSIC  G3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B3,    -
    MUSIC    -,    S,    -
    MUSIC   E4,    -,    -
    MUSIC    S,    -,    -
    MUSIC  G3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B3,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,   D4
    MUSIC    S,    S,    S
    MUSIC   E4,  G4#,    S
    MUSIC    S,    S,    S
    MUSIC   B4,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S

REM Timing 2000 frames, 40.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B2,   B3,    -
    MUSIC    S,    S,   C3
    MUSIC   C4,   D4,    S
    MUSIC    S,    S,    S
    MUSIC   E3,    S,   E4
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   F3,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D4,   D3,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   E3,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C4,   C3,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D4,   D3,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -

REM Timing 2100 frames, 42.00 secs

    MUSIC   B3,   B2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   E2,   E3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   F4,   F2,   F3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D4,   D2,   D3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E4,   E2,   E3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C4,   C2,   C3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC   D4,   D2,   D3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B3,   B2,   B2
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C4,   C2,   C3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S

REM Timing 2200 frames, 44.00 secs

    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   G5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -

REM Timing 2300 frames, 46.00 secs

    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -

REM Timing 2400 frames, 48.00 secs

    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC   F4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,    S,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -

REM Timing 2500 frames, 50.00 secs

    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S

REM Timing 2600 frames, 52.00 secs

    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   G5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5

REM Timing 2700 frames, 54.00 secs

    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   C6,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,   E5

REM Timing 2800 frames, 56.00 secs

    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B2,   F4,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,    S,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S

REM Timing 2900 frames, 58.00 secs

    MUSIC   E4,   A2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A4,   B2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC   F5,   A2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,  F3#,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,   D2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,  F3#
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   E4
    MUSIC    -,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   G5,  F3#,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC   F5,  F3#,    -
    MUSIC    S,    S,    -

REM Timing 3000 frames, 60.00 secs

    MUSIC   D5,   C2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E5,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,   E2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,  F3#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,   D2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,  F3#
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,   B2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,   D2,   A4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S

REM Timing 3100 frames, 62.00 secs

    MUSIC    -,    -,    S
    MUSIC   B2,   E4,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    S
    MUSIC    -,    S,    S
    MUSIC    -,    -,    S
    MUSIC   B2,   E4,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A2,   E4,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,  F3#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   F5,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,  F3#,    S
    MUSIC    -,    S,    S
    MUSIC    -,    -,    S
    MUSIC   E5,   A2,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   F5,   B2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,  F3#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E5,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A4,   E2,  C4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC   D5,  A2#,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -

REM Timing 3200 frames, 64.00 secs

    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,   D3,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,   E2,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC  F3#,   D3,    -
    MUSIC    S,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   E2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S

REM Timing 3300 frames, 66.00 secs

    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   E2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC   D4,   D2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   D4,   A3,   B2
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   D4,   F3,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -

REM Timing 3400 frames, 68.00 secs

    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   E2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   F3,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   D2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   A5,    S,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E6,   A2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E6,    S,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E6,    S,   E5
    MUSIC    S,    S,    S

REM Timing 3500 frames, 70.00 secs

    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E5,   E2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   A5,   A2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   C3,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E3,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  D6#,  D3#,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC  D6#,    S,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC  D6#,    S,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC  D6#,    S,  D5#

REM Timing 3600 frames, 72.00 secs

    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC  D6#,    S,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   F5,   F2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   A5,   A2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   C3,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  D6#,  D3#,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   D6,   D3,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   C6,    S,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A4,   C5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   E3,   E5

REM Timing 3700 frames, 74.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   E3,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   A5,    S,   C5
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S

REM Timing 3800 frames, 76.00 secs

    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -

REM Timing 3900 frames, 78.00 secs

    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   F4,   A2,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   F4,   A2,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S

REM Timing 4000 frames, 80.00 secs

    MUSIC    -,    S,    S
    MUSIC   E4,   A2,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   F4,  G2#,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,  G2#,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  G4#,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S

REM Timing 4100 frames, 82.00 secs

    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   E2,   E2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E2,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E3,   D2,   E2
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   E2,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   B2,   B4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   B4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,   E2
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   E2,   F4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S

REM Timing 4200 frames, 84.00 secs

    MUSIC   B5,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -

REM Timing 4300 frames, 86.00 secs

    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   F4,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,   A2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   F4,  G2#,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  G2#,   B3
    MUSIC    S,    S,    S

REM Timing 4400 frames, 88.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,  G2#,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  G2#,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,  G2#,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  G4#,  G2#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   E2,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E2,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E2,   D2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E3,   E2,    -

REM Timing 4500 frames, 90.00 secs

    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F5,   E2,   B4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A5,   A2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3

REM Timing 4600 frames, 92.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   A2,   B4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   C5,   A2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S

REM Timing 4700 frames, 94.00 secs

    MUSIC    S,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A2,   E2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   B2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   A2,  G4#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   A2,  G4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   A2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC   B4,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A5,   A2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   B2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC   E6,    -,    S
    MUSIC    S,    -,    S

REM Timing 4800 frames, 96.00 secs

    MUSIC   A5,   G2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B5,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   C6,   G2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   F2,   F3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   D5,   F2,  A4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   F2,  A4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,   F2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   F2,   A4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   C5,   F2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   F2,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -

REM Timing 4900 frames, 98.00 secs

    MUSIC    -,    S,    -
    MUSIC   C5,   B2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   F2,   G4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   F2,   G4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,   F2,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   F2,   F4
    MUSIC    S,    S,    S
    MUSIC   B4,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   A4,   F2,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,   B2,   F2
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   E2,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,   E3,   E4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -

REM Timing 5000 frames, 100.00 secs

    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,   B2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC   B4,   D3,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   D2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   A4,   D3,   F4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,   B2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   B2,   F4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   D2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   A4,   B2,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,   B2,  F4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S

REM Timing 5100 frames, 102.00 secs

    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   B4,  D3#,  F4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,  D2#,  F4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,  D2#,  F4#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A4,   B2,  F4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   C5,  D3#,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,  D2#,   E2
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   B4,  D3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   F3,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -

REM Timing 5200 frames, 104.00 secs

    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   D3,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,   E3,   E4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C4,   C3,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D4,   D3,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B3,   B2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E5,   E2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   F5,   F2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D5,   D2,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E5,   E2,   E4
    MUSIC    S,    S,    S

REM Timing 5300 frames, 106.00 secs

    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C5,   C2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC   D5,   D2,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B4,   B2,   B3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   C5,   C2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5

REM Timing 5400 frames, 108.00 secs

    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5

REM Timing 5500 frames, 110.00 secs

    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   C6,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -

REM Timing 5600 frames, 112.00 secs

    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC   F4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   E4,    S,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   E4,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   A3,  F3#,    -
    MUSIC    S,    S,    -

REM Timing 5700 frames, 114.00 secs

    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -

REM Timing 5800 frames, 116.00 secs

    MUSIC    -,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F4#,  F3#,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC  F4#,   B2,  D4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -

REM Timing 5900 frames, 118.00 secs

    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F4,  F3#,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC   B2,   F4,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC   E4,    S,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -

REM Timing 6000 frames, 120.00 secs

    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   E4,    -,   C4
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC   A3,    S,  F3#
    MUSIC    S,    -,    S
    MUSIC   A4,   B2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   A2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D6,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E6,   F3,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -

REM Timing 6100 frames, 122.00 secs

    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F6,   D2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   D6,    -,   D5
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F6,   D2,   G5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   F5,    S,  F3#
    MUSIC    S,    S,    S
    MUSIC   D5,   C2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   A2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   B3,   B2,  G3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B3,  F3#,  G3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E6,   E2,   E5
    MUSIC    S,    S,    S

REM Timing 6200 frames, 124.00 secs

    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D6,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F6,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC   A4,   D2,   E4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,  F3#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,   E6,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,  C4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,   A2,  C4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,   F6,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   E6,   E5

REM Timing 6300 frames, 126.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   F6,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   E5,   E6,   A2
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   E2,   A4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D6,   D2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC   B2,   D4,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC   D4,   F3,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   D4,   E2,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A3,   D3,  F3#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,  D5#

REM Timing 6400 frames, 128.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   E2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   A2,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   B5,   B2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -

REM Timing 6500 frames, 130.00 secs

    MUSIC   C6,   C2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   E4,   E2,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   D4,   D2,   A3
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC   D4,   A3,   B2
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   D4,   F3,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   B5,   E2,   D5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   A5,   F3,   C5
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   E2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S

REM Timing 6600 frames, 132.00 secs

    MUSIC   D2,  F3#,    S
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC   A5,   E2,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,  F3#,    S
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   A2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E6,    S,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,   E4,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E5,   E4,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   A5,   A4,    -
    MUSIC    S,    S,    -

REM Timing 6700 frames, 134.00 secs

    MUSIC    S,    S,    -
    MUSIC   C6,    S,   C5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E5,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   F4,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   G2,   F2,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -

REM Timing 6800 frames, 136.00 secs

    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   C6,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C6#,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC  C6#,  C2#,   F5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F4,   B2,  C4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -

REM Timing 6900 frames, 138.00 secs

    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC  C6#,  C2#,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  D4#,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -

REM Timing 7000 frames, 140.00 secs

    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC  C6#,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C6#,  C2#,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC  D4#,   B2,  C4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  C4#,    S,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC  C4#,   F3,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C4#,   B2,  A3#
    MUSIC    S,    S,    S

REM Timing 7100 frames, 142.00 secs

    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  C4#,   F3,  A3#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,   B2,  C4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC  C4#,   F3,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  A3#,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC  C4#,   B2,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  C4#,   F3,  A3#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C6#,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#

REM Timing 7200 frames, 144.00 secs

    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    -
    MUSIC  C6#,  C2#,   F5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC   F4,   B2,  C4#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   E4,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,  D5#

REM Timing 7300 frames, 146.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC  C6#,  C2#,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC   E4,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  D4#,  F3#,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC  C6#,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -

REM Timing 7400 frames, 148.00 secs

    MUSIC  C6#,  C2#,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    -,    S
    MUSIC  C4#,   B2,   C4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  C4#,    S,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC  C4#,    S,  A3#
    MUSIC    S,    -,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C4#,   B2,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  C4#,   F3,  A3#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,   B2,  C4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,  A2#,  C4#
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC  A3#,    S,  F3#
    MUSIC    S,    S,    S

REM Timing 7500 frames, 150.00 secs

    MUSIC  A4#,   B2,  C4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC  C4#,  A2#,  A3#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F6,  D2#,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F6#,  C2#,  F5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC  D6#,  A2#,  D5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F6,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F6#,   B2,  G5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F5#,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC  D5#,  C2#,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,    S,  F4#
    MUSIC    S,    S,    S

REM Timing 7600 frames, 152.00 secs

    MUSIC    S,    -,    S
    MUSIC   F6,  A2#,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C4,   B2,   A3
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  D4#,   F2,   C4
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC   F6,  D2#,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC  D6#,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F6,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  F6#,  F3#,  F5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  A4#,  D2#,  D4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    S,    S,  F3#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,   F6,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -

REM Timing 7700 frames, 154.00 secs

    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC    S,   B2,   D4
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,  F3#,  G3#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    S,  F6#,  F5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    -,    -
    MUSIC   F5,   F6,  F3#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F6#,   B2,  F5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   F6,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  A5#,   E2,  A4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D6#,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC   B2,  A3#,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S

REM Timing 7800 frames, 156.00 secs

    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,  D4#,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  D4#,   E2,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,  D2#,  F3#
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  C6#,   B2,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   E2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,  A2#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    S,    S
    MUSIC    S,    S,    -
    MUSIC   C6,   C2,  D5#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S

REM Timing 7900 frames, 158.00 secs

    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C6#,  C2#,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A2#,  C5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC   C6,   B2,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C6#,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  D4#,   E2,  C4#
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    S,  F3#,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC  D4#,  D3#,  A3#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A3#,   B2,  F3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC  D4#,  F3#,  A3#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC   C6,   E2,  D5#
    MUSIC    S,    S,    S

REM Timing 8000 frames, 160.00 secs

    MUSIC    S,    -,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  D2#,  C5#
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC  C6#,   B2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC  F3#,    -,    -
    MUSIC    S,    -,    -
    MUSIC    S,    -,    -
    MUSIC  C6#,   F2,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  F3#,    -,    S
    MUSIC    S,    -,    S
    MUSIC  F3#,  D2#,  F2#
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC  F3#,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC  A5#,   B2,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    S,  F3#,    S
    MUSIC    -,    S,    S
    MUSIC    -,    -,    S
    MUSIC   F6,  A2#,  A5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC   F6,    S,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC   F6,   F4,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F6,   F4,   F5

REM Timing 8100 frames, 162.00 secs

    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F6,   F4,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   F6,   F4,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    S
    MUSIC   F5,   F2,   F4
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  A5#,  A2#,  A4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  C6#,  C3#,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   F6,   F3,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E3,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E6,    S,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E6,    S,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E6,    S,   E5
    MUSIC    S,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC   E6,  F4#,   E5

REM Timing 8200 frames, 164.00 secs

    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC   E6,  F4#,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  F5#,  F2#,  F4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  A5#,  A2#,  A4#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  C6#,  C3#,  C5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC   E6,   E3,   E5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC  D6#,  D3#,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC   C6,    S,  D5#
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    -,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  A5#,  A4#,  C5#
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC  C6#,   F3,   F5
    MUSIC    S,    S,    S
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -

REM Timing 8300 frames, 166.00 secs

    MUSIC  C6#,   F3,   F5
    MUSIC    S,    S,    S
    MUSIC    S,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    S
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    S,    -
    MUSIC    -,    -,    -
    MUSIC  A3#,    -,  A4#
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC    S,    -,    S
    MUSIC  A2#,    -,    S
    MUSIC    -,  A2#,    S
    MUSIC    -,    S,    S
    MUSIC  A2#,    -,    S
    MUSIC    S,  A2#,    S
    MUSIC  A2#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,  A2#,    S
    MUSIC  A2#,    -,    S
    MUSIC    S,    -,    S
    MUSIC    -,  A2#,    S
    MUSIC   E2,  A2#,    -
    MUSIC    S,    S,  A2#
    MUSIC   E2,    -,    S
    MUSIC    S,  A2#,    -
    MUSIC   E2,    -,  A2#
    MUSIC    S,    -,    S
    MUSIC  A2#,   E2,    -
    MUSIC    -,   E2,  A2#
    MUSIC  A2#,    S,    S
    MUSIC    S,   E2,    -
    MUSIC    -,    S,  A2#
    MUSIC  A6#,  A5#,    -
    MUSIC    S,    S,    -
    MUSIC    S,    S,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC    -,    -,    -
    MUSIC REPEAT


ASM ORG $6000
